import csv
import json
import datetime


"""
Criação de módulo que calcula as compensações de continuidade à consumidores.
"""


class CompensationContinuityConsumer:
    __code_consumer = ""
    __year = 0
    __type_tension = "BT"
    __type_area = "URB"
    __type_system = "INT"
    __code_conjunt = 0
    __dic_monthly_h = [0.0] * 12
    __dic_quartely_h = [0.0] * 4
    __proportion_dic_quartely = [0.0] * 4
    __paid_monthly_dic_quartely_rs = [0.0] * 4
    __dic_yearly_h = [0.0] * 1
    __proportion_dic_yearly = [0.0] * 1
    __paid_monthly_dic_yearly_rs = [0.0] * 1
    __fic_monthly = [0.0] * 12
    __fic_quartely = [0.0] * 4
    __proportion_fic_quartely = [0.0] * 4
    __paid_monthly_fic_quartely_rs = [0.0] * 4
    __fic_yearly = [0.0] * 1
    __proportion_fic_yearly = [0.0] * 1
    __paid_monthly_fic_yearly_rs = [0.0] * 1
    __dmic_monthly_h = [0.0] * 12
    __eusd_monthly_rs = [0.0] * 12
    __eusd_quartely_rs = [0.0] * 4
    __eusd_yearly_rs = [0.0] * 1
    __kei = 0
    __limit_dec_yearly_h = 0
    __limit_fec_yearly = 0
    __limit_dic_monthly_h = 0
    __limit_fic_monthly = 0
    __limit_dmic_monthly_h = 0
    __limit_dic_quartely_h = 0
    __limit_fic_quartely = 0
    __limit_dic_yearly_h = 0
    __limit_fic_yearly = 0
    __monthly_value_compensation = [0.0] * 12
    __monthly_indicator_compensation = ["NA"] * 12
    __quartely_value_compensation = [0.0] * 4
    __quartely_indicator_compensation = ["NA"] * 4
    __yearly_value_compensation = [0.0] * 1
    __yearly_indicator_compensation = ["NA"] * 1

    def set_features(self, code_consumer, year, type_tension, type_area, type_system, code_conjunt, dic_h, fic, dmic_h,
                     eusd_rs):
        self.__code_consumer = code_consumer
        self.__year = year
        self.__type_tension = type_tension
        self.__type_area = type_area
        self.__type_system = type_system
        self.__code_conjunt = code_conjunt
        self.__dic_monthly_h = dic_h
        self.__fic_monthly = fic
        self.__dmic_monthly_h = dmic_h
        self.__eusd_monthly_rs = eusd_rs
        self.calculate_compensation()

    @classmethod
    def get_kei(cls, type_tension):
        if type_tension == "BT":
            return 15
        elif type_tension == "MT":
            return 20
        elif type_tension == "AT":
            return 27

    def __set_kei(self):
        self.__kei = CompensationContinuityConsumer.get_kei(self.__type_tension)

    @classmethod
    def get_dec_fec_limits(cls, code_conjunt, year):
        dec_fec_limits = [0.0] * 2
        # Each register must follow the pattern
        # [year1, codeConjunt1, yearlyDech, yearlyFec]
        limits_table_dech_fec = [
            [1996, 6000, 30, 45],
            [1996, 6001, 30, 45],
            [1996, 6003, 30, 45],
            [1996, 6004, 30, 45],
            [1996, 6005, 30, 45],
            [1996, 6006, 30, 45],
            [1996, 6007, 30, 45],
            [1996, 6008, 30, 45],
            [1996, 6009, 30, 45],
            [1996, 6010, 30, 45],
            [1996, 6011, 30, 45],
            [1996, 6012, 30, 45],
            [1996, 6013, 30, 45],
            [1996, 6014, 30, 45],
            [1996, 6015, 30, 45],
            [1996, 6016, 30, 45],
            [1996, 6018, 30, 45],
            [1996, 6019, 30, 45],
            [1996, 6020, 30, 45],
            [1996, 6021, 30, 45],
            [1996, 6022, 30, 45],
            [1996, 6023, 30, 45],
            [1996, 6024, 30, 45],
            [1996, 6025, 30, 45],
            [1996, 6026, 30, 45],
            [1996, 6027, 30, 45],
            [1996, 6028, 30, 45],
            [1996, 6031, 30, 45],
            [1996, 6032, 30, 45],
            [1996, 6034, 30, 45],
            [1996, 6035, 30, 45],
            [1996, 6036, 30, 45],
            [1996, 6037, 30, 45],
            [1996, 6038, 30, 45],
            [1996, 6039, 30, 45],
            [1996, 6040, 30, 45],
            [1996, 6041, 30, 45],
            [1996, 6042, 30, 45],
            [1997, 1, 50, 60],
            [1997, 2, 120, 90],
            [1997, 3, 70, 70],
            [1997, 4, 120, 90],
            [1997, 5, 120, 90],
            [1997, 6, 120, 90],
            [1997, 7, 120, 90],
            [1997, 8, 70, 70],
            [1997, 13, 120, 90],
            [1997, 14, 120, 90],
            [1997, 15, 70, 70],
            [1997, 16, 70, 70],
            [1997, 17, 120, 90],
            [1997, 18, 70, 70],
            [1997, 19, 70, 70],
            [1997, 20, 120, 90],
            [1997, 21, 70, 70],
            [1997, 22, 120, 90],
            [1997, 23, 120, 90],
            [1997, 24, 120, 90],
            [1997, 25, 13.55, 9.36],
            [1997, 26, 70, 70],
            [1997, 27, 120, 90],
            [1997, 28, 50, 60],
            [1997, 29, 120, 90],
            [1997, 30, 31.41, 21.15],
            [1997, 32, 120, 90],
            [1997, 33, 70, 70],
            [1997, 34, 120, 90],
            [1997, 35, 120, 90],
            [1997, 37, 120, 90],
            [1997, 38, 120, 90],
            [1997, 39, 30, 45],
            [1997, 40, 70, 70],
            [1997, 41, 120, 90],
            [1997, 42, 70, 70],
            [1997, 43, 120, 90],
            [1997, 44, 120, 90],
            [1997, 45, 70, 70],
            [1997, 46, 120, 90],
            [1997, 47, 70, 70],
            [1997, 48, 70, 70],
            [1997, 49, 50, 60],
            [1997, 50, 120, 90],
            [1997, 51, 120, 90],
            [1997, 53, 40, 50],
            [1997, 54, 120, 90],
            [1997, 55, 50, 60],
            [1997, 56, 120, 90],
            [1997, 57, 120, 90],
            [1997, 59, 70, 70],
            [1997, 60, 120, 90],
            [1997, 61, 70, 70],
            [1997, 62, 120, 90],
            [1997, 63, 70, 70],
            [1997, 64, 30, 45],
            [1997, 65, 50, 60],
            [1997, 66, 20, 25],
            [1997, 68, 70, 70],
            [1997, 69, 70, 70],
            [1997, 70, 50, 60],
            [1997, 71, 50, 60],
            [1997, 72, 120, 90],
            [1997, 73, 120, 90],
            [1997, 75, 50, 60],
            [1997, 76, 120, 90],
            [1997, 77, 35.02, 25.49],
            [1997, 78, 120, 90],
            [1997, 81, 70, 70],
            [1997, 82, 70, 70],
            [1997, 83, 40, 50],
            [1997, 84, 120, 90],
            [1997, 87, 120, 90],
            [1997, 88, 15.28, 7.56],
            [1997, 89, 32.24, 21.39],
            [1997, 90, 120, 90],
            [1997, 91, 40, 50],
            [1997, 94, 120, 90],
            [1997, 95, 120, 90],
            [1997, 96, 70, 70],
            [1997, 97, 120, 90],
            [1997, 98, 120, 90],
            [1997, 99, 70, 70],
            [1997, 101, 70, 70],
            [1997, 103, 120, 90],
            [1997, 104, 50, 60],
            [1997, 105, 40, 50],
            [1997, 106, 70, 70],
            [1997, 107, 50, 60],
            [1997, 108, 50, 60],
            [1997, 109, 40, 50],
            [1997, 110, 120, 90],
            [1997, 111, 70, 70],
            [1997, 113, 70, 70],
            [1997, 115, 120, 90],
            [1997, 116, 70, 70],
            [1997, 117, 70, 70],
            [1997, 119, 70, 70],
            [1997, 120, 120, 90],
            [1997, 121, 17.05, 9.84],
            [1997, 122, 120, 90],
            [1997, 123, 120, 90],
            [1997, 124, 70, 70],
            [1997, 125, 120, 90],
            [1997, 128, 70, 70],
            [1997, 129, 120, 90],
            [1997, 130, 30, 45],
            [1997, 131, 120, 90],
            [1997, 133, 35.02, 25.49],
            [1997, 134, 120, 90],
            [1997, 135, 120, 90],
            [1997, 136, 120, 90],
            [1997, 137, 120, 90],
            [1997, 138, 120, 90],
            [1997, 139, 120, 90],
            [1997, 140, 50, 60],
            [1997, 141, 70, 70],
            [1997, 142, 70, 70],
            [1997, 143, 120, 90],
            [1997, 144, 50, 60],
            [1997, 146, 35.02, 25.49],
            [1997, 147, 32.24, 21.39],
            [1997, 149, 50, 60],
            [1997, 150, 50, 60],
            [1997, 152, 120, 90],
            [1997, 153, 30, 45],
            [1997, 154, 120, 90],
            [1997, 155, 120, 90],
            [1997, 156, 120, 90],
            [1997, 157, 120, 90],
            [1997, 158, 35.02, 25.49],
            [1997, 160, 120, 90],
            [1997, 161, 50, 60],
            [1997, 162, 17.62, 13.77],
            [1997, 163, 70, 70],
            [1997, 164, 120, 90],
            [1997, 165, 120, 90],
            [1997, 166, 120, 90],
            [1997, 167, 120, 90],
            [1997, 168, 50, 60],
            [1997, 169, 70, 70],
            [1997, 170, 120, 90],
            [1997, 171, 70, 70],
            [1997, 173, 30, 45],
            [1997, 174, 70, 70],
            [1997, 175, 120, 90],
            [1997, 176, 70, 70],
            [1997, 177, 70, 70],
            [1997, 178, 120, 90],
            [1997, 181, 120, 90],
            [1997, 182, 120, 90],
            [1997, 183, 70, 70],
            [1997, 184, 120, 90],
            [1997, 185, 120, 90],
            [1997, 186, 120, 90],
            [1997, 187, 50, 60],
            [1997, 189, 120, 90],
            [1997, 190, 70, 70],
            [1997, 191, 120, 90],
            [1997, 192, 70, 70],
            [1997, 193, 50, 60],
            [1997, 194, 120, 90],
            [1997, 195, 70, 70],
            [1997, 197, 120, 90],
            [1997, 198, 120, 90],
            [1997, 199, 120, 90],
            [1997, 200, 50, 60],
            [1997, 201, 120, 90],
            [1997, 203, 70, 70],
            [1997, 204, 70, 70],
            [1997, 205, 50, 60],
            [1997, 206, 120, 90],
            [1997, 207, 120, 90],
            [1997, 208, 120, 90],
            [1997, 209, 120, 90],
            [1997, 210, 120, 90],
            [1997, 211, 120, 90],
            [1997, 212, 70, 70],
            [1997, 213, 120, 90],
            [1997, 214, 120, 90],
            [1997, 215, 50, 60],
            [1997, 216, 120, 90],
            [1997, 217, 120, 90],
            [1997, 218, 70, 70],
            [1997, 219, 50, 60],
            [1997, 220, 70, 70],
            [1997, 221, 70, 70],
            [1997, 225, 50, 60],
            [1997, 226, 70, 70],
            [1997, 227, 120, 90],
            [1997, 228, 50, 60],
            [1997, 229, 70, 70],
            [1997, 230, 40, 50],
            [1997, 231, 70, 70],
            [1997, 232, 70, 70],
            [1997, 233, 70, 70],
            [1997, 234, 50, 60],
            [1997, 235, 70, 70],
            [1997, 236, 70, 70],
            [1997, 237, 10.83, 7.57],
            [1997, 239, 120, 90],
            [1997, 240, 120, 90],
            [1997, 241, 70, 70],
            [1997, 242, 120, 90],
            [1997, 243, 120, 90],
            [1997, 244, 120, 90],
            [1997, 245, 120, 90],
            [1997, 246, 120, 90],
            [1997, 247, 120, 90],
            [1997, 248, 120, 90],
            [1997, 249, 120, 90],
            [1997, 250, 50, 60],
            [1997, 252, 120, 90],
            [1997, 253, 120, 90],
            [1997, 254, 120, 90],
            [1997, 256, 50, 60],
            [1997, 257, 120, 90],
            [1997, 258, 120, 90],
            [1997, 259, 70, 70],
            [1997, 260, 70, 70],
            [1997, 261, 15, 25],
            [1997, 262, 70, 70],
            [1997, 264, 70, 70],
            [1997, 265, 120, 90],
            [1997, 267, 120, 90],
            [1997, 268, 35.02, 25.49],
            [1997, 269, 120, 90],
            [1997, 270, 120, 90],
            [1997, 271, 120, 90],
            [1997, 272, 120, 90],
            [1997, 273, 30, 45],
            [1997, 274, 120, 90],
            [1997, 275, 40, 50],
            [1997, 277, 70, 70],
            [1997, 278, 120, 90],
            [1997, 279, 120, 90],
            [1997, 280, 50, 60],
            [1997, 282, 70, 70],
            [1997, 283, 35.02, 25.49],
            [1997, 284, 70, 70],
            [1997, 285, 120, 90],
            [1997, 286, 120, 90],
            [1997, 287, 40, 50],
            [1997, 288, 120, 90],
            [1997, 289, 120, 90],
            [1997, 291, 70, 70],
            [1997, 292, 50, 60],
            [1997, 293, 120, 90],
            [1997, 295, 120, 90],
            [1997, 296, 70, 70],
            [1997, 297, 35.02, 25.49],
            [1997, 298, 50, 60],
            [1997, 299, 120, 90],
            [1997, 300, 120, 90],
            [1997, 302, 120, 90],
            [1997, 305, 120, 90],
            [1997, 306, 120, 90],
            [1997, 307, 120, 90],
            [1997, 308, 50, 60],
            [1997, 309, 35.02, 25.49],
            [1997, 310, 70, 70],
            [1997, 311, 70, 70],
            [1997, 312, 120, 90],
            [1997, 313, 120, 90],
            [1997, 314, 70, 70],
            [1997, 315, 120, 90],
            [1997, 316, 120, 90],
            [1997, 317, 120, 90],
            [1997, 318, 120, 90],
            [1997, 319, 40, 50],
            [1997, 320, 120, 90],
            [1997, 321, 120, 90],
            [1997, 322, 120, 90],
            [1997, 323, 120, 90],
            [1997, 324, 40, 50],
            [1997, 325, 120, 90],
            [1997, 326, 50, 60],
            [1997, 327, 120, 90],
            [1997, 328, 120, 90],
            [1997, 329, 70, 70],
            [1997, 330, 120, 90],
            [1997, 331, 70, 70],
            [1997, 332, 120, 90],
            [1997, 333, 120, 90],
            [1997, 334, 120, 90],
            [1997, 335, 120, 90],
            [1997, 336, 120, 90],
            [1997, 337, 120, 90],
            [1997, 339, 120, 90],
            [1997, 340, 120, 90],
            [1997, 342, 70, 70],
            [1997, 343, 120, 90],
            [1997, 344, 120, 90],
            [1997, 345, 120, 90],
            [1997, 346, 120, 90],
            [1997, 347, 120, 90],
            [1997, 348, 120, 90],
            [1997, 350, 70, 70],
            [1997, 351, 120, 90],
            [1997, 352, 120, 90],
            [1997, 353, 20.67, 13.88],
            [1997, 354, 50, 60],
            [1997, 355, 70, 70],
            [1997, 356, 120, 90],
            [1997, 357, 120, 90],
            [1997, 358, 32.24, 21.39],
            [1997, 360, 120, 90],
            [1997, 361, 70, 70],
            [1997, 362, 50, 60],
            [1997, 363, 70, 70],
            [1997, 364, 120, 90],
            [1997, 365, 120, 90],
            [1997, 366, 70, 70],
            [1997, 367, 50, 60],
            [1997, 368, 120, 90],
            [1997, 369, 6.34, 5.27],
            [1997, 370, 70, 70],
            [1997, 371, 120, 90],
            [1997, 373, 40, 50],
            [1997, 374, 50, 60],
            [1997, 375, 120, 90],
            [1997, 377, 40, 50],
            [1997, 378, 120, 90],
            [1997, 379, 70, 70],
            [1997, 380, 70, 70],
            [1997, 381, 120, 90],
            [1997, 382, 120, 90],
            [1997, 383, 70, 70],
            [1997, 384, 120, 90],
            [1997, 385, 120, 90],
            [1997, 386, 50, 60],
            [1997, 387, 70, 70],
            [1997, 389, 50, 60],
            [1997, 390, 120, 90],
            [1997, 391, 70, 70],
            [1997, 392, 120, 90],
            [1997, 393, 50, 60],
            [1997, 394, 50, 60],
            [1997, 395, 120, 90],
            [1997, 396, 120, 90],
            [1997, 397, 120, 90],
            [1997, 398, 70, 70],
            [1997, 399, 70, 70],
            [1997, 400, 120, 90],
            [1997, 401, 120, 90],
            [1997, 402, 120, 90],
            [1997, 403, 120, 90],
            [1997, 404, 40, 50],
            [1997, 405, 70, 70],
            [1997, 406, 120, 90],
            [1997, 407, 120, 90],
            [1997, 409, 50, 60],
            [1997, 410, 70, 70],
            [1997, 411, 120, 90],
            [1997, 412, 120, 90],
            [1997, 413, 30, 45],
            [1997, 415, 120, 90],
            [1997, 416, 50, 60],
            [1997, 417, 120, 90],
            [1997, 418, 120, 90],
            [1997, 419, 120, 90],
            [1997, 421, 70, 70],
            [1997, 422, 35.02, 25.49],
            [1997, 424, 120, 90],
            [1997, 425, 70, 70],
            [1997, 426, 35.02, 25.49],
            [1997, 427, 40, 50],
            [1997, 428, 70, 70],
            [1997, 429, 70, 70],
            [1997, 430, 70, 70],
            [1997, 432, 70, 70],
            [1997, 433, 120, 90],
            [1997, 434, 70, 70],
            [1997, 436, 70, 70],
            [1997, 437, 50, 60],
            [1997, 438, 70, 70],
            [1997, 439, 70, 70],
            [1997, 440, 120, 90],
            [1997, 441, 70, 70],
            [1997, 442, 50, 60],
            [1997, 443, 120, 90],
            [1997, 444, 20.67, 13.88],
            [1997, 445, 120, 90],
            [1997, 446, 120, 90],
            [1997, 447, 70, 70],
            [1997, 448, 120, 90],
            [1997, 449, 70, 70],
            [1997, 450, 120, 90],
            [1997, 451, 120, 90],
            [1997, 452, 120, 90],
            [1997, 453, 70, 70],
            [1997, 454, 120, 90],
            [1997, 455, 120, 90],
            [1997, 456, 120, 90],
            [1997, 457, 50, 60],
            [1997, 458, 70, 70],
            [1997, 459, 120, 90],
            [1997, 460, 70, 70],
            [1997, 461, 50, 60],
            [1997, 462, 120, 90],
            [1997, 465, 120, 90],
            [1997, 466, 120, 90],
            [1997, 467, 35.02, 25.49],
            [1997, 468, 120, 90],
            [1997, 469, 120, 90],
            [1997, 470, 35.02, 25.49],
            [1997, 471, 70, 70],
            [1997, 472, 120, 90],
            [1997, 473, 120, 90],
            [1997, 474, 70, 70],
            [1997, 475, 120, 90],
            [1997, 476, 120, 90],
            [1997, 477, 120, 90],
            [1997, 478, 120, 90],
            [1997, 479, 70, 70],
            [1997, 480, 70, 70],
            [1997, 481, 70, 70],
            [1997, 482, 70, 70],
            [1997, 483, 120, 90],
            [1997, 484, 70, 70],
            [1997, 485, 120, 90],
            [1997, 486, 50, 60],
            [1997, 487, 30, 45],
            [1997, 488, 120, 90],
            [1997, 490, 120, 90],
            [1997, 491, 70, 70],
            [1997, 493, 120, 90],
            [1997, 494, 120, 90],
            [1997, 495, 120, 90],
            [1997, 496, 70, 70],
            [1997, 497, 70, 70],
            [1997, 498, 70, 70],
            [1997, 499, 120, 90],
            [1997, 500, 120, 90],
            [1997, 501, 70, 70],
            [1997, 502, 120, 90],
            [1997, 503, 70, 70],
            [1997, 504, 40, 50],
            [1997, 505, 50, 60],
            [1997, 507, 120, 90],
            [1997, 508, 70, 70],
            [1997, 509, 5.13, 4.64],
            [1997, 510, 50, 60],
            [1997, 512, 40, 50],
            [1997, 513, 70, 70],
            [1997, 514, 120, 90],
            [1997, 515, 120, 90],
            [1997, 516, 120, 90],
            [1997, 517, 120, 90],
            [1997, 518, 120, 90],
            [1997, 519, 70, 70],
            [1997, 520, 120, 90],
            [1997, 521, 120, 90],
            [1997, 522, 70, 70],
            [1997, 523, 120, 90],
            [1997, 524, 70, 70],
            [1997, 525, 120, 90],
            [1997, 526, 70, 70],
            [1997, 527, 70, 70],
            [1997, 528, 50, 60],
            [1997, 529, 70, 70],
            [1997, 530, 70, 70],
            [1997, 531, 10.37, 9.91],
            [1997, 532, 50, 60],
            [1997, 533, 70, 70],
            [1997, 534, 50, 60],
            [1997, 535, 120, 90],
            [1997, 536, 40, 50],
            [1997, 537, 70, 70],
            [1997, 538, 120, 90],
            [1997, 539, 70, 70],
            [1997, 540, 70, 70],
            [1997, 541, 70, 70],
            [1997, 542, 120, 90],
            [1997, 543, 120, 90],
            [1997, 545, 120, 90],
            [1997, 546, 120, 90],
            [1997, 547, 15, 25],
            [1997, 548, 120, 90],
            [1997, 549, 120, 90],
            [1997, 550, 70, 70],
            [1997, 551, 120, 90],
            [1997, 552, 120, 90],
            [1997, 553, 120, 90],
            [1997, 554, 15, 25],
            [1997, 555, 120, 90],
            [1997, 556, 120, 90],
            [1997, 557, 40, 50],
            [1997, 558, 120, 90],
            [1997, 559, 70, 70],
            [1997, 561, 120, 90],
            [1997, 562, 120, 90],
            [1997, 563, 70, 70],
            [1997, 564, 12.02, 6.99],
            [1997, 565, 30, 45],
            [1997, 566, 120, 90],
            [1997, 567, 70, 70],
            [1997, 568, 70, 70],
            [1997, 569, 70, 70],
            [1997, 570, 120, 90],
            [1997, 571, 70, 70],
            [1997, 572, 40, 50],
            [1997, 573, 120, 90],
            [1997, 574, 70, 70],
            [1997, 575, 120, 90],
            [1997, 576, 120, 90],
            [1997, 577, 120, 90],
            [1997, 578, 120, 90],
            [1997, 579, 40, 50],
            [1997, 580, 120, 90],
            [1997, 581, 30, 45],
            [1997, 582, 70, 70],
            [1997, 583, 70, 70],
            [1997, 584, 21.39, 10.39],
            [1997, 585, 70, 70],
            [1997, 586, 50, 60],
            [1997, 587, 120, 90],
            [1997, 588, 70, 70],
            [1997, 589, 120, 90],
            [1997, 590, 70, 70],
            [1997, 591, 120, 90],
            [1997, 592, 120, 90],
            [1997, 593, 70, 70],
            [1997, 594, 32.24, 21.39],
            [1997, 595, 50, 60],
            [1997, 596, 50, 60],
            [1997, 597, 70, 70],
            [1997, 599, 120, 90],
            [1997, 600, 120, 90],
            [1997, 601, 120, 90],
            [1997, 602, 70, 70],
            [1997, 603, 120, 90],
            [1997, 604, 120, 90],
            [1997, 605, 70, 70],
            [1997, 606, 120, 90],
            [1997, 607, 50, 60],
            [1997, 608, 70, 70],
            [1997, 609, 40, 50],
            [1997, 610, 50, 60],
            [1997, 611, 120, 90],
            [1997, 612, 70, 70],
            [1997, 614, 70, 70],
            [1997, 615, 120, 90],
            [1997, 616, 120, 90],
            [1997, 618, 40, 50],
            [1997, 619, 120, 90],
            [1997, 621, 120, 90],
            [1997, 623, 8.39, 6.11],
            [1997, 625, 120, 90],
            [1997, 626, 40, 50],
            [1997, 627, 50, 60],
            [1997, 628, 70, 70],
            [1997, 629, 120, 90],
            [1997, 630, 120, 90],
            [1997, 631, 120, 90],
            [1997, 632, 30, 45],
            [1997, 633, 120, 90],
            [1997, 635, 70, 70],
            [1997, 636, 70, 70],
            [1997, 637, 7.01, 5.35],
            [1997, 638, 120, 90],
            [1997, 639, 70, 70],
            [1997, 640, 70, 70],
            [1997, 641, 120, 90],
            [1997, 642, 120, 90],
            [1997, 643, 120, 90],
            [1997, 644, 120, 90],
            [1997, 645, 50, 60],
            [1997, 646, 120, 90],
            [1997, 647, 70, 70],
            [1997, 648, 70, 70],
            [1997, 649, 70, 70],
            [1997, 650, 120, 90],
            [1997, 651, 120, 90],
            [1997, 652, 70, 70],
            [1997, 653, 70, 70],
            [1997, 654, 120, 90],
            [1997, 656, 120, 90],
            [1997, 657, 120, 90],
            [1997, 658, 120, 90],
            [1997, 660, 50, 60],
            [1997, 661, 70, 70],
            [1997, 662, 120, 90],
            [1997, 663, 120, 90],
            [1997, 664, 70, 70],
            [1997, 665, 120, 90],
            [1997, 666, 120, 90],
            [1997, 667, 120, 90],
            [1997, 668, 120, 90],
            [1997, 669, 50, 60],
            [1997, 670, 70, 70],
            [1997, 672, 70, 70],
            [1997, 673, 120, 90],
            [1997, 674, 70, 70],
            [1997, 675, 70, 70],
            [1997, 676, 120, 90],
            [1997, 677, 120, 90],
            [1997, 678, 70, 70],
            [1997, 679, 120, 90],
            [1997, 681, 32.24, 21.39],
            [1997, 682, 8.1, 6.18],
            [1997, 685, 70, 70],
            [1997, 686, 50, 60],
            [1997, 687, 120, 90],
            [1997, 688, 120, 90],
            [1997, 689, 120, 90],
            [1997, 690, 50, 60],
            [1997, 691, 120, 90],
            [1997, 692, 32.24, 21.39],
            [1997, 693, 70, 70],
            [1997, 694, 50, 60],
            [1997, 695, 120, 90],
            [1997, 697, 120, 90],
            [1997, 698, 70, 70],
            [1997, 699, 30, 45],
            [1997, 700, 70, 70],
            [1997, 701, 120, 90],
            [1997, 702, 70, 70],
            [1997, 703, 70, 70],
            [1997, 704, 120, 90],
            [1997, 705, 40, 50],
            [1997, 706, 70, 70],
            [1997, 707, 120, 90],
            [1997, 708, 70, 70],
            [1997, 709, 120, 90],
            [1997, 710, 120, 90],
            [1997, 711, 50, 60],
            [1997, 712, 120, 90],
            [1997, 713, 120, 90],
            [1997, 714, 50, 60],
            [1997, 715, 120, 90],
            [1997, 716, 70, 70],
            [1997, 717, 70, 70],
            [1997, 718, 50, 60],
            [1997, 719, 120, 90],
            [1997, 720, 120, 90],
            [1997, 721, 50, 60],
            [1997, 722, 120, 90],
            [1997, 723, 120, 90],
            [1997, 724, 120, 90],
            [1997, 726, 120, 90],
            [1997, 727, 50, 60],
            [1997, 730, 35.02, 25.49],
            [1997, 731, 50, 60],
            [1997, 732, 120, 90],
            [1997, 733, 120, 90],
            [1997, 734, 30, 45],
            [1997, 735, 120, 90],
            [1997, 736, 70, 70],
            [1997, 737, 70, 70],
            [1997, 738, 120, 90],
            [1997, 739, 70, 70],
            [1997, 740, 120, 90],
            [1997, 741, 120, 90],
            [1997, 742, 40, 50],
            [1997, 744, 120, 90],
            [1997, 745, 120, 90],
            [1997, 746, 40, 50],
            [1997, 747, 50, 60],
            [1997, 748, 70, 70],
            [1997, 749, 50, 60],
            [1997, 750, 120, 90],
            [1997, 751, 50, 60],
            [1997, 752, 120, 90],
            [1997, 753, 50, 60],
            [1997, 754, 70, 70],
            [1997, 755, 120, 90],
            [1997, 756, 70, 70],
            [1997, 757, 120, 90],
            [1997, 758, 70, 70],
            [1997, 759, 70, 70],
            [1997, 761, 120, 90],
            [1997, 762, 70, 70],
            [1997, 763, 70, 70],
            [1997, 765, 120, 90],
            [1997, 766, 120, 90],
            [1997, 767, 70, 70],
            [1997, 768, 120, 90],
            [1997, 769, 120, 90],
            [1997, 771, 120, 90],
            [1997, 772, 70, 70],
            [1997, 773, 120, 90],
            [1997, 774, 120, 90],
            [1997, 775, 70, 70],
            [1997, 776, 120, 90],
            [1997, 777, 70, 70],
            [1997, 778, 120, 90],
            [1997, 779, 50, 60],
            [1997, 781, 120, 90],
            [1997, 782, 120, 90],
            [1997, 783, 50, 60],
            [1997, 784, 50, 60],
            [1997, 785, 120, 90],
            [1997, 786, 120, 90],
            [1997, 787, 70, 70],
            [1997, 788, 50, 60],
            [1997, 789, 120, 90],
            [1997, 790, 120, 90],
            [1997, 791, 120, 90],
            [1997, 792, 40, 50],
            [1997, 793, 120, 90],
            [1997, 794, 120, 90],
            [1997, 795, 120, 90],
            [1997, 796, 70, 70],
            [1997, 797, 120, 90],
            [1997, 799, 50, 60],
            [1997, 801, 70, 70],
            [1997, 802, 120, 90],
            [1997, 803, 120, 90],
            [1997, 804, 120, 90],
            [1997, 805, 70, 70],
            [1997, 806, 120, 90],
            [1997, 807, 30, 45],
            [1997, 809, 120, 90],
            [1997, 810, 120, 90],
            [1997, 811, 120, 90],
            [1997, 812, 50, 60],
            [1997, 814, 120, 90],
            [1997, 815, 120, 90],
            [1997, 817, 70, 70],
            [1997, 818, 120, 90],
            [1997, 819, 120, 90],
            [1997, 820, 120, 90],
            [1997, 821, 120, 90],
            [1997, 822, 40, 50],
            [1997, 823, 120, 90],
            [1997, 824, 120, 90],
            [1997, 825, 70, 70],
            [1997, 826, 120, 90],
            [1997, 827, 70, 70],
            [1997, 830, 120, 90],
            [1997, 831, 120, 90],
            [1997, 832, 120, 90],
            [1997, 833, 120, 90],
            [1997, 834, 70, 70],
            [1997, 835, 70, 70],
            [1997, 836, 120, 90],
            [1997, 837, 70, 70],
            [1997, 838, 120, 90],
            [1997, 839, 70, 70],
            [1997, 840, 70, 70],
            [1997, 841, 120, 90],
            [1997, 842, 50, 60],
            [1997, 843, 120, 90],
            [1997, 844, 120, 90],
            [1997, 845, 70, 70],
            [1997, 846, 120, 90],
            [1997, 847, 32.24, 21.39],
            [1997, 848, 120, 90],
            [1997, 850, 40, 50],
            [1997, 852, 70, 70],
            [1997, 853, 120, 90],
            [1997, 854, 120, 90],
            [1997, 855, 9.81, 9.88],
            [1997, 856, 120, 90],
            [1997, 857, 120, 90],
            [1997, 858, 120, 90],
            [1997, 859, 120, 90],
            [1997, 860, 70, 70],
            [1997, 861, 120, 90],
            [1997, 863, 40, 50],
            [1997, 865, 70, 70],
            [1997, 867, 120, 90],
            [1997, 868, 70, 70],
            [1997, 869, 70, 70],
            [1997, 870, 120, 90],
            [1997, 871, 120, 90],
            [1997, 872, 70, 70],
            [1997, 873, 70, 70],
            [1997, 874, 50, 60],
            [1997, 875, 120, 90],
            [1997, 876, 120, 90],
            [1997, 877, 120, 90],
            [1997, 878, 5.59, 4.6],
            [1997, 879, 120, 90],
            [1997, 880, 120, 90],
            [1997, 881, 35.02, 25.49],
            [1997, 882, 50, 60],
            [1997, 883, 120, 90],
            [1997, 884, 50, 60],
            [1997, 885, 70, 70],
            [1997, 886, 120, 90],
            [1997, 887, 50, 60],
            [1997, 888, 120, 90],
            [1997, 890, 120, 90],
            [1997, 891, 120, 90],
            [1997, 892, 120, 90],
            [1997, 894, 120, 90],
            [1997, 895, 120, 90],
            [1997, 896, 120, 90],
            [1997, 897, 30, 45],
            [1997, 898, 120, 90],
            [1997, 899, 120, 90],
            [1997, 900, 6.81, 4.72],
            [1997, 901, 120, 90],
            [1997, 902, 70, 70],
            [1997, 903, 70, 70],
            [1997, 904, 120, 90],
            [1997, 905, 120, 90],
            [1997, 906, 70, 70],
            [1997, 907, 120, 90],
            [1997, 908, 50, 60],
            [1997, 910, 17.59, 7.29],
            [1997, 911, 50, 60],
            [1997, 912, 40, 50],
            [1997, 913, 40, 50],
            [1997, 914, 120, 90],
            [1997, 915, 120, 90],
            [1997, 916, 50, 60],
            [1997, 917, 30, 45],
            [1997, 918, 120, 90],
            [1997, 919, 120, 90],
            [1997, 920, 40, 50],
            [1997, 921, 120, 90],
            [1997, 922, 40, 50],
            [1997, 924, 11.58, 10.56],
            [1997, 926, 120, 90],
            [1997, 927, 70, 70],
            [1997, 928, 120, 90],
            [1997, 929, 120, 90],
            [1997, 930, 120, 90],
            [1997, 931, 120, 90],
            [1997, 932, 70, 70],
            [1997, 933, 70, 70],
            [1997, 934, 50, 60],
            [1997, 935, 120, 90],
            [1997, 936, 50, 60],
            [1997, 937, 120, 90],
            [1997, 938, 70, 70],
            [1997, 939, 70, 70],
            [1997, 940, 70, 70],
            [1997, 941, 70, 70],
            [1997, 942, 120, 90],
            [1997, 943, 120, 90],
            [1997, 944, 120, 90],
            [1997, 945, 50, 60],
            [1997, 946, 50, 60],
            [1997, 947, 120, 90],
            [1997, 948, 70, 70],
            [1997, 949, 120, 90],
            [1997, 950, 70, 70],
            [1997, 951, 120, 90],
            [1997, 953, 70, 70],
            [1997, 954, 120, 90],
            [1997, 955, 120, 90],
            [1997, 957, 120, 90],
            [1997, 958, 50, 60],
            [1997, 960, 50, 60],
            [1997, 961, 120, 90],
            [1997, 963, 32.24, 21.39],
            [1997, 964, 50, 60],
            [1997, 965, 50, 60],
            [1997, 967, 120, 90],
            [1997, 968, 120, 90],
            [1997, 969, 70, 70],
            [1997, 970, 20.67, 13.88],
            [1997, 971, 50, 60],
            [1997, 972, 120, 90],
            [1997, 973, 70, 70],
            [1997, 974, 30, 45],
            [1997, 975, 70, 70],
            [1997, 978, 70, 70],
            [1997, 979, 70, 70],
            [1997, 980, 70, 70],
            [1997, 981, 120, 90],
            [1997, 982, 120, 90],
            [1997, 984, 120, 90],
            [1997, 985, 70, 70],
            [1997, 987, 35.02, 25.49],
            [1997, 988, 6.14, 5.32],
            [1997, 989, 120, 90],
            [1997, 990, 120, 90],
            [1997, 991, 120, 90],
            [1997, 992, 120, 90],
            [1997, 993, 120, 90],
            [1997, 994, 120, 90],
            [1997, 995, 120, 90],
            [1997, 996, 120, 90],
            [1997, 997, 120, 90],
            [1997, 998, 70, 70],
            [1997, 999, 120, 90],
            [1997, 1000, 120, 90],
            [1997, 1001, 120, 90],
            [1997, 1003, 8.24, 5.82],
            [1997, 1004, 70, 70],
            [1997, 1005, 17.62, 13.77],
            [1997, 1006, 120, 90],
            [1997, 1007, 40, 50],
            [1997, 1008, 50, 60],
            [1997, 1009, 120, 90],
            [1997, 1010, 50, 60],
            [1997, 1011, 120, 90],
            [1997, 1012, 120, 90],
            [1997, 1013, 120, 90],
            [1997, 1014, 70, 70],
            [1997, 1015, 120, 90],
            [1997, 1016, 50, 60],
            [1997, 1017, 70, 70],
            [1997, 1018, 120, 90],
            [1997, 1019, 70, 70],
            [1997, 1020, 32.24, 21.39],
            [1997, 1021, 70, 70],
            [1997, 1022, 120, 90],
            [1997, 1023, 50, 60],
            [1997, 1025, 120, 90],
            [1997, 1026, 30, 45],
            [1997, 1027, 120, 90],
            [1997, 1029, 32.24, 21.39],
            [1997, 1030, 40, 50],
            [1997, 1031, 120, 90],
            [1997, 1033, 120, 90],
            [1997, 1034, 120, 90],
            [1997, 1035, 30, 45],
            [1997, 1036, 70, 70],
            [1997, 1037, 120, 90],
            [1997, 1038, 70, 70],
            [1997, 1039, 120, 90],
            [1997, 1040, 15, 20],
            [1997, 1041, 120, 90],
            [1997, 1043, 120, 90],
            [1997, 1044, 120, 90],
            [1997, 1045, 120, 90],
            [1997, 1046, 50, 60],
            [1997, 1047, 70, 70],
            [1997, 1048, 70, 70],
            [1997, 1050, 70, 70],
            [1997, 1051, 120, 90],
            [1997, 1052, 50, 60],
            [1997, 1053, 70, 70],
            [1997, 1054, 120, 90],
            [1997, 1055, 120, 90],
            [1997, 1056, 70, 70],
            [1997, 1057, 50, 60],
            [1997, 1058, 70, 70],
            [1997, 1059, 70, 70],
            [1997, 1061, 70, 70],
            [1997, 1062, 70, 70],
            [1997, 1063, 120, 90],
            [1997, 1064, 20.67, 13.88],
            [1997, 1065, 120, 90],
            [1997, 1066, 50, 60],
            [1997, 1067, 120, 90],
            [1997, 1069, 50, 60],
            [1997, 1070, 50, 60],
            [1997, 1071, 70, 70],
            [1997, 1073, 120, 90],
            [1997, 1074, 120, 90],
            [1997, 1076, 70, 70],
            [1997, 1077, 120, 90],
            [1997, 1078, 120, 90],
            [1997, 1079, 120, 90],
            [1997, 1080, 120, 90],
            [1997, 1081, 70, 70],
            [1997, 1082, 120, 90],
            [1997, 1083, 40, 50],
            [1997, 1084, 120, 90],
            [1997, 1085, 120, 90],
            [1997, 1086, 120, 90],
            [1997, 1087, 70, 70],
            [1997, 1088, 120, 90],
            [1997, 1089, 50, 60],
            [1997, 1090, 120, 90],
            [1997, 1091, 120, 90],
            [1997, 1092, 15, 25],
            [1997, 1093, 50, 60],
            [1997, 1094, 120, 90],
            [1997, 1095, 120, 90],
            [1997, 1096, 120, 90],
            [1997, 1097, 70, 70],
            [1997, 1098, 120, 90],
            [1997, 1100, 120, 90],
            [1997, 1102, 120, 90],
            [1997, 1104, 70, 70],
            [1997, 1105, 120, 90],
            [1997, 1106, 120, 90],
            [1997, 1108, 120, 90],
            [1997, 1109, 120, 90],
            [1997, 1110, 120, 90],
            [1997, 1111, 120, 90],
            [1997, 1112, 120, 90],
            [1997, 1113, 120, 90],
            [1997, 1114, 120, 90],
            [1997, 1115, 120, 90],
            [1997, 1116, 120, 90],
            [1997, 1117, 70, 70],
            [1997, 1118, 50, 60],
            [1997, 1119, 50, 60],
            [1997, 1120, 120, 90],
            [1997, 1121, 120, 90],
            [1997, 1122, 35.02, 25.49],
            [1997, 1123, 70, 70],
            [1997, 1124, 70, 70],
            [1997, 1125, 120, 90],
            [1997, 1126, 70, 70],
            [1997, 1127, 35.02, 25.49],
            [1997, 1128, 70, 70],
            [1997, 1129, 20.67, 13.88],
            [1997, 1130, 120, 90],
            [1997, 1131, 40, 50],
            [1997, 1132, 50, 60],
            [1997, 1133, 70, 70],
            [1997, 1134, 120, 90],
            [1997, 1135, 50, 60],
            [1997, 1136, 70, 70],
            [1997, 1137, 120, 90],
            [1997, 1138, 120, 90],
            [1997, 1139, 70, 70],
            [1997, 1140, 50, 60],
            [1997, 1141, 120, 90],
            [1997, 1142, 70, 70],
            [1997, 1143, 70, 70],
            [1997, 1144, 120, 90],
            [1997, 1145, 120, 90],
            [1997, 1148, 120, 90],
            [1997, 1149, 50, 60],
            [1997, 1150, 70, 70],
            [1997, 1151, 70, 70],
            [1997, 1153, 120, 90],
            [1997, 1154, 120, 90],
            [1997, 1155, 120, 90],
            [1997, 1156, 50, 60],
            [1997, 1157, 120, 90],
            [1997, 1158, 50, 60],
            [1997, 1159, 70, 70],
            [1997, 1160, 120, 90],
            [1997, 1161, 120, 90],
            [1997, 1162, 120, 90],
            [1997, 1163, 70, 70],
            [1997, 1164, 120, 90],
            [1997, 1165, 120, 90],
            [1997, 1166, 120, 90],
            [1997, 1167, 70, 70],
            [1997, 1168, 120, 90],
            [1997, 1169, 120, 90],
            [1997, 1170, 120, 90],
            [1997, 1171, 70, 70],
            [1997, 1172, 70, 70],
            [1997, 1173, 50, 60],
            [1997, 1174, 70, 70],
            [1997, 1175, 120, 90],
            [1997, 1176, 120, 90],
            [1997, 1177, 70, 70],
            [1997, 1179, 120, 90],
            [1997, 1181, 120, 90],
            [1997, 1183, 70, 70],
            [1997, 1185, 120, 90],
            [1997, 1186, 70, 70],
            [1997, 1187, 120, 90],
            [1997, 1188, 40, 50],
            [1997, 1189, 120, 90],
            [1997, 1190, 50, 60],
            [1997, 1191, 50, 60],
            [1997, 1192, 70, 70],
            [1997, 1193, 120, 90],
            [1997, 1194, 120, 90],
            [1997, 1195, 120, 90],
            [1997, 1196, 120, 90],
            [1997, 1197, 120, 90],
            [1997, 1198, 120, 90],
            [1997, 1199, 40, 50],
            [1997, 1200, 120, 90],
            [1997, 1201, 70, 70],
            [1997, 1202, 30, 45],
            [1997, 1203, 15, 25],
            [1997, 1204, 70, 70],
            [1997, 1205, 120, 90],
            [1997, 1206, 120, 90],
            [1997, 1207, 30, 45],
            [1997, 1208, 120, 90],
            [1997, 1209, 40, 50],
            [1997, 1210, 40, 50],
            [1997, 1211, 50, 60],
            [1997, 1212, 120, 90],
            [1997, 1213, 40, 50],
            [1997, 1214, 50, 60],
            [1997, 1215, 120, 90],
            [1997, 1216, 50, 60],
            [1997, 1217, 120, 90],
            [1997, 1219, 120, 90],
            [1997, 1220, 120, 90],
            [1997, 1221, 50, 60],
            [1997, 1223, 70, 70],
            [1997, 1224, 120, 90],
            [1997, 1225, 70, 70],
            [1997, 1226, 70, 70],
            [1997, 1227, 120, 90],
            [1997, 1228, 120, 90],
            [1997, 1230, 50, 60],
            [1997, 1232, 30, 45],
            [1997, 1233, 50, 60],
            [1997, 1234, 70, 70],
            [1997, 1235, 50, 60],
            [1997, 1236, 70, 70],
            [1997, 1237, 50, 60],
            [1997, 1238, 70, 70],
            [1997, 1239, 120, 90],
            [1997, 1240, 120, 90],
            [1997, 1241, 70, 70],
            [1997, 1242, 120, 90],
            [1997, 1243, 120, 90],
            [1997, 1244, 70, 70],
            [1997, 1245, 120, 90],
            [1997, 1246, 70, 70],
            [1997, 1247, 70, 70],
            [1997, 1248, 70, 70],
            [1997, 1249, 70, 70],
            [1997, 1250, 40, 50],
            [1997, 1251, 70, 70],
            [1997, 1252, 120, 90],
            [1997, 1253, 50, 60],
            [1997, 1254, 70, 70],
            [1997, 1255, 120, 90],
            [1997, 1257, 50, 60],
            [1997, 1258, 70, 70],
            [1997, 1260, 120, 90],
            [1997, 1261, 50, 60],
            [1997, 1262, 120, 90],
            [1997, 1263, 120, 90],
            [1997, 1264, 120, 90],
            [1997, 1266, 35.02, 25.49],
            [1997, 1267, 120, 90],
            [1997, 1268, 70, 70],
            [1997, 1269, 50, 60],
            [1997, 1270, 120, 90],
            [1997, 1271, 70, 70],
            [1997, 1272, 70, 70],
            [1997, 1273, 120, 90],
            [1997, 1274, 120, 90],
            [1997, 1275, 50, 60],
            [1997, 1276, 32.24, 21.39],
            [1997, 1278, 70, 70],
            [1997, 1280, 14.3, 8.12],
            [1997, 1281, 50, 60],
            [1997, 1282, 50, 60],
            [1997, 1283, 120, 90],
            [1997, 1286, 120, 90],
            [1997, 1287, 70, 70],
            [1997, 1288, 70, 70],
            [1997, 1289, 70, 70],
            [1997, 1290, 120, 90],
            [1997, 1291, 70, 70],
            [1997, 1292, 70, 70],
            [1997, 1293, 20, 25],
            [1997, 1294, 120, 90],
            [1997, 1295, 70, 70],
            [1997, 1296, 50, 60],
            [1997, 1297, 70, 70],
            [1997, 1298, 120, 90],
            [1997, 1299, 120, 90],
            [1997, 1300, 50, 60],
            [1997, 1301, 70, 70],
            [1997, 1302, 30, 45],
            [1997, 1303, 70, 70],
            [1997, 1304, 70, 70],
            [1997, 1305, 120, 90],
            [1997, 1306, 50, 60],
            [1997, 1307, 120, 90],
            [1997, 1308, 120, 90],
            [1997, 1309, 70, 70],
            [1997, 1311, 30, 45],
            [1997, 1312, 26.57, 15.77],
            [1997, 1313, 120, 90],
            [1997, 1314, 50, 60],
            [1997, 1315, 120, 90],
            [1997, 1317, 120, 90],
            [1997, 1318, 120, 90],
            [1997, 1319, 120, 90],
            [1997, 1320, 120, 90],
            [1997, 1322, 50, 60],
            [1997, 1323, 120, 90],
            [1997, 1324, 120, 90],
            [1997, 1325, 120, 90],
            [1997, 1326, 70, 70],
            [1997, 1327, 120, 90],
            [1997, 1328, 70, 70],
            [1997, 1329, 70, 70],
            [1997, 1330, 120, 90],
            [1997, 1331, 120, 90],
            [1997, 1333, 120, 90],
            [1997, 1334, 120, 90],
            [1997, 1335, 70, 70],
            [1997, 1336, 120, 90],
            [1997, 1337, 5.66, 6.03],
            [1997, 1338, 120, 90],
            [1997, 1339, 11.12, 9.1],
            [1997, 1340, 50, 60],
            [1997, 1341, 35.02, 25.49],
            [1997, 1342, 120, 90],
            [1997, 1343, 70, 70],
            [1997, 1344, 120, 90],
            [1997, 1345, 120, 90],
            [1997, 1346, 20.67, 13.88],
            [1997, 1347, 120, 90],
            [1997, 1348, 40, 50],
            [1997, 1349, 70, 70],
            [1997, 1350, 70, 70],
            [1997, 1351, 70, 70],
            [1997, 1352, 35.02, 25.49],
            [1997, 1353, 50, 60],
            [1997, 1355, 120, 90],
            [1997, 1357, 70, 70],
            [1997, 1358, 120, 90],
            [1997, 1359, 120, 90],
            [1997, 1360, 120, 90],
            [1997, 1361, 120, 90],
            [1997, 1362, 70, 70],
            [1997, 1363, 70, 70],
            [1997, 1364, 120, 90],
            [1997, 1365, 40, 50],
            [1997, 1367, 120, 90],
            [1997, 1369, 70, 70],
            [1997, 1370, 120, 90],
            [1997, 1371, 70, 70],
            [1997, 1372, 120, 90],
            [1997, 1373, 70, 70],
            [1997, 1374, 120, 90],
            [1997, 1375, 120, 90],
            [1997, 1376, 40, 50],
            [1997, 1377, 120, 90],
            [1997, 1378, 50, 60],
            [1997, 1379, 120, 90],
            [1997, 1380, 70, 70],
            [1997, 1381, 120, 90],
            [1997, 1382, 50, 60],
            [1997, 1384, 120, 90],
            [1997, 1385, 32.24, 21.39],
            [1997, 1387, 50, 60],
            [1997, 1388, 120, 90],
            [1997, 1390, 120, 90],
            [1997, 1391, 120, 90],
            [1997, 1392, 35.02, 25.49],
            [1997, 1393, 120, 90],
            [1997, 1394, 120, 90],
            [1997, 1395, 70, 70],
            [1997, 1396, 70, 70],
            [1997, 1398, 50, 60],
            [1997, 1400, 120, 90],
            [1997, 1401, 70, 70],
            [1997, 1402, 70, 70],
            [1997, 1403, 120, 90],
            [1997, 1404, 40, 50],
            [1997, 1405, 120, 90],
            [1997, 1409, 120, 90],
            [1997, 1410, 70, 70],
            [1997, 1411, 20.67, 13.88],
            [1997, 1412, 70, 70],
            [1997, 1414, 70, 70],
            [1997, 1415, 70, 70],
            [1997, 1416, 70, 70],
            [1997, 1417, 120, 90],
            [1997, 1418, 70, 70],
            [1997, 1419, 120, 90],
            [1997, 1420, 50, 60],
            [1997, 1421, 120, 90],
            [1997, 1422, 120, 90],
            [1997, 1423, 120, 90],
            [1997, 1424, 50, 60],
            [1997, 1425, 120, 90],
            [1997, 1426, 8.57, 6.77],
            [1997, 1427, 30, 45],
            [1997, 1428, 10.79, 6.72],
            [1997, 1430, 70, 70],
            [1997, 1431, 120, 90],
            [1997, 1432, 6.73, 7.01],
            [1997, 1433, 70, 70],
            [1997, 1434, 70, 70],
            [1997, 1435, 120, 90],
            [1997, 1436, 70, 70],
            [1997, 1437, 120, 90],
            [1997, 1438, 120, 90],
            [1997, 1439, 120, 90],
            [1997, 1440, 120, 90],
            [1997, 1441, 120, 90],
            [1997, 1442, 120, 90],
            [1997, 1443, 50, 60],
            [1997, 1444, 120, 90],
            [1997, 1445, 120, 90],
            [1997, 1447, 120, 90],
            [1997, 1448, 70, 70],
            [1997, 1449, 120, 90],
            [1997, 1450, 120, 90],
            [1997, 1451, 35.02, 25.49],
            [1997, 1452, 70, 70],
            [1997, 1453, 120, 90],
            [1997, 1454, 120, 90],
            [1997, 1455, 120, 90],
            [1997, 1456, 70, 70],
            [1997, 1457, 120, 90],
            [1997, 1458, 40, 50],
            [1997, 1459, 120, 90],
            [1997, 1460, 120, 90],
            [1997, 1461, 6.14, 6.98],
            [1997, 1463, 70, 70],
            [1997, 1464, 50, 60],
            [1997, 1465, 70, 70],
            [1997, 1466, 50, 60],
            [1997, 1467, 70, 70],
            [1997, 1468, 120, 90],
            [1997, 1469, 120, 90],
            [1997, 1470, 30, 45],
            [1997, 1471, 120, 90],
            [1997, 1472, 120, 90],
            [1997, 1473, 50, 60],
            [1997, 1474, 70, 70],
            [1997, 1475, 70, 70],
            [1997, 1476, 70, 70],
            [1997, 1477, 120, 90],
            [1997, 1478, 17.41, 11.68],
            [1997, 1479, 120, 90],
            [1997, 1481, 50, 60],
            [1997, 1482, 70, 70],
            [1997, 1483, 70, 70],
            [1997, 1484, 70, 70],
            [1997, 1485, 120, 90],
            [1997, 1486, 120, 90],
            [1997, 1487, 120, 90],
            [1997, 1488, 120, 90],
            [1997, 1489, 120, 90],
            [1997, 1490, 120, 90],
            [1997, 1491, 13.55, 10.7],
            [1997, 1492, 70, 70],
            [1997, 1493, 120, 90],
            [1997, 1495, 120, 90],
            [1997, 1496, 50, 60],
            [1997, 1497, 120, 90],
            [1997, 1498, 30, 45],
            [1997, 1499, 30, 45],
            [1997, 1500, 120, 90],
            [1997, 1502, 120, 90],
            [1997, 1503, 120, 90],
            [1997, 1505, 120, 90],
            [1997, 1506, 120, 90],
            [1997, 1507, 70, 70],
            [1997, 1508, 120, 90],
            [1997, 1509, 120, 90],
            [1997, 1510, 120, 90],
            [1997, 1511, 50, 60],
            [1997, 1512, 50, 60],
            [1997, 1513, 32.24, 21.39],
            [1997, 1514, 70, 70],
            [1997, 1515, 30, 45],
            [1997, 1516, 70, 70],
            [1997, 1517, 120, 90],
            [1997, 1518, 120, 90],
            [1997, 1519, 120, 90],
            [1997, 1520, 70, 70],
            [1997, 1521, 120, 90],
            [1997, 1522, 120, 90],
            [1997, 1523, 120, 90],
            [1997, 1524, 120, 90],
            [1997, 1525, 40, 50],
            [1997, 1526, 50, 60],
            [1997, 1527, 120, 90],
            [1997, 1528, 70, 70],
            [1997, 1529, 40, 50],
            [1997, 1530, 120, 90],
            [1997, 1531, 120, 90],
            [1997, 1533, 120, 90],
            [1997, 1535, 70, 70],
            [1997, 1536, 70, 70],
            [1997, 1537, 70, 70],
            [1997, 1538, 120, 90],
            [1997, 1539, 40, 50],
            [1997, 1540, 50, 60],
            [1997, 1541, 70, 70],
            [1997, 1542, 50, 60],
            [1997, 1543, 70, 70],
            [1997, 1544, 120, 90],
            [1997, 1545, 120, 90],
            [1997, 1546, 70, 70],
            [1997, 1547, 70, 70],
            [1997, 1548, 120, 90],
            [1997, 1549, 70, 70],
            [1997, 1550, 120, 90],
            [1997, 1551, 120, 90],
            [1997, 1552, 40, 50],
            [1997, 1553, 120, 90],
            [1997, 1554, 70, 70],
            [1997, 1555, 40, 50],
            [1997, 1556, 70, 70],
            [1997, 1557, 120, 90],
            [1997, 1558, 50, 60],
            [1997, 1559, 50, 60],
            [1997, 1560, 70, 70],
            [1997, 1561, 120, 90],
            [1997, 1562, 120, 90],
            [1997, 1563, 30, 45],
            [1997, 1565, 120, 90],
            [1997, 1567, 120, 90],
            [1997, 1568, 70, 70],
            [1997, 1569, 120, 90],
            [1997, 1571, 120, 90],
            [1997, 1572, 120, 90],
            [1997, 1573, 70, 70],
            [1997, 1574, 50, 60],
            [1997, 1575, 120, 90],
            [1997, 1576, 50, 60],
            [1997, 1577, 50, 60],
            [1997, 1578, 120, 90],
            [1997, 1579, 120, 90],
            [1997, 1580, 50, 60],
            [1997, 1581, 19.75, 12.12],
            [1997, 1582, 70, 70],
            [1997, 1583, 120, 90],
            [1997, 1584, 120, 90],
            [1997, 1585, 70, 70],
            [1997, 1586, 120, 90],
            [1997, 1587, 70, 70],
            [1997, 1588, 40, 50],
            [1997, 1589, 70, 70],
            [1997, 1590, 70, 70],
            [1997, 1591, 70, 70],
            [1997, 1592, 32.24, 21.39],
            [1997, 1593, 30, 45],
            [1997, 1595, 70, 70],
            [1997, 1596, 120, 90],
            [1997, 1597, 70, 70],
            [1997, 1599, 120, 90],
            [1997, 1600, 120, 90],
            [1997, 1601, 70, 70],
            [1997, 1602, 120, 90],
            [1997, 1603, 40, 50],
            [1997, 1605, 120, 90],
            [1997, 1606, 120, 90],
            [1997, 1607, 70, 70],
            [1997, 1608, 120, 90],
            [1997, 1609, 120, 90],
            [1997, 1610, 70, 70],
            [1997, 1611, 120, 90],
            [1997, 1612, 120, 90],
            [1997, 1613, 120, 90],
            [1997, 1614, 70, 70],
            [1997, 1615, 120, 90],
            [1997, 1616, 120, 90],
            [1997, 1617, 120, 90],
            [1997, 1619, 120, 90],
            [1997, 1620, 120, 90],
            [1997, 1621, 120, 90],
            [1997, 1622, 70, 70],
            [1997, 1623, 50, 60],
            [1997, 1624, 35.02, 25.49],
            [1997, 1625, 70, 70],
            [1997, 1626, 70, 70],
            [1997, 1627, 70, 70],
            [1997, 1628, 50, 60],
            [1997, 1629, 40, 50],
            [1997, 1630, 70, 70],
            [1997, 1631, 70, 70],
            [1997, 1633, 120, 90],
            [1997, 1634, 70, 70],
            [1997, 1635, 70, 70],
            [1997, 1636, 120, 90],
            [1997, 1637, 120, 90],
            [1997, 1638, 70, 70],
            [1997, 1639, 70, 70],
            [1997, 1640, 70, 70],
            [1997, 1641, 70, 70],
            [1997, 1642, 120, 90],
            [1997, 1644, 50, 60],
            [1997, 1645, 70, 70],
            [1997, 1647, 70, 70],
            [1997, 1648, 120, 90],
            [1997, 1649, 120, 90],
            [1997, 1650, 70, 70],
            [1997, 1651, 120, 90],
            [1997, 1652, 70, 70],
            [1997, 1653, 120, 90],
            [1997, 1654, 70, 70],
            [1997, 1655, 120, 90],
            [1997, 1657, 70, 70],
            [1997, 1658, 120, 90],
            [1997, 1659, 70, 70],
            [1997, 1660, 120, 90],
            [1997, 1661, 32.24, 21.39],
            [1997, 1662, 70, 70],
            [1997, 1663, 70, 70],
            [1997, 1664, 70, 70],
            [1997, 1665, 50, 60],
            [1997, 1666, 6.17, 5.14],
            [1997, 1667, 120, 90],
            [1997, 1668, 70, 70],
            [1997, 1669, 120, 90],
            [1997, 1670, 120, 90],
            [1997, 1671, 120, 90],
            [1997, 1672, 120, 90],
            [1997, 1673, 70, 70],
            [1997, 1674, 70, 70],
            [1997, 1675, 11.86, 16.02],
            [1997, 1676, 70, 70],
            [1997, 1677, 70, 70],
            [1997, 1678, 120, 90],
            [1997, 1679, 40, 50],
            [1997, 1680, 120, 90],
            [1997, 1681, 120, 90],
            [1997, 1682, 120, 90],
            [1997, 1683, 120, 90],
            [1997, 1684, 120, 90],
            [1997, 1685, 50, 60],
            [1997, 1687, 120, 90],
            [1997, 1688, 30, 45],
            [1997, 1689, 120, 90],
            [1997, 1690, 120, 90],
            [1997, 1691, 120, 90],
            [1997, 1692, 120, 90],
            [1997, 1693, 120, 90],
            [1997, 1694, 120, 90],
            [1997, 1695, 120, 90],
            [1997, 1696, 120, 90],
            [1997, 1697, 70, 70],
            [1997, 1698, 120, 90],
            [1997, 1699, 70, 70],
            [1997, 1700, 120, 90],
            [1997, 1701, 120, 90],
            [1997, 1702, 70, 70],
            [1997, 1704, 50, 60],
            [1997, 1705, 70, 70],
            [1997, 1706, 120, 90],
            [1997, 1707, 120, 90],
            [1997, 1708, 120, 90],
            [1997, 1709, 30, 45],
            [1997, 1710, 50, 60],
            [1997, 1711, 70, 70],
            [1997, 1712, 120, 90],
            [1997, 1713, 50, 60],
            [1997, 1714, 120, 90],
            [1997, 1715, 120, 90],
            [1997, 1716, 70, 70],
            [1997, 1717, 70, 70],
            [1997, 1719, 70, 70],
            [1997, 1720, 4.58, 3.57],
            [1997, 1721, 120, 90],
            [1997, 1722, 120, 90],
            [1997, 1723, 70, 70],
            [1997, 1724, 120, 90],
            [1997, 1725, 70, 70],
            [1997, 1726, 120, 90],
            [1997, 1727, 120, 90],
            [1997, 1728, 120, 90],
            [1997, 1730, 70, 70],
            [1997, 1732, 120, 90],
            [1997, 1735, 120, 90],
            [1997, 1736, 120, 90],
            [1997, 1737, 70, 70],
            [1997, 1738, 120, 90],
            [1997, 1739, 32.24, 21.39],
            [1997, 1740, 50, 60],
            [1997, 1741, 70, 70],
            [1997, 1742, 120, 90],
            [1997, 1743, 120, 90],
            [1997, 1744, 120, 90],
            [1997, 1746, 70, 70],
            [1997, 1748, 70, 70],
            [1997, 1749, 50, 60],
            [1997, 1750, 70, 70],
            [1997, 1752, 120, 90],
            [1997, 1754, 120, 90],
            [1997, 1755, 50, 60],
            [1997, 1756, 120, 90],
            [1997, 1757, 120, 90],
            [1997, 1758, 32.24, 21.39],
            [1997, 1759, 120, 90],
            [1997, 1760, 70, 70],
            [1997, 1762, 120, 90],
            [1997, 1763, 120, 90],
            [1997, 1764, 70, 70],
            [1997, 1765, 120, 90],
            [1997, 1766, 120, 90],
            [1997, 1767, 120, 90],
            [1997, 1769, 70, 70],
            [1997, 1770, 70, 70],
            [1997, 1771, 120, 90],
            [1997, 1772, 40, 50],
            [1997, 1773, 50, 60],
            [1997, 1774, 70, 70],
            [1997, 1775, 70, 70],
            [1997, 1776, 120, 90],
            [1997, 1777, 120, 90],
            [1997, 1778, 120, 90],
            [1997, 1779, 70, 70],
            [1997, 1780, 70, 70],
            [1997, 1781, 120, 90],
            [1997, 1782, 120, 90],
            [1997, 1783, 120, 90],
            [1997, 1784, 70, 70],
            [1997, 1785, 120, 90],
            [1997, 1786, 120, 90],
            [1997, 1787, 120, 90],
            [1997, 1788, 120, 90],
            [1997, 1789, 120, 90],
            [1997, 1790, 120, 90],
            [1997, 1791, 120, 90],
            [1997, 1792, 120, 90],
            [1997, 1793, 70, 70],
            [1997, 1794, 70, 70],
            [1997, 1795, 9.04, 6.4],
            [1997, 1796, 50, 60],
            [1997, 1797, 70, 70],
            [1997, 1798, 70, 70],
            [1997, 1801, 70, 70],
            [1997, 1802, 120, 90],
            [1997, 1803, 120, 90],
            [1997, 1804, 120, 90],
            [1997, 1805, 50, 60],
            [1997, 1806, 120, 90],
            [1997, 1807, 70, 70],
            [1997, 1808, 70, 70],
            [1997, 1809, 120, 90],
            [1997, 1810, 120, 90],
            [1997, 1811, 120, 90],
            [1997, 1812, 120, 90],
            [1997, 1813, 70, 70],
            [1997, 1814, 40, 50],
            [1997, 1815, 17.45, 9.13],
            [1997, 1816, 120, 90],
            [1997, 1817, 70, 70],
            [1997, 1818, 120, 90],
            [1997, 1819, 120, 90],
            [1997, 1820, 120, 90],
            [1997, 1821, 40, 50],
            [1997, 1822, 70, 70],
            [1997, 1823, 120, 90],
            [1997, 1824, 70, 70],
            [1997, 1825, 70, 70],
            [1997, 1826, 120, 90],
            [1997, 1827, 70, 70],
            [1997, 1829, 120, 90],
            [1997, 1830, 50, 60],
            [1997, 1831, 50, 60],
            [1997, 1832, 70, 70],
            [1997, 1833, 120, 90],
            [1997, 1834, 120, 90],
            [1997, 1837, 120, 90],
            [1997, 1839, 120, 90],
            [1997, 1840, 120, 90],
            [1997, 1841, 70, 70],
            [1997, 1842, 120, 90],
            [1997, 1844, 30, 45],
            [1997, 1845, 40, 50],
            [1997, 1846, 120, 90],
            [1997, 1847, 50, 60],
            [1997, 1848, 70, 70],
            [1997, 1849, 120, 90],
            [1997, 1850, 8.32, 6.64],
            [1997, 1851, 120, 90],
            [1997, 1852, 70, 70],
            [1997, 1853, 120, 90],
            [1997, 1854, 120, 90],
            [1997, 1855, 120, 90],
            [1997, 1856, 30, 45],
            [1997, 1857, 70, 70],
            [1997, 1859, 120, 90],
            [1997, 1860, 120, 90],
            [1997, 1861, 120, 90],
            [1997, 1863, 18.35, 13.66],
            [1997, 1864, 120, 90],
            [1997, 1865, 120, 90],
            [1997, 1866, 70, 70],
            [1997, 1868, 35.02, 25.49],
            [1997, 1869, 40, 50],
            [1997, 1870, 32.24, 21.39],
            [1997, 1871, 120, 90],
            [1997, 1872, 50, 60],
            [1997, 1873, 70, 70],
            [1997, 1874, 70, 70],
            [1997, 1875, 120, 90],
            [1997, 1876, 70, 70],
            [1997, 1877, 120, 90],
            [1997, 1878, 120, 90],
            [1997, 1879, 120, 90],
            [1997, 1881, 50, 60],
            [1997, 1882, 70, 70],
            [1997, 1883, 120, 90],
            [1997, 1884, 50, 60],
            [1997, 1885, 70, 70],
            [1997, 1886, 120, 90],
            [1997, 1887, 70, 70],
            [1997, 1888, 120, 90],
            [1997, 1889, 120, 90],
            [1997, 1890, 120, 90],
            [1997, 1891, 50, 60],
            [1997, 1892, 70, 70],
            [1997, 1893, 120, 90],
            [1997, 1894, 50, 60],
            [1997, 1895, 70, 70],
            [1997, 1896, 120, 90],
            [1997, 1898, 12.47, 7.24],
            [1997, 1899, 70, 70],
            [1997, 1900, 30, 45],
            [1997, 1901, 120, 90],
            [1997, 1902, 120, 90],
            [1997, 1903, 70, 70],
            [1997, 1904, 120, 90],
            [1997, 1905, 120, 90],
            [1997, 1906, 20.9, 12.43],
            [1997, 1907, 70, 70],
            [1997, 1909, 120, 90],
            [1997, 1910, 120, 90],
            [1997, 1911, 70, 70],
            [1997, 1912, 70, 70],
            [1997, 1913, 120, 90],
            [1997, 1914, 120, 90],
            [1997, 1915, 120, 90],
            [1997, 1916, 120, 90],
            [1997, 1917, 120, 90],
            [1997, 1918, 120, 90],
            [1997, 1919, 120, 90],
            [1997, 1920, 70, 70],
            [1997, 1921, 30, 45],
            [1997, 1922, 120, 90],
            [1997, 1923, 40, 50],
            [1997, 1924, 120, 90],
            [1997, 1925, 120, 90],
            [1997, 1926, 120, 90],
            [1997, 1928, 120, 90],
            [1997, 1929, 6.5, 4.93],
            [1997, 1930, 10.76, 8.15],
            [1997, 1933, 70, 70],
            [1997, 1934, 120, 90],
            [1997, 1935, 120, 90],
            [1997, 1936, 70, 70],
            [1997, 1937, 70, 70],
            [1997, 1938, 120, 90],
            [1997, 1939, 120, 90],
            [1997, 1940, 120, 90],
            [1997, 1941, 120, 90],
            [1997, 1942, 120, 90],
            [1997, 1944, 120, 90],
            [1997, 1945, 120, 90],
            [1997, 1946, 70, 70],
            [1997, 1947, 120, 90],
            [1997, 1948, 120, 90],
            [1997, 1949, 120, 90],
            [1997, 1950, 120, 90],
            [1997, 1951, 50, 60],
            [1997, 1952, 120, 90],
            [1997, 1953, 120, 90],
            [1997, 1954, 120, 90],
            [1997, 1955, 70, 70],
            [1997, 1956, 40, 50],
            [1997, 1957, 70, 70],
            [1997, 1959, 120, 90],
            [1997, 1961, 120, 90],
            [1997, 1962, 40, 50],
            [1997, 1963, 7.89, 5.56],
            [1997, 1964, 50, 60],
            [1997, 1965, 50, 60],
            [1997, 1966, 120, 90],
            [1997, 1967, 32.24, 21.39],
            [1997, 1969, 70, 70],
            [1997, 1971, 120, 90],
            [1997, 1972, 11.39, 7.39],
            [1997, 1973, 70, 70],
            [1997, 1974, 70, 70],
            [1997, 1975, 120, 90],
            [1997, 1976, 14.59, 10.01],
            [1997, 1977, 70, 70],
            [1997, 1978, 120, 90],
            [1997, 1979, 50, 60],
            [1997, 1980, 120, 90],
            [1997, 1981, 70, 70],
            [1997, 1982, 70, 70],
            [1997, 1983, 120, 90],
            [1997, 1984, 120, 90],
            [1997, 1985, 70, 70],
            [1997, 1986, 120, 90],
            [1997, 1987, 120, 90],
            [1997, 1988, 70, 70],
            [1997, 1989, 50, 60],
            [1997, 1990, 70, 70],
            [1997, 1992, 50, 60],
            [1997, 1994, 120, 90],
            [1997, 1995, 70, 70],
            [1997, 1996, 120, 90],
            [1997, 1997, 70, 70],
            [1997, 1998, 8.45, 8.42],
            [1997, 1999, 120, 90],
            [1997, 2000, 70, 70],
            [1997, 2001, 120, 90],
            [1997, 2002, 50, 60],
            [1997, 2003, 120, 90],
            [1997, 2005, 50, 60],
            [1997, 2006, 70, 70],
            [1997, 2007, 120, 90],
            [1997, 2008, 70, 70],
            [1997, 2009, 120, 90],
            [1997, 2010, 120, 90],
            [1997, 2011, 120, 90],
            [1997, 2012, 70, 70],
            [1997, 2014, 120, 90],
            [1997, 2015, 50, 60],
            [1997, 2016, 70, 70],
            [1997, 2017, 40, 50],
            [1997, 2018, 120, 90],
            [1997, 2019, 120, 90],
            [1997, 2020, 32.24, 21.39],
            [1997, 2021, 120, 90],
            [1997, 2022, 120, 90],
            [1997, 2023, 50, 60],
            [1997, 2024, 50, 60],
            [1997, 2025, 120, 90],
            [1997, 2026, 120, 90],
            [1997, 2027, 120, 90],
            [1997, 2028, 120, 90],
            [1997, 2029, 50, 60],
            [1997, 2030, 50, 60],
            [1997, 2031, 6.44, 5.98],
            [1997, 2032, 120, 90],
            [1997, 2033, 70, 70],
            [1997, 2034, 120, 90],
            [1997, 2035, 70, 70],
            [1997, 2036, 70, 70],
            [1997, 2037, 120, 90],
            [1997, 2038, 120, 90],
            [1997, 2040, 120, 90],
            [1997, 2041, 120, 90],
            [1997, 2042, 120, 90],
            [1997, 2043, 70, 70],
            [1997, 2044, 120, 90],
            [1997, 2045, 120, 90],
            [1997, 2046, 50, 60],
            [1997, 2048, 70, 70],
            [1997, 2049, 70, 70],
            [1997, 2050, 70, 70],
            [1997, 2051, 120, 90],
            [1997, 2052, 120, 90],
            [1997, 2053, 70, 70],
            [1997, 2054, 40, 50],
            [1997, 2055, 70, 70],
            [1997, 2056, 50, 60],
            [1997, 2057, 120, 90],
            [1997, 2059, 14.88, 8.19],
            [1997, 2060, 70, 70],
            [1997, 2061, 70, 70],
            [1997, 2062, 120, 90],
            [1997, 2063, 70, 70],
            [1997, 2064, 70, 70],
            [1997, 2066, 120, 90],
            [1997, 2067, 70, 70],
            [1997, 2068, 70, 70],
            [1997, 2069, 120, 90],
            [1997, 2071, 120, 90],
            [1997, 2072, 120, 90],
            [1997, 2073, 120, 90],
            [1997, 2074, 70, 70],
            [1997, 2075, 70, 70],
            [1997, 2076, 70, 70],
            [1997, 2077, 120, 90],
            [1997, 2078, 50, 60],
            [1997, 2079, 120, 90],
            [1997, 2080, 120, 90],
            [1997, 2081, 120, 90],
            [1997, 2082, 120, 90],
            [1997, 2083, 120, 90],
            [1997, 2084, 120, 90],
            [1997, 2086, 40, 50],
            [1997, 2087, 120, 90],
            [1997, 2089, 0, 0],
            [1997, 2090, 120, 90],
            [1997, 2091, 120, 90],
            [1997, 2092, 120, 90],
            [1997, 2095, 120, 90],
            [1997, 2096, 120, 90],
            [1997, 2097, 50, 60],
            [1997, 2098, 40, 50],
            [1997, 2099, 120, 90],
            [1997, 2100, 70, 70],
            [1997, 2101, 70, 70],
            [1997, 2102, 120, 90],
            [1997, 2103, 12.45, 12.74],
            [1997, 2104, 120, 90],
            [1997, 2105, 120, 90],
            [1997, 2106, 50, 60],
            [1997, 2107, 70, 70],
            [1997, 2108, 120, 90],
            [1997, 2109, 120, 90],
            [1997, 2110, 40, 50],
            [1997, 2111, 70, 70],
            [1997, 2112, 70, 70],
            [1997, 2113, 120, 90],
            [1997, 2114, 120, 90],
            [1997, 2115, 70, 70],
            [1997, 2116, 70, 70],
            [1997, 2118, 120, 90],
            [1997, 2119, 16.05, 9.74],
            [1997, 2121, 120, 90],
            [1997, 2122, 120, 90],
            [1997, 2123, 70, 70],
            [1997, 2124, 70, 70],
            [1997, 2125, 120, 90],
            [1997, 2126, 50, 60],
            [1997, 2127, 50, 60],
            [1997, 2128, 70, 70],
            [1997, 2129, 120, 90],
            [1997, 2130, 120, 90],
            [1997, 2131, 120, 90],
            [1997, 2133, 70, 70],
            [1997, 2134, 120, 90],
            [1997, 2135, 50, 60],
            [1997, 2136, 120, 90],
            [1997, 2137, 70, 70],
            [1997, 2138, 70, 70],
            [1997, 2139, 120, 90],
            [1997, 2140, 120, 90],
            [1997, 2141, 120, 90],
            [1997, 2142, 70, 70],
            [1997, 2143, 120, 90],
            [1997, 2144, 120, 90],
            [1997, 2146, 70, 70],
            [1997, 2147, 120, 90],
            [1997, 2148, 70, 70],
            [1997, 2149, 120, 90],
            [1997, 2150, 120, 90],
            [1997, 2152, 120, 90],
            [1997, 2154, 120, 90],
            [1997, 2155, 120, 90],
            [1997, 2156, 70, 70],
            [1997, 2157, 120, 90],
            [1997, 2158, 50, 60],
            [1997, 2159, 120, 90],
            [1997, 2160, 120, 90],
            [1997, 2161, 70, 70],
            [1997, 2162, 120, 90],
            [1997, 2163, 120, 90],
            [1997, 2164, 50, 60],
            [1997, 2165, 50, 60],
            [1997, 2166, 35.02, 25.49],
            [1997, 2169, 120, 90],
            [1997, 2170, 120, 90],
            [1997, 2171, 120, 90],
            [1997, 2172, 120, 90],
            [1997, 2174, 70, 70],
            [1997, 2175, 120, 90],
            [1997, 2178, 70, 70],
            [1997, 2179, 50, 60],
            [1997, 2180, 70, 70],
            [1997, 2181, 70, 70],
            [1997, 2182, 120, 90],
            [1997, 2183, 40, 50],
            [1997, 2184, 40, 50],
            [1997, 2185, 70, 70],
            [1997, 2186, 120, 90],
            [1997, 2187, 120, 90],
            [1997, 2188, 120, 90],
            [1997, 2189, 70, 70],
            [1997, 2190, 70, 70],
            [1997, 2191, 120, 90],
            [1997, 2192, 120, 90],
            [1997, 2193, 70, 70],
            [1997, 2194, 120, 90],
            [1997, 2195, 50, 60],
            [1997, 2196, 70, 70],
            [1997, 2197, 120, 90],
            [1997, 2198, 40, 50],
            [1997, 2199, 120, 90],
            [1997, 2200, 70, 70],
            [1997, 2201, 120, 90],
            [1997, 2202, 120, 90],
            [1997, 2203, 12.12, 8.84],
            [1997, 2204, 14.98, 8.4],
            [1997, 2205, 120, 90],
            [1997, 2206, 50, 60],
            [1997, 2207, 70, 70],
            [1997, 2208, 120, 90],
            [1997, 2210, 120, 90],
            [1997, 2211, 50, 60],
            [1997, 2212, 70, 70],
            [1997, 2213, 50, 60],
            [1997, 2214, 20, 25],
            [1997, 2215, 70, 70],
            [1997, 2216, 120, 90],
            [1997, 2217, 120, 90],
            [1997, 2219, 120, 90],
            [1997, 2220, 120, 90],
            [1997, 2221, 120, 90],
            [1997, 2223, 40, 50],
            [1997, 2224, 70, 70],
            [1997, 2225, 40, 50],
            [1997, 2226, 120, 90],
            [1997, 2227, 50, 60],
            [1997, 2228, 50, 60],
            [1997, 2229, 120, 90],
            [1997, 2230, 120, 90],
            [1997, 2231, 120, 90],
            [1997, 2232, 50, 60],
            [1997, 2234, 70, 70],
            [1997, 2235, 50, 60],
            [1997, 2236, 120, 90],
            [1997, 2237, 120, 90],
            [1997, 2238, 70, 70],
            [1997, 2239, 120, 90],
            [1997, 2240, 120, 90],
            [1997, 2241, 14.63, 9.52],
            [1997, 2242, 70, 70],
            [1997, 2243, 120, 90],
            [1997, 2244, 120, 90],
            [1997, 2245, 70, 70],
            [1997, 2246, 50, 60],
            [1997, 2247, 120, 90],
            [1997, 2248, 40, 50],
            [1997, 2249, 120, 90],
            [1997, 2250, 50, 60],
            [1997, 2251, 120, 90],
            [1997, 2252, 70, 70],
            [1997, 2253, 14.51, 10.23],
            [1997, 2254, 70, 70],
            [1997, 2255, 70, 70],
            [1997, 2256, 120, 90],
            [1997, 2258, 50, 60],
            [1997, 2259, 15, 20],
            [1997, 2260, 70, 70],
            [1997, 2262, 120, 90],
            [1997, 2263, 70, 70],
            [1997, 2264, 120, 90],
            [1997, 2265, 120, 90],
            [1997, 2267, 10.9, 7.43],
            [1997, 2268, 120, 90],
            [1997, 2269, 70, 70],
            [1997, 2270, 120, 90],
            [1997, 2271, 9.23, 6.76],
            [1997, 2272, 50, 60],
            [1997, 2273, 70, 70],
            [1997, 2274, 70, 70],
            [1997, 2275, 120, 90],
            [1997, 2276, 120, 90],
            [1997, 2277, 50, 60],
            [1997, 2278, 40, 50],
            [1997, 2279, 120, 90],
            [1997, 2280, 8.57, 5.83],
            [1997, 2281, 120, 90],
            [1997, 2282, 70, 70],
            [1997, 2283, 120, 90],
            [1997, 2284, 70, 70],
            [1997, 2285, 40, 50],
            [1997, 2286, 70, 70],
            [1997, 2288, 70, 70],
            [1997, 2289, 120, 90],
            [1997, 2290, 120, 90],
            [1997, 2291, 120, 90],
            [1997, 2292, 120, 90],
            [1997, 2293, 120, 90],
            [1997, 2294, 50, 60],
            [1997, 2295, 120, 90],
            [1997, 2296, 70, 70],
            [1997, 2297, 120, 90],
            [1997, 2298, 120, 90],
            [1997, 2300, 50, 60],
            [1997, 2301, 70, 70],
            [1997, 2302, 120, 90],
            [1997, 2303, 120, 90],
            [1997, 2304, 70, 70],
            [1997, 2305, 120, 90],
            [1997, 2306, 120, 90],
            [1997, 2307, 70, 70],
            [1997, 2311, 70, 70],
            [1997, 2312, 120, 90],
            [1997, 2313, 40, 50],
            [1997, 2314, 120, 90],
            [1997, 2316, 120, 90],
            [1997, 2317, 120, 90],
            [1997, 2319, 50, 60],
            [1997, 2321, 120, 90],
            [1997, 2323, 70, 70],
            [1997, 2324, 120, 90],
            [1997, 2325, 120, 90],
            [1997, 2326, 120, 90],
            [1997, 2327, 120, 90],
            [1997, 2328, 120, 90],
            [1997, 2329, 70, 70],
            [1997, 2330, 120, 90],
            [1997, 2331, 40, 50],
            [1997, 2332, 120, 90],
            [1997, 2333, 70, 70],
            [1997, 2335, 120, 90],
            [1997, 2336, 120, 90],
            [1997, 2337, 120, 90],
            [1997, 2338, 32.24, 21.39],
            [1997, 2339, 120, 90],
            [1997, 2340, 120, 90],
            [1997, 2341, 70, 70],
            [1997, 2342, 70, 70],
            [1997, 2343, 70, 70],
            [1997, 2344, 120, 90],
            [1997, 2345, 40, 50],
            [1997, 2346, 70, 70],
            [1997, 2347, 120, 90],
            [1997, 2348, 70, 70],
            [1997, 2349, 70, 70],
            [1997, 2350, 120, 90],
            [1997, 2352, 50, 60],
            [1997, 2353, 120, 90],
            [1997, 2354, 40, 50],
            [1997, 2355, 120, 90],
            [1997, 2356, 120, 90],
            [1997, 2357, 120, 90],
            [1997, 2358, 50, 60],
            [1997, 2359, 50, 60],
            [1997, 2360, 120, 90],
            [1997, 2361, 50, 60],
            [1997, 2362, 70, 70],
            [1997, 2363, 70, 70],
            [1997, 2364, 32.24, 21.39],
            [1997, 2365, 120, 90],
            [1997, 2366, 50, 60],
            [1997, 2367, 120, 90],
            [1997, 2368, 70, 70],
            [1997, 2369, 70, 70],
            [1997, 2371, 70, 70],
            [1997, 2372, 30, 45],
            [1997, 2373, 120, 90],
            [1997, 2374, 14.36, 11.08],
            [1997, 2375, 120, 90],
            [1997, 2376, 120, 90],
            [1997, 2379, 120, 90],
            [1997, 2380, 30, 45],
            [1997, 2381, 40, 50],
            [1997, 2382, 120, 90],
            [1997, 2383, 120, 90],
            [1997, 2384, 40, 50],
            [1997, 2385, 70, 70],
            [1997, 2387, 40, 50],
            [1997, 2388, 120, 90],
            [1997, 2389, 70, 70],
            [1997, 2390, 120, 90],
            [1997, 2391, 70, 70],
            [1997, 2393, 70, 70],
            [1997, 2394, 120, 90],
            [1997, 2395, 120, 90],
            [1997, 2396, 120, 90],
            [1997, 2397, 120, 90],
            [1997, 2398, 120, 90],
            [1997, 2399, 120, 90],
            [1997, 2400, 120, 90],
            [1997, 2401, 9.42, 9.69],
            [1997, 2402, 70, 70],
            [1997, 2403, 120, 90],
            [1997, 2404, 120, 90],
            [1997, 2405, 70, 70],
            [1997, 2406, 120, 90],
            [1997, 2407, 120, 90],
            [1997, 2408, 50, 60],
            [1997, 2409, 50, 60],
            [1997, 2410, 70, 70],
            [1997, 2411, 9.59, 8.49],
            [1997, 2412, 6.63, 7.08],
            [1997, 2413, 120, 90],
            [1997, 2414, 8.64, 7.09],
            [1997, 2416, 120, 90],
            [1997, 2417, 120, 90],
            [1997, 2418, 120, 90],
            [1997, 2420, 120, 90],
            [1997, 2421, 120, 90],
            [1997, 2422, 120, 90],
            [1997, 2423, 70, 70],
            [1997, 2424, 120, 90],
            [1997, 2425, 70, 70],
            [1997, 2426, 120, 90],
            [1997, 2428, 120, 90],
            [1997, 2429, 70, 70],
            [1997, 2430, 120, 90],
            [1997, 2431, 30, 45],
            [1997, 2432, 120, 90],
            [1997, 2433, 70, 70],
            [1997, 2434, 120, 90],
            [1997, 2435, 40, 50],
            [1997, 2436, 70, 70],
            [1997, 2437, 16.17, 13.35],
            [1997, 2438, 120, 90],
            [1997, 2439, 70, 70],
            [1997, 2440, 5.64, 5.78],
            [1997, 2441, 120, 90],
            [1997, 2442, 120, 90],
            [1997, 2443, 70, 70],
            [1997, 2444, 120, 90],
            [1997, 2445, 120, 90],
            [1997, 2447, 120, 90],
            [1997, 2448, 120, 90],
            [1997, 2449, 35.02, 25.49],
            [1997, 2450, 120, 90],
            [1997, 2452, 120, 90],
            [1997, 2454, 120, 90],
            [1997, 2455, 70, 70],
            [1997, 2456, 70, 70],
            [1997, 2458, 50, 60],
            [1997, 2459, 70, 70],
            [1997, 2460, 70, 70],
            [1997, 2461, 120, 90],
            [1997, 2462, 120, 90],
            [1997, 2463, 120, 90],
            [1997, 2464, 120, 90],
            [1997, 2465, 120, 90],
            [1997, 2466, 120, 90],
            [1997, 2467, 70, 70],
            [1997, 2468, 40, 50],
            [1997, 2469, 30, 45],
            [1997, 2470, 120, 90],
            [1997, 2471, 120, 90],
            [1997, 2472, 120, 90],
            [1997, 2473, 120, 90],
            [1997, 2474, 120, 90],
            [1997, 2475, 70, 70],
            [1997, 2476, 120, 90],
            [1997, 2477, 70, 70],
            [1997, 2478, 120, 90],
            [1997, 2479, 120, 90],
            [1997, 2481, 50, 60],
            [1997, 2482, 120, 90],
            [1997, 2483, 120, 90],
            [1997, 2484, 120, 90],
            [1997, 2485, 50, 60],
            [1997, 2486, 70, 70],
            [1997, 2487, 70, 70],
            [1997, 2488, 70, 70],
            [1997, 2489, 30, 45],
            [1997, 2490, 70, 70],
            [1997, 2491, 120, 90],
            [1997, 2492, 50, 60],
            [1997, 2493, 120, 90],
            [1997, 2494, 70, 70],
            [1997, 2495, 40, 50],
            [1997, 2496, 120, 90],
            [1997, 2497, 120, 90],
            [1997, 2498, 120, 90],
            [1997, 2499, 17.64, 11.45],
            [1997, 2500, 40, 50],
            [1997, 2501, 70, 70],
            [1997, 2502, 50, 60],
            [1997, 2504, 120, 90],
            [1997, 2505, 70, 70],
            [1997, 2506, 120, 90],
            [1997, 2507, 120, 90],
            [1997, 2508, 70, 70],
            [1997, 2509, 70, 70],
            [1997, 2510, 70, 70],
            [1997, 2511, 35.02, 25.49],
            [1997, 2512, 120, 90],
            [1997, 2513, 120, 90],
            [1997, 2515, 50, 60],
            [1997, 2516, 120, 90],
            [1997, 2517, 120, 90],
            [1997, 2518, 120, 90],
            [1997, 2519, 35.02, 25.49],
            [1997, 2520, 70, 70],
            [1997, 2521, 50, 60],
            [1997, 2522, 120, 90],
            [1997, 2523, 120, 90],
            [1997, 2524, 50, 60],
            [1997, 2525, 70, 70],
            [1997, 2526, 120, 90],
            [1997, 2527, 120, 90],
            [1997, 2528, 120, 90],
            [1997, 2529, 70, 70],
            [1997, 2530, 70, 70],
            [1997, 2531, 70, 70],
            [1997, 2532, 70, 70],
            [1997, 2533, 70, 70],
            [1997, 2534, 120, 90],
            [1997, 2535, 5.8, 6.5],
            [1997, 2537, 120, 90],
            [1997, 2538, 120, 90],
            [1997, 2539, 70, 70],
            [1997, 2540, 120, 90],
            [1997, 2541, 70, 70],
            [1997, 2543, 40, 50],
            [1997, 2544, 120, 90],
            [1997, 2545, 120, 90],
            [1997, 2546, 120, 90],
            [1997, 2547, 70, 70],
            [1997, 2548, 70, 70],
            [1997, 2549, 70, 70],
            [1997, 2550, 120, 90],
            [1997, 2551, 120, 90],
            [1997, 2552, 120, 90],
            [1997, 2553, 70, 70],
            [1997, 2554, 70, 70],
            [1997, 2555, 70, 70],
            [1997, 2556, 120, 90],
            [1997, 2558, 40, 50],
            [1997, 2560, 120, 90],
            [1997, 2561, 120, 90],
            [1997, 2562, 120, 90],
            [1997, 2563, 70, 70],
            [1997, 2564, 120, 90],
            [1997, 2565, 40, 50],
            [1997, 2567, 120, 90],
            [1997, 2568, 50, 60],
            [1997, 2569, 50, 60],
            [1997, 2570, 120, 90],
            [1997, 2571, 50, 60],
            [1997, 2572, 120, 90],
            [1997, 2573, 120, 90],
            [1997, 2574, 120, 90],
            [1997, 2575, 70, 70],
            [1997, 2576, 70, 70],
            [1997, 2578, 70, 70],
            [1997, 2579, 120, 90],
            [1997, 2580, 120, 90],
            [1997, 2581, 120, 90],
            [1997, 2582, 70, 70],
            [1997, 2584, 120, 90],
            [1997, 2585, 70, 70],
            [1997, 2586, 120, 90],
            [1997, 2587, 120, 90],
            [1997, 2588, 70, 70],
            [1997, 2589, 70, 70],
            [1997, 2590, 120, 90],
            [1997, 2591, 120, 90],
            [1997, 2592, 120, 90],
            [1997, 2593, 120, 90],
            [1997, 2594, 40, 50],
            [1997, 2595, 70, 70],
            [1997, 2596, 120, 90],
            [1997, 2597, 40, 50],
            [1997, 2598, 70, 70],
            [1997, 2599, 40, 50],
            [1997, 2600, 50, 60],
            [1997, 2601, 70, 70],
            [1997, 2602, 120, 90],
            [1997, 2603, 120, 90],
            [1997, 2604, 70, 70],
            [1997, 2606, 70, 70],
            [1997, 2607, 120, 90],
            [1997, 2608, 70, 70],
            [1997, 2609, 120, 90],
            [1997, 2610, 70, 70],
            [1997, 2612, 30, 45],
            [1997, 2613, 35.02, 25.49],
            [1997, 2614, 120, 90],
            [1997, 2615, 120, 90],
            [1997, 2616, 120, 90],
            [1997, 2617, 120, 90],
            [1997, 2618, 120, 90],
            [1997, 2619, 120, 90],
            [1997, 2620, 50, 60],
            [1997, 2621, 120, 90],
            [1997, 2622, 120, 90],
            [1997, 2623, 70, 70],
            [1997, 2624, 35.02, 25.49],
            [1997, 2625, 120, 90],
            [1997, 2626, 30, 45],
            [1997, 2627, 70, 70],
            [1997, 2628, 120, 90],
            [1997, 2629, 120, 90],
            [1997, 2630, 70, 70],
            [1997, 2631, 70, 70],
            [1997, 2632, 120, 90],
            [1997, 2633, 120, 90],
            [1997, 2634, 120, 90],
            [1997, 2635, 70, 70],
            [1997, 2636, 70, 70],
            [1997, 2637, 120, 90],
            [1997, 2638, 70, 70],
            [1997, 2642, 120, 90],
            [1997, 2644, 120, 90],
            [1997, 2645, 120, 90],
            [1997, 2646, 30, 45],
            [1997, 2647, 120, 90],
            [1997, 2649, 50, 60],
            [1997, 2650, 120, 90],
            [1997, 2651, 40, 50],
            [1997, 2652, 50, 60],
            [1997, 2653, 70, 70],
            [1997, 2654, 70, 70],
            [1997, 2655, 120, 90],
            [1997, 2656, 120, 90],
            [1997, 2657, 120, 90],
            [1997, 2658, 70, 70],
            [1997, 2659, 70, 70],
            [1997, 2660, 40, 50],
            [1997, 2661, 70, 70],
            [1997, 2662, 120, 90],
            [1997, 2663, 50, 60],
            [1997, 2664, 120, 90],
            [1997, 2665, 70, 70],
            [1997, 2666, 120, 90],
            [1997, 2667, 120, 90],
            [1997, 2668, 120, 90],
            [1997, 2669, 120, 90],
            [1997, 2670, 70, 70],
            [1997, 2671, 50, 60],
            [1997, 2672, 70, 70],
            [1997, 2673, 120, 90],
            [1997, 2675, 120, 90],
            [1997, 2676, 70, 70],
            [1997, 2677, 70, 70],
            [1997, 2678, 70, 70],
            [1997, 2679, 120, 90],
            [1997, 2680, 120, 90],
            [1997, 2681, 70, 70],
            [1997, 2682, 120, 90],
            [1997, 2683, 11.9, 7.65],
            [1997, 2684, 70, 70],
            [1997, 2685, 120, 90],
            [1997, 2687, 120, 90],
            [1997, 2688, 70, 70],
            [1997, 2690, 120, 90],
            [1997, 2691, 70, 70],
            [1997, 2692, 70, 70],
            [1997, 2693, 120, 90],
            [1997, 2694, 35.02, 25.49],
            [1997, 2695, 70, 70],
            [1997, 2696, 32.24, 21.39],
            [1997, 2697, 120, 90],
            [1997, 2698, 70, 70],
            [1997, 2699, 40, 50],
            [1997, 2702, 120, 90],
            [1997, 2703, 70, 70],
            [1997, 2706, 120, 90],
            [1997, 2707, 70, 70],
            [1997, 2709, 120, 90],
            [1997, 2711, 50, 60],
            [1997, 2712, 70, 70],
            [1997, 2713, 70, 70],
            [1997, 2714, 50, 60],
            [1997, 2715, 120, 90],
            [1997, 2716, 70, 70],
            [1997, 2717, 120, 90],
            [1997, 2718, 120, 90],
            [1997, 2719, 70, 70],
            [1997, 2720, 120, 90],
            [1997, 2721, 70, 70],
            [1997, 2722, 120, 90],
            [1997, 2723, 70, 70],
            [1997, 2724, 70, 70],
            [1997, 2725, 120, 90],
            [1997, 2726, 70, 70],
            [1997, 2727, 120, 90],
            [1997, 2728, 35.02, 25.49],
            [1997, 2730, 50, 60],
            [1997, 2731, 120, 90],
            [1997, 2732, 70, 70],
            [1997, 2733, 120, 90],
            [1997, 2734, 50, 60],
            [1997, 2736, 30, 45],
            [1997, 2737, 40, 50],
            [1997, 2738, 40, 50],
            [1997, 2739, 50, 60],
            [1997, 2740, 120, 90],
            [1997, 2741, 120, 90],
            [1997, 2742, 70, 70],
            [1997, 2743, 70, 70],
            [1997, 2745, 70, 70],
            [1997, 2746, 32.24, 21.39],
            [1997, 2747, 120, 90],
            [1997, 2748, 120, 90],
            [1997, 2749, 120, 90],
            [1997, 2750, 30, 45],
            [1997, 2751, 120, 90],
            [1997, 2752, 70, 70],
            [1997, 2753, 50, 60],
            [1997, 2754, 70, 70],
            [1997, 2755, 120, 90],
            [1997, 2756, 70, 70],
            [1997, 2757, 120, 90],
            [1997, 2758, 70, 70],
            [1997, 2759, 120, 90],
            [1997, 2760, 120, 90],
            [1997, 2761, 120, 90],
            [1997, 2762, 120, 90],
            [1997, 2763, 120, 90],
            [1997, 2764, 120, 90],
            [1997, 2765, 120, 90],
            [1997, 2766, 5.69, 6.72],
            [1997, 2767, 120, 90],
            [1997, 2768, 120, 90],
            [1997, 2769, 120, 90],
            [1997, 2770, 120, 90],
            [1997, 2772, 70, 70],
            [1997, 2773, 50, 60],
            [1997, 2774, 120, 90],
            [1997, 2775, 70, 70],
            [1997, 2776, 120, 90],
            [1997, 2777, 120, 90],
            [1997, 2778, 70, 70],
            [1997, 2779, 120, 90],
            [1997, 2780, 70, 70],
            [1997, 2782, 50, 60],
            [1997, 2783, 70, 70],
            [1997, 2784, 70, 70],
            [1997, 2785, 40, 50],
            [1997, 2786, 70, 70],
            [1997, 2787, 120, 90],
            [1997, 2788, 120, 90],
            [1997, 2789, 30, 45],
            [1997, 2790, 70, 70],
            [1997, 2791, 40, 50],
            [1997, 2792, 120, 90],
            [1997, 2793, 40, 50],
            [1997, 2794, 70, 70],
            [1997, 2795, 32.24, 21.39],
            [1997, 2796, 70, 70],
            [1997, 2797, 120, 90],
            [1997, 2798, 70, 70],
            [1997, 2799, 50, 60],
            [1997, 2800, 70, 70],
            [1997, 2801, 120, 90],
            [1997, 2802, 70, 70],
            [1997, 2803, 120, 90],
            [1997, 2804, 20.57, 14.3],
            [1997, 2805, 120, 90],
            [1997, 2806, 70, 70],
            [1997, 2808, 50, 60],
            [1997, 2809, 120, 90],
            [1997, 2810, 50, 60],
            [1997, 2811, 50, 60],
            [1997, 2812, 120, 90],
            [1997, 2813, 70, 70],
            [1997, 2814, 120, 90],
            [1997, 2818, 30, 45],
            [1997, 2819, 11.84, 8.58],
            [1997, 2820, 120, 90],
            [1997, 2821, 70, 70],
            [1997, 2822, 50, 60],
            [1997, 2823, 70, 70],
            [1997, 2824, 120, 90],
            [1997, 2825, 120, 90],
            [1997, 2826, 40, 50],
            [1997, 2827, 50, 60],
            [1997, 2829, 40, 50],
            [1997, 2830, 70, 70],
            [1997, 2831, 120, 90],
            [1997, 2832, 70, 70],
            [1997, 2833, 120, 90],
            [1997, 2834, 50, 60],
            [1997, 2835, 50, 60],
            [1997, 2836, 70, 70],
            [1997, 2837, 120, 90],
            [1997, 2838, 120, 90],
            [1997, 2839, 120, 90],
            [1997, 2840, 70, 70],
            [1997, 2841, 120, 90],
            [1997, 2842, 120, 90],
            [1997, 2843, 120, 90],
            [1997, 2844, 70, 70],
            [1997, 2845, 120, 90],
            [1997, 2846, 120, 90],
            [1997, 2847, 30, 45],
            [1997, 2850, 20.67, 13.88],
            [1997, 2851, 120, 90],
            [1997, 2852, 50, 60],
            [1997, 2853, 70, 70],
            [1997, 2854, 120, 90],
            [1997, 2855, 50, 60],
            [1997, 2856, 70, 70],
            [1997, 2857, 35.02, 25.49],
            [1997, 2858, 120, 90],
            [1997, 2860, 120, 90],
            [1997, 2861, 70, 70],
            [1997, 2862, 70, 70],
            [1997, 2863, 70, 70],
            [1997, 2864, 120, 90],
            [1997, 2865, 120, 90],
            [1997, 2866, 50, 60],
            [1997, 2868, 70, 70],
            [1997, 2869, 5.93, 4.86],
            [1997, 2871, 120, 90],
            [1997, 2872, 70, 70],
            [1997, 2873, 120, 90],
            [1997, 2874, 120, 90],
            [1997, 2875, 120, 90],
            [1997, 2876, 120, 90],
            [1997, 2877, 120, 90],
            [1997, 2878, 120, 90],
            [1997, 2879, 50, 60],
            [1997, 2880, 70, 70],
            [1997, 2881, 70, 70],
            [1997, 2882, 120, 90],
            [1997, 2883, 70, 70],
            [1997, 2884, 120, 90],
            [1997, 2885, 70, 70],
            [1997, 2886, 70, 70],
            [1997, 2887, 120, 90],
            [1997, 2888, 120, 90],
            [1997, 2889, 120, 90],
            [1997, 2890, 70, 70],
            [1997, 2891, 120, 90],
            [1997, 2892, 120, 90],
            [1997, 2893, 120, 90],
            [1997, 2894, 120, 90],
            [1997, 2896, 30, 45],
            [1997, 2897, 120, 90],
            [1997, 2898, 70, 70],
            [1997, 2899, 70, 70],
            [1997, 2900, 20.67, 13.88],
            [1997, 2901, 120, 90],
            [1997, 2902, 120, 90],
            [1997, 2903, 120, 90],
            [1997, 2904, 120, 90],
            [1997, 2905, 50, 60],
            [1997, 2906, 70, 70],
            [1997, 2907, 16.83, 17.5],
            [1997, 2908, 50, 60],
            [1997, 2909, 70, 70],
            [1997, 2910, 120, 90],
            [1997, 2911, 120, 90],
            [1997, 2912, 50, 60],
            [1997, 2913, 70, 70],
            [1997, 2914, 120, 90],
            [1997, 2916, 120, 90],
            [1997, 2917, 20.67, 13.88],
            [1997, 2918, 120, 90],
            [1997, 2919, 70, 70],
            [1997, 2920, 120, 90],
            [1997, 2921, 120, 90],
            [1997, 2922, 50, 60],
            [1997, 2923, 70, 70],
            [1997, 2924, 120, 90],
            [1997, 2925, 120, 90],
            [1997, 2926, 120, 90],
            [1997, 2927, 120, 90],
            [1997, 2928, 120, 90],
            [1997, 2929, 70, 70],
            [1997, 2930, 120, 90],
            [1997, 2931, 120, 90],
            [1997, 2932, 120, 90],
            [1997, 2933, 70, 70],
            [1997, 2934, 70, 70],
            [1997, 2935, 120, 90],
            [1997, 2936, 120, 90],
            [1997, 2937, 120, 90],
            [1997, 2939, 50, 60],
            [1997, 2940, 120, 90],
            [1997, 2942, 70, 70],
            [1997, 2943, 120, 90],
            [1997, 2944, 70, 70],
            [1997, 2945, 70, 70],
            [1997, 2946, 120, 90],
            [1997, 2947, 70, 70],
            [1997, 2948, 50, 60],
            [1997, 2949, 50, 60],
            [1997, 2950, 70, 70],
            [1997, 2951, 120, 90],
            [1997, 2952, 120, 90],
            [1997, 2953, 120, 90],
            [1997, 2954, 70, 70],
            [1997, 2955, 120, 90],
            [1997, 2956, 70, 70],
            [1997, 2957, 70, 70],
            [1997, 2958, 70, 70],
            [1997, 2959, 70, 70],
            [1997, 2960, 50, 60],
            [1997, 2961, 70, 70],
            [1997, 2962, 40, 50],
            [1997, 2963, 120, 90],
            [1997, 2964, 50, 60],
            [1997, 2965, 120, 90],
            [1997, 2967, 40, 50],
            [1997, 2968, 120, 90],
            [1997, 2969, 120, 90],
            [1997, 2970, 120, 90],
            [1997, 2971, 70, 70],
            [1997, 2972, 120, 90],
            [1997, 2973, 120, 90],
            [1997, 2974, 120, 90],
            [1997, 2975, 70, 70],
            [1997, 2976, 120, 90],
            [1997, 2978, 120, 90],
            [1997, 2979, 70, 70],
            [1997, 2980, 120, 90],
            [1997, 2981, 120, 90],
            [1997, 2982, 120, 90],
            [1997, 2984, 15.43, 13.81],
            [1997, 2985, 50, 60],
            [1997, 2986, 35.02, 25.49],
            [1997, 2987, 120, 90],
            [1997, 2988, 120, 90],
            [1997, 2989, 50, 60],
            [1997, 2990, 50, 60],
            [1997, 2991, 50, 60],
            [1997, 2992, 120, 90],
            [1997, 2993, 120, 90],
            [1997, 2994, 120, 90],
            [1997, 2995, 120, 90],
            [1997, 2996, 120, 90],
            [1997, 2998, 70, 70],
            [1997, 3000, 50, 60],
            [1997, 3001, 70, 70],
            [1997, 3002, 120, 90],
            [1997, 3003, 120, 90],
            [1997, 3004, 120, 90],
            [1997, 3005, 50, 60],
            [1997, 3006, 120, 90],
            [1997, 3007, 120, 90],
            [1997, 3008, 70, 70],
            [1997, 3009, 50, 60],
            [1997, 3010, 40, 50],
            [1997, 3011, 70, 70],
            [1997, 3012, 120, 90],
            [1997, 3013, 40, 50],
            [1997, 3014, 120, 90],
            [1997, 3015, 40, 50],
            [1997, 3016, 50, 60],
            [1997, 3017, 120, 90],
            [1997, 3018, 70, 70],
            [1997, 3019, 50, 60],
            [1997, 3021, 120, 90],
            [1997, 3022, 120, 90],
            [1997, 3023, 120, 90],
            [1997, 3024, 70, 70],
            [1997, 3025, 120, 90],
            [1997, 3027, 120, 90],
            [1997, 3028, 50, 60],
            [1997, 3029, 70, 70],
            [1997, 3030, 120, 90],
            [1997, 3031, 20.67, 13.88],
            [1997, 3032, 120, 90],
            [1997, 3033, 120, 90],
            [1997, 3034, 120, 90],
            [1997, 3035, 70, 70],
            [1997, 3036, 120, 90],
            [1997, 3037, 70, 70],
            [1997, 3039, 120, 90],
            [1997, 3040, 120, 90],
            [1997, 3041, 70, 70],
            [1997, 3042, 10.27, 8.48],
            [1997, 3043, 70, 70],
            [1997, 3044, 120, 90],
            [1997, 3045, 120, 90],
            [1997, 3046, 120, 90],
            [1997, 3047, 120, 90],
            [1997, 3048, 120, 90],
            [1997, 3049, 120, 90],
            [1997, 3050, 120, 90],
            [1997, 3051, 120, 90],
            [1997, 3052, 70, 70],
            [1997, 3053, 70, 70],
            [1997, 3054, 120, 90],
            [1997, 3055, 120, 90],
            [1997, 3057, 70, 70],
            [1997, 3058, 70, 70],
            [1997, 3059, 120, 90],
            [1997, 3060, 70, 70],
            [1997, 3061, 120, 90],
            [1997, 3062, 120, 90],
            [1997, 3063, 70, 70],
            [1997, 3064, 70, 70],
            [1997, 3065, 120, 90],
            [1997, 3066, 50, 60],
            [1997, 3069, 35.02, 25.49],
            [1997, 3070, 120, 90],
            [1997, 3071, 70, 70],
            [1997, 3072, 120, 90],
            [1997, 3073, 120, 90],
            [1997, 3074, 120, 90],
            [1997, 3076, 120, 90],
            [1997, 3077, 120, 90],
            [1997, 3078, 120, 90],
            [1997, 3079, 70, 70],
            [1997, 3081, 120, 90],
            [1997, 3083, 70, 70],
            [1997, 3084, 70, 70],
            [1997, 3085, 70, 70],
            [1997, 3086, 70, 70],
            [1997, 3087, 70, 70],
            [1997, 3088, 70, 70],
            [1997, 3090, 50, 60],
            [1997, 3091, 40, 50],
            [1997, 3092, 70, 70],
            [1997, 3094, 120, 90],
            [1997, 3095, 120, 90],
            [1997, 3096, 70, 70],
            [1997, 3097, 120, 90],
            [1997, 3098, 120, 90],
            [1997, 3100, 120, 90],
            [1997, 3101, 120, 90],
            [1997, 3102, 120, 90],
            [1997, 3103, 70, 70],
            [1997, 3104, 7.73, 6.59],
            [1997, 3105, 120, 90],
            [1997, 3106, 70, 70],
            [1997, 3107, 120, 90],
            [1997, 3108, 120, 90],
            [1997, 3109, 120, 90],
            [1997, 3110, 120, 90],
            [1997, 3111, 70, 70],
            [1997, 3112, 70, 70],
            [1997, 3113, 120, 90],
            [1997, 3115, 120, 90],
            [1997, 3116, 120, 90],
            [1997, 3117, 70, 70],
            [1997, 3118, 120, 90],
            [1997, 3119, 40, 50],
            [1997, 3120, 70, 70],
            [1997, 3121, 120, 90],
            [1997, 3122, 120, 90],
            [1997, 3124, 120, 90],
            [1997, 3125, 120, 90],
            [1997, 3126, 70, 70],
            [1997, 3127, 9.37, 9.65],
            [1997, 3128, 120, 90],
            [1997, 3129, 120, 90],
            [1997, 3130, 40, 50],
            [1997, 3131, 8.89, 9.07],
            [1997, 3132, 120, 90],
            [1997, 3133, 120, 90],
            [1997, 3134, 50, 60],
            [1997, 3135, 120, 90],
            [1997, 3136, 40, 50],
            [1997, 3137, 70, 70],
            [1997, 3138, 120, 90],
            [1997, 3139, 10.29, 7.91],
            [1997, 3140, 120, 90],
            [1997, 3141, 120, 90],
            [1997, 3142, 40, 50],
            [1997, 3143, 70, 70],
            [1997, 3144, 120, 90],
            [1997, 3145, 120, 90],
            [1997, 3148, 120, 90],
            [1997, 3149, 120, 90],
            [1997, 3150, 70, 70],
            [1997, 3151, 120, 90],
            [1997, 3152, 120, 90],
            [1997, 3153, 70, 70],
            [1997, 3154, 120, 90],
            [1997, 3155, 120, 90],
            [1997, 3156, 120, 90],
            [1997, 3157, 120, 90],
            [1997, 3158, 120, 90],
            [1997, 3159, 120, 90],
            [1997, 3160, 120, 90],
            [1997, 3161, 70, 70],
            [1997, 3162, 120, 90],
            [1997, 3163, 120, 90],
            [1997, 3164, 70, 70],
            [1997, 3166, 15, 20],
            [1997, 3167, 70, 70],
            [1997, 3168, 120, 90],
            [1997, 3169, 70, 70],
            [1997, 3170, 120, 90],
            [1997, 3171, 50, 60],
            [1997, 3172, 120, 90],
            [1997, 3175, 120, 90],
            [1997, 3176, 120, 90],
            [1997, 3177, 50, 60],
            [1997, 3178, 120, 90],
            [1997, 3179, 120, 90],
            [1997, 3182, 50, 60],
            [1997, 3183, 40, 50],
            [1997, 3184, 70, 70],
            [1997, 3186, 40, 50],
            [1997, 3187, 120, 90],
            [1997, 3188, 120, 90],
            [1997, 3189, 70, 70],
            [1997, 3190, 40, 50],
            [1997, 3191, 70, 70],
            [1997, 3192, 120, 90],
            [1997, 3193, 50, 60],
            [1997, 3194, 70, 70],
            [1997, 3195, 120, 90],
            [1997, 3196, 70, 70],
            [1997, 3197, 70, 70],
            [1997, 3198, 50, 60],
            [1997, 3199, 70, 70],
            [1997, 3200, 40, 50],
            [1997, 3201, 120, 90],
            [1997, 3202, 50, 60],
            [1997, 3203, 12.22, 11.28],
            [1997, 3206, 70, 70],
            [1997, 3207, 70, 70],
            [1997, 3208, 120, 90],
            [1997, 3210, 30, 45],
            [1997, 3211, 50, 60],
            [1997, 3212, 120, 90],
            [1997, 3213, 70, 70],
            [1997, 3214, 120, 90],
            [1997, 3215, 70, 70],
            [1997, 3216, 120, 90],
            [1997, 3217, 120, 90],
            [1997, 3218, 50, 60],
            [1997, 3219, 10.87, 12.56],
            [1997, 3220, 120, 90],
            [1997, 3221, 70, 70],
            [1997, 3222, 70, 70],
            [1997, 3224, 120, 90],
            [1997, 3225, 8.05, 7.89],
            [1997, 3226, 50, 60],
            [1997, 3227, 70, 70],
            [1997, 3228, 40, 50],
            [1997, 3229, 35.02, 25.49],
            [1997, 3230, 50, 60],
            [1997, 3231, 120, 90],
            [1997, 3232, 70, 70],
            [1997, 3234, 70, 70],
            [1997, 3235, 120, 90],
            [1997, 3237, 120, 90],
            [1997, 3238, 120, 90],
            [1997, 3239, 120, 90],
            [1997, 3240, 120, 90],
            [1997, 3241, 40, 50],
            [1997, 3242, 120, 90],
            [1997, 3243, 12.14, 9.5],
            [1997, 3244, 120, 90],
            [1997, 3245, 120, 90],
            [1997, 3246, 120, 90],
            [1997, 3247, 120, 90],
            [1997, 3248, 50, 60],
            [1997, 3249, 120, 90],
            [1997, 3250, 70, 70],
            [1997, 3251, 40, 50],
            [1997, 3252, 50, 60],
            [1997, 3253, 70, 70],
            [1997, 3254, 50, 60],
            [1997, 3255, 70, 70],
            [1997, 3256, 120, 90],
            [1997, 3257, 50, 60],
            [1997, 3258, 70, 70],
            [1997, 3259, 50, 60],
            [1997, 3260, 20, 25],
            [1997, 3261, 120, 90],
            [1997, 3262, 70, 70],
            [1997, 3263, 120, 90],
            [1997, 3264, 40, 50],
            [1997, 3265, 120, 90],
            [1997, 3266, 70, 70],
            [1997, 3267, 50, 60],
            [1997, 3268, 120, 90],
            [1997, 3269, 120, 90],
            [1997, 3271, 35.02, 25.49],
            [1997, 3272, 120, 90],
            [1997, 3273, 120, 90],
            [1997, 3274, 50, 60],
            [1997, 3275, 120, 90],
            [1997, 3276, 35.02, 25.49],
            [1997, 3277, 120, 90],
            [1997, 3278, 70, 70],
            [1997, 3279, 32.24, 21.39],
            [1997, 3280, 120, 90],
            [1997, 3281, 120, 90],
            [1997, 3282, 120, 90],
            [1997, 3284, 120, 90],
            [1997, 3285, 120, 90],
            [1997, 3286, 15.7, 9.65],
            [1997, 3287, 50, 60],
            [1997, 3288, 50, 60],
            [1997, 3289, 120, 90],
            [1997, 3290, 70, 70],
            [1997, 3291, 120, 90],
            [1997, 3292, 120, 90],
            [1997, 3293, 70, 70],
            [1997, 3294, 20.67, 13.88],
            [1997, 3295, 120, 90],
            [1997, 3296, 30, 45],
            [1997, 3297, 120, 90],
            [1997, 3299, 40, 50],
            [1997, 3300, 70, 70],
            [1997, 3301, 70, 70],
            [1997, 3302, 70, 70],
            [1997, 3303, 120, 90],
            [1997, 3305, 120, 90],
            [1997, 3306, 70, 70],
            [1997, 3308, 70, 70],
            [1997, 3309, 50, 60],
            [1997, 3310, 50, 60],
            [1997, 3311, 70, 70],
            [1997, 3312, 70, 70],
            [1997, 3313, 120, 90],
            [1997, 3314, 50, 60],
            [1997, 3315, 120, 90],
            [1997, 3316, 120, 90],
            [1997, 3317, 120, 90],
            [1997, 3318, 70, 70],
            [1997, 3319, 70, 70],
            [1997, 3320, 120, 90],
            [1997, 3321, 50, 60],
            [1997, 3322, 120, 90],
            [1997, 3323, 120, 90],
            [1997, 3324, 70, 70],
            [1997, 3325, 40, 50],
            [1997, 3326, 120, 90],
            [1997, 3327, 120, 90],
            [1997, 3328, 120, 90],
            [1997, 3329, 8.87, 8.14],
            [1997, 3330, 120, 90],
            [1997, 3331, 120, 90],
            [1997, 3332, 120, 90],
            [1997, 3333, 120, 90],
            [1997, 3335, 70, 70],
            [1997, 3336, 120, 90],
            [1997, 3337, 120, 90],
            [1997, 3338, 70, 70],
            [1997, 3339, 70, 70],
            [1997, 3340, 70, 70],
            [1997, 3341, 24.19, 14.72],
            [1997, 3342, 32.24, 21.39],
            [1997, 3343, 120, 90],
            [1997, 3344, 120, 90],
            [1997, 3345, 70, 70],
            [1997, 3346, 120, 90],
            [1997, 3347, 120, 90],
            [1997, 3348, 70, 70],
            [1997, 3350, 35.02, 25.49],
            [1997, 3351, 35.02, 25.49],
            [1997, 3352, 120, 90],
            [1997, 3353, 120, 90],
            [1997, 3354, 50, 60],
            [1997, 3356, 120, 90],
            [1997, 3357, 120, 90],
            [1997, 3358, 120, 90],
            [1997, 3359, 120, 90],
            [1997, 3360, 50, 60],
            [1997, 3361, 120, 90],
            [1997, 3362, 120, 90],
            [1997, 3363, 120, 90],
            [1997, 3364, 70, 70],
            [1997, 3365, 70, 70],
            [1997, 3366, 120, 90],
            [1997, 3367, 50, 60],
            [1997, 3368, 120, 90],
            [1997, 3369, 120, 90],
            [1997, 3370, 70, 70],
            [1997, 3371, 70, 70],
            [1997, 3372, 70, 70],
            [1997, 3373, 30, 45],
            [1997, 3375, 120, 90],
            [1997, 3376, 35.02, 25.49],
            [1997, 3377, 70, 70],
            [1997, 3378, 9.02, 8.54],
            [1997, 3379, 120, 90],
            [1997, 3380, 120, 90],
            [1997, 3381, 120, 90],
            [1997, 3382, 70, 70],
            [1997, 3384, 120, 90],
            [1997, 3385, 70, 70],
            [1997, 3386, 120, 90],
            [1997, 3387, 70, 70],
            [1997, 3388, 120, 90],
            [1997, 3389, 70, 70],
            [1997, 3390, 120, 90],
            [1997, 3391, 120, 90],
            [1997, 3392, 120, 90],
            [1997, 3393, 120, 90],
            [1997, 3394, 120, 90],
            [1997, 3397, 70, 70],
            [1997, 3398, 120, 90],
            [1997, 3399, 70, 70],
            [1997, 3400, 40, 50],
            [1997, 3401, 30, 45],
            [1997, 3402, 120, 90],
            [1997, 3404, 120, 90],
            [1997, 3407, 120, 90],
            [1997, 3408, 35.02, 25.49],
            [1997, 3409, 120, 90],
            [1997, 3410, 50, 60],
            [1997, 3411, 70, 70],
            [1997, 3412, 50, 60],
            [1997, 3414, 50, 60],
            [1997, 3415, 40, 50],
            [1997, 3416, 40, 50],
            [1997, 3417, 70, 70],
            [1997, 3418, 120, 90],
            [1997, 3419, 70, 70],
            [1997, 3420, 70, 70],
            [1997, 3422, 120, 90],
            [1997, 3423, 120, 90],
            [1997, 3424, 50, 60],
            [1997, 3425, 70, 70],
            [1997, 3426, 120, 90],
            [1997, 3427, 70, 70],
            [1997, 3428, 70, 70],
            [1997, 3429, 120, 90],
            [1997, 3430, 120, 90],
            [1997, 3431, 120, 90],
            [1997, 3432, 120, 90],
            [1997, 3433, 70, 70],
            [1997, 3434, 6.86, 5.46],
            [1997, 3435, 120, 90],
            [1997, 3436, 120, 90],
            [1997, 3437, 70, 70],
            [1997, 3439, 70, 70],
            [1997, 3440, 120, 90],
            [1997, 3441, 120, 90],
            [1997, 3442, 120, 90],
            [1997, 3444, 30, 45],
            [1997, 3445, 70, 70],
            [1997, 3446, 70, 70],
            [1997, 3447, 120, 90],
            [1997, 3448, 5.56, 6.38],
            [1997, 3449, 70, 70],
            [1997, 3450, 120, 90],
            [1997, 3451, 120, 90],
            [1997, 3452, 120, 90],
            [1997, 3453, 120, 90],
            [1997, 3454, 40, 50],
            [1997, 3456, 120, 90],
            [1997, 3458, 120, 90],
            [1997, 3459, 120, 90],
            [1997, 3460, 120, 90],
            [1997, 3461, 70, 70],
            [1997, 3462, 70, 24.96],
            [1997, 3463, 120, 90],
            [1997, 3464, 120, 90],
            [1997, 3466, 120, 90],
            [1997, 3467, 70, 70],
            [1997, 3468, 120, 90],
            [1997, 3469, 120, 90],
            [1997, 3470, 120, 90],
            [1997, 3471, 70, 70],
            [1997, 3472, 120, 90],
            [1997, 3473, 22.49, 13.06],
            [1997, 3474, 70, 70],
            [1997, 3475, 50, 60],
            [1997, 3476, 40, 50],
            [1997, 3477, 120, 90],
            [1997, 3478, 120, 90],
            [1997, 3480, 120, 90],
            [1997, 3481, 70, 70],
            [1997, 3482, 32.24, 21.39],
            [1997, 3483, 70, 70],
            [1997, 3484, 120, 90],
            [1997, 3485, 50, 60],
            [1997, 3486, 70, 70],
            [1997, 3487, 20.67, 13.88],
            [1997, 3488, 50, 60],
            [1997, 3489, 50, 60],
            [1997, 3490, 120, 90],
            [1997, 3491, 120, 90],
            [1997, 3492, 120, 90],
            [1997, 3493, 70, 70],
            [1997, 3494, 40, 50],
            [1997, 3495, 120, 90],
            [1997, 3496, 120, 90],
            [1997, 3497, 120, 90],
            [1997, 3498, 40, 50],
            [1997, 3499, 120, 90],
            [1997, 3500, 120, 90],
            [1997, 3501, 120, 90],
            [1997, 3503, 120, 90],
            [1997, 3504, 70, 70],
            [1997, 3505, 120, 90],
            [1997, 3506, 120, 90],
            [1997, 3508, 120, 90],
            [1997, 3509, 50, 60],
            [1997, 3510, 120, 90],
            [1997, 3511, 70, 70],
            [1997, 3514, 50, 60],
            [1997, 3515, 70, 70],
            [1997, 3516, 120, 90],
            [1997, 3517, 70, 70],
            [1997, 3518, 120, 90],
            [1997, 3519, 50, 60],
            [1997, 3520, 120, 90],
            [1997, 3521, 120, 90],
            [1997, 3522, 70, 70],
            [1997, 3523, 35.02, 25.49],
            [1997, 3524, 70, 70],
            [1997, 3525, 120, 90],
            [1997, 3527, 120, 90],
            [1997, 3528, 70, 70],
            [1997, 3529, 70, 70],
            [1997, 3530, 70, 70],
            [1997, 3531, 120, 90],
            [1997, 3533, 70, 70],
            [1997, 3534, 50, 60],
            [1997, 3535, 30, 45],
            [1997, 3536, 70, 70],
            [1997, 3537, 120, 90],
            [1997, 3538, 70, 70],
            [1997, 3539, 120, 90],
            [1997, 3540, 120, 90],
            [1997, 3541, 120, 90],
            [1997, 3542, 70, 70],
            [1997, 3543, 120, 90],
            [1997, 3544, 120, 90],
            [1997, 3545, 120, 90],
            [1997, 3546, 35.02, 25.49],
            [1997, 3547, 120, 90],
            [1997, 3548, 120, 90],
            [1997, 3549, 30, 45],
            [1997, 3550, 50, 60],
            [1997, 3551, 120, 90],
            [1997, 3552, 40, 50],
            [1997, 3553, 70, 70],
            [1997, 3554, 50, 60],
            [1997, 3555, 40, 50],
            [1997, 3557, 50, 60],
            [1997, 3558, 70, 70],
            [1997, 3559, 50, 60],
            [1997, 3560, 120, 90],
            [1997, 3561, 120, 90],
            [1997, 3562, 120, 90],
            [1997, 3563, 120, 90],
            [1997, 3564, 120, 90],
            [1997, 3566, 120, 90],
            [1997, 3568, 12.22, 9.98],
            [1997, 3569, 50, 60],
            [1997, 3570, 70, 70],
            [1997, 3571, 70, 70],
            [1997, 3572, 120, 90],
            [1997, 3573, 120, 90],
            [1997, 3575, 120, 90],
            [1997, 3576, 120, 90],
            [1997, 3577, 120, 90],
            [1997, 3578, 70, 70],
            [1997, 3579, 40, 50],
            [1997, 3580, 70, 70],
            [1997, 3581, 120, 90],
            [1997, 3583, 120, 90],
            [1997, 3584, 70, 70],
            [1997, 3585, 70, 70],
            [1997, 3586, 70, 70],
            [1997, 3587, 70, 70],
            [1997, 3588, 120, 90],
            [1997, 3589, 70, 70],
            [1997, 3590, 40, 50],
            [1997, 3592, 70, 70],
            [1997, 3593, 70, 70],
            [1997, 3594, 120, 90],
            [1997, 3595, 120, 90],
            [1997, 3596, 35.02, 25.49],
            [1997, 3597, 70, 70],
            [1997, 3598, 120, 90],
            [1997, 3599, 120, 90],
            [1997, 3600, 70, 70],
            [1997, 3601, 40, 50],
            [1997, 3602, 120, 90],
            [1997, 3603, 30, 45],
            [1997, 3604, 120, 90],
            [1997, 3606, 40, 50],
            [1997, 3607, 70, 70],
            [1997, 3608, 120, 90],
            [1997, 3609, 120, 90],
            [1997, 3610, 50, 60],
            [1997, 3611, 70, 70],
            [1997, 3612, 70, 70],
            [1997, 3613, 40, 50],
            [1997, 3615, 70, 70],
            [1997, 3616, 70, 70],
            [1997, 3617, 120, 90],
            [1997, 3619, 70, 70],
            [1997, 3620, 50, 60],
            [1997, 3621, 50, 60],
            [1997, 3622, 120, 90],
            [1997, 3623, 120, 90],
            [1997, 3625, 120, 90],
            [1997, 3626, 120, 90],
            [1997, 3627, 120, 90],
            [1997, 3628, 30, 45],
            [1997, 3629, 32.24, 21.39],
            [1997, 3630, 50, 60],
            [1997, 3631, 70, 70],
            [1997, 3632, 120, 90],
            [1997, 3633, 70, 70],
            [1997, 3635, 50, 60],
            [1997, 3636, 70, 70],
            [1997, 3637, 40, 50],
            [1997, 3638, 120, 90],
            [1997, 3639, 120, 90],
            [1997, 3640, 120, 90],
            [1997, 3641, 40, 50],
            [1997, 3642, 70, 70],
            [1997, 3643, 70, 70],
            [1997, 3644, 70, 70],
            [1997, 3646, 70, 70],
            [1997, 3647, 120, 90],
            [1997, 3648, 70, 70],
            [1997, 3649, 120, 90],
            [1997, 3650, 120, 90],
            [1997, 3651, 40, 50],
            [1997, 3652, 40, 50],
            [1997, 3653, 120, 90],
            [1997, 3654, 120, 90],
            [1997, 3655, 120, 90],
            [1997, 3656, 70, 70],
            [1997, 3657, 120, 90],
            [1997, 3658, 120, 90],
            [1997, 3659, 120, 90],
            [1997, 3660, 120, 90],
            [1997, 3661, 120, 90],
            [1997, 3662, 30, 45],
            [1997, 3663, 120, 90],
            [1997, 3664, 120, 90],
            [1997, 3665, 120, 90],
            [1997, 3666, 35.02, 25.49],
            [1997, 3667, 120, 90],
            [1997, 3668, 120, 90],
            [1997, 3669, 50, 60],
            [1997, 3670, 70, 70],
            [1997, 3671, 120, 90],
            [1997, 3672, 40, 50],
            [1997, 3673, 120, 90],
            [1997, 3674, 70, 70],
            [1997, 3675, 120, 90],
            [1997, 3676, 120, 90],
            [1997, 3677, 50, 60],
            [1997, 3678, 6.48, 4.68],
            [1997, 3679, 50, 60],
            [1997, 3680, 120, 90],
            [1997, 3681, 70, 70],
            [1997, 3682, 120, 90],
            [1997, 3683, 70, 70],
            [1997, 3684, 120, 90],
            [1997, 3685, 120, 90],
            [1997, 3686, 35.02, 25.49],
            [1997, 3687, 70, 70],
            [1997, 3688, 120, 90],
            [1997, 3689, 120, 90],
            [1997, 3690, 120, 90],
            [1997, 3691, 14.78, 14.29],
            [1997, 3692, 50, 60],
            [1997, 3693, 120, 90],
            [1997, 3694, 70, 70],
            [1997, 3695, 35.02, 25.49],
            [1997, 3696, 70, 70],
            [1997, 3697, 50, 60],
            [1997, 3698, 120, 90],
            [1997, 3699, 120, 90],
            [1997, 3700, 50, 60],
            [1997, 3701, 40, 50],
            [1997, 3702, 18.29, 11.85],
            [1997, 3703, 120, 90],
            [1997, 3704, 70, 70],
            [1997, 3705, 14.08, 13.22],
            [1997, 3706, 120, 90],
            [1997, 3707, 70, 70],
            [1997, 3708, 70, 70],
            [1997, 3710, 50, 60],
            [1997, 3712, 120, 90],
            [1997, 3713, 70, 70],
            [1997, 3714, 120, 90],
            [1997, 3715, 120, 90],
            [1997, 3716, 120, 90],
            [1997, 3718, 70, 70],
            [1997, 3719, 35.02, 25.49],
            [1997, 3720, 50, 60],
            [1997, 3721, 120, 90],
            [1997, 3722, 40, 50],
            [1997, 3723, 40, 50],
            [1997, 3725, 70, 70],
            [1997, 3726, 70, 70],
            [1997, 3727, 50, 60],
            [1997, 3728, 120, 90],
            [1997, 3729, 120, 90],
            [1997, 3730, 30, 45],
            [1997, 3731, 120, 90],
            [1997, 3733, 120, 90],
            [1997, 3736, 120, 90],
            [1997, 3737, 70, 70],
            [1997, 3738, 30, 45],
            [1997, 3739, 70, 70],
            [1997, 3741, 120, 90],
            [1997, 3742, 120, 90],
            [1997, 3743, 30, 45],
            [1997, 3744, 120, 90],
            [1997, 3745, 120, 90],
            [1997, 3746, 120, 90],
            [1997, 3747, 120, 90],
            [1997, 3748, 120, 90],
            [1997, 3749, 35.02, 25.49],
            [1997, 3750, 120, 90],
            [1997, 3751, 120, 90],
            [1997, 3752, 120, 90],
            [1997, 3753, 50, 60],
            [1997, 3754, 120, 90],
            [1997, 3755, 50, 60],
            [1997, 3756, 120, 90],
            [1997, 3757, 70, 70],
            [1997, 3758, 50, 60],
            [1997, 3759, 70, 70],
            [1997, 3760, 40, 50],
            [1997, 3761, 120, 90],
            [1997, 3762, 50, 60],
            [1997, 3763, 70, 70],
            [1997, 3764, 50, 60],
            [1997, 3765, 70, 70],
            [1997, 3766, 50, 60],
            [1997, 3767, 50, 60],
            [1997, 3768, 70, 70],
            [1997, 3769, 120, 90],
            [1997, 3770, 30, 45],
            [1997, 3772, 120, 90],
            [1997, 3773, 70, 70],
            [1997, 3775, 50, 60],
            [1997, 3776, 120, 90],
            [1997, 3777, 120, 90],
            [1997, 3778, 30, 45],
            [1997, 3779, 120, 90],
            [1997, 3780, 70, 70],
            [1997, 3781, 120, 90],
            [1997, 3782, 120, 90],
            [1997, 3783, 70, 70],
            [1997, 3785, 35.02, 25.49],
            [1997, 3786, 50, 60],
            [1997, 3787, 70, 70],
            [1997, 3789, 70, 70],
            [1997, 3791, 120, 90],
            [1997, 3793, 70, 70],
            [1997, 3794, 30, 45],
            [1997, 3795, 120, 90],
            [1997, 3796, 120, 90],
            [1997, 3797, 70, 70],
            [1997, 3798, 120, 90],
            [1997, 3799, 50, 60],
            [1997, 3800, 70, 70],
            [1997, 3801, 120, 90],
            [1997, 3802, 40, 50],
            [1997, 3804, 70, 70],
            [1997, 3806, 120, 90],
            [1997, 3807, 120, 90],
            [1997, 3809, 120, 90],
            [1997, 3810, 30, 45],
            [1997, 3811, 120, 90],
            [1997, 3812, 120, 90],
            [1997, 3813, 120, 90],
            [1997, 3814, 70, 70],
            [1997, 3816, 120, 90],
            [1997, 3817, 70, 70],
            [1997, 3818, 40, 50],
            [1997, 3819, 120, 90],
            [1997, 3820, 50, 60],
            [1997, 3821, 120, 90],
            [1997, 3822, 120, 90],
            [1997, 3824, 120, 90],
            [1997, 3825, 120, 90],
            [1997, 3826, 70, 70],
            [1997, 3827, 120, 90],
            [1997, 3828, 120, 90],
            [1997, 3829, 70, 70],
            [1997, 3831, 120, 90],
            [1997, 3832, 120, 90],
            [1997, 3833, 30, 45],
            [1997, 3834, 120, 90],
            [1997, 3835, 70, 70],
            [1997, 3836, 50, 60],
            [1997, 3837, 70, 70],
            [1997, 3838, 120, 90],
            [1997, 3839, 120, 90],
            [1997, 3840, 120, 90],
            [1997, 3841, 120, 90],
            [1997, 3842, 50, 60],
            [1997, 3843, 120, 90],
            [1997, 3844, 120, 90],
            [1997, 3845, 40, 50],
            [1997, 3846, 70, 70],
            [1997, 3847, 50, 60],
            [1997, 3849, 32.24, 21.39],
            [1997, 3850, 120, 90],
            [1997, 3851, 120, 90],
            [1997, 3852, 120, 90],
            [1997, 3853, 35.02, 25.49],
            [1997, 3854, 120, 90],
            [1997, 3855, 120, 90],
            [1997, 3856, 120, 90],
            [1997, 3857, 70, 70],
            [1997, 3858, 120, 90],
            [1997, 3859, 70, 70],
            [1997, 3862, 70, 70],
            [1997, 3863, 50, 60],
            [1997, 3864, 70, 70],
            [1997, 3865, 120, 90],
            [1997, 3867, 35.02, 25.49],
            [1997, 3868, 120, 90],
            [1997, 3869, 40, 50],
            [1997, 3870, 120, 90],
            [1997, 3871, 70, 70],
            [1997, 3872, 120, 90],
            [1997, 3873, 120, 90],
            [1997, 3874, 120, 90],
            [1997, 3875, 70, 70],
            [1997, 3877, 70, 70],
            [1997, 3878, 70, 70],
            [1997, 3879, 70, 70],
            [1997, 3881, 120, 90],
            [1997, 3882, 120, 90],
            [1997, 3883, 120, 90],
            [1997, 3884, 70, 70],
            [1997, 3885, 70, 70],
            [1997, 3886, 120, 90],
            [1997, 3887, 120, 90],
            [1997, 3888, 120, 90],
            [1997, 3889, 70, 70],
            [1997, 3891, 70, 70],
            [1997, 3892, 120, 90],
            [1997, 3893, 70, 70],
            [1997, 3894, 120, 90],
            [1997, 3895, 120, 90],
            [1997, 3896, 70, 70],
            [1997, 3897, 120, 90],
            [1997, 3898, 120, 90],
            [1997, 3899, 120, 90],
            [1997, 3900, 120, 90],
            [1997, 3901, 120, 90],
            [1997, 3902, 120, 90],
            [1997, 3903, 70, 70],
            [1997, 3905, 120, 90],
            [1997, 3906, 70, 70],
            [1997, 3907, 120, 90],
            [1997, 3908, 120, 90],
            [1997, 3909, 120, 90],
            [1997, 3910, 32.24, 21.39],
            [1997, 3912, 70, 70],
            [1997, 3913, 120, 90],
            [1997, 3914, 70, 70],
            [1997, 3915, 30, 45],
            [1997, 3916, 120, 90],
            [1997, 3917, 70, 70],
            [1997, 3918, 8.88, 7.78],
            [1997, 3919, 120, 90],
            [1997, 3920, 70, 70],
            [1997, 3921, 120, 90],
            [1997, 3922, 120, 90],
            [1997, 3923, 70, 70],
            [1997, 3925, 120, 90],
            [1997, 3926, 120, 90],
            [1997, 3927, 70, 70],
            [1997, 3929, 120, 90],
            [1997, 3930, 70, 70],
            [1997, 3931, 120, 90],
            [1997, 3932, 70, 70],
            [1997, 3933, 120, 90],
            [1997, 3934, 120, 90],
            [1997, 3935, 120, 90],
            [1997, 3936, 120, 90],
            [1997, 3937, 70, 70],
            [1997, 3938, 40, 50],
            [1997, 3939, 120, 90],
            [1997, 3940, 50, 60],
            [1997, 3941, 120, 90],
            [1997, 3942, 120, 90],
            [1997, 3943, 70, 70],
            [1997, 3944, 35.02, 25.49],
            [1997, 3945, 120, 90],
            [1997, 3946, 13.42, 11.21],
            [1997, 3947, 120, 90],
            [1997, 3948, 30, 45],
            [1997, 3949, 120, 90],
            [1997, 3950, 120, 90],
            [1997, 3951, 120, 90],
            [1997, 3952, 120, 90],
            [1997, 3953, 120, 90],
            [1997, 3954, 120, 90],
            [1997, 3955, 120, 90],
            [1997, 3956, 50, 60],
            [1997, 3958, 13.07, 12.08],
            [1997, 3959, 120, 90],
            [1997, 3960, 50, 60],
            [1997, 3961, 10.48, 9.83],
            [1997, 3962, 120, 90],
            [1997, 3963, 50, 60],
            [1997, 3964, 120, 90],
            [1997, 3965, 70, 70],
            [1997, 3966, 70, 70],
            [1997, 3968, 40, 50],
            [1997, 3969, 70, 70],
            [1997, 3970, 120, 90],
            [1997, 3971, 120, 90],
            [1997, 3972, 120, 90],
            [1997, 3973, 120, 90],
            [1997, 3974, 120, 90],
            [1997, 3975, 120, 90],
            [1997, 3976, 70, 70],
            [1997, 3978, 70, 70],
            [1997, 3979, 70, 70],
            [1997, 3980, 120, 90],
            [1997, 3981, 70, 70],
            [1997, 3982, 120, 90],
            [1997, 3983, 30, 45],
            [1997, 3984, 120, 90],
            [1997, 3985, 70, 70],
            [1997, 3986, 120, 90],
            [1997, 3988, 120, 90],
            [1997, 3990, 70, 70],
            [1997, 3991, 120, 90],
            [1997, 3992, 70, 70],
            [1997, 3993, 70, 70],
            [1997, 3994, 120, 90],
            [1997, 3995, 120, 90],
            [1997, 3996, 70, 70],
            [1997, 3997, 120, 90],
            [1997, 3998, 120, 90],
            [1997, 3999, 70, 70],
            [1997, 4001, 120, 90],
            [1997, 4002, 120, 90],
            [1997, 4003, 70, 70],
            [1997, 4004, 70, 70],
            [1997, 4005, 40, 50],
            [1997, 4006, 120, 90],
            [1997, 4007, 120, 90],
            [1997, 4008, 70, 70],
            [1997, 4009, 120, 90],
            [1997, 4010, 30, 45],
            [1997, 4011, 120, 90],
            [1997, 4012, 120, 90],
            [1997, 4013, 120, 90],
            [1997, 4014, 120, 90],
            [1997, 4015, 120, 90],
            [1997, 4016, 30, 45],
            [1997, 4017, 70, 70],
            [1997, 4018, 70, 70],
            [1997, 4019, 120, 90],
            [1997, 4020, 70, 70],
            [1997, 4021, 70, 70],
            [1997, 4022, 70, 70],
            [1997, 4023, 50, 60],
            [1997, 4024, 120, 90],
            [1997, 4025, 70, 70],
            [1997, 4026, 70, 70],
            [1997, 4027, 120, 90],
            [1997, 4028, 70, 70],
            [1997, 4029, 120, 90],
            [1997, 4031, 50, 60],
            [1997, 4032, 120, 90],
            [1997, 4033, 70, 70],
            [1997, 4035, 120, 90],
            [1997, 4036, 120, 90],
            [1997, 4037, 70, 70],
            [1997, 4038, 120, 90],
            [1997, 4039, 120, 90],
            [1997, 4040, 120, 90],
            [1997, 4041, 120, 90],
            [1997, 4042, 120, 90],
            [1997, 4043, 70, 70],
            [1997, 4044, 120, 90],
            [1997, 4045, 10.74, 9.07],
            [1997, 4046, 120, 90],
            [1997, 4047, 120, 90],
            [1997, 4048, 50, 60],
            [1997, 4049, 70, 70],
            [1997, 4050, 120, 90],
            [1997, 4051, 120, 90],
            [1997, 4053, 70, 70],
            [1997, 4056, 70, 70],
            [1997, 4057, 50, 60],
            [1997, 4059, 70, 70],
            [1997, 4060, 120, 90],
            [1997, 4062, 70, 70],
            [1997, 4063, 50, 60],
            [1997, 4064, 30, 45],
            [1997, 4065, 70, 70],
            [1997, 4066, 70, 70],
            [1997, 4067, 70, 70],
            [1997, 4068, 120, 90],
            [1997, 4069, 50, 60],
            [1997, 4070, 120, 90],
            [1997, 4071, 70, 70],
            [1997, 4072, 120, 90],
            [1997, 4073, 30, 45],
            [1997, 4074, 70, 70],
            [1997, 4075, 120, 90],
            [1997, 4076, 120, 90],
            [1997, 4077, 120, 90],
            [1997, 4078, 120, 90],
            [1997, 4079, 120, 90],
            [1997, 4080, 120, 90],
            [1997, 4081, 120, 90],
            [1997, 4082, 120, 90],
            [1997, 4083, 120, 90],
            [1997, 4084, 120, 90],
            [1997, 4085, 70, 70],
            [1997, 4086, 120, 90],
            [1997, 4087, 120, 90],
            [1997, 4088, 120, 90],
            [1997, 4089, 120, 90],
            [1997, 4090, 120, 90],
            [1997, 4091, 70, 70],
            [1997, 4092, 70, 70],
            [1997, 4093, 120, 90],
            [1997, 4094, 32.24, 21.39],
            [1997, 4095, 70, 70],
            [1997, 4096, 70, 70],
            [1997, 4097, 120, 90],
            [1997, 4098, 50, 60],
            [1997, 4100, 50, 60],
            [1997, 4101, 120, 90],
            [1997, 4102, 70, 70],
            [1997, 4103, 70, 70],
            [1997, 4104, 70, 70],
            [1997, 4105, 120, 90],
            [1997, 4106, 70, 70],
            [1997, 4107, 120, 90],
            [1997, 4108, 120, 90],
            [1997, 4109, 120, 90],
            [1997, 4110, 70, 70],
            [1997, 4111, 70, 70],
            [1997, 4112, 40, 50],
            [1997, 4113, 120, 90],
            [1997, 4115, 120, 90],
            [1997, 4116, 120, 90],
            [1997, 4117, 50, 60],
            [1997, 4118, 120, 90],
            [1997, 4119, 35.02, 25.49],
            [1997, 4120, 70, 70],
            [1997, 4121, 70, 70],
            [1997, 4122, 120, 90],
            [1997, 4123, 70, 70],
            [1997, 4124, 30, 45],
            [1997, 4125, 70, 70],
            [1997, 4126, 120, 90],
            [1997, 4127, 120, 90],
            [1997, 4128, 70, 70],
            [1997, 4131, 16.41, 11.51],
            [1997, 4132, 120, 90],
            [1997, 4133, 70, 70],
            [1997, 4134, 120, 90],
            [1997, 4135, 120, 90],
            [1997, 4136, 50, 60],
            [1997, 4137, 120, 90],
            [1997, 4138, 11.77, 6.96],
            [1997, 4139, 30, 45],
            [1997, 4140, 70, 70],
            [1997, 4141, 120, 90],
            [1997, 4142, 120, 90],
            [1997, 4143, 50, 60],
            [1997, 4144, 120, 90],
            [1997, 4145, 120, 90],
            [1997, 4147, 120, 90],
            [1997, 4148, 120, 90],
            [1997, 4149, 120, 90],
            [1997, 4150, 70, 70],
            [1997, 4151, 120, 90],
            [1997, 4152, 120, 90],
            [1997, 4153, 120, 90],
            [1997, 4154, 120, 90],
            [1997, 4155, 70, 70],
            [1997, 4156, 120, 90],
            [1997, 4157, 70, 70],
            [1997, 4158, 120, 90],
            [1997, 4159, 6.8, 6.9],
            [1997, 4160, 120, 90],
            [1997, 4161, 120, 90],
            [1997, 4162, 120, 90],
            [1997, 4163, 120, 90],
            [1997, 4164, 120, 90],
            [1997, 4165, 120, 90],
            [1997, 4166, 30, 45],
            [1997, 4167, 120, 90],
            [1997, 4168, 50, 60],
            [1997, 4169, 70, 70],
            [1997, 4170, 70, 70],
            [1997, 4171, 120, 90],
            [1997, 4172, 120, 90],
            [1997, 4173, 70, 70],
            [1997, 4174, 70, 70],
            [1997, 4175, 40, 50],
            [1997, 4176, 50, 60],
            [1997, 4177, 120, 90],
            [1997, 4178, 120, 90],
            [1997, 4181, 70, 70],
            [1997, 4182, 120, 90],
            [1997, 4184, 120, 90],
            [1997, 4185, 70, 70],
            [1997, 4186, 120, 90],
            [1997, 4187, 120, 90],
            [1997, 4188, 120, 90],
            [1997, 4189, 50, 60],
            [1997, 4190, 120, 90],
            [1997, 4192, 50, 60],
            [1997, 4193, 120, 90],
            [1997, 4194, 120, 90],
            [1997, 4195, 120, 90],
            [1997, 4196, 120, 90],
            [1997, 4197, 120, 90],
            [1997, 4198, 120, 90],
            [1997, 4199, 70, 70],
            [1997, 4200, 13.33, 9.28],
            [1997, 4201, 70, 70],
            [1997, 4202, 70, 70],
            [1997, 4203, 120, 90],
            [1997, 4204, 50, 60],
            [1997, 4205, 120, 90],
            [1997, 4206, 40, 50],
            [1997, 4207, 50, 60],
            [1997, 4208, 120, 90],
            [1997, 4209, 120, 90],
            [1997, 4210, 40, 50],
            [1997, 4211, 120, 90],
            [1997, 4212, 30, 45],
            [1997, 4213, 70, 70],
            [1997, 4214, 120, 90],
            [1997, 4215, 35.02, 25.49],
            [1997, 4216, 120, 90],
            [1997, 4218, 70, 70],
            [1997, 4219, 30, 45],
            [1997, 4220, 120, 90],
            [1997, 4221, 32.24, 21.39],
            [1997, 4222, 120, 90],
            [1997, 4224, 70, 70],
            [1997, 4225, 120, 90],
            [1997, 4226, 70, 70],
            [1997, 4228, 120, 90],
            [1997, 4229, 120, 90],
            [1997, 4230, 70, 70],
            [1997, 4231, 70, 70],
            [1997, 4232, 50, 60],
            [1997, 4233, 40, 50],
            [1997, 4234, 50, 60],
            [1997, 4235, 13.03, 13.29],
            [1997, 4236, 70, 70],
            [1997, 4237, 120, 90],
            [1997, 4238, 120, 90],
            [1997, 4239, 120, 90],
            [1997, 4240, 15, 25],
            [1997, 4241, 120, 90],
            [1997, 4242, 120, 90],
            [1997, 4244, 30, 45],
            [1997, 4245, 50, 60],
            [1997, 4246, 50, 60],
            [1997, 4247, 120, 90],
            [1997, 4248, 120, 90],
            [1997, 4249, 120, 90],
            [1997, 4250, 120, 90],
            [1997, 4251, 120, 90],
            [1997, 4252, 11.19, 9.3],
            [1997, 4253, 120, 90],
            [1997, 4255, 120, 90],
            [1997, 4256, 50, 60],
            [1997, 4257, 40, 50],
            [1997, 4258, 50, 60],
            [1997, 4260, 120, 90],
            [1997, 4261, 50, 60],
            [1997, 4262, 70, 70],
            [1997, 4263, 120, 90],
            [1997, 4264, 13.05, 10.17],
            [1997, 4265, 70, 70],
            [1997, 4266, 120, 90],
            [1997, 4267, 120, 90],
            [1997, 4268, 120, 90],
            [1997, 4269, 120, 90],
            [1997, 4270, 120, 90],
            [1997, 4271, 70, 70],
            [1997, 4272, 120, 90],
            [1997, 4273, 120, 90],
            [1997, 4274, 120, 90],
            [1997, 4275, 70, 70],
            [1997, 4276, 120, 90],
            [1997, 4277, 120, 90],
            [1997, 4278, 120, 90],
            [1997, 4279, 120, 90],
            [1997, 4280, 120, 90],
            [1997, 4281, 70, 70],
            [1997, 4282, 50, 60],
            [1997, 4283, 120, 90],
            [1997, 4284, 120, 90],
            [1997, 4285, 50, 60],
            [1997, 4286, 120, 90],
            [1997, 4287, 25.96, 16.87],
            [1997, 4288, 120, 90],
            [1997, 4290, 50, 60],
            [1997, 4291, 120, 90],
            [1997, 4292, 120, 90],
            [1997, 4293, 9.17, 7.22],
            [1997, 4294, 120, 90],
            [1997, 4295, 120, 90],
            [1997, 4296, 120, 90],
            [1997, 4297, 70, 70],
            [1997, 4298, 120, 90],
            [1997, 4299, 70, 70],
            [1997, 4300, 50, 60],
            [1997, 4301, 70, 70],
            [1997, 4302, 120, 90],
            [1997, 4304, 120, 90],
            [1997, 4305, 70, 70],
            [1997, 4306, 70, 70],
            [1997, 4307, 120, 90],
            [1997, 4308, 120, 90],
            [1997, 4309, 50, 60],
            [1997, 4310, 50, 60],
            [1997, 4311, 120, 90],
            [1997, 4312, 70, 70],
            [1997, 4313, 120, 90],
            [1997, 4314, 70, 70],
            [1997, 4315, 120, 90],
            [1997, 4316, 30, 45],
            [1997, 4317, 50, 60],
            [1997, 4318, 120, 90],
            [1997, 4319, 120, 90],
            [1997, 4320, 70, 70],
            [1997, 4321, 120, 90],
            [1997, 4322, 70, 70],
            [1997, 4323, 30, 45],
            [1997, 4325, 70, 70],
            [1997, 4326, 40, 50],
            [1997, 4328, 70, 70],
            [1997, 4329, 120, 90],
            [1997, 4330, 120, 90],
            [1997, 4333, 120, 90],
            [1997, 4334, 120, 90],
            [1997, 4335, 70, 70],
            [1997, 4336, 50, 60],
            [1997, 4337, 40, 50],
            [1997, 4338, 70, 70],
            [1997, 4339, 30, 45],
            [1997, 4340, 120, 90],
            [1997, 4341, 120, 90],
            [1997, 4342, 120, 90],
            [1997, 4343, 120, 90],
            [1997, 4345, 120, 90],
            [1997, 4346, 50, 60],
            [1997, 4347, 120, 90],
            [1997, 4348, 70, 70],
            [1997, 4349, 120, 90],
            [1997, 4350, 120, 90],
            [1997, 4352, 120, 90],
            [1997, 4353, 70, 70],
            [1997, 4355, 120, 90],
            [1997, 4356, 40, 50],
            [1997, 4357, 120, 90],
            [1997, 4358, 70, 70],
            [1997, 4360, 70, 70],
            [1997, 4362, 70, 70],
            [1997, 4363, 120, 90],
            [1997, 4364, 120, 90],
            [1997, 4365, 120, 90],
            [1997, 4366, 120, 90],
            [1997, 4367, 120, 90],
            [1997, 4368, 120, 90],
            [1997, 4370, 70, 70],
            [1997, 4371, 120, 90],
            [1997, 4372, 70, 70],
            [1997, 4373, 30, 45],
            [1997, 4374, 40, 50],
            [1997, 4375, 120, 90],
            [1997, 4376, 120, 90],
            [1997, 4377, 70, 70],
            [1997, 4378, 70, 70],
            [1997, 4379, 120, 90],
            [1997, 4380, 70, 70],
            [1997, 4381, 120, 90],
            [1997, 4382, 70, 70],
            [1997, 4383, 70, 70],
            [1997, 4384, 120, 90],
            [1997, 4385, 120, 90],
            [1997, 4386, 70, 70],
            [1997, 4387, 120, 90],
            [1997, 4389, 120, 90],
            [1997, 4390, 35.02, 25.49],
            [1997, 4391, 120, 90],
            [1997, 4392, 120, 90],
            [1997, 4393, 120, 90],
            [1997, 4394, 70, 70],
            [1997, 4395, 120, 90],
            [1997, 4396, 120, 90],
            [1997, 4398, 70, 70],
            [1997, 4399, 70, 70],
            [1997, 4400, 120, 90],
            [1997, 4401, 70, 70],
            [1997, 4404, 120, 90],
            [1997, 4405, 6.35, 4.6],
            [1997, 4406, 120, 90],
            [1997, 4407, 70, 70],
            [1997, 4408, 120, 90],
            [1997, 4409, 120, 90],
            [1997, 4410, 70, 70],
            [1997, 4411, 120, 90],
            [1997, 4412, 120, 90],
            [1997, 4413, 50, 60],
            [1997, 4414, 70, 70],
            [1997, 4415, 120, 90],
            [1997, 4416, 120, 90],
            [1997, 4417, 50, 60],
            [1997, 4418, 70, 70],
            [1997, 4419, 120, 90],
            [1997, 4420, 7.46, 6.7],
            [1997, 4421, 120, 90],
            [1997, 4422, 120, 90],
            [1997, 4423, 120, 90],
            [1997, 4426, 70, 70],
            [1997, 4427, 40, 50],
            [1997, 4428, 32.24, 21.39],
            [1997, 4430, 50, 60],
            [1997, 4431, 70, 70],
            [1997, 4432, 32.24, 21.39],
            [1997, 4433, 120, 90],
            [1997, 4435, 120, 90],
            [1997, 4436, 40, 50],
            [1997, 4437, 120, 90],
            [1997, 4438, 50, 60],
            [1997, 4439, 40, 50],
            [1997, 4440, 70, 70],
            [1997, 4441, 120, 90],
            [1997, 4442, 70, 70],
            [1997, 4443, 70, 70],
            [1997, 4444, 120, 90],
            [1997, 4445, 120, 90],
            [1997, 4446, 120, 90],
            [1997, 4447, 120, 90],
            [1997, 4448, 70, 70],
            [1997, 4450, 120, 90],
            [1997, 4451, 40, 50],
            [1997, 4453, 70, 70],
            [1997, 4454, 70, 70],
            [1997, 4455, 70, 70],
            [1997, 4456, 70, 70],
            [1997, 4457, 40, 50],
            [1997, 4459, 120, 90],
            [1997, 4460, 120, 90],
            [1997, 4461, 70, 70],
            [1997, 4463, 50, 60],
            [1997, 4464, 70, 70],
            [1997, 4465, 70, 70],
            [1997, 4466, 120, 90],
            [1997, 4467, 120, 90],
            [1997, 4468, 70, 70],
            [1997, 4470, 50, 60],
            [1997, 4471, 120, 90],
            [1997, 4472, 70, 70],
            [1997, 4473, 32.24, 21.39],
            [1997, 4474, 120, 90],
            [1997, 4475, 120, 90],
            [1997, 4476, 120, 90],
            [1997, 4477, 50, 60],
            [1997, 4478, 120, 90],
            [1997, 4479, 120, 90],
            [1997, 4481, 120, 90],
            [1997, 4482, 120, 90],
            [1997, 4483, 120, 90],
            [1997, 4484, 120, 90],
            [1997, 4485, 120, 90],
            [1997, 4486, 120, 90],
            [1997, 4487, 50, 60],
            [1997, 4488, 70, 70],
            [1997, 4489, 11.71, 6.08],
            [1997, 4490, 120, 90],
            [1997, 4491, 70, 70],
            [1997, 4492, 120, 90],
            [1997, 4493, 70, 70],
            [1997, 4494, 120, 90],
            [1997, 4495, 120, 90],
            [1997, 4496, 70, 70],
            [1997, 4497, 120, 90],
            [1997, 4498, 120, 90],
            [1997, 4500, 120, 90],
            [1997, 4501, 120, 90],
            [1997, 4502, 120, 90],
            [1997, 4504, 70, 70],
            [1997, 4505, 70, 70],
            [1997, 4506, 70, 70],
            [1997, 4508, 120, 90],
            [1997, 4509, 120, 90],
            [1997, 4510, 120, 90],
            [1997, 4511, 70, 70],
            [1997, 4512, 12.38, 7.83],
            [1997, 4513, 120, 90],
            [1997, 4514, 120, 90],
            [1997, 4515, 70, 70],
            [1997, 4516, 120, 90],
            [1997, 4517, 50, 60],
            [1997, 4518, 70, 70],
            [1997, 4519, 70, 70],
            [1997, 4520, 50, 60],
            [1997, 4521, 120, 90],
            [1997, 4523, 50, 60],
            [1997, 4524, 70, 70],
            [1997, 4525, 70, 70],
            [1997, 4526, 9.64, 9.7],
            [1997, 4527, 120, 90],
            [1997, 4528, 120, 90],
            [1997, 4529, 120, 90],
            [1997, 4531, 120, 90],
            [1997, 4532, 70, 70],
            [1997, 4533, 70, 70],
            [1997, 4534, 70, 70],
            [1997, 4535, 120, 90],
            [1997, 4536, 70, 70],
            [1997, 4537, 120, 90],
            [1997, 4538, 70, 70],
            [1997, 4539, 50, 60],
            [1997, 4541, 120, 90],
            [1997, 4542, 70, 70],
            [1997, 4543, 50, 60],
            [1997, 4544, 70, 70],
            [1997, 4545, 70, 70],
            [1997, 4546, 120, 90],
            [1997, 4547, 50, 60],
            [1997, 4548, 20.54, 15.72],
            [1997, 4549, 40, 50],
            [1997, 4550, 120, 90],
            [1997, 4551, 120, 90],
            [1997, 4552, 120, 90],
            [1997, 4553, 120, 90],
            [1997, 4554, 70, 70],
            [1997, 4555, 70, 70],
            [1997, 4556, 120, 90],
            [1997, 4557, 120, 90],
            [1997, 4558, 120, 90],
            [1997, 4559, 120, 90],
            [1997, 4560, 120, 90],
            [1997, 4561, 70, 70],
            [1997, 4562, 70, 70],
            [1997, 4563, 120, 90],
            [1997, 4565, 70, 70],
            [1997, 4566, 70, 70],
            [1997, 4568, 70, 70],
            [1997, 4569, 120, 90],
            [1997, 4571, 70, 70],
            [1997, 4572, 120, 90],
            [1997, 4574, 50, 60],
            [1997, 4575, 70, 70],
            [1997, 4576, 120, 90],
            [1997, 4578, 70, 70],
            [1997, 4579, 9.23, 6.62],
            [1997, 4580, 50, 60],
            [1997, 4581, 120, 90],
            [1997, 4582, 70, 70],
            [1997, 4584, 40, 50],
            [1997, 4585, 70, 70],
            [1997, 4587, 120, 90],
            [1997, 4588, 120, 90],
            [1997, 4590, 70, 70],
            [1997, 4591, 120, 90],
            [1997, 4592, 70, 70],
            [1997, 4595, 120, 90],
            [1997, 4596, 70, 70],
            [1997, 4597, 120, 90],
            [1997, 4598, 120, 90],
            [1997, 4599, 35.02, 25.49],
            [1997, 4600, 120, 90],
            [1997, 4601, 120, 90],
            [1997, 4602, 120, 90],
            [1997, 4603, 120, 90],
            [1997, 4604, 120, 90],
            [1997, 4605, 50, 60],
            [1997, 4606, 120, 90],
            [1997, 4607, 120, 90],
            [1997, 4608, 50, 60],
            [1997, 4610, 70, 70],
            [1997, 4611, 120, 90],
            [1997, 4612, 120, 90],
            [1997, 4613, 120, 90],
            [1997, 4614, 70, 70],
            [1997, 4615, 120, 90],
            [1997, 4616, 120, 90],
            [1997, 4617, 70, 70],
            [1997, 4618, 70, 70],
            [1997, 4619, 70, 70],
            [1997, 4620, 70, 70],
            [1997, 4621, 120, 90],
            [1997, 4622, 120, 90],
            [1997, 4623, 70, 70],
            [1997, 4624, 120, 90],
            [1997, 4625, 120, 90],
            [1997, 4626, 40, 50],
            [1997, 4627, 120, 90],
            [1997, 4628, 120, 90],
            [1997, 4629, 70, 70],
            [1997, 4630, 120, 90],
            [1997, 4631, 40, 50],
            [1997, 4633, 120, 90],
            [1997, 4634, 70, 70],
            [1997, 4635, 40, 50],
            [1997, 4636, 120, 90],
            [1997, 4637, 70, 70],
            [1997, 4638, 70, 70],
            [1997, 4640, 120, 90],
            [1997, 4641, 15.54, 8.85],
            [1997, 4643, 120, 90],
            [1997, 4644, 70, 70],
            [1997, 4645, 32.24, 21.39],
            [1997, 4646, 70, 70],
            [1997, 4647, 50, 60],
            [1997, 4648, 70, 70],
            [1997, 4649, 50, 60],
            [1997, 4651, 70, 70],
            [1997, 4652, 70, 70],
            [1997, 4653, 120, 90],
            [1997, 4654, 70, 70],
            [1997, 4655, 120, 90],
            [1997, 4657, 120, 90],
            [1997, 4658, 70, 70],
            [1997, 4659, 70, 70],
            [1997, 4660, 70, 70],
            [1997, 4661, 32.24, 21.39],
            [1997, 4662, 70, 70],
            [1997, 4663, 30, 45],
            [1997, 4664, 10.86, 8.78],
            [1997, 4665, 120, 90],
            [1997, 4666, 120, 90],
            [1997, 4667, 120, 90],
            [1997, 4668, 70, 70],
            [1997, 4669, 120, 90],
            [1997, 4670, 70, 70],
            [1997, 4671, 120, 90],
            [1997, 4673, 50, 60],
            [1997, 4674, 15, 20],
            [1997, 4675, 50, 60],
            [1997, 4676, 70, 70],
            [1997, 4677, 70, 70],
            [1997, 4679, 120, 90],
            [1997, 4680, 120, 90],
            [1997, 4682, 120, 90],
            [1997, 4683, 50, 60],
            [1997, 4684, 120, 90],
            [1997, 4686, 70, 70],
            [1997, 4687, 120, 90],
            [1997, 4689, 50, 60],
            [1997, 4690, 32.24, 21.39],
            [1997, 4691, 40, 50],
            [1997, 4692, 70, 70],
            [1997, 4693, 120, 90],
            [1997, 4694, 120, 90],
            [1997, 4695, 70, 70],
            [1997, 4696, 120, 90],
            [1997, 4697, 120, 90],
            [1997, 4698, 70, 70],
            [1997, 4699, 120, 90],
            [1997, 4701, 120, 90],
            [1997, 4702, 120, 90],
            [1997, 4703, 50, 60],
            [1997, 4704, 120, 90],
            [1997, 4705, 120, 90],
            [1997, 4706, 120, 90],
            [1997, 4707, 70, 70],
            [1997, 4708, 70, 70],
            [1997, 4709, 120, 90],
            [1997, 4711, 120, 90],
            [1997, 4712, 120, 90],
            [1997, 4713, 70, 70],
            [1997, 4714, 70, 70],
            [1997, 4715, 40, 50],
            [1997, 4716, 35.02, 25.49],
            [1997, 4717, 70, 70],
            [1997, 4718, 120, 90],
            [1997, 4720, 50, 60],
            [1997, 4722, 120, 90],
            [1997, 4723, 70, 70],
            [1997, 4724, 50, 60],
            [1997, 4725, 8.65, 7.78],
            [1997, 4726, 120, 90],
            [1997, 4728, 120, 90],
            [1997, 4729, 120, 90],
            [1997, 4730, 70, 70],
            [1997, 4731, 4.74, 5.56],
            [1997, 4732, 50, 60],
            [1997, 4733, 70, 70],
            [1997, 4734, 40, 50],
            [1997, 4735, 120, 90],
            [1997, 4736, 32.24, 21.39],
            [1997, 4737, 120, 90],
            [1997, 4738, 120, 90],
            [1997, 4739, 120, 90],
            [1997, 4740, 70, 70],
            [1997, 4741, 70, 70],
            [1997, 4742, 120, 90],
            [1997, 4743, 32.24, 21.39],
            [1997, 4744, 40, 50],
            [1997, 4745, 40, 50],
            [1997, 4747, 120, 90],
            [1997, 4749, 70, 70],
            [1997, 4750, 9.46, 11.76],
            [1997, 4751, 50, 60],
            [1997, 4752, 120, 90],
            [1997, 4753, 120, 90],
            [1997, 4754, 120, 90],
            [1997, 4756, 40, 50],
            [1997, 4757, 120, 90],
            [1997, 4758, 120, 90],
            [1997, 4760, 120, 90],
            [1997, 4761, 22.44, 14.33],
            [1997, 4762, 70, 70],
            [1997, 4763, 120, 90],
            [1997, 4764, 120, 90],
            [1997, 4765, 50, 60],
            [1997, 4766, 120, 90],
            [1997, 4767, 120, 90],
            [1997, 4770, 120, 90],
            [1997, 4771, 120, 90],
            [1997, 4772, 70, 70],
            [1997, 4773, 70, 70],
            [1997, 4774, 120, 90],
            [1997, 4775, 32.24, 21.39],
            [1997, 4776, 50, 60],
            [1997, 4777, 70, 70],
            [1997, 4778, 50, 60],
            [1997, 4779, 70, 70],
            [1997, 4780, 120, 90],
            [1997, 4781, 40, 50],
            [1997, 4782, 70, 70],
            [1997, 4783, 70, 70],
            [1997, 4784, 120, 90],
            [1997, 4785, 120, 90],
            [1997, 4786, 120, 90],
            [1997, 4788, 50, 60],
            [1997, 4789, 70, 70],
            [1997, 4790, 120, 90],
            [1997, 4791, 70, 70],
            [1997, 4792, 70, 70],
            [1997, 4793, 120, 90],
            [1997, 4794, 70, 70],
            [1997, 4795, 70, 70],
            [1997, 4796, 120, 90],
            [1997, 4797, 50, 60],
            [1997, 4798, 70, 70],
            [1997, 4799, 70, 70],
            [1997, 4800, 120, 90],
            [1997, 4801, 70, 70],
            [1997, 4802, 120, 90],
            [1997, 4803, 70, 70],
            [1997, 4804, 120, 90],
            [1997, 4805, 70, 70],
            [1997, 4806, 120, 90],
            [1997, 4807, 50, 60],
            [1997, 4808, 120, 90],
            [1997, 4809, 120, 90],
            [1997, 4810, 120, 90],
            [1997, 4811, 50, 60],
            [1997, 4812, 120, 90],
            [1997, 4814, 120, 90],
            [1997, 4815, 70, 70],
            [1997, 4816, 120, 90],
            [1997, 4817, 120, 90],
            [1997, 4818, 120, 90],
            [1997, 4819, 120, 90],
            [1997, 4820, 70, 70],
            [1997, 4821, 120, 90],
            [1997, 4823, 70, 70],
            [1997, 4825, 120, 90],
            [1997, 4826, 120, 90],
            [1997, 4827, 120, 90],
            [1997, 4828, 70, 70],
            [1997, 4829, 120, 90],
            [1997, 4830, 120, 90],
            [1997, 4831, 9.72, 8.44],
            [1997, 4832, 70, 70],
            [1997, 4833, 70, 70],
            [1997, 4834, 120, 90],
            [1997, 4835, 120, 90],
            [1997, 4836, 30, 45],
            [1997, 4837, 120, 90],
            [1997, 4838, 40, 50],
            [1997, 4839, 120, 90],
            [1997, 4840, 70, 70],
            [1997, 4841, 120, 90],
            [1997, 4842, 120, 90],
            [1997, 4843, 120, 90],
            [1997, 4844, 120, 90],
            [1997, 4845, 120, 90],
            [1997, 4846, 120, 90],
            [1997, 4847, 120, 90],
            [1997, 4848, 120, 90],
            [1997, 4849, 40, 50],
            [1997, 4850, 30, 45],
            [1997, 4851, 120, 90],
            [1997, 4852, 120, 90],
            [1997, 4853, 70, 70],
            [1997, 4854, 120, 90],
            [1997, 4855, 120, 90],
            [1997, 4856, 120, 90],
            [1997, 4857, 120, 90],
            [1997, 4858, 120, 90],
            [1997, 4860, 120, 90],
            [1997, 4862, 40, 50],
            [1997, 4863, 70, 70],
            [1997, 4864, 120, 90],
            [1997, 4865, 40, 50],
            [1997, 4866, 15, 25],
            [1997, 4867, 120, 90],
            [1997, 4868, 70, 70],
            [1997, 4869, 120, 90],
            [1997, 4871, 50, 60],
            [1997, 4872, 40, 50],
            [1997, 4874, 120, 90],
            [1997, 4875, 70, 70],
            [1997, 4876, 40, 50],
            [1997, 4877, 120, 90],
            [1997, 4878, 50, 60],
            [1997, 4879, 120, 90],
            [1997, 4880, 70, 70],
            [1997, 4881, 70, 70],
            [1997, 4882, 120, 90],
            [1997, 4883, 120, 90],
            [1997, 4885, 120, 90],
            [1997, 4886, 30, 45],
            [1997, 4887, 120, 90],
            [1997, 4888, 70, 70],
            [1997, 4890, 70, 70],
            [1997, 4891, 120, 90],
            [1997, 4892, 120, 90],
            [1997, 4893, 50, 60],
            [1997, 4894, 70, 70],
            [1997, 4895, 120, 90],
            [1997, 4896, 70, 70],
            [1997, 4897, 50, 60],
            [1997, 4898, 120, 90],
            [1997, 4899, 120, 90],
            [1997, 4900, 70, 70],
            [1997, 4901, 70, 70],
            [1997, 4902, 70, 70],
            [1997, 4903, 120, 90],
            [1997, 4904, 120, 90],
            [1997, 4905, 40, 50],
            [1997, 4906, 120, 90],
            [1997, 4907, 70, 70],
            [1997, 4908, 50, 60],
            [1997, 4909, 40, 50],
            [1997, 4910, 70, 70],
            [1997, 4911, 11.82, 7.07],
            [1997, 4912, 50, 60],
            [1997, 4914, 70, 70],
            [1997, 4915, 120, 90],
            [1997, 4916, 70, 70],
            [1997, 4917, 70, 70],
            [1997, 4918, 50, 60],
            [1997, 4919, 120, 90],
            [1997, 4920, 120, 90],
            [1997, 4922, 120, 90],
            [1997, 4923, 120, 90],
            [1997, 4924, 120, 90],
            [1997, 4925, 120, 90],
            [1997, 4926, 120, 90],
            [1997, 4927, 120, 90],
            [1997, 4928, 70, 70],
            [1997, 4929, 70, 70],
            [1997, 4930, 70, 70],
            [1997, 4931, 70, 70],
            [1997, 4932, 120, 90],
            [1997, 4934, 70, 70],
            [1997, 4935, 30, 45],
            [1997, 4936, 120, 90],
            [1997, 4937, 70, 70],
            [1997, 4938, 120, 90],
            [1997, 4939, 70, 70],
            [1997, 4940, 120, 90],
            [1997, 4941, 120, 90],
            [1997, 4942, 50, 60],
            [1997, 4944, 70, 70],
            [1997, 4945, 120, 90],
            [1997, 4946, 120, 90],
            [1997, 4947, 70, 70],
            [1997, 4948, 70, 70],
            [1997, 4949, 120, 90],
            [1997, 4950, 70, 70],
            [1997, 4951, 70, 70],
            [1997, 4952, 50, 60],
            [1997, 4953, 35.02, 25.49],
            [1997, 4954, 70, 70],
            [1997, 4955, 70, 70],
            [1997, 4956, 32.24, 21.39],
            [1997, 4957, 120, 90],
            [1997, 4958, 120, 90],
            [1997, 4959, 120, 90],
            [1997, 4960, 120, 90],
            [1997, 4961, 70, 70],
            [1997, 4962, 70, 70],
            [1997, 4963, 70, 70],
            [1997, 4964, 7.37, 6.44],
            [1997, 4965, 50, 60],
            [1997, 4966, 70, 70],
            [1997, 4968, 120, 90],
            [1997, 4969, 120, 90],
            [1997, 4970, 70, 70],
            [1997, 4971, 32.24, 21.39],
            [1997, 4972, 35.02, 25.49],
            [1997, 4973, 70, 70],
            [1997, 4974, 70, 70],
            [1997, 4975, 120, 90],
            [1997, 4976, 40, 50],
            [1997, 4977, 120, 90],
            [1997, 4978, 120, 90],
            [1997, 4979, 120, 90],
            [1997, 4980, 70, 70],
            [1997, 4981, 50, 60],
            [1997, 4982, 70, 70],
            [1997, 4983, 50, 60],
            [1997, 4984, 40, 50],
            [1997, 4987, 120, 90],
            [1997, 4988, 70, 70],
            [1997, 4989, 120, 90],
            [1997, 4990, 120, 90],
            [1997, 4992, 70, 70],
            [1997, 4993, 120, 90],
            [1997, 4994, 120, 90],
            [1997, 4995, 120, 90],
            [1997, 4996, 120, 90],
            [1997, 4997, 120, 90],
            [1997, 4998, 70, 70],
            [1997, 5000, 13.36, 12.29],
            [1997, 5001, 70, 70],
            [1997, 5002, 120, 90],
            [1997, 5003, 120, 90],
            [1997, 5004, 120, 90],
            [1997, 5005, 70, 70],
            [1997, 5006, 120, 90],
            [1997, 5007, 120, 90],
            [1997, 5008, 70, 70],
            [1997, 5009, 120, 90],
            [1997, 5010, 8.39, 5.61],
            [1997, 5011, 50, 60],
            [1997, 5012, 120, 90],
            [1997, 5013, 70, 70],
            [1997, 5014, 70, 70],
            [1997, 5015, 50, 60],
            [1997, 5017, 70, 70],
            [1997, 5018, 30, 45],
            [1997, 5019, 70, 70],
            [1997, 5020, 40, 50],
            [1997, 5021, 120, 90],
            [1997, 5022, 120, 90],
            [1997, 5023, 70, 70],
            [1997, 5024, 120, 90],
            [1997, 5025, 120, 90],
            [1997, 5026, 120, 90],
            [1997, 5027, 120, 90],
            [1997, 5028, 120, 90],
            [1997, 5029, 120, 90],
            [1997, 5030, 120, 90],
            [1997, 5031, 40, 50],
            [1997, 5032, 120, 90],
            [1997, 5033, 120, 90],
            [1997, 5034, 120, 90],
            [1997, 5035, 50, 60],
            [1997, 5036, 120, 90],
            [1997, 5037, 120, 90],
            [1997, 5038, 70, 70],
            [1997, 5039, 70, 70],
            [1997, 5040, 120, 90],
            [1997, 5041, 120, 90],
            [1997, 5042, 120, 90],
            [1997, 5043, 50, 60],
            [1997, 5044, 70, 70],
            [1997, 5045, 120, 90],
            [1997, 5046, 50, 60],
            [1997, 5047, 30, 45],
            [1997, 5048, 70, 70],
            [1997, 5049, 120, 90],
            [1997, 5050, 50, 60],
            [1997, 5051, 70, 70],
            [1997, 5052, 120, 90],
            [1997, 5053, 120, 90],
            [1997, 5054, 120, 90],
            [1997, 5056, 120, 90],
            [1997, 5057, 120, 90],
            [1997, 5058, 120, 90],
            [1997, 5059, 120, 90],
            [1997, 5060, 120, 90],
            [1997, 5061, 120, 90],
            [1997, 5062, 70, 70],
            [1997, 5063, 40, 50],
            [1997, 5064, 120, 90],
            [1997, 5065, 120, 90],
            [1997, 5066, 120, 90],
            [1997, 5068, 120, 90],
            [1997, 5069, 120, 90],
            [1997, 5070, 120, 90],
            [1997, 5071, 50, 60],
            [1997, 5072, 120, 90],
            [1997, 5073, 50, 60],
            [1997, 5075, 120, 90],
            [1997, 5076, 30, 45],
            [1997, 5077, 40, 50],
            [1997, 5078, 120, 90],
            [1997, 5079, 70, 70],
            [1997, 5080, 70, 70],
            [1997, 5081, 120, 90],
            [1997, 5082, 12.57, 13.41],
            [1997, 5084, 50, 60],
            [1997, 5085, 50, 60],
            [1997, 5086, 70, 70],
            [1997, 5087, 120, 90],
            [1997, 5088, 120, 90],
            [1997, 5089, 120, 90],
            [1997, 5091, 120, 90],
            [1997, 5092, 50, 60],
            [1997, 5093, 120, 90],
            [1997, 5094, 40, 50],
            [1997, 5095, 50, 60],
            [1997, 5097, 120, 90],
            [1997, 5098, 120, 90],
            [1997, 5099, 70, 70],
            [1997, 5100, 120, 90],
            [1997, 5101, 5.93, 6.65],
            [1997, 5102, 120, 90],
            [1997, 5103, 120, 90],
            [1997, 5104, 120, 90],
            [1997, 5105, 120, 90],
            [1997, 5106, 50, 60],
            [1997, 5107, 120, 90],
            [1997, 5108, 70, 70],
            [1997, 5109, 120, 90],
            [1997, 5110, 120, 90],
            [1997, 5111, 35.02, 25.49],
            [1997, 5114, 4.87, 4],
            [1997, 5115, 120, 90],
            [1997, 5116, 70, 70],
            [1997, 5117, 40, 50],
            [1997, 5118, 70, 70],
            [1997, 5119, 120, 90],
            [1997, 5120, 50, 60],
            [1997, 5121, 120, 90],
            [1997, 5122, 120, 90],
            [1997, 5124, 70, 70],
            [1997, 5125, 50, 60],
            [1997, 5126, 120, 90],
            [1997, 5127, 70, 70],
            [1997, 5128, 32.24, 21.39],
            [1997, 5129, 70, 70],
            [1997, 5130, 70, 70],
            [1997, 5131, 120, 90],
            [1997, 5132, 120, 90],
            [1997, 5135, 50, 60],
            [1997, 5137, 120, 90],
            [1997, 5138, 120, 90],
            [1997, 5139, 70, 70],
            [1997, 5140, 70, 70],
            [1997, 5141, 50, 60],
            [1997, 5142, 120, 90],
            [1997, 5143, 70, 70],
            [1997, 5144, 70, 70],
            [1997, 5145, 35.02, 25.49],
            [1997, 5148, 120, 90],
            [1997, 5149, 120, 90],
            [1997, 5150, 120, 90],
            [1997, 5151, 70, 70],
            [1997, 5152, 120, 90],
            [1997, 5153, 120, 90],
            [1997, 5154, 120, 90],
            [1997, 5155, 70, 70],
            [1997, 5156, 120, 90],
            [1997, 5157, 50, 60],
            [1997, 5158, 40, 50],
            [1997, 5159, 70, 70],
            [1997, 5160, 120, 90],
            [1997, 5161, 50, 60],
            [1997, 5162, 120, 90],
            [1997, 5163, 120, 90],
            [1997, 5164, 120, 90],
            [1997, 5165, 70, 70],
            [1997, 5166, 50, 60],
            [1997, 5167, 120, 90],
            [1997, 5168, 70, 70],
            [1997, 5169, 120, 90],
            [1997, 5170, 120, 90],
            [1997, 5171, 70, 70],
            [1997, 5172, 70, 70],
            [1997, 5173, 120, 90],
            [1997, 5174, 70, 70],
            [1997, 5175, 120, 90],
            [1997, 5177, 120, 90],
            [1997, 5178, 120, 90],
            [1997, 5179, 120, 90],
            [1997, 5180, 120, 90],
            [1997, 5181, 120, 90],
            [1997, 5182, 120, 90],
            [1997, 5183, 120, 90],
            [1997, 5189, 40, 50],
            [1997, 5271, 70, 70],
            [1997, 5627, 70, 70],
            [1997, 5632, 120, 90],
            [1997, 5999, 50, 60],
            [1997, 6000, 30, 45],
            [1997, 6001, 30, 45],
            [1997, 6002, 30, 45],
            [1997, 6003, 30, 45],
            [1997, 6004, 30, 45],
            [1997, 6005, 30, 45],
            [1997, 6006, 30, 45],
            [1997, 6007, 30, 45],
            [1997, 6008, 30, 45],
            [1997, 6011, 30, 45],
            [1997, 6012, 30, 45],
            [1997, 6013, 30, 45],
            [1997, 6014, 30, 45],
            [1997, 6015, 30, 45],
            [1997, 6016, 30, 45],
            [1997, 6020, 30, 45],
            [1997, 6021, 30, 45],
            [1997, 6022, 30, 45],
            [1997, 6023, 30, 45],
            [1997, 6024, 30, 45],
            [1997, 6028, 30, 45],
            [1997, 6031, 30, 45],
            [1997, 6032, 30, 45],
            [1997, 6034, 30, 45],
            [1997, 6035, 30, 45],
            [1997, 6036, 30, 45],
            [1997, 6037, 30, 45],
            [1997, 6038, 30, 45],
            [1997, 6040, 30, 45],
            [1997, 6041, 30, 45],
            [1997, 6042, 30, 45],
            [1997, 6043, 30, 45],
            [1997, 6044, 30, 45],
            [1997, 6045, 30, 45],
            [1997, 6046, 30, 45],
            [1997, 6047, 30, 45],
            [1997, 6048, 30, 45],
            [1997, 6050, 70, 70],
            [1997, 6051, 70, 70],
            [1997, 6052, 120, 90],
            [1997, 6053, 120, 90],
            [1997, 6248, 30, 45],
            [1997, 6252, 50, 60],
            [1997, 6253, 120, 90],
            [1997, 6255, 70, 70],
            [1997, 6256, 50, 60],
            [1997, 6258, 50, 60],
            [1997, 6259, 120, 90],
            [1997, 6260, 120, 90],
            [1997, 6261, 70, 70],
            [1997, 6262, 70, 70],
            [1997, 6263, 120, 90],
            [1997, 6264, 70, 70],
            [1997, 6265, 70, 70],
            [1997, 6266, 50, 60],
            [1997, 6267, 50, 60],
            [1997, 6268, 70, 70],
            [1997, 6269, 50, 60],
            [1997, 6270, 50, 60],
            [1997, 6271, 70, 70],
            [1997, 6272, 40, 50],
            [1997, 6274, 70, 70],
            [1997, 6275, 70, 70],
            [1997, 6276, 50, 60],
            [1997, 6277, 120, 90],
            [1997, 6279, 70, 70],
            [1997, 6280, 70, 70],
            [1997, 6281, 70, 70],
            [1997, 6282, 50, 60],
            [1997, 6283, 70, 70],
            [1997, 6284, 50, 60],
            [1997, 6286, 70, 70],
            [1997, 6287, 50, 60],
            [1997, 6288, 70, 70],
            [1997, 6289, 50, 60],
            [1997, 6290, 120, 90],
            [1997, 6292, 70, 70],
            [1997, 6293, 70, 70],
            [1997, 6294, 120, 90],
            [1997, 6295, 120, 90],
            [1997, 6296, 70, 70],
            [1997, 6297, 120, 90],
            [1997, 6299, 70, 70],
            [1997, 6300, 70, 70],
            [1997, 6301, 70, 70],
            [1997, 6302, 70, 70],
            [1997, 6303, 70, 70],
            [1997, 6305, 120, 90],
            [1997, 6306, 70, 70],
            [1997, 6307, 120, 90],
            [1997, 6308, 120, 90],
            [1997, 6309, 70, 70],
            [1997, 6310, 50, 60],
            [1997, 6312, 120, 90],
            [1997, 6313, 70, 70],
            [1997, 6314, 120, 90],
            [1997, 6315, 70, 70],
            [1997, 6316, 70, 70],
            [1997, 6317, 70, 70],
            [1997, 6319, 50, 60],
            [1997, 6320, 70, 70],
            [1997, 6321, 70, 70],
            [1997, 6326, 70, 70],
            [1997, 6328, 120, 90],
            [1997, 6330, 120, 90],
            [1998, 1, 50, 60],
            [1998, 2, 120, 90],
            [1998, 3, 70, 70],
            [1998, 7, 35.26, 21.02],
            [1998, 9, 120, 90],
            [1998, 13, 120, 90],
            [1998, 14, 70, 70],
            [1998, 15, 70, 70],
            [1998, 16, 70, 70],
            [1998, 17, 120, 90],
            [1998, 18, 70, 70],
            [1998, 19, 70, 70],
            [1998, 20, 120, 90],
            [1998, 21, 70, 70],
            [1998, 22, 120, 90],
            [1998, 23, 120, 90],
            [1998, 25, 13.55, 9.36],
            [1998, 26, 70, 70],
            [1998, 27, 120, 90],
            [1998, 28, 50, 60],
            [1998, 29, 120, 90],
            [1998, 30, 31.41, 21.15],
            [1998, 31, 11.48, 9.38],
            [1998, 32, 120, 90],
            [1998, 33, 70, 70],
            [1998, 35, 120, 90],
            [1998, 37, 120, 90],
            [1998, 38, 120, 90],
            [1998, 40, 70, 70],
            [1998, 42, 70, 70],
            [1998, 43, 120, 90],
            [1998, 44, 120, 90],
            [1998, 46, 120, 90],
            [1998, 47, 70, 70],
            [1998, 48, 70, 70],
            [1998, 49, 37.5, 45],
            [1998, 50, 120, 90],
            [1998, 51, 15.57, 18.15],
            [1998, 53, 40, 50],
            [1998, 56, 120, 90],
            [1998, 57, 120, 90],
            [1998, 58, 61.93, 51.53],
            [1998, 61, 70, 70],
            [1998, 62, 120, 90],
            [1998, 63, 70, 70],
            [1998, 64, 30, 45],
            [1998, 65, 50, 60],
            [1998, 66, 20, 25],
            [1998, 68, 70, 70],
            [1998, 69, 70, 70],
            [1998, 70, 50, 60],
            [1998, 71, 120, 90],
            [1998, 72, 120, 90],
            [1998, 73, 120, 90],
            [1998, 75, 50, 60],
            [1998, 77, 35.02, 25.49],
            [1998, 78, 59.13, 56.03],
            [1998, 81, 70, 70],
            [1998, 82, 70, 70],
            [1998, 83, 40, 37.5],
            [1998, 84, 120, 90],
            [1998, 87, 140.68, 39.98],
            [1998, 88, 15.28, 7.56],
            [1998, 89, 32.24, 21.39],
            [1998, 91, 40, 50],
            [1998, 93, 10.29, 11.63],
            [1998, 94, 120, 90],
            [1998, 96, 120, 90],
            [1998, 98, 120, 90],
            [1998, 99, 15.91, 13.12],
            [1998, 100, 13.94, 11.33],
            [1998, 101, 70, 70],
            [1998, 103, 120, 90],
            [1998, 105, 40, 50],
            [1998, 106, 70, 70],
            [1998, 109, 40, 50],
            [1998, 110, 120, 90],
            [1998, 113, 50, 60],
            [1998, 119, 70, 70],
            [1998, 121, 17.05, 9.84],
            [1998, 122, 42.72, 53.2],
            [1998, 123, 120, 90],
            [1998, 125, 24.22, 37.94],
            [1998, 128, 70, 70],
            [1998, 133, 35.02, 25.49],
            [1998, 135, 24.22, 25.06],
            [1998, 136, 120, 90],
            [1998, 138, 83.99, 31.46],
            [1998, 140, 50, 60],
            [1998, 141, 70, 70],
            [1998, 142, 70, 70],
            [1998, 144, 50, 60],
            [1998, 145, 10.42, 10.42],
            [1998, 146, 35.02, 25.49],
            [1998, 147, 32.24, 21.39],
            [1998, 149, 70, 70],
            [1998, 150, 50, 60],
            [1998, 151, 47.1, 33.3],
            [1998, 153, 12, 18],
            [1998, 156, 120, 90],
            [1998, 157, 120, 90],
            [1998, 158, 35.02, 25.49],
            [1998, 160, 120, 90],
            [1998, 161, 50, 60],
            [1998, 162, 17.62, 13.77],
            [1998, 163, 70, 70],
            [1998, 164, 120, 90],
            [1998, 165, 70, 70],
            [1998, 166, 31.35, 44.44],
            [1998, 169, 97.7, 41.85],
            [1998, 170, 120, 90],
            [1998, 171, 70, 70],
            [1998, 175, 70, 70],
            [1998, 177, 70, 70],
            [1998, 181, 120, 90],
            [1998, 182, 120, 90],
            [1998, 183, 70, 70],
            [1998, 184, 120, 90],
            [1998, 186, 42.55, 28.63],
            [1998, 187, 50, 60],
            [1998, 188, 50.99, 26.41],
            [1998, 189, 120, 90],
            [1998, 190, 41.9, 24.53],
            [1998, 192, 70, 70],
            [1998, 193, 50, 60],
            [1998, 194, 120, 90],
            [1998, 195, 70, 70],
            [1998, 196, 9.99, 9.76],
            [1998, 197, 120, 90],
            [1998, 198, 120, 90],
            [1998, 199, 120, 90],
            [1998, 200, 50, 60],
            [1998, 203, 70, 70],
            [1998, 204, 70, 70],
            [1998, 206, 120, 90],
            [1998, 207, 50, 60],
            [1998, 210, 120, 90],
            [1998, 211, 120, 90],
            [1998, 212, 70, 70],
            [1998, 213, 70, 70],
            [1998, 214, 120, 90],
            [1998, 215, 39.31, 26.34],
            [1998, 216, 72.31, 55.31],
            [1998, 217, 120, 90],
            [1998, 218, 53.89, 34.22],
            [1998, 219, 50, 60],
            [1998, 220, 23.35, 19.12],
            [1998, 222, 13.4, 9.72],
            [1998, 225, 37.5, 45],
            [1998, 226, 13.66, 15.31],
            [1998, 227, 120, 90],
            [1998, 228, 50, 60],
            [1998, 230, 30, 37.5],
            [1998, 231, 70, 70],
            [1998, 232, 70, 70],
            [1998, 233, 70, 70],
            [1998, 234, 50, 60],
            [1998, 235, 70, 70],
            [1998, 236, 70, 70],
            [1998, 237, 10.83, 7.57],
            [1998, 239, 57.35, 74.71],
            [1998, 240, 120, 90],
            [1998, 241, 70, 70],
            [1998, 242, 164.4, 59.03],
            [1998, 243, 118.04, 58],
            [1998, 244, 120, 90],
            [1998, 245, 120, 90],
            [1998, 246, 60.21, 33.65],
            [1998, 247, 120, 90],
            [1998, 248, 60.9, 49.22],
            [1998, 249, 70, 70],
            [1998, 250, 50, 60],
            [1998, 253, 120, 90],
            [1998, 256, 50, 60],
            [1998, 257, 120, 90],
            [1998, 260, 70, 70],
            [1998, 264, 50, 60],
            [1998, 265, 120, 90],
            [1998, 267, 120, 90],
            [1998, 268, 35.02, 25.49],
            [1998, 269, 120, 90],
            [1998, 270, 102.9, 57.89],
            [1998, 272, 120, 90],
            [1998, 273, 30, 45],
            [1998, 275, 40, 50],
            [1998, 282, 70, 70],
            [1998, 283, 35.02, 25.49],
            [1998, 284, 70, 70],
            [1998, 285, 62.31, 50.39],
            [1998, 286, 33.37, 83.43],
            [1998, 287, 40, 37.5],
            [1998, 289, 120, 90],
            [1998, 291, 70, 70],
            [1998, 292, 50, 60],
            [1998, 294, 118.68, 38.52],
            [1998, 295, 120, 90],
            [1998, 296, 70, 70],
            [1998, 297, 35.02, 25.49],
            [1998, 298, 70, 70],
            [1998, 299, 56.16, 71.39],
            [1998, 302, 120, 90],
            [1998, 303, 60.81, 38.31],
            [1998, 305, 21.98, 26],
            [1998, 306, 53.16, 39.53],
            [1998, 307, 120, 90],
            [1998, 308, 22.69, 32.81],
            [1998, 309, 35.02, 25.49],
            [1998, 310, 20.76, 23.58],
            [1998, 311, 70, 70],
            [1998, 312, 98.14, 57.65],
            [1998, 313, 50, 60],
            [1998, 314, 28.98, 30.23],
            [1998, 315, 120, 90],
            [1998, 317, 34.9, 28.91],
            [1998, 320, 120, 90],
            [1998, 321, 120, 90],
            [1998, 322, 120, 90],
            [1998, 324, 37.5, 45],
            [1998, 325, 120, 90],
            [1998, 326, 28.63, 19.82],
            [1998, 327, 120, 90],
            [1998, 328, 70, 70],
            [1998, 329, 70, 70],
            [1998, 330, 24.63, 27.62],
            [1998, 332, 101.6, 71.83],
            [1998, 333, 120, 90],
            [1998, 334, 14.71, 16.26],
            [1998, 337, 19.61, 30.02],
            [1998, 339, 74, 62.86],
            [1998, 340, 120, 90],
            [1998, 342, 70, 70],
            [1998, 343, 120, 90],
            [1998, 344, 89.38, 44.91],
            [1998, 346, 120, 90],
            [1998, 347, 120, 90],
            [1998, 348, 120, 90],
            [1998, 350, 70, 70],
            [1998, 351, 70, 70],
            [1998, 353, 20.67, 13.88],
            [1998, 354, 37.5, 45],
            [1998, 355, 70, 70],
            [1998, 356, 120, 90],
            [1998, 358, 32.24, 21.39],
            [1998, 361, 41.38, 37.74],
            [1998, 362, 50, 60],
            [1998, 365, 120, 90],
            [1998, 367, 50, 60],
            [1998, 368, 50, 60],
            [1998, 369, 6.34, 5.27],
            [1998, 370, 70, 70],
            [1998, 371, 120, 90],
            [1998, 372, 25.28, 18],
            [1998, 374, 50, 60],
            [1998, 376, 22.12, 15.98],
            [1998, 377, 40, 50],
            [1998, 378, 31.66, 30.53],
            [1998, 379, 11.67, 16.73],
            [1998, 382, 120, 90],
            [1998, 383, 70, 70],
            [1998, 385, 120, 90],
            [1998, 386, 50, 60],
            [1998, 387, 50, 60],
            [1998, 389, 37.5, 45],
            [1998, 390, 70, 70],
            [1998, 391, 70, 70],
            [1998, 392, 72.06, 47.49],
            [1998, 394, 50, 60],
            [1998, 396, 120, 90],
            [1998, 398, 70, 70],
            [1998, 399, 70, 70],
            [1998, 400, 50, 60],
            [1998, 401, 70, 70],
            [1998, 402, 120, 90],
            [1998, 403, 25.72, 27.84],
            [1998, 405, 70, 70],
            [1998, 406, 120, 90],
            [1998, 407, 50, 60],
            [1998, 409, 50, 60],
            [1998, 411, 120, 90],
            [1998, 412, 120, 90],
            [1998, 413, 30, 45],
            [1998, 415, 120, 90],
            [1998, 416, 50, 60],
            [1998, 418, 37.33, 36.38],
            [1998, 419, 120, 90],
            [1998, 422, 35.02, 25.49],
            [1998, 424, 32.02, 28.67],
            [1998, 425, 12.16, 14.12],
            [1998, 426, 35.02, 25.49],
            [1998, 427, 16, 20],
            [1998, 428, 13.52, 12.14],
            [1998, 429, 70, 70],
            [1998, 430, 50, 60],
            [1998, 432, 60.55, 31.38],
            [1998, 434, 70, 70],
            [1998, 436, 70, 70],
            [1998, 437, 16, 20],
            [1998, 439, 70, 70],
            [1998, 443, 120, 90],
            [1998, 444, 20.67, 13.88],
            [1998, 445, 120, 90],
            [1998, 446, 70, 70],
            [1998, 450, 120, 90],
            [1998, 451, 50, 60],
            [1998, 452, 120, 90],
            [1998, 453, 70, 70],
            [1998, 454, 120, 90],
            [1998, 455, 71.93, 65.93],
            [1998, 457, 50, 60],
            [1998, 458, 70, 70],
            [1998, 459, 120, 90],
            [1998, 460, 50, 60],
            [1998, 461, 50, 60],
            [1998, 463, 14.85, 9.88],
            [1998, 464, 21.08, 14.31],
            [1998, 465, 50, 60],
            [1998, 466, 120, 90],
            [1998, 467, 35.02, 25.49],
            [1998, 468, 120, 90],
            [1998, 469, 120, 90],
            [1998, 470, 35.02, 25.49],
            [1998, 471, 29.42, 44.44],
            [1998, 473, 120, 90],
            [1998, 474, 70, 70],
            [1998, 476, 120, 90],
            [1998, 477, 120, 90],
            [1998, 478, 120, 90],
            [1998, 479, 70, 70],
            [1998, 480, 70, 70],
            [1998, 481, 70, 70],
            [1998, 482, 70, 70],
            [1998, 484, 70, 70],
            [1998, 485, 120, 90],
            [1998, 486, 50, 60],
            [1998, 487, 22.74, 35.74],
            [1998, 488, 70, 70],
            [1998, 490, 70, 70],
            [1998, 493, 120, 90],
            [1998, 494, 120, 90],
            [1998, 495, 120, 90],
            [1998, 496, 70, 70],
            [1998, 497, 20.34, 27.7],
            [1998, 498, 50, 60],
            [1998, 500, 70, 70],
            [1998, 501, 70, 70],
            [1998, 503, 70, 70],
            [1998, 504, 14.4, 17.19],
            [1998, 505, 24.91, 27.22],
            [1998, 507, 120, 90],
            [1998, 508, 70, 70],
            [1998, 509, 5.13, 4.64],
            [1998, 510, 50, 60],
            [1998, 512, 40, 50],
            [1998, 513, 70, 70],
            [1998, 515, 120, 90],
            [1998, 518, 120, 90],
            [1998, 519, 26.44, 21.57],
            [1998, 520, 120, 90],
            [1998, 521, 120, 90],
            [1998, 522, 70, 70],
            [1998, 523, 120, 90],
            [1998, 524, 70, 70],
            [1998, 525, 120, 90],
            [1998, 526, 50, 60],
            [1998, 527, 70, 70],
            [1998, 528, 50, 60],
            [1998, 531, 10.37, 9.91],
            [1998, 532, 50, 60],
            [1998, 534, 50, 60],
            [1998, 535, 40, 50],
            [1998, 536, 18.74, 29.58],
            [1998, 537, 70, 70],
            [1998, 540, 70, 70],
            [1998, 541, 61.04, 50.11],
            [1998, 543, 120, 90],
            [1998, 545, 35.62, 43.31],
            [1998, 547, 15, 25],
            [1998, 548, 120, 90],
            [1998, 549, 120, 90],
            [1998, 550, 70, 70],
            [1998, 551, 120, 90],
            [1998, 553, 120, 90],
            [1998, 554, 15, 25],
            [1998, 555, 120, 90],
            [1998, 556, 120, 90],
            [1998, 557, 40, 50],
            [1998, 558, 120, 90],
            [1998, 559, 70, 70],
            [1998, 561, 120, 90],
            [1998, 563, 70, 70],
            [1998, 564, 12.02, 6.99],
            [1998, 565, 30, 45],
            [1998, 568, 44.41, 35.25],
            [1998, 569, 106.46, 58.13],
            [1998, 570, 77.63, 49.89],
            [1998, 571, 70, 70],
            [1998, 572, 30, 45],
            [1998, 573, 34.75, 26.58],
            [1998, 574, 70, 70],
            [1998, 577, 32.7, 38.7],
            [1998, 579, 40, 50],
            [1998, 581, 30, 45],
            [1998, 582, 120, 90],
            [1998, 583, 70, 70],
            [1998, 584, 21.39, 10.39],
            [1998, 585, 70, 70],
            [1998, 586, 50, 60],
            [1998, 588, 70, 70],
            [1998, 589, 120, 90],
            [1998, 590, 70, 70],
            [1998, 591, 120, 90],
            [1998, 593, 70, 70],
            [1998, 594, 32.24, 21.39],
            [1998, 595, 62.54, 30.08],
            [1998, 596, 50, 60],
            [1998, 597, 70, 70],
            [1998, 599, 37.1, 32.34],
            [1998, 600, 120, 90],
            [1998, 601, 70, 70],
            [1998, 604, 120, 90],
            [1998, 606, 120, 90],
            [1998, 607, 50, 60],
            [1998, 608, 54.37, 25.93],
            [1998, 610, 50, 60],
            [1998, 611, 50, 60],
            [1998, 612, 70, 70],
            [1998, 614, 28.93, 29.68],
            [1998, 615, 120, 90],
            [1998, 616, 120, 90],
            [1998, 618, 30, 37.5],
            [1998, 619, 120, 90],
            [1998, 621, 120, 90],
            [1998, 623, 8.39, 6.11],
            [1998, 625, 51.68, 25.98],
            [1998, 626, 40, 50],
            [1998, 627, 50, 60],
            [1998, 628, 20.36, 23.58],
            [1998, 629, 120, 90],
            [1998, 630, 70, 70],
            [1998, 631, 43.54, 34.8],
            [1998, 633, 120, 90],
            [1998, 635, 120, 90],
            [1998, 636, 70, 70],
            [1998, 637, 7.01, 5.35],
            [1998, 639, 70, 70],
            [1998, 641, 120, 90],
            [1998, 645, 50, 60],
            [1998, 647, 70, 70],
            [1998, 648, 70, 70],
            [1998, 649, 70, 70],
            [1998, 650, 120, 90],
            [1998, 651, 120, 90],
            [1998, 652, 70, 70],
            [1998, 653, 70, 70],
            [1998, 654, 120, 90],
            [1998, 656, 120, 90],
            [1998, 657, 120, 90],
            [1998, 659, 9.95, 8.02],
            [1998, 660, 24.24, 22.96],
            [1998, 662, 120, 90],
            [1998, 663, 120, 90],
            [1998, 664, 70, 70],
            [1998, 665, 120, 90],
            [1998, 666, 120, 90],
            [1998, 669, 50, 60],
            [1998, 670, 70, 70],
            [1998, 672, 70, 70],
            [1998, 673, 120, 90],
            [1998, 675, 70, 70],
            [1998, 678, 47.55, 39.99],
            [1998, 679, 120, 90],
            [1998, 680, 11.71, 8.44],
            [1998, 681, 32.24, 21.39],
            [1998, 682, 8.1, 6.18],
            [1998, 683, 16.28, 9.76],
            [1998, 686, 50, 60],
            [1998, 687, 120, 90],
            [1998, 688, 120, 90],
            [1998, 690, 50, 60],
            [1998, 691, 18.17, 15.1],
            [1998, 692, 32.24, 21.39],
            [1998, 693, 70, 70],
            [1998, 694, 50, 60],
            [1998, 695, 74.53, 49.3],
            [1998, 697, 120, 90],
            [1998, 698, 70, 70],
            [1998, 700, 70, 70],
            [1998, 701, 120, 90],
            [1998, 702, 70, 70],
            [1998, 703, 70, 70],
            [1998, 704, 55.7, 36.5],
            [1998, 705, 40, 50],
            [1998, 706, 70, 70],
            [1998, 708, 70, 70],
            [1998, 709, 32.88, 46.39],
            [1998, 710, 120, 90],
            [1998, 711, 50, 60],
            [1998, 712, 120, 90],
            [1998, 714, 50, 60],
            [1998, 715, 120, 90],
            [1998, 716, 70, 70],
            [1998, 717, 36.27, 32.74],
            [1998, 718, 70, 70],
            [1998, 719, 120, 90],
            [1998, 720, 87.15, 35.16],
            [1998, 721, 50, 60],
            [1998, 722, 120, 90],
            [1998, 723, 50, 60],
            [1998, 724, 29.85, 64.97],
            [1998, 727, 50, 45],
            [1998, 730, 35.02, 25.49],
            [1998, 731, 50, 60],
            [1998, 732, 120, 90],
            [1998, 734, 30, 45],
            [1998, 736, 70, 70],
            [1998, 737, 70, 70],
            [1998, 738, 120, 90],
            [1998, 740, 120, 90],
            [1998, 741, 120, 90],
            [1998, 742, 40, 50],
            [1998, 745, 120, 90],
            [1998, 746, 40, 50],
            [1998, 747, 50, 60],
            [1998, 748, 70, 70],
            [1998, 749, 50, 60],
            [1998, 750, 133.42, 46.75],
            [1998, 751, 50, 60],
            [1998, 753, 50, 60],
            [1998, 754, 36.5, 31.71],
            [1998, 756, 70, 70],
            [1998, 759, 70, 70],
            [1998, 762, 70, 70],
            [1998, 763, 70, 70],
            [1998, 766, 120, 90],
            [1998, 767, 70, 70],
            [1998, 769, 120, 90],
            [1998, 771, 120, 90],
            [1998, 772, 70, 70],
            [1998, 773, 64.93, 30.4],
            [1998, 774, 120, 90],
            [1998, 775, 70, 70],
            [1998, 776, 120, 90],
            [1998, 778, 120, 90],
            [1998, 779, 50, 60],
            [1998, 781, 71.84, 33.52],
            [1998, 782, 120, 90],
            [1998, 783, 50, 45],
            [1998, 784, 50, 60],
            [1998, 785, 120, 90],
            [1998, 787, 70, 70],
            [1998, 789, 70, 70],
            [1998, 790, 120, 90],
            [1998, 795, 120, 90],
            [1998, 796, 70, 70],
            [1998, 799, 50, 60],
            [1998, 801, 35.37, 49.96],
            [1998, 802, 120, 90],
            [1998, 803, 70, 70],
            [1998, 804, 120, 90],
            [1998, 805, 13.65, 18.71],
            [1998, 806, 120, 90],
            [1998, 807, 30, 45],
            [1998, 811, 120, 90],
            [1998, 812, 50, 60],
            [1998, 813, 15.18, 11.6],
            [1998, 814, 120, 90],
            [1998, 815, 120, 90],
            [1998, 818, 70, 70],
            [1998, 819, 120, 90],
            [1998, 820, 120, 90],
            [1998, 821, 24.1, 26.31],
            [1998, 822, 40, 50],
            [1998, 823, 120, 90],
            [1998, 824, 120, 90],
            [1998, 825, 70, 70],
            [1998, 826, 17.52, 8.25],
            [1998, 827, 70, 70],
            [1998, 829, 11.79, 8.2],
            [1998, 830, 120, 90],
            [1998, 831, 120, 90],
            [1998, 833, 120, 90],
            [1998, 834, 70, 70],
            [1998, 835, 69.3, 61.77],
            [1998, 836, 120, 90],
            [1998, 837, 70, 70],
            [1998, 840, 70, 70],
            [1998, 842, 50, 60],
            [1998, 843, 50.2, 42.1],
            [1998, 844, 117.83, 54.95],
            [1998, 845, 79.17, 68.36],
            [1998, 846, 120, 90],
            [1998, 847, 32.24, 21.39],
            [1998, 848, 9.12, 11.53],
            [1998, 850, 40, 50],
            [1998, 851, 18.96, 12.46],
            [1998, 852, 70, 70],
            [1998, 855, 9.81, 9.88],
            [1998, 857, 120, 90],
            [1998, 860, 70, 70],
            [1998, 863, 40, 50],
            [1998, 865, 70, 70],
            [1998, 867, 120, 90],
            [1998, 869, 70, 70],
            [1998, 871, 16.44, 22.77],
            [1998, 872, 70, 70],
            [1998, 873, 70, 70],
            [1998, 875, 120, 90],
            [1998, 876, 120, 90],
            [1998, 877, 120, 90],
            [1998, 878, 5.59, 4.6],
            [1998, 881, 35.02, 25.49],
            [1998, 882, 50, 60],
            [1998, 883, 120, 90],
            [1998, 884, 70, 70],
            [1998, 885, 70, 70],
            [1998, 886, 120, 90],
            [1998, 889, 11.95, 11.69],
            [1998, 890, 62.93, 34.45],
            [1998, 891, 120, 90],
            [1998, 892, 120, 90],
            [1998, 894, 23.13, 17.71],
            [1998, 895, 120, 90],
            [1998, 896, 70, 70],
            [1998, 897, 13.97, 22.37],
            [1998, 899, 120, 90],
            [1998, 900, 6.81, 4.72],
            [1998, 901, 120, 90],
            [1998, 905, 120, 90],
            [1998, 909, 120, 90],
            [1998, 910, 17.59, 7.29],
            [1998, 913, 40, 50],
            [1998, 914, 120, 90],
            [1998, 915, 38.46, 49.72],
            [1998, 916, 40, 50],
            [1998, 917, 30, 45],
            [1998, 918, 120, 90],
            [1998, 919, 120, 90],
            [1998, 922, 16, 20],
            [1998, 924, 11.58, 10.56],
            [1998, 926, 40.84, 38.58],
            [1998, 927, 70, 70],
            [1998, 928, 120, 90],
            [1998, 929, 120, 90],
            [1998, 930, 50, 60],
            [1998, 931, 70, 70],
            [1998, 934, 37.5, 45],
            [1998, 935, 120, 90],
            [1998, 936, 50, 60],
            [1998, 937, 120, 90],
            [1998, 938, 70, 70],
            [1998, 940, 70, 70],
            [1998, 941, 70, 70],
            [1998, 942, 70, 70],
            [1998, 944, 96.61, 70.21],
            [1998, 945, 50, 60],
            [1998, 946, 50, 60],
            [1998, 948, 70, 70],
            [1998, 949, 79.45, 48.51],
            [1998, 950, 13.52, 21.99],
            [1998, 952, 16.43, 13.85],
            [1998, 953, 50, 60],
            [1998, 954, 120, 90],
            [1998, 955, 120, 90],
            [1998, 957, 120, 90],
            [1998, 958, 50, 60],
            [1998, 960, 50, 60],
            [1998, 961, 120, 90],
            [1998, 963, 32.24, 21.39],
            [1998, 964, 50, 60],
            [1998, 965, 50, 60],
            [1998, 966, 7.47, 7.71],
            [1998, 969, 70, 70],
            [1998, 970, 20.67, 13.88],
            [1998, 971, 35.72, 14.91],
            [1998, 972, 35.77, 19.67],
            [1998, 974, 30, 45],
            [1998, 976, 8.35, 13.66],
            [1998, 977, 17.03, 11.19],
            [1998, 978, 70, 70],
            [1998, 979, 36.64, 34.46],
            [1998, 980, 70, 70],
            [1998, 981, 120, 90],
            [1998, 982, 120, 90],
            [1998, 983, 71.83, 43.14],
            [1998, 985, 194.37, 75.01],
            [1998, 986, 12.4, 12.01],
            [1998, 987, 35.02, 25.49],
            [1998, 988, 6.14, 5.32],
            [1998, 990, 71.86, 39.63],
            [1998, 991, 120, 90],
            [1998, 993, 120, 90],
            [1998, 994, 40, 50],
            [1998, 997, 120, 90],
            [1998, 998, 70, 70],
            [1998, 999, 120, 90],
            [1998, 1000, 50, 60],
            [1998, 1003, 8.24, 5.82],
            [1998, 1004, 70, 70],
            [1998, 1005, 17.62, 13.77],
            [1998, 1006, 120, 90],
            [1998, 1007, 40, 50],
            [1998, 1008, 37.5, 45],
            [1998, 1009, 120, 90],
            [1998, 1013, 120, 90],
            [1998, 1015, 70, 70],
            [1998, 1016, 14.94, 23.74],
            [1998, 1017, 50, 60],
            [1998, 1018, 120, 90],
            [1998, 1020, 32.24, 21.39],
            [1998, 1021, 70, 70],
            [1998, 1022, 120, 90],
            [1998, 1023, 50, 60],
            [1998, 1025, 120, 90],
            [1998, 1027, 120, 90],
            [1998, 1028, 50, 60],
            [1998, 1029, 32.24, 21.39],
            [1998, 1030, 40, 50],
            [1998, 1032, 35.33, 27.71],
            [1998, 1033, 27.47, 30.75],
            [1998, 1034, 70, 70],
            [1998, 1036, 70, 70],
            [1998, 1038, 70, 70],
            [1998, 1039, 120, 90],
            [1998, 1042, 120, 90],
            [1998, 1043, 120, 90],
            [1998, 1044, 120, 90],
            [1998, 1045, 120, 90],
            [1998, 1046, 50, 60],
            [1998, 1047, 70, 70],
            [1998, 1048, 70, 70],
            [1998, 1050, 70, 70],
            [1998, 1051, 92.72, 35.97],
            [1998, 1052, 50, 60],
            [1998, 1053, 50, 60],
            [1998, 1054, 70, 70],
            [1998, 1056, 70, 70],
            [1998, 1057, 50, 60],
            [1998, 1058, 70, 70],
            [1998, 1059, 70, 70],
            [1998, 1061, 70, 70],
            [1998, 1062, 70, 70],
            [1998, 1063, 120, 90],
            [1998, 1064, 20.67, 13.88],
            [1998, 1065, 120, 90],
            [1998, 1067, 120, 90],
            [1998, 1069, 50, 60],
            [1998, 1070, 50, 60],
            [1998, 1071, 125.97, 49.26],
            [1998, 1073, 84.92, 72.24],
            [1998, 1075, 9.34, 8.91],
            [1998, 1077, 120, 90],
            [1998, 1078, 120, 90],
            [1998, 1080, 120, 90],
            [1998, 1081, 70, 70],
            [1998, 1082, 120, 90],
            [1998, 1084, 160.19, 70.76],
            [1998, 1087, 70, 70],
            [1998, 1090, 120, 90],
            [1998, 1091, 40, 50],
            [1998, 1092, 15, 25],
            [1998, 1093, 50, 60],
            [1998, 1094, 23.66, 23.15],
            [1998, 1095, 34.76, 26.62],
            [1998, 1096, 120, 90],
            [1998, 1097, 8.07, 10.33],
            [1998, 1099, 20.2, 20.63],
            [1998, 1100, 55.33, 47.25],
            [1998, 1102, 120, 90],
            [1998, 1104, 70, 70],
            [1998, 1106, 120, 90],
            [1998, 1108, 120, 90],
            [1998, 1109, 71.26, 34.85],
            [1998, 1110, 120, 90],
            [1998, 1111, 120, 90],
            [1998, 1113, 120, 90],
            [1998, 1114, 120, 90],
            [1998, 1117, 50, 60],
            [1998, 1118, 50, 60],
            [1998, 1119, 50, 60],
            [1998, 1120, 120, 90],
            [1998, 1121, 120, 90],
            [1998, 1122, 35.02, 25.49],
            [1998, 1124, 33.6, 22.42],
            [1998, 1125, 120, 90],
            [1998, 1126, 70, 70],
            [1998, 1127, 35.02, 25.49],
            [1998, 1128, 70, 70],
            [1998, 1129, 20.67, 13.88],
            [1998, 1130, 120, 90],
            [1998, 1131, 19.62, 27.9],
            [1998, 1132, 50, 60],
            [1998, 1136, 70, 70],
            [1998, 1137, 120, 90],
            [1998, 1138, 120, 90],
            [1998, 1139, 120, 90],
            [1998, 1140, 50, 45],
            [1998, 1141, 151.96, 55.04],
            [1998, 1142, 87.4, 44.91],
            [1998, 1144, 70.4, 75.66],
            [1998, 1145, 120, 90],
            [1998, 1147, 22.6, 14.7],
            [1998, 1149, 50, 60],
            [1998, 1150, 50, 60],
            [1998, 1152, 70, 70],
            [1998, 1153, 120, 90],
            [1998, 1154, 120, 90],
            [1998, 1155, 12.52, 12.5],
            [1998, 1156, 50, 60],
            [1998, 1157, 120, 90],
            [1998, 1158, 50, 60],
            [1998, 1159, 70, 70],
            [1998, 1161, 120, 90],
            [1998, 1163, 70, 70],
            [1998, 1164, 120, 90],
            [1998, 1165, 120, 90],
            [1998, 1167, 85.7, 63.16],
            [1998, 1168, 120, 90],
            [1998, 1169, 34.55, 69.22],
            [1998, 1170, 70, 70],
            [1998, 1171, 120, 90],
            [1998, 1172, 70, 70],
            [1998, 1173, 50, 60],
            [1998, 1174, 70, 70],
            [1998, 1175, 28.04, 39.32],
            [1998, 1176, 120, 90],
            [1998, 1177, 70, 70],
            [1998, 1178, 9.93, 8.3],
            [1998, 1180, 20.27, 16.1],
            [1998, 1181, 120, 90],
            [1998, 1186, 70, 70],
            [1998, 1187, 120, 90],
            [1998, 1188, 40, 50],
            [1998, 1189, 120, 90],
            [1998, 1190, 70, 70],
            [1998, 1191, 70, 70],
            [1998, 1194, 82.38, 42.91],
            [1998, 1195, 120, 90],
            [1998, 1198, 120, 90],
            [1998, 1199, 40, 50],
            [1998, 1200, 27.2, 13.54],
            [1998, 1202, 30, 45],
            [1998, 1203, 120, 90],
            [1998, 1204, 70, 70],
            [1998, 1205, 85.87, 50.11],
            [1998, 1206, 120, 90],
            [1998, 1207, 30, 45],
            [1998, 1209, 40, 50],
            [1998, 1210, 40, 37.5],
            [1998, 1211, 53.75, 32.19],
            [1998, 1212, 120, 90],
            [1998, 1213, 40, 50],
            [1998, 1214, 70, 70],
            [1998, 1216, 50, 60],
            [1998, 1217, 90.55, 46.37],
            [1998, 1219, 116.48, 55.12],
            [1998, 1221, 22.66, 24.86],
            [1998, 1223, 70, 70],
            [1998, 1224, 49.77, 79.26],
            [1998, 1225, 70, 70],
            [1998, 1226, 70, 70],
            [1998, 1227, 120, 90],
            [1998, 1228, 57.49, 37.38],
            [1998, 1230, 50, 60],
            [1998, 1233, 50, 60],
            [1998, 1234, 70, 70],
            [1998, 1235, 50, 60],
            [1998, 1236, 70, 70],
            [1998, 1237, 37.5, 45],
            [1998, 1238, 70, 70],
            [1998, 1239, 120, 90],
            [1998, 1240, 120, 90],
            [1998, 1244, 70, 70],
            [1998, 1245, 120, 90],
            [1998, 1246, 70, 70],
            [1998, 1247, 70, 70],
            [1998, 1250, 70, 70],
            [1998, 1251, 70, 70],
            [1998, 1253, 50, 60],
            [1998, 1254, 70, 70],
            [1998, 1255, 120, 90],
            [1998, 1257, 50, 60],
            [1998, 1259, 105.06, 30.34],
            [1998, 1260, 50, 60],
            [1998, 1262, 110.05, 49.65],
            [1998, 1263, 120, 90],
            [1998, 1264, 120, 90],
            [1998, 1265, 13.84, 11.71],
            [1998, 1266, 35.02, 25.49],
            [1998, 1268, 30.72, 32.5],
            [1998, 1269, 50, 60],
            [1998, 1271, 85.26, 44.5],
            [1998, 1272, 70, 70],
            [1998, 1275, 50, 60],
            [1998, 1276, 32.24, 21.39],
            [1998, 1278, 70, 70],
            [1998, 1280, 14.3, 8.12],
            [1998, 1281, 21.65, 27],
            [1998, 1282, 50, 60],
            [1998, 1286, 120, 90],
            [1998, 1287, 70, 70],
            [1998, 1288, 70, 70],
            [1998, 1290, 120, 90],
            [1998, 1291, 70, 70],
            [1998, 1292, 70, 70],
            [1998, 1293, 20, 25],
            [1998, 1295, 70, 70],
            [1998, 1298, 50, 60],
            [1998, 1299, 70, 70],
            [1998, 1300, 50, 60],
            [1998, 1301, 70, 70],
            [1998, 1302, 30, 45],
            [1998, 1303, 70, 70],
            [1998, 1305, 17.46, 22.11],
            [1998, 1306, 50, 60],
            [1998, 1308, 120, 90],
            [1998, 1312, 26.57, 15.77],
            [1998, 1313, 120, 90],
            [1998, 1314, 40, 50],
            [1998, 1315, 120, 90],
            [1998, 1317, 70, 70],
            [1998, 1318, 120, 90],
            [1998, 1319, 46.62, 28.16],
            [1998, 1320, 120, 90],
            [1998, 1321, 48.13, 28.8],
            [1998, 1323, 75.54, 72.3],
            [1998, 1324, 120, 90],
            [1998, 1325, 120, 90],
            [1998, 1326, 70, 70],
            [1998, 1327, 120, 90],
            [1998, 1328, 70, 70],
            [1998, 1329, 70, 70],
            [1998, 1331, 120, 90],
            [1998, 1332, 10.21, 7.08],
            [1998, 1333, 120, 90],
            [1998, 1334, 87.72, 70.36],
            [1998, 1335, 70, 70],
            [1998, 1337, 5.66, 6.03],
            [1998, 1338, 120, 90],
            [1998, 1339, 11.12, 9.1],
            [1998, 1340, 50, 60],
            [1998, 1341, 35.02, 25.49],
            [1998, 1342, 70, 70],
            [1998, 1345, 40, 50],
            [1998, 1346, 20.67, 13.88],
            [1998, 1349, 70, 70],
            [1998, 1350, 70, 70],
            [1998, 1351, 70, 70],
            [1998, 1352, 35.02, 25.49],
            [1998, 1353, 120, 90],
            [1998, 1355, 120, 90],
            [1998, 1357, 70, 70],
            [1998, 1358, 120, 90],
            [1998, 1359, 67.94, 52.51],
            [1998, 1360, 120, 90],
            [1998, 1361, 77.94, 60.66],
            [1998, 1363, 83.47, 31.82],
            [1998, 1367, 53.29, 36.48],
            [1998, 1370, 17.21, 28.49],
            [1998, 1371, 70, 70],
            [1998, 1372, 120, 90],
            [1998, 1375, 22.3, 23.87],
            [1998, 1376, 30, 37.5],
            [1998, 1378, 70, 70],
            [1998, 1379, 120, 90],
            [1998, 1380, 70, 70],
            [1998, 1381, 120, 90],
            [1998, 1382, 50, 60],
            [1998, 1383, 8.95, 7.72],
            [1998, 1385, 32.24, 21.39],
            [1998, 1387, 50, 60],
            [1998, 1388, 120, 90],
            [1998, 1391, 120, 90],
            [1998, 1392, 35.02, 25.49],
            [1998, 1393, 120, 90],
            [1998, 1395, 70, 70],
            [1998, 1396, 70, 70],
            [1998, 1398, 50, 60],
            [1998, 1399, 9.27, 9.03],
            [1998, 1402, 70, 70],
            [1998, 1404, 40, 50],
            [1998, 1405, 120, 90],
            [1998, 1406, 6.5, 5.37],
            [1998, 1410, 70, 70],
            [1998, 1411, 20.67, 13.88],
            [1998, 1415, 70, 70],
            [1998, 1417, 120, 90],
            [1998, 1420, 20, 24],
            [1998, 1421, 120, 90],
            [1998, 1422, 120, 90],
            [1998, 1424, 50, 60],
            [1998, 1425, 70, 70],
            [1998, 1426, 8.57, 6.77],
            [1998, 1427, 30, 45],
            [1998, 1428, 10.79, 6.72],
            [1998, 1431, 120, 90],
            [1998, 1432, 6.73, 7.01],
            [1998, 1434, 70, 70],
            [1998, 1436, 70, 70],
            [1998, 1438, 70, 70],
            [1998, 1439, 120, 90],
            [1998, 1440, 70, 70],
            [1998, 1441, 120, 90],
            [1998, 1442, 70, 70],
            [1998, 1443, 50, 60],
            [1998, 1444, 120, 90],
            [1998, 1445, 120, 90],
            [1998, 1448, 70, 70],
            [1998, 1449, 40, 50],
            [1998, 1450, 120, 90],
            [1998, 1451, 35.02, 25.49],
            [1998, 1453, 70, 70],
            [1998, 1454, 20.61, 20.28],
            [1998, 1456, 70, 70],
            [1998, 1459, 120, 90],
            [1998, 1460, 120, 90],
            [1998, 1461, 6.14, 6.98],
            [1998, 1464, 50, 60],
            [1998, 1465, 70, 70],
            [1998, 1466, 50, 60],
            [1998, 1467, 70, 70],
            [1998, 1469, 70, 70],
            [1998, 1470, 30, 45],
            [1998, 1471, 58.78, 40.42],
            [1998, 1472, 120, 90],
            [1998, 1473, 11.99, 10.02],
            [1998, 1474, 70, 70],
            [1998, 1475, 93.38, 40.44],
            [1998, 1476, 39.76, 77.7],
            [1998, 1477, 104.5, 55.33],
            [1998, 1478, 17.41, 11.68],
            [1998, 1479, 40, 50],
            [1998, 1481, 70, 70],
            [1998, 1482, 70, 70],
            [1998, 1483, 70, 70],
            [1998, 1484, 24.92, 66.54],
            [1998, 1485, 120, 90],
            [1998, 1486, 73.81, 56.6],
            [1998, 1487, 120, 90],
            [1998, 1488, 120, 90],
            [1998, 1490, 35.69, 22.38],
            [1998, 1491, 13.55, 10.7],
            [1998, 1493, 40.01, 20.74],
            [1998, 1503, 120, 90],
            [1998, 1505, 120, 90],
            [1998, 1506, 120, 90],
            [1998, 1507, 70, 70],
            [1998, 1508, 21.47, 18.5],
            [1998, 1509, 120, 90],
            [1998, 1510, 31.13, 26.62],
            [1998, 1511, 21.14, 10.89],
            [1998, 1512, 20, 24],
            [1998, 1513, 32.24, 21.39],
            [1998, 1514, 70, 70],
            [1998, 1515, 30, 45],
            [1998, 1516, 70, 70],
            [1998, 1517, 120, 90],
            [1998, 1518, 120, 90],
            [1998, 1519, 120, 90],
            [1998, 1520, 70, 70],
            [1998, 1521, 120, 90],
            [1998, 1522, 35.03, 33.83],
            [1998, 1523, 120, 90],
            [1998, 1524, 120, 90],
            [1998, 1525, 30, 37.5],
            [1998, 1526, 70, 70],
            [1998, 1527, 17.34, 33.26],
            [1998, 1530, 70, 70],
            [1998, 1533, 70, 70],
            [1998, 1534, 10.96, 7.99],
            [1998, 1536, 30.57, 20.35],
            [1998, 1537, 35.55, 43.28],
            [1998, 1538, 120, 90],
            [1998, 1539, 40, 50],
            [1998, 1540, 40, 50],
            [1998, 1541, 70, 70],
            [1998, 1542, 50, 60],
            [1998, 1544, 120, 90],
            [1998, 1546, 70, 70],
            [1998, 1547, 70, 70],
            [1998, 1548, 120, 90],
            [1998, 1549, 70, 70],
            [1998, 1550, 120, 90],
            [1998, 1552, 30, 45],
            [1998, 1553, 70.57, 50.89],
            [1998, 1555, 30, 37.5],
            [1998, 1556, 27.63, 11.76],
            [1998, 1557, 70, 70],
            [1998, 1559, 50, 60],
            [1998, 1560, 70, 70],
            [1998, 1561, 30.82, 30.34],
            [1998, 1562, 97.79, 51.18],
            [1998, 1565, 120, 90],
            [1998, 1567, 120, 90],
            [1998, 1568, 17.56, 11.49],
            [1998, 1571, 70, 70],
            [1998, 1572, 120, 90],
            [1998, 1574, 50, 60],
            [1998, 1575, 124.82, 81.48],
            [1998, 1576, 50, 60],
            [1998, 1577, 50, 60],
            [1998, 1578, 120, 90],
            [1998, 1580, 50, 60],
            [1998, 1581, 19.75, 12.12],
            [1998, 1582, 22.41, 22.97],
            [1998, 1583, 120, 90],
            [1998, 1585, 70, 70],
            [1998, 1587, 70, 70],
            [1998, 1589, 70, 70],
            [1998, 1590, 70, 70],
            [1998, 1591, 70, 70],
            [1998, 1592, 32.24, 21.39],
            [1998, 1593, 25.91, 24.87],
            [1998, 1595, 70, 70],
            [1998, 1596, 120, 90],
            [1998, 1597, 50, 60],
            [1998, 1598, 19.88, 13.26],
            [1998, 1600, 120, 90],
            [1998, 1601, 70, 70],
            [1998, 1602, 120, 90],
            [1998, 1603, 50, 60],
            [1998, 1605, 50, 60],
            [1998, 1606, 120, 90],
            [1998, 1607, 70, 70],
            [1998, 1609, 120, 90],
            [1998, 1610, 18.25, 11.14],
            [1998, 1612, 40, 50],
            [1998, 1614, 70, 70],
            [1998, 1615, 120, 90],
            [1998, 1617, 120, 90],
            [1998, 1619, 120, 90],
            [1998, 1620, 50, 60],
            [1998, 1621, 70, 70],
            [1998, 1623, 50, 60],
            [1998, 1624, 35.02, 25.49],
            [1998, 1625, 70, 70],
            [1998, 1626, 70, 70],
            [1998, 1627, 70, 70],
            [1998, 1628, 50, 60],
            [1998, 1629, 16, 20],
            [1998, 1630, 70, 70],
            [1998, 1632, 13.48, 10.49],
            [1998, 1634, 70, 70],
            [1998, 1635, 16.96, 17.21],
            [1998, 1637, 120, 90],
            [1998, 1638, 70, 70],
            [1998, 1639, 70, 70],
            [1998, 1640, 70, 70],
            [1998, 1641, 70, 70],
            [1998, 1643, 18.14, 22.93],
            [1998, 1644, 48.21, 38.33],
            [1998, 1645, 70, 70],
            [1998, 1647, 70, 70],
            [1998, 1648, 120, 90],
            [1998, 1649, 120, 90],
            [1998, 1650, 70, 70],
            [1998, 1651, 120, 90],
            [1998, 1652, 70, 70],
            [1998, 1653, 120, 90],
            [1998, 1654, 70, 70],
            [1998, 1656, 8.81, 6.01],
            [1998, 1657, 70, 70],
            [1998, 1658, 120, 90],
            [1998, 1659, 38.85, 38.2],
            [1998, 1660, 134.83, 48.67],
            [1998, 1661, 32.24, 21.39],
            [1998, 1662, 70, 70],
            [1998, 1663, 28.45, 30.94],
            [1998, 1664, 70, 70],
            [1998, 1665, 50, 60],
            [1998, 1666, 6.17, 5.14],
            [1998, 1667, 120, 90],
            [1998, 1668, 50, 60],
            [1998, 1669, 120, 90],
            [1998, 1671, 120, 90],
            [1998, 1672, 20.29, 61.88],
            [1998, 1673, 40.58, 28.22],
            [1998, 1674, 70, 70],
            [1998, 1675, 11.86, 16.02],
            [1998, 1679, 40, 50],
            [1998, 1680, 55.76, 53.89],
            [1998, 1681, 120, 90],
            [1998, 1684, 120, 90],
            [1998, 1685, 37.5, 45],
            [1998, 1686, 120, 90],
            [1998, 1688, 25.71, 34.65],
            [1998, 1689, 120, 90],
            [1998, 1690, 120, 90],
            [1998, 1692, 120, 90],
            [1998, 1694, 120, 90],
            [1998, 1695, 120, 90],
            [1998, 1697, 70, 70],
            [1998, 1701, 70, 70],
            [1998, 1702, 70, 70],
            [1998, 1704, 50, 60],
            [1998, 1705, 70, 70],
            [1998, 1706, 50, 60],
            [1998, 1707, 120, 90],
            [1998, 1709, 30, 45],
            [1998, 1711, 70, 70],
            [1998, 1713, 50, 60],
            [1998, 1715, 120, 90],
            [1998, 1717, 70, 70],
            [1998, 1720, 4.58, 3.57],
            [1998, 1722, 120, 90],
            [1998, 1724, 31.04, 29.1],
            [1998, 1726, 120, 90],
            [1998, 1728, 120, 90],
            [1998, 1729, 36.89, 30.28],
            [1998, 1730, 70, 70],
            [1998, 1734, 22.97, 21.82],
            [1998, 1737, 70, 70],
            [1998, 1739, 32.24, 21.39],
            [1998, 1740, 50, 60],
            [1998, 1741, 70, 70],
            [1998, 1742, 120, 90],
            [1998, 1743, 70, 70],
            [1998, 1744, 48.44, 41.98],
            [1998, 1745, 55.29, 18.61],
            [1998, 1746, 70, 70],
            [1998, 1748, 109.42, 45.47],
            [1998, 1749, 50, 60],
            [1998, 1750, 70, 70],
            [1998, 1752, 120, 90],
            [1998, 1753, 25.17, 15.07],
            [1998, 1754, 120, 90],
            [1998, 1756, 47.81, 29.86],
            [1998, 1757, 70, 70],
            [1998, 1758, 32.24, 21.39],
            [1998, 1760, 70, 70],
            [1998, 1763, 43.44, 47.84],
            [1998, 1764, 70, 70],
            [1998, 1765, 50, 60],
            [1998, 1766, 120, 90],
            [1998, 1767, 120, 90],
            [1998, 1769, 70, 70],
            [1998, 1770, 70, 70],
            [1998, 1771, 19.39, 23.78],
            [1998, 1772, 25.48, 41.18],
            [1998, 1773, 50, 60],
            [1998, 1774, 17.87, 21.37],
            [1998, 1775, 70, 70],
            [1998, 1776, 35.63, 37.22],
            [1998, 1778, 120, 90],
            [1998, 1779, 70, 70],
            [1998, 1780, 37.79, 33.06],
            [1998, 1781, 113.83, 52.58],
            [1998, 1783, 120, 90],
            [1998, 1784, 70, 70],
            [1998, 1785, 120, 90],
            [1998, 1786, 120, 90],
            [1998, 1787, 120, 90],
            [1998, 1788, 120, 90],
            [1998, 1789, 120, 90],
            [1998, 1790, 48.09, 38.27],
            [1998, 1792, 25.36, 24.69],
            [1998, 1793, 70, 70],
            [1998, 1794, 70, 70],
            [1998, 1795, 9.04, 6.4],
            [1998, 1796, 50, 60],
            [1998, 1797, 70, 70],
            [1998, 1798, 70, 70],
            [1998, 1799, 4.8, 5.01],
            [1998, 1800, 15.42, 8.83],
            [1998, 1801, 70, 70],
            [1998, 1802, 120, 90],
            [1998, 1803, 120, 90],
            [1998, 1804, 105.47, 52.76],
            [1998, 1805, 50, 60],
            [1998, 1806, 120, 90],
            [1998, 1808, 70, 70],
            [1998, 1809, 120, 90],
            [1998, 1810, 50, 60],
            [1998, 1811, 120, 90],
            [1998, 1812, 43.07, 42.87],
            [1998, 1814, 40, 50],
            [1998, 1815, 17.45, 9.13],
            [1998, 1816, 83.79, 61.8],
            [1998, 1817, 70, 70],
            [1998, 1818, 27.25, 18.05],
            [1998, 1819, 70, 70],
            [1998, 1822, 70, 70],
            [1998, 1824, 70, 70],
            [1998, 1825, 50.4, 52.17],
            [1998, 1827, 70, 70],
            [1998, 1829, 120, 90],
            [1998, 1832, 70, 70],
            [1998, 1833, 120, 90],
            [1998, 1834, 120, 90],
            [1998, 1837, 120, 90],
            [1998, 1839, 70, 70],
            [1998, 1841, 70, 70],
            [1998, 1843, 14.6, 13.38],
            [1998, 1844, 30, 45],
            [1998, 1845, 20.52, 19.97],
            [1998, 1846, 120, 90],
            [1998, 1847, 50, 60],
            [1998, 1848, 66.18, 60.25],
            [1998, 1849, 120, 90],
            [1998, 1850, 8.32, 6.64],
            [1998, 1851, 120, 90],
            [1998, 1852, 70, 70],
            [1998, 1853, 120, 90],
            [1998, 1855, 120, 90],
            [1998, 1856, 30, 45],
            [1998, 1857, 70, 70],
            [1998, 1859, 120, 90],
            [1998, 1860, 120, 90],
            [1998, 1863, 18.35, 13.66],
            [1998, 1864, 120, 90],
            [1998, 1866, 70, 70],
            [1998, 1868, 35.02, 25.49],
            [1998, 1869, 40, 37.5],
            [1998, 1870, 32.24, 21.39],
            [1998, 1873, 70, 70],
            [1998, 1875, 50, 60],
            [1998, 1876, 35.35, 35.59],
            [1998, 1877, 120, 90],
            [1998, 1879, 43.02, 40.39],
            [1998, 1881, 50, 60],
            [1998, 1882, 104.15, 43.17],
            [1998, 1883, 120, 90],
            [1998, 1884, 50, 60],
            [1998, 1885, 70, 70],
            [1998, 1886, 50, 60],
            [1998, 1887, 70, 70],
            [1998, 1888, 120, 90],
            [1998, 1889, 70, 70],
            [1998, 1890, 120, 90],
            [1998, 1891, 50, 60],
            [1998, 1892, 70, 70],
            [1998, 1894, 50, 60],
            [1998, 1895, 50, 60],
            [1998, 1896, 120, 90],
            [1998, 1897, 18.91, 17.19],
            [1998, 1898, 12.47, 7.24],
            [1998, 1899, 70, 70],
            [1998, 1900, 20, 25],
            [1998, 1901, 27.52, 29.78],
            [1998, 1903, 70, 70],
            [1998, 1904, 120, 90],
            [1998, 1906, 20.9, 12.43],
            [1998, 1909, 120, 90],
            [1998, 1910, 120, 90],
            [1998, 1912, 70, 70],
            [1998, 1914, 120, 90],
            [1998, 1915, 120, 90],
            [1998, 1916, 120, 90],
            [1998, 1917, 120, 90],
            [1998, 1919, 120, 90],
            [1998, 1920, 70, 70],
            [1998, 1921, 30, 45],
            [1998, 1924, 120, 90],
            [1998, 1925, 59.83, 43.65],
            [1998, 1928, 120, 90],
            [1998, 1929, 6.5, 4.93],
            [1998, 1930, 10.76, 8.15],
            [1998, 1933, 12.42, 12.39],
            [1998, 1937, 70, 70],
            [1998, 1938, 120, 90],
            [1998, 1940, 120, 90],
            [1998, 1941, 120, 90],
            [1998, 1945, 45.16, 27.63],
            [1998, 1946, 70, 70],
            [1998, 1948, 120, 90],
            [1998, 1949, 120, 90],
            [1998, 1950, 120, 90],
            [1998, 1952, 92.32, 71.14],
            [1998, 1955, 70, 70],
            [1998, 1956, 40, 50],
            [1998, 1957, 70, 70],
            [1998, 1959, 120, 90],
            [1998, 1961, 120, 90],
            [1998, 1962, 40, 50],
            [1998, 1963, 7.89, 5.56],
            [1998, 1964, 50, 60],
            [1998, 1965, 50, 60],
            [1998, 1967, 32.24, 21.39],
            [1998, 1969, 70, 70],
            [1998, 1972, 11.39, 7.39],
            [1998, 1974, 70, 70],
            [1998, 1976, 14.59, 10.01],
            [1998, 1978, 120, 90],
            [1998, 1979, 50, 60],
            [1998, 1980, 120, 90],
            [1998, 1981, 70, 70],
            [1998, 1982, 70, 70],
            [1998, 1984, 70, 70],
            [1998, 1986, 120, 90],
            [1998, 1989, 50, 60],
            [1998, 1991, 18.88, 13.68],
            [1998, 1992, 50, 60],
            [1998, 1995, 39.6, 34.17],
            [1998, 1996, 120, 90],
            [1998, 1997, 120, 90],
            [1998, 1998, 8.45, 8.42],
            [1998, 2000, 32.3, 7.9],
            [1998, 2001, 120, 90],
            [1998, 2002, 50, 60],
            [1998, 2004, 8.73, 6.08],
            [1998, 2005, 50, 60],
            [1998, 2006, 34.13, 29.15],
            [1998, 2007, 70, 70],
            [1998, 2008, 70, 70],
            [1998, 2009, 120, 90],
            [1998, 2011, 120, 90],
            [1998, 2012, 70, 70],
            [1998, 2013, 70, 70],
            [1998, 2015, 50, 60],
            [1998, 2016, 50, 60],
            [1998, 2017, 40, 37.5],
            [1998, 2018, 70, 70],
            [1998, 2020, 32.24, 21.39],
            [1998, 2021, 91.08, 54.55],
            [1998, 2022, 120, 90],
            [1998, 2023, 12.93, 13.98],
            [1998, 2025, 47.08, 35.03],
            [1998, 2026, 122.65, 67.48],
            [1998, 2027, 120, 90],
            [1998, 2028, 120, 90],
            [1998, 2029, 30.65, 35.97],
            [1998, 2030, 50, 60],
            [1998, 2031, 6.44, 5.98],
            [1998, 2032, 120, 90],
            [1998, 2034, 120, 90],
            [1998, 2035, 70, 70],
            [1998, 2038, 120, 90],
            [1998, 2040, 120, 90],
            [1998, 2041, 120, 90],
            [1998, 2042, 25.88, 9.57],
            [1998, 2043, 70, 70],
            [1998, 2044, 120, 90],
            [1998, 2046, 50, 60],
            [1998, 2048, 70, 70],
            [1998, 2049, 70, 70],
            [1998, 2050, 70, 70],
            [1998, 2051, 120, 90],
            [1998, 2052, 120, 90],
            [1998, 2053, 70, 70],
            [1998, 2054, 40, 50],
            [1998, 2055, 70, 70],
            [1998, 2056, 50, 60],
            [1998, 2057, 120, 90],
            [1998, 2058, 9.96, 8.92],
            [1998, 2059, 14.88, 8.19],
            [1998, 2060, 70, 70],
            [1998, 2061, 70, 70],
            [1998, 2062, 120, 90],
            [1998, 2063, 50, 60],
            [1998, 2064, 61.23, 37.87],
            [1998, 2066, 120, 90],
            [1998, 2068, 70, 70],
            [1998, 2070, 21.34, 9.3],
            [1998, 2071, 120, 90],
            [1998, 2072, 120, 90],
            [1998, 2073, 120, 90],
            [1998, 2074, 70, 70],
            [1998, 2075, 70, 70],
            [1998, 2076, 70, 70],
            [1998, 2077, 120, 90],
            [1998, 2081, 57.1, 44.75],
            [1998, 2083, 120, 90],
            [1998, 2084, 23.59, 36.63],
            [1998, 2085, 9.03, 8.79],
            [1998, 2086, 40, 50],
            [1998, 2087, 70, 70],
            [1998, 2089, 0, 0],
            [1998, 2090, 120, 90],
            [1998, 2091, 120, 90],
            [1998, 2095, 70, 70],
            [1998, 2096, 120, 90],
            [1998, 2097, 50, 60],
            [1998, 2098, 40, 50],
            [1998, 2099, 89.29, 46.57],
            [1998, 2100, 70, 70],
            [1998, 2101, 70, 70],
            [1998, 2103, 12.45, 12.74],
            [1998, 2104, 111.3, 45.15],
            [1998, 2105, 120, 90],
            [1998, 2106, 50, 60],
            [1998, 2107, 120, 90],
            [1998, 2109, 120, 90],
            [1998, 2110, 40, 50],
            [1998, 2112, 70, 70],
            [1998, 2115, 70, 70],
            [1998, 2116, 50, 60],
            [1998, 2118, 120, 90],
            [1998, 2119, 16.05, 9.74],
            [1998, 2121, 120, 90],
            [1998, 2122, 70, 70],
            [1998, 2125, 120, 90],
            [1998, 2126, 50, 60],
            [1998, 2127, 44.84, 32.36],
            [1998, 2128, 29.14, 12.62],
            [1998, 2130, 120, 90],
            [1998, 2131, 120, 90],
            [1998, 2132, 19.44, 13.59],
            [1998, 2134, 70, 70],
            [1998, 2135, 50, 60],
            [1998, 2136, 70, 70],
            [1998, 2137, 70, 70],
            [1998, 2138, 38.63, 26.61],
            [1998, 2139, 70, 70],
            [1998, 2140, 50, 60],
            [1998, 2142, 70, 70],
            [1998, 2144, 120, 90],
            [1998, 2146, 70, 70],
            [1998, 2147, 120, 90],
            [1998, 2148, 70, 70],
            [1998, 2149, 120, 90],
            [1998, 2150, 120, 90],
            [1998, 2151, 62.81, 37.98],
            [1998, 2152, 120, 90],
            [1998, 2154, 120, 90],
            [1998, 2155, 120, 90],
            [1998, 2156, 70, 70],
            [1998, 2159, 120, 90],
            [1998, 2161, 50, 60],
            [1998, 2162, 34.02, 34.24],
            [1998, 2163, 120, 90],
            [1998, 2164, 50, 60],
            [1998, 2165, 50, 60],
            [1998, 2166, 35.02, 25.49],
            [1998, 2167, 10.33, 10.88],
            [1998, 2169, 70, 70],
            [1998, 2170, 50.17, 28.05],
            [1998, 2171, 120, 90],
            [1998, 2174, 40.28, 40.83],
            [1998, 2177, 8.15, 8.97],
            [1998, 2178, 70, 70],
            [1998, 2179, 70, 70],
            [1998, 2180, 14.38, 10.62],
            [1998, 2181, 58.9, 76.35],
            [1998, 2182, 120, 90],
            [1998, 2184, 40, 50],
            [1998, 2186, 50, 60],
            [1998, 2187, 120, 90],
            [1998, 2190, 70, 70],
            [1998, 2191, 120, 90],
            [1998, 2197, 120, 90],
            [1998, 2198, 40, 50],
            [1998, 2199, 120, 90],
            [1998, 2200, 70, 70],
            [1998, 2201, 23.77, 27.53],
            [1998, 2203, 12.12, 8.84],
            [1998, 2204, 14.98, 8.4],
            [1998, 2205, 120, 90],
            [1998, 2208, 81.25, 48.76],
            [1998, 2212, 70, 70],
            [1998, 2213, 50, 60],
            [1998, 2214, 20, 25],
            [1998, 2216, 34.36, 17.02],
            [1998, 2217, 120, 90],
            [1998, 2219, 120, 90],
            [1998, 2220, 37.11, 22.57],
            [1998, 2223, 40, 50],
            [1998, 2224, 29.41, 34.07],
            [1998, 2225, 50, 60],
            [1998, 2226, 120, 90],
            [1998, 2227, 39.22, 33.66],
            [1998, 2228, 50, 60],
            [1998, 2230, 120, 90],
            [1998, 2231, 120, 90],
            [1998, 2232, 17.94, 39.15],
            [1998, 2233, 34.95, 29.11],
            [1998, 2235, 50, 60],
            [1998, 2236, 26.79, 29.04],
            [1998, 2237, 120, 90],
            [1998, 2238, 26.85, 29.25],
            [1998, 2239, 21.85, 11.47],
            [1998, 2240, 120, 90],
            [1998, 2241, 14.63, 9.52],
            [1998, 2242, 70, 70],
            [1998, 2243, 120, 90],
            [1998, 2244, 70, 70],
            [1998, 2245, 70, 70],
            [1998, 2247, 50, 60],
            [1998, 2248, 16, 20],
            [1998, 2249, 120, 90],
            [1998, 2250, 50, 60],
            [1998, 2252, 70, 70],
            [1998, 2253, 14.51, 10.23],
            [1998, 2254, 70, 70],
            [1998, 2255, 22.3, 61.32],
            [1998, 2256, 70, 70],
            [1998, 2258, 42.22, 34.38],
            [1998, 2259, 2, 2],
            [1998, 2260, 70, 70],
            [1998, 2262, 70, 70],
            [1998, 2265, 120, 90],
            [1998, 2267, 10.9, 7.43],
            [1998, 2268, 120, 90],
            [1998, 2269, 70, 70],
            [1998, 2270, 120, 90],
            [1998, 2271, 9.23, 6.76],
            [1998, 2273, 70, 70],
            [1998, 2274, 70, 70],
            [1998, 2277, 50, 60],
            [1998, 2280, 8.57, 5.83],
            [1998, 2281, 120, 90],
            [1998, 2282, 70, 70],
            [1998, 2283, 120, 90],
            [1998, 2284, 70, 70],
            [1998, 2285, 40, 50],
            [1998, 2286, 70, 70],
            [1998, 2289, 120, 90],
            [1998, 2290, 120, 90],
            [1998, 2292, 120, 90],
            [1998, 2293, 109.99, 52.3],
            [1998, 2294, 50, 60],
            [1998, 2295, 120, 90],
            [1998, 2297, 153.15, 64.3],
            [1998, 2300, 50, 60],
            [1998, 2301, 70, 70],
            [1998, 2302, 120, 90],
            [1998, 2303, 56.37, 41.39],
            [1998, 2304, 70, 70],
            [1998, 2305, 120, 90],
            [1998, 2306, 50, 60],
            [1998, 2307, 70, 70],
            [1998, 2311, 70, 70],
            [1998, 2312, 33.27, 33.84],
            [1998, 2314, 120, 90],
            [1998, 2316, 70, 70],
            [1998, 2317, 120, 90],
            [1998, 2319, 50, 60],
            [1998, 2320, 8.59, 9.12],
            [1998, 2321, 120, 90],
            [1998, 2323, 70, 70],
            [1998, 2325, 120, 90],
            [1998, 2326, 120, 90],
            [1998, 2327, 120, 90],
            [1998, 2328, 70, 70],
            [1998, 2332, 120, 90],
            [1998, 2335, 85.28, 79.59],
            [1998, 2336, 120, 90],
            [1998, 2337, 120, 90],
            [1998, 2338, 32.24, 21.39],
            [1998, 2339, 120, 90],
            [1998, 2340, 120, 90],
            [1998, 2341, 70, 70],
            [1998, 2342, 70, 70],
            [1998, 2343, 70, 70],
            [1998, 2345, 40, 50],
            [1998, 2346, 70, 70],
            [1998, 2347, 120, 90],
            [1998, 2348, 70, 70],
            [1998, 2349, 70, 70],
            [1998, 2352, 50, 60],
            [1998, 2356, 226.56, 56.42],
            [1998, 2359, 50, 60],
            [1998, 2363, 50, 60],
            [1998, 2364, 32.24, 21.39],
            [1998, 2366, 50, 60],
            [1998, 2367, 59.45, 50.23],
            [1998, 2368, 70, 70],
            [1998, 2371, 70, 70],
            [1998, 2372, 30, 45],
            [1998, 2373, 70, 70],
            [1998, 2374, 14.36, 11.08],
            [1998, 2375, 120, 90],
            [1998, 2378, 47.63, 26.72],
            [1998, 2382, 70, 70],
            [1998, 2383, 96.19, 48.48],
            [1998, 2384, 30, 45],
            [1998, 2385, 70, 70],
            [1998, 2387, 40, 50],
            [1998, 2388, 70, 70],
            [1998, 2390, 120, 90],
            [1998, 2391, 70, 70],
            [1998, 2392, 8.47, 8.48],
            [1998, 2394, 50, 60],
            [1998, 2396, 120, 90],
            [1998, 2397, 120, 90],
            [1998, 2398, 120, 90],
            [1998, 2399, 120, 90],
            [1998, 2401, 9.42, 9.69],
            [1998, 2402, 70, 70],
            [1998, 2404, 120, 90],
            [1998, 2405, 22.61, 36.11],
            [1998, 2406, 120, 90],
            [1998, 2407, 120, 90],
            [1998, 2408, 50, 60],
            [1998, 2409, 50, 60],
            [1998, 2410, 70, 70],
            [1998, 2411, 9.59, 8.49],
            [1998, 2412, 6.63, 7.08],
            [1998, 2413, 120, 90],
            [1998, 2414, 8.64, 7.09],
            [1998, 2416, 120, 90],
            [1998, 2420, 120, 90],
            [1998, 2423, 70, 70],
            [1998, 2424, 120, 90],
            [1998, 2425, 70, 70],
            [1998, 2428, 10.11, 12.8],
            [1998, 2429, 70, 70],
            [1998, 2430, 70, 70],
            [1998, 2433, 70, 70],
            [1998, 2434, 120, 90],
            [1998, 2435, 40, 50],
            [1998, 2436, 70, 70],
            [1998, 2437, 16.17, 13.35],
            [1998, 2438, 120, 90],
            [1998, 2439, 70, 70],
            [1998, 2440, 5.64, 5.78],
            [1998, 2441, 120, 90],
            [1998, 2442, 120, 90],
            [1998, 2443, 70, 70],
            [1998, 2444, 120, 90],
            [1998, 2447, 25.21, 17.4],
            [1998, 2448, 120, 90],
            [1998, 2449, 35.02, 25.49],
            [1998, 2452, 70, 70],
            [1998, 2454, 120, 90],
            [1998, 2456, 70, 70],
            [1998, 2458, 50, 60],
            [1998, 2459, 32.63, 40.69],
            [1998, 2460, 70, 70],
            [1998, 2462, 120, 90],
            [1998, 2463, 40, 50],
            [1998, 2465, 120, 90],
            [1998, 2466, 120, 90],
            [1998, 2467, 70, 70],
            [1998, 2468, 40, 50],
            [1998, 2470, 120, 90],
            [1998, 2471, 120, 90],
            [1998, 2472, 78.4, 34.97],
            [1998, 2473, 120, 90],
            [1998, 2474, 120, 90],
            [1998, 2475, 70, 70],
            [1998, 2476, 120, 90],
            [1998, 2477, 70, 70],
            [1998, 2478, 120, 90],
            [1998, 2479, 50, 60],
            [1998, 2480, 33.47, 21.67],
            [1998, 2481, 50, 60],
            [1998, 2482, 120, 90],
            [1998, 2483, 120, 90],
            [1998, 2484, 120, 90],
            [1998, 2485, 50, 60],
            [1998, 2486, 70, 70],
            [1998, 2487, 70, 70],
            [1998, 2488, 53.21, 52.23],
            [1998, 2490, 70, 70],
            [1998, 2493, 104.76, 45.88],
            [1998, 2494, 57.1, 29.4],
            [1998, 2495, 40, 50],
            [1998, 2496, 120, 90],
            [1998, 2497, 40.2, 11.31],
            [1998, 2499, 17.64, 11.45],
            [1998, 2500, 14.55, 14.52],
            [1998, 2501, 70, 70],
            [1998, 2502, 50, 60],
            [1998, 2503, 50, 60],
            [1998, 2504, 120, 90],
            [1998, 2505, 70, 70],
            [1998, 2507, 120, 90],
            [1998, 2508, 70, 70],
            [1998, 2509, 70, 70],
            [1998, 2510, 70, 70],
            [1998, 2511, 35.02, 25.49],
            [1998, 2512, 120, 90],
            [1998, 2513, 120, 90],
            [1998, 2514, 120, 90],
            [1998, 2515, 50, 60],
            [1998, 2516, 40.7, 39.93],
            [1998, 2518, 74.82, 43.44],
            [1998, 2519, 35.02, 25.49],
            [1998, 2520, 70, 70],
            [1998, 2521, 50, 60],
            [1998, 2524, 50, 60],
            [1998, 2525, 70, 70],
            [1998, 2526, 70, 70],
            [1998, 2527, 49.14, 44.47],
            [1998, 2528, 120, 90],
            [1998, 2529, 70, 70],
            [1998, 2530, 70, 70],
            [1998, 2532, 70, 70],
            [1998, 2533, 23.69, 46.33],
            [1998, 2534, 120, 90],
            [1998, 2535, 5.8, 6.5],
            [1998, 2536, 6.37, 5.06],
            [1998, 2537, 120, 90],
            [1998, 2539, 70, 70],
            [1998, 2540, 40.04, 38.42],
            [1998, 2542, 34.79, 22.79],
            [1998, 2543, 40, 50],
            [1998, 2545, 40, 50],
            [1998, 2546, 70, 70],
            [1998, 2547, 70, 70],
            [1998, 2548, 70, 70],
            [1998, 2549, 70, 70],
            [1998, 2551, 71.76, 36.27],
            [1998, 2553, 70, 70],
            [1998, 2554, 70, 70],
            [1998, 2555, 52.5, 52.5],
            [1998, 2558, 40, 50],
            [1998, 2562, 111.85, 42.43],
            [1998, 2563, 70, 70],
            [1998, 2564, 40.56, 78.59],
            [1998, 2565, 40, 50],
            [1998, 2566, 10.44, 11.25],
            [1998, 2568, 50, 60],
            [1998, 2569, 50, 60],
            [1998, 2571, 50, 60],
            [1998, 2572, 120, 90],
            [1998, 2574, 107.79, 57.67],
            [1998, 2575, 70, 70],
            [1998, 2576, 70, 70],
            [1998, 2577, 30.15, 21.64],
            [1998, 2578, 70, 70],
            [1998, 2580, 120, 90],
            [1998, 2582, 70, 70],
            [1998, 2584, 120, 90],
            [1998, 2585, 70, 70],
            [1998, 2587, 66.78, 50.99],
            [1998, 2589, 70, 70],
            [1998, 2590, 120, 90],
            [1998, 2591, 120, 90],
            [1998, 2592, 120, 90],
            [1998, 2593, 109.49, 44.64],
            [1998, 2595, 70, 70],
            [1998, 2596, 120, 90],
            [1998, 2597, 40, 50],
            [1998, 2598, 70, 70],
            [1998, 2600, 50, 60],
            [1998, 2601, 70, 70],
            [1998, 2603, 120, 90],
            [1998, 2604, 14.91, 16.67],
            [1998, 2606, 18.48, 15.38],
            [1998, 2607, 14.85, 16.55],
            [1998, 2608, 70, 70],
            [1998, 2610, 70, 70],
            [1998, 2612, 19.02, 24.51],
            [1998, 2613, 35.02, 25.49],
            [1998, 2615, 80.55, 54.14],
            [1998, 2617, 17.59, 35.03],
            [1998, 2619, 57.48, 50.98],
            [1998, 2620, 50, 60],
            [1998, 2621, 120, 90],
            [1998, 2622, 22.29, 20.66],
            [1998, 2623, 36.98, 28.35],
            [1998, 2624, 35.02, 25.49],
            [1998, 2627, 70, 70],
            [1998, 2628, 47.2, 82.28],
            [1998, 2630, 120, 90],
            [1998, 2631, 70, 70],
            [1998, 2632, 22.83, 26.19],
            [1998, 2633, 36.95, 67.11],
            [1998, 2634, 120, 90],
            [1998, 2635, 70, 70],
            [1998, 2636, 70, 70],
            [1998, 2638, 70, 70],
            [1998, 2639, 10.59, 10.5],
            [1998, 2642, 120, 90],
            [1998, 2644, 71.93, 71.93],
            [1998, 2646, 30, 45],
            [1998, 2647, 51.91, 54.1],
            [1998, 2649, 50, 60],
            [1998, 2650, 120, 90],
            [1998, 2651, 40, 50],
            [1998, 2652, 37.5, 45],
            [1998, 2653, 70, 70],
            [1998, 2655, 40, 50],
            [1998, 2656, 69.06, 43.42],
            [1998, 2658, 40.97, 26.68],
            [1998, 2660, 40, 50],
            [1998, 2661, 70, 70],
            [1998, 2663, 50, 60],
            [1998, 2664, 120, 90],
            [1998, 2665, 70, 70],
            [1998, 2667, 63.81, 52.19],
            [1998, 2668, 39.53, 31.14],
            [1998, 2669, 120, 90],
            [1998, 2670, 70, 70],
            [1998, 2671, 50, 45],
            [1998, 2672, 70, 70],
            [1998, 2677, 70, 70],
            [1998, 2681, 70, 70],
            [1998, 2682, 120, 90],
            [1998, 2683, 11.9, 7.65],
            [1998, 2684, 70.83, 69.48],
            [1998, 2685, 50, 60],
            [1998, 2686, 9.12, 8.59],
            [1998, 2687, 94.14, 34.56],
            [1998, 2691, 50, 60],
            [1998, 2692, 70, 70],
            [1998, 2694, 35.02, 25.49],
            [1998, 2695, 70, 70],
            [1998, 2696, 32.24, 21.39],
            [1998, 2697, 120, 90],
            [1998, 2698, 70, 70],
            [1998, 2703, 50, 60],
            [1998, 2704, 15.95, 11.19],
            [1998, 2706, 120, 90],
            [1998, 2707, 70, 70],
            [1998, 2708, 120, 90],
            [1998, 2710, 22.67, 16.2],
            [1998, 2711, 50, 60],
            [1998, 2712, 70, 70],
            [1998, 2713, 70, 70],
            [1998, 2714, 50, 60],
            [1998, 2716, 70, 70],
            [1998, 2719, 70, 70],
            [1998, 2720, 120, 90],
            [1998, 2722, 120, 90],
            [1998, 2723, 70, 70],
            [1998, 2725, 70, 70],
            [1998, 2726, 70, 70],
            [1998, 2728, 35.02, 25.49],
            [1998, 2730, 50, 60],
            [1998, 2731, 120, 90],
            [1998, 2734, 50, 60],
            [1998, 2735, 8.55, 9.81],
            [1998, 2736, 30, 45],
            [1998, 2737, 40, 50],
            [1998, 2738, 40, 37.5],
            [1998, 2739, 50, 60],
            [1998, 2740, 120, 90],
            [1998, 2741, 120, 90],
            [1998, 2742, 70, 70],
            [1998, 2743, 30.71, 32.21],
            [1998, 2746, 32.24, 21.39],
            [1998, 2747, 63.12, 31.83],
            [1998, 2748, 123.58, 59.04],
            [1998, 2750, 30, 45],
            [1998, 2752, 70, 70],
            [1998, 2753, 50, 60],
            [1998, 2755, 120, 90],
            [1998, 2756, 70, 70],
            [1998, 2757, 120, 90],
            [1998, 2758, 36.94, 36.69],
            [1998, 2759, 120, 90],
            [1998, 2760, 120, 90],
            [1998, 2762, 120, 90],
            [1998, 2763, 120, 90],
            [1998, 2764, 70, 70],
            [1998, 2765, 120, 90],
            [1998, 2766, 5.69, 6.72],
            [1998, 2767, 120, 90],
            [1998, 2768, 120, 90],
            [1998, 2770, 120, 90],
            [1998, 2772, 70, 70],
            [1998, 2773, 50, 60],
            [1998, 2774, 120, 90],
            [1998, 2775, 70, 70],
            [1998, 2778, 70, 70],
            [1998, 2781, 9.91, 6.13],
            [1998, 2782, 50, 60],
            [1998, 2783, 70, 70],
            [1998, 2784, 70, 70],
            [1998, 2785, 5.56, 14],
            [1998, 2786, 70, 70],
            [1998, 2787, 64.37, 35.05],
            [1998, 2788, 96.68, 56.26],
            [1998, 2791, 30, 37.5],
            [1998, 2792, 120, 90],
            [1998, 2793, 16, 20],
            [1998, 2795, 32.24, 21.39],
            [1998, 2796, 70, 70],
            [1998, 2797, 120, 90],
            [1998, 2798, 70, 70],
            [1998, 2800, 70, 70],
            [1998, 2801, 120, 90],
            [1998, 2804, 20.57, 14.3],
            [1998, 2806, 70, 70],
            [1998, 2807, 36.77, 11.92],
            [1998, 2808, 50, 60],
            [1998, 2809, 120, 90],
            [1998, 2811, 50, 60],
            [1998, 2813, 34.06, 29.31],
            [1998, 2814, 120, 90],
            [1998, 2818, 30, 45],
            [1998, 2819, 11.84, 8.58],
            [1998, 2820, 120, 90],
            [1998, 2821, 70, 70],
            [1998, 2822, 40, 50],
            [1998, 2823, 59.27, 44.08],
            [1998, 2826, 40, 50],
            [1998, 2827, 21.89, 30.71],
            [1998, 2831, 120, 90],
            [1998, 2832, 70, 70],
            [1998, 2833, 120, 90],
            [1998, 2834, 50, 60],
            [1998, 2835, 37.5, 45],
            [1998, 2836, 36.81, 31.39],
            [1998, 2837, 120, 90],
            [1998, 2838, 120, 90],
            [1998, 2839, 120, 90],
            [1998, 2841, 120, 90],
            [1998, 2844, 70, 70],
            [1998, 2845, 120, 90],
            [1998, 2846, 120, 90],
            [1998, 2847, 30, 45],
            [1998, 2850, 20.67, 13.88],
            [1998, 2851, 75.14, 53.01],
            [1998, 2852, 37.5, 45],
            [1998, 2853, 70, 70],
            [1998, 2854, 25.17, 19.72],
            [1998, 2856, 124.74, 77.59],
            [1998, 2857, 35.02, 25.49],
            [1998, 2861, 70, 70],
            [1998, 2862, 70, 70],
            [1998, 2863, 70, 70],
            [1998, 2864, 120, 90],
            [1998, 2865, 120, 90],
            [1998, 2866, 50, 60],
            [1998, 2867, 120, 90],
            [1998, 2869, 5.93, 4.86],
            [1998, 2871, 120, 90],
            [1998, 2872, 31.07, 14.75],
            [1998, 2876, 101.18, 75.84],
            [1998, 2877, 120, 90],
            [1998, 2878, 120, 90],
            [1998, 2879, 50, 60],
            [1998, 2880, 39, 52.5],
            [1998, 2882, 120, 90],
            [1998, 2883, 70, 70],
            [1998, 2884, 70.14, 48.85],
            [1998, 2885, 70, 70],
            [1998, 2886, 70, 70],
            [1998, 2887, 70, 70],
            [1998, 2889, 70, 70],
            [1998, 2890, 120, 90],
            [1998, 2891, 120, 90],
            [1998, 2893, 120, 90],
            [1998, 2894, 120, 90],
            [1998, 2897, 120, 90],
            [1998, 2899, 70, 70],
            [1998, 2900, 20.67, 13.88],
            [1998, 2901, 120, 90],
            [1998, 2902, 120, 90],
            [1998, 2903, 120, 90],
            [1998, 2904, 120, 90],
            [1998, 2905, 50, 60],
            [1998, 2906, 120, 90],
            [1998, 2907, 16.83, 17.5],
            [1998, 2908, 50, 60],
            [1998, 2910, 49.02, 40.47],
            [1998, 2911, 120, 90],
            [1998, 2914, 70, 70],
            [1998, 2916, 70, 70],
            [1998, 2917, 20.67, 13.88],
            [1998, 2918, 17.8, 10.33],
            [1998, 2919, 120, 90],
            [1998, 2921, 120, 90],
            [1998, 2922, 50, 60],
            [1998, 2923, 26.73, 30.82],
            [1998, 2924, 120, 90],
            [1998, 2925, 120, 90],
            [1998, 2928, 70, 70],
            [1998, 2929, 50.7, 47.79],
            [1998, 2930, 120, 90],
            [1998, 2931, 70, 70],
            [1998, 2932, 120, 90],
            [1998, 2933, 70, 70],
            [1998, 2934, 85.78, 39.36],
            [1998, 2935, 120, 90],
            [1998, 2936, 90.08, 68.66],
            [1998, 2937, 120, 90],
            [1998, 2940, 120, 90],
            [1998, 2942, 70, 70],
            [1998, 2943, 120, 90],
            [1998, 2944, 50, 60],
            [1998, 2946, 117.5, 74.87],
            [1998, 2948, 50, 60],
            [1998, 2950, 110.01, 49.26],
            [1998, 2951, 120, 90],
            [1998, 2952, 120, 90],
            [1998, 2955, 70, 70],
            [1998, 2956, 70, 70],
            [1998, 2957, 120, 90],
            [1998, 2958, 50, 60],
            [1998, 2960, 50, 60],
            [1998, 2961, 50, 60],
            [1998, 2962, 40, 50],
            [1998, 2963, 120, 90],
            [1998, 2964, 50, 60],
            [1998, 2965, 120, 90],
            [1998, 2969, 15.24, 25.59],
            [1998, 2971, 70, 70],
            [1998, 2972, 120, 90],
            [1998, 2973, 120, 90],
            [1998, 2974, 22.89, 34.75],
            [1998, 2975, 70, 70],
            [1998, 2976, 120, 90],
            [1998, 2978, 24.61, 18.48],
            [1998, 2979, 70, 70],
            [1998, 2980, 120, 90],
            [1998, 2982, 40, 50],
            [1998, 2984, 15.43, 13.81],
            [1998, 2985, 50, 60],
            [1998, 2986, 35.02, 25.49],
            [1998, 2988, 120, 90],
            [1998, 2989, 50, 60],
            [1998, 2991, 50, 60],
            [1998, 2995, 36.26, 41.54],
            [1998, 2997, 12.34, 10.34],
            [1998, 2998, 70, 70],
            [1998, 2999, 7.91, 8.83],
            [1998, 3000, 50, 60],
            [1998, 3001, 70, 70],
            [1998, 3002, 120, 90],
            [1998, 3003, 120, 90],
            [1998, 3004, 120, 90],
            [1998, 3006, 70, 70],
            [1998, 3008, 70, 70],
            [1998, 3009, 50, 60],
            [1998, 3011, 13.6, 28.86],
            [1998, 3012, 70, 70],
            [1998, 3014, 120, 90],
            [1998, 3015, 30, 37.5],
            [1998, 3016, 22.14, 18.78],
            [1998, 3017, 120, 90],
            [1998, 3019, 50, 60],
            [1998, 3022, 120, 90],
            [1998, 3024, 70, 70],
            [1998, 3025, 70, 70],
            [1998, 3026, 21.48, 22.87],
            [1998, 3027, 22, 43.41],
            [1998, 3031, 20.67, 13.88],
            [1998, 3033, 120, 90],
            [1998, 3035, 29.76, 27.35],
            [1998, 3037, 50, 60],
            [1998, 3041, 52.5, 52.5],
            [1998, 3042, 10.27, 8.48],
            [1998, 3043, 70, 70],
            [1998, 3044, 70, 70],
            [1998, 3045, 120, 90],
            [1998, 3046, 120, 90],
            [1998, 3047, 50, 60],
            [1998, 3048, 101.09, 97.17],
            [1998, 3049, 120, 90],
            [1998, 3050, 27.97, 29.63],
            [1998, 3051, 120, 90],
            [1998, 3052, 70, 70],
            [1998, 3053, 70, 70],
            [1998, 3054, 50, 60],
            [1998, 3055, 120, 90],
            [1998, 3056, 15.98, 17.91],
            [1998, 3057, 70, 70],
            [1998, 3058, 70, 70],
            [1998, 3059, 120, 90],
            [1998, 3060, 70, 70],
            [1998, 3061, 128.24, 46.52],
            [1998, 3063, 70, 70],
            [1998, 3064, 70, 70],
            [1998, 3066, 50, 60],
            [1998, 3069, 35.02, 25.49],
            [1998, 3070, 56.43, 49.17],
            [1998, 3073, 120, 90],
            [1998, 3076, 120, 90],
            [1998, 3077, 39.42, 34.65],
            [1998, 3078, 70, 70],
            [1998, 3079, 70, 70],
            [1998, 3083, 70, 70],
            [1998, 3084, 70, 70],
            [1998, 3085, 50, 60],
            [1998, 3086, 97.92, 38.7],
            [1998, 3087, 70, 70],
            [1998, 3089, 43.11, 25.75],
            [1998, 3090, 50, 60],
            [1998, 3091, 19.67, 20.1],
            [1998, 3092, 70, 70],
            [1998, 3095, 120, 90],
            [1998, 3098, 20.76, 58.98],
            [1998, 3100, 120, 90],
            [1998, 3101, 120, 90],
            [1998, 3102, 120, 90],
            [1998, 3104, 7.73, 6.59],
            [1998, 3105, 70, 70],
            [1998, 3106, 70, 70],
            [1998, 3107, 120, 90],
            [1998, 3109, 50, 60],
            [1998, 3112, 79.98, 40.43],
            [1998, 3113, 70, 70],
            [1998, 3114, 120, 90],
            [1998, 3115, 120, 90],
            [1998, 3117, 50, 60],
            [1998, 3118, 120, 90],
            [1998, 3119, 40, 50],
            [1998, 3121, 69.55, 32.33],
            [1998, 3122, 63.25, 33.78],
            [1998, 3123, 120, 90],
            [1998, 3125, 120, 90],
            [1998, 3126, 70, 70],
            [1998, 3127, 9.37, 9.65],
            [1998, 3128, 120, 90],
            [1998, 3129, 37.84, 31.71],
            [1998, 3130, 40, 50],
            [1998, 3131, 8.89, 9.07],
            [1998, 3132, 120, 90],
            [1998, 3133, 72.02, 36.75],
            [1998, 3134, 50, 45],
            [1998, 3135, 120, 90],
            [1998, 3136, 40, 50],
            [1998, 3137, 12.56, 13.35],
            [1998, 3138, 120, 90],
            [1998, 3139, 10.29, 7.91],
            [1998, 3140, 70, 70],
            [1998, 3141, 50, 60],
            [1998, 3142, 40, 50],
            [1998, 3143, 70, 70],
            [1998, 3144, 120, 90],
            [1998, 3148, 33.08, 29.22],
            [1998, 3149, 120, 90],
            [1998, 3151, 120, 90],
            [1998, 3152, 50, 60],
            [1998, 3153, 70, 70],
            [1998, 3154, 87.45, 60.56],
            [1998, 3155, 98.27, 51.32],
            [1998, 3158, 120, 90],
            [1998, 3160, 37.27, 60.05],
            [1998, 3161, 20.3, 19.5],
            [1998, 3163, 70, 70],
            [1998, 3164, 70, 70],
            [1998, 3165, 70, 54.11],
            [1998, 3166, 15, 20],
            [1998, 3167, 69.49, 38],
            [1998, 3168, 120, 90],
            [1998, 3171, 50, 60],
            [1998, 3172, 120, 90],
            [1998, 3175, 73.26, 36.41],
            [1998, 3177, 37.5, 45],
            [1998, 3181, 8.14, 6.4],
            [1998, 3182, 22.27, 15.36],
            [1998, 3183, 40, 50],
            [1998, 3184, 70, 70],
            [1998, 3186, 40, 50],
            [1998, 3187, 120, 90],
            [1998, 3188, 14.43, 16.56],
            [1998, 3189, 192.54, 70.66],
            [1998, 3190, 40, 50],
            [1998, 3191, 70, 70],
            [1998, 3192, 120, 90],
            [1998, 3195, 22.52, 19.08],
            [1998, 3196, 70, 70],
            [1998, 3197, 99.63, 37.69],
            [1998, 3198, 50, 60],
            [1998, 3199, 70, 70],
            [1998, 3200, 40, 50],
            [1998, 3203, 12.22, 11.28],
            [1998, 3206, 36.81, 46.42],
            [1998, 3207, 50, 60],
            [1998, 3208, 120, 90],
            [1998, 3211, 50, 60],
            [1998, 3212, 120, 90],
            [1998, 3214, 70, 70],
            [1998, 3216, 120, 90],
            [1998, 3217, 34.82, 34.71],
            [1998, 3219, 10.87, 12.56],
            [1998, 3220, 120, 90],
            [1998, 3221, 70, 70],
            [1998, 3225, 8.05, 7.89],
            [1998, 3227, 70, 70],
            [1998, 3228, 34.26, 35.61],
            [1998, 3229, 35.02, 25.49],
            [1998, 3231, 26.42, 28.94],
            [1998, 3234, 37.45, 21.3],
            [1998, 3239, 120, 90],
            [1998, 3240, 120, 90],
            [1998, 3241, 50, 60],
            [1998, 3242, 70, 70],
            [1998, 3243, 12.14, 9.5],
            [1998, 3244, 120, 90],
            [1998, 3246, 65.38, 60.87],
            [1998, 3247, 120, 90],
            [1998, 3248, 50, 60],
            [1998, 3249, 120, 90],
            [1998, 3251, 40, 50],
            [1998, 3252, 50, 60],
            [1998, 3253, 70, 70],
            [1998, 3254, 50, 60],
            [1998, 3255, 70, 70],
            [1998, 3256, 30.27, 22.34],
            [1998, 3257, 50, 60],
            [1998, 3258, 70, 70],
            [1998, 3259, 50, 60],
            [1998, 3260, 20, 25],
            [1998, 3262, 70, 70],
            [1998, 3263, 120, 90],
            [1998, 3264, 13.13, 23.21],
            [1998, 3265, 120, 90],
            [1998, 3266, 70, 70],
            [1998, 3267, 50, 60],
            [1998, 3268, 59.2, 40.69],
            [1998, 3270, 21.48, 22.87],
            [1998, 3271, 35.02, 25.49],
            [1998, 3272, 106.83, 78.93],
            [1998, 3273, 120, 90],
            [1998, 3274, 50, 60],
            [1998, 3275, 120, 90],
            [1998, 3276, 35.02, 25.49],
            [1998, 3277, 91.74, 42.99],
            [1998, 3278, 70, 70],
            [1998, 3279, 32.24, 21.39],
            [1998, 3280, 59.87, 41.55],
            [1998, 3283, 12.69, 12.13],
            [1998, 3284, 42.57, 30.98],
            [1998, 3286, 15.7, 9.65],
            [1998, 3287, 50, 60],
            [1998, 3288, 50, 60],
            [1998, 3289, 120, 90],
            [1998, 3290, 70, 70],
            [1998, 3292, 120, 90],
            [1998, 3293, 70, 70],
            [1998, 3294, 20.67, 13.88],
            [1998, 3295, 120, 90],
            [1998, 3296, 30, 45],
            [1998, 3300, 70, 70],
            [1998, 3301, 70, 70],
            [1998, 3302, 70, 70],
            [1998, 3303, 70, 70],
            [1998, 3305, 120, 90],
            [1998, 3306, 32.44, 29.79],
            [1998, 3308, 70, 70],
            [1998, 3309, 50, 45],
            [1998, 3312, 70, 70],
            [1998, 3313, 120, 90],
            [1998, 3314, 50, 60],
            [1998, 3315, 120, 90],
            [1998, 3316, 120, 90],
            [1998, 3318, 70, 70],
            [1998, 3319, 70, 70],
            [1998, 3320, 120, 90],
            [1998, 3321, 50, 60],
            [1998, 3322, 120, 90],
            [1998, 3323, 40, 50],
            [1998, 3324, 70, 70],
            [1998, 3325, 40, 50],
            [1998, 3326, 51.15, 39.66],
            [1998, 3327, 120, 90],
            [1998, 3328, 120, 90],
            [1998, 3329, 8.87, 8.14],
            [1998, 3331, 108.09, 47.79],
            [1998, 3332, 120, 90],
            [1998, 3333, 120, 90],
            [1998, 3334, 14.53, 16.63],
            [1998, 3335, 70, 70],
            [1998, 3336, 46.22, 26.88],
            [1998, 3338, 70, 70],
            [1998, 3340, 50, 60],
            [1998, 3341, 24.19, 14.72],
            [1998, 3342, 32.24, 21.39],
            [1998, 3343, 120, 90],
            [1998, 3344, 99.81, 58.02],
            [1998, 3346, 62.21, 43.82],
            [1998, 3347, 120, 90],
            [1998, 3348, 70, 70],
            [1998, 3350, 35.02, 25.49],
            [1998, 3351, 35.02, 25.49],
            [1998, 3353, 120, 90],
            [1998, 3354, 50, 60],
            [1998, 3357, 12.58, 12.94],
            [1998, 3358, 19.2, 17.45],
            [1998, 3359, 120, 90],
            [1998, 3361, 120, 90],
            [1998, 3363, 14.08, 11.88],
            [1998, 3364, 70, 70],
            [1998, 3366, 120, 90],
            [1998, 3367, 50, 60],
            [1998, 3369, 120, 90],
            [1998, 3370, 70, 70],
            [1998, 3371, 70, 70],
            [1998, 3372, 70, 70],
            [1998, 3376, 35.02, 25.49],
            [1998, 3378, 9.02, 8.54],
            [1998, 3380, 120, 90],
            [1998, 3381, 120, 90],
            [1998, 3382, 23.2, 25.03],
            [1998, 3384, 120, 90],
            [1998, 3386, 120, 90],
            [1998, 3387, 70, 70],
            [1998, 3388, 120, 90],
            [1998, 3389, 70, 70],
            [1998, 3390, 120, 90],
            [1998, 3391, 120, 90],
            [1998, 3392, 120, 90],
            [1998, 3393, 120, 90],
            [1998, 3394, 120, 90],
            [1998, 3396, 31.22, 33.2],
            [1998, 3399, 70, 70],
            [1998, 3400, 40, 50],
            [1998, 3402, 120, 90],
            [1998, 3403, 16.87, 10.26],
            [1998, 3404, 41.37, 52.15],
            [1998, 3407, 59.05, 33.48],
            [1998, 3408, 35.02, 25.49],
            [1998, 3411, 70, 70],
            [1998, 3414, 50, 60],
            [1998, 3415, 40, 50],
            [1998, 3416, 40, 50],
            [1998, 3417, 70, 70],
            [1998, 3418, 120, 90],
            [1998, 3419, 70, 70],
            [1998, 3420, 70, 70],
            [1998, 3422, 50.99, 25.75],
            [1998, 3423, 120, 90],
            [1998, 3424, 37.5, 45],
            [1998, 3426, 120, 90],
            [1998, 3428, 70, 70],
            [1998, 3429, 46.45, 44.76],
            [1998, 3431, 120, 90],
            [1998, 3432, 70, 70],
            [1998, 3433, 70, 70],
            [1998, 3434, 6.86, 5.46],
            [1998, 3436, 50, 60],
            [1998, 3437, 70, 70],
            [1998, 3438, 70, 70],
            [1998, 3439, 60.72, 58.05],
            [1998, 3440, 50, 60],
            [1998, 3441, 59.78, 46.81],
            [1998, 3442, 42.15, 37.9],
            [1998, 3444, 30, 45],
            [1998, 3445, 70, 70],
            [1998, 3448, 5.56, 6.38],
            [1998, 3449, 70, 70],
            [1998, 3450, 70, 70],
            [1998, 3451, 120, 90],
            [1998, 3452, 120, 90],
            [1998, 3453, 15.33, 23.54],
            [1998, 3454, 18.63, 15.82],
            [1998, 3456, 120, 90],
            [1998, 3457, 120, 90],
            [1998, 3459, 120, 90],
            [1998, 3461, 70, 70],
            [1998, 3462, 70, 24.96],
            [1998, 3463, 120, 90],
            [1998, 3464, 120, 90],
            [1998, 3468, 73.94, 42.49],
            [1998, 3469, 34.89, 19.21],
            [1998, 3471, 70, 70],
            [1998, 3473, 22.49, 13.06],
            [1998, 3474, 70, 70],
            [1998, 3476, 40, 50],
            [1998, 3480, 120, 90],
            [1998, 3481, 70, 70],
            [1998, 3482, 32.24, 21.39],
            [1998, 3483, 70, 70],
            [1998, 3484, 120, 90],
            [1998, 3485, 50, 60],
            [1998, 3487, 20.67, 13.88],
            [1998, 3488, 50, 60],
            [1998, 3489, 40, 50],
            [1998, 3492, 120, 90],
            [1998, 3493, 70, 70],
            [1998, 3494, 40, 50],
            [1998, 3496, 120, 90],
            [1998, 3497, 120, 90],
            [1998, 3498, 40, 50],
            [1998, 3499, 120, 90],
            [1998, 3501, 120, 90],
            [1998, 3503, 120, 90],
            [1998, 3504, 70, 70],
            [1998, 3505, 120, 90],
            [1998, 3508, 120, 90],
            [1998, 3509, 50, 60],
            [1998, 3510, 120, 90],
            [1998, 3511, 70, 70],
            [1998, 3514, 50, 60],
            [1998, 3515, 70, 70],
            [1998, 3516, 120, 90],
            [1998, 3517, 70, 70],
            [1998, 3518, 120, 90],
            [1998, 3519, 50, 60],
            [1998, 3520, 120, 90],
            [1998, 3521, 120, 90],
            [1998, 3523, 35.02, 25.49],
            [1998, 3525, 120, 90],
            [1998, 3527, 120, 90],
            [1998, 3530, 70, 70],
            [1998, 3531, 70.97, 39.98],
            [1998, 3534, 70, 70],
            [1998, 3535, 30, 45],
            [1998, 3537, 120, 90],
            [1998, 3539, 120, 90],
            [1998, 3541, 42.81, 43.65],
            [1998, 3543, 120, 90],
            [1998, 3545, 120, 90],
            [1998, 3546, 35.02, 25.49],
            [1998, 3549, 22.69, 14.46],
            [1998, 3551, 120, 90],
            [1998, 3553, 70, 70],
            [1998, 3554, 50, 60],
            [1998, 3555, 40, 50],
            [1998, 3557, 16.81, 25.35],
            [1998, 3558, 70, 70],
            [1998, 3559, 50, 60],
            [1998, 3560, 120, 90],
            [1998, 3561, 120, 90],
            [1998, 3564, 120, 90],
            [1998, 3566, 17.61, 17.41],
            [1998, 3568, 12.22, 9.98],
            [1998, 3569, 50, 60],
            [1998, 3570, 70, 70],
            [1998, 3571, 70, 70],
            [1998, 3572, 120, 90],
            [1998, 3573, 120, 90],
            [1998, 3575, 120, 90],
            [1998, 3576, 120, 90],
            [1998, 3577, 120, 90],
            [1998, 3579, 40, 50],
            [1998, 3580, 70, 70],
            [1998, 3581, 120, 90],
            [1998, 3582, 4.45, 5.68],
            [1998, 3583, 120, 90],
            [1998, 3585, 70, 70],
            [1998, 3586, 70, 70],
            [1998, 3587, 70, 70],
            [1998, 3588, 120, 90],
            [1998, 3589, 70, 70],
            [1998, 3590, 40, 50],
            [1998, 3592, 70, 70],
            [1998, 3593, 70, 70],
            [1998, 3594, 120, 90],
            [1998, 3595, 120, 90],
            [1998, 3596, 35.02, 25.49],
            [1998, 3597, 70, 70],
            [1998, 3598, 22.96, 24.32],
            [1998, 3599, 120, 90],
            [1998, 3600, 70, 70],
            [1998, 3601, 40, 50],
            [1998, 3602, 51.79, 46.05],
            [1998, 3606, 40, 50],
            [1998, 3607, 70, 70],
            [1998, 3608, 33.57, 26.7],
            [1998, 3609, 120, 90],
            [1998, 3610, 50, 60],
            [1998, 3611, 70, 70],
            [1998, 3612, 70, 70],
            [1998, 3613, 40, 50],
            [1998, 3614, 9.76, 9.91],
            [1998, 3615, 70, 70],
            [1998, 3617, 70, 70],
            [1998, 3619, 70, 70],
            [1998, 3620, 50, 60],
            [1998, 3621, 50, 60],
            [1998, 3622, 120, 90],
            [1998, 3623, 120, 90],
            [1998, 3624, 18.29, 11.74],
            [1998, 3626, 120, 90],
            [1998, 3627, 120, 90],
            [1998, 3628, 30, 45],
            [1998, 3629, 32.24, 21.39],
            [1998, 3631, 70, 70],
            [1998, 3632, 47.16, 37.74],
            [1998, 3633, 70, 70],
            [1998, 3634, 24.1, 17.24],
            [1998, 3635, 50, 60],
            [1998, 3636, 70, 70],
            [1998, 3637, 40, 50],
            [1998, 3639, 120, 90],
            [1998, 3641, 40, 50],
            [1998, 3642, 58.18, 27.21],
            [1998, 3643, 70, 70],
            [1998, 3644, 36.34, 36.78],
            [1998, 3647, 120, 90],
            [1998, 3648, 70, 70],
            [1998, 3649, 120, 90],
            [1998, 3650, 93.96, 49.61],
            [1998, 3651, 40, 50],
            [1998, 3652, 40, 50],
            [1998, 3653, 52.81, 42.1],
            [1998, 3656, 16.63, 13.83],
            [1998, 3657, 40, 50],
            [1998, 3659, 120, 90],
            [1998, 3661, 49.38, 28.07],
            [1998, 3662, 30, 45],
            [1998, 3663, 120, 90],
            [1998, 3665, 120, 90],
            [1998, 3666, 35.02, 25.49],
            [1998, 3667, 30.55, 36.38],
            [1998, 3668, 120, 90],
            [1998, 3669, 50, 60],
            [1998, 3670, 91.39, 52.48],
            [1998, 3671, 120, 90],
            [1998, 3674, 70, 70],
            [1998, 3675, 120, 90],
            [1998, 3676, 120, 90],
            [1998, 3677, 50, 60],
            [1998, 3678, 6.48, 4.68],
            [1998, 3679, 29.5, 43.67],
            [1998, 3681, 70, 70],
            [1998, 3683, 70, 70],
            [1998, 3685, 120, 90],
            [1998, 3686, 35.02, 25.49],
            [1998, 3687, 70, 70],
            [1998, 3688, 120, 90],
            [1998, 3690, 120, 90],
            [1998, 3691, 14.78, 14.29],
            [1998, 3692, 50, 60],
            [1998, 3694, 70, 70],
            [1998, 3695, 35.02, 25.49],
            [1998, 3696, 70, 70],
            [1998, 3697, 20, 24],
            [1998, 3698, 120, 90],
            [1998, 3700, 25.38, 59.21],
            [1998, 3701, 40, 50],
            [1998, 3702, 18.29, 11.85],
            [1998, 3703, 175.88, 66.13],
            [1998, 3705, 14.08, 13.22],
            [1998, 3707, 70, 70],
            [1998, 3708, 70, 70],
            [1998, 3710, 50, 60],
            [1998, 3711, 15.93, 11.6],
            [1998, 3713, 70, 70],
            [1998, 3714, 120, 90],
            [1998, 3716, 120, 90],
            [1998, 3718, 70, 70],
            [1998, 3719, 35.02, 25.49],
            [1998, 3720, 50, 60],
            [1998, 3722, 40, 50],
            [1998, 3723, 30, 45],
            [1998, 3724, 12.29, 14.45],
            [1998, 3726, 70, 70],
            [1998, 3728, 120, 90],
            [1998, 3729, 120, 90],
            [1998, 3731, 120, 90],
            [1998, 3733, 120, 90],
            [1998, 3738, 30, 45],
            [1998, 3741, 120, 90],
            [1998, 3744, 120, 90],
            [1998, 3745, 120, 90],
            [1998, 3747, 33.24, 30.21],
            [1998, 3748, 120, 90],
            [1998, 3749, 35.02, 25.49],
            [1998, 3751, 27.22, 22.15],
            [1998, 3752, 120, 90],
            [1998, 3753, 50, 60],
            [1998, 3754, 120, 90],
            [1998, 3755, 31.04, 34.22],
            [1998, 3756, 120, 90],
            [1998, 3757, 70, 70],
            [1998, 3758, 120, 90],
            [1998, 3759, 120, 90],
            [1998, 3761, 36.17, 17.01],
            [1998, 3762, 50, 60],
            [1998, 3763, 70, 70],
            [1998, 3764, 50, 60],
            [1998, 3765, 36.87, 29.24],
            [1998, 3766, 50, 60],
            [1998, 3768, 70, 70],
            [1998, 3769, 120, 90],
            [1998, 3775, 50, 60],
            [1998, 3776, 120, 90],
            [1998, 3777, 64.75, 33.71],
            [1998, 3780, 70, 70],
            [1998, 3781, 120, 90],
            [1998, 3782, 33.84, 17.76],
            [1998, 3783, 70, 70],
            [1998, 3785, 35.02, 25.49],
            [1998, 3786, 50, 60],
            [1998, 3791, 120, 90],
            [1998, 3792, 120, 90],
            [1998, 3793, 70, 70],
            [1998, 3795, 28.93, 71.01],
            [1998, 3796, 34.35, 19.61],
            [1998, 3797, 120, 90],
            [1998, 3799, 50, 60],
            [1998, 3800, 70, 70],
            [1998, 3801, 120, 90],
            [1998, 3802, 50, 60],
            [1998, 3804, 70, 70],
            [1998, 3807, 23.88, 19.39],
            [1998, 3811, 50, 60],
            [1998, 3812, 120, 90],
            [1998, 3814, 70, 70],
            [1998, 3815, 11.6, 10.05],
            [1998, 3816, 120, 90],
            [1998, 3818, 40, 50],
            [1998, 3820, 50, 60],
            [1998, 3821, 120, 90],
            [1998, 3822, 120, 90],
            [1998, 3824, 70, 70],
            [1998, 3826, 70, 70],
            [1998, 3827, 104.49, 49.9],
            [1998, 3828, 48.71, 27.21],
            [1998, 3830, 8.66, 6.14],
            [1998, 3832, 58.73, 69.61],
            [1998, 3833, 30, 45],
            [1998, 3834, 82.66, 53.29],
            [1998, 3837, 70, 70],
            [1998, 3839, 120, 90],
            [1998, 3840, 120, 90],
            [1998, 3841, 115.85, 58.55],
            [1998, 3842, 50, 60],
            [1998, 3843, 120, 90],
            [1998, 3845, 16.28, 21.19],
            [1998, 3846, 70, 70],
            [1998, 3849, 32.24, 21.39],
            [1998, 3850, 120, 90],
            [1998, 3851, 120, 90],
            [1998, 3853, 35.02, 25.49],
            [1998, 3854, 20.59, 23],
            [1998, 3855, 120, 90],
            [1998, 3856, 120, 90],
            [1998, 3858, 120, 90],
            [1998, 3859, 70, 70],
            [1998, 3862, 70, 70],
            [1998, 3863, 50, 60],
            [1998, 3865, 120, 90],
            [1998, 3866, 15.15, 16.66],
            [1998, 3867, 35.02, 25.49],
            [1998, 3868, 120, 90],
            [1998, 3869, 16, 20],
            [1998, 3870, 113.75, 53.42],
            [1998, 3871, 46.79, 28.4],
            [1998, 3873, 120, 90],
            [1998, 3874, 41.13, 34.16],
            [1998, 3877, 40, 50],
            [1998, 3879, 120, 90],
            [1998, 3880, 19.75, 22.98],
            [1998, 3881, 50, 60],
            [1998, 3882, 120, 90],
            [1998, 3883, 57.22, 73.4],
            [1998, 3884, 70, 70],
            [1998, 3886, 70, 70],
            [1998, 3887, 120, 90],
            [1998, 3889, 70, 70],
            [1998, 3890, 10.56, 9.77],
            [1998, 3891, 70, 70],
            [1998, 3892, 70, 70],
            [1998, 3896, 70, 70],
            [1998, 3897, 46.88, 27.21],
            [1998, 3898, 120, 90],
            [1998, 3899, 120, 90],
            [1998, 3900, 50.61, 29.08],
            [1998, 3901, 70, 70],
            [1998, 3903, 50, 60],
            [1998, 3905, 90.98, 55.27],
            [1998, 3906, 70, 70],
            [1998, 3909, 120, 90],
            [1998, 3910, 32.24, 21.39],
            [1998, 3915, 30, 45],
            [1998, 3916, 120, 90],
            [1998, 3918, 8.88, 7.78],
            [1998, 3919, 120, 90],
            [1998, 3921, 34.37, 32.04],
            [1998, 3922, 120, 90],
            [1998, 3923, 70, 70],
            [1998, 3924, 14.82, 9.49],
            [1998, 3925, 120, 90],
            [1998, 3927, 70, 70],
            [1998, 3928, 19.06, 19.47],
            [1998, 3929, 120, 90],
            [1998, 3930, 70, 70],
            [1998, 3931, 70, 70],
            [1998, 3932, 32.72, 42.52],
            [1998, 3933, 120, 90],
            [1998, 3935, 120, 90],
            [1998, 3936, 120, 90],
            [1998, 3937, 70, 70],
            [1998, 3938, 50, 60],
            [1998, 3939, 50, 60],
            [1998, 3940, 50, 60],
            [1998, 3941, 120, 90],
            [1998, 3942, 32.24, 20.58],
            [1998, 3943, 16.04, 19.53],
            [1998, 3944, 35.02, 25.49],
            [1998, 3946, 13.42, 11.21],
            [1998, 3947, 120, 90],
            [1998, 3950, 120, 90],
            [1998, 3951, 120, 90],
            [1998, 3952, 120, 90],
            [1998, 3953, 130.15, 56.8],
            [1998, 3954, 120, 90],
            [1998, 3956, 50, 60],
            [1998, 3958, 13.07, 12.08],
            [1998, 3959, 107.55, 47.75],
            [1998, 3960, 26.79, 20.82],
            [1998, 3961, 10.48, 9.83],
            [1998, 3963, 24.93, 29.76],
            [1998, 3964, 70, 70],
            [1998, 3966, 70, 70],
            [1998, 3968, 40, 50],
            [1998, 3969, 73.5, 49.04],
            [1998, 3970, 22.45, 62.54],
            [1998, 3971, 120, 90],
            [1998, 3972, 120, 90],
            [1998, 3976, 70, 70],
            [1998, 3978, 70, 70],
            [1998, 3979, 70, 70],
            [1998, 3980, 50, 60],
            [1998, 3981, 70, 70],
            [1998, 3982, 120, 90],
            [1998, 3983, 30, 45],
            [1998, 3985, 70, 70],
            [1998, 3988, 120, 90],
            [1998, 3990, 70, 70],
            [1998, 3991, 120, 90],
            [1998, 3992, 53.73, 58.98],
            [1998, 3993, 70, 70],
            [1998, 3994, 120, 90],
            [1998, 3996, 70, 70],
            [1998, 3997, 120, 90],
            [1998, 3998, 120, 90],
            [1998, 3999, 29.09, 38.47],
            [1998, 4001, 120, 90],
            [1998, 4002, 120, 90],
            [1998, 4003, 70, 70],
            [1998, 4004, 70, 70],
            [1998, 4005, 40, 50],
            [1998, 4007, 120, 90],
            [1998, 4008, 70, 70],
            [1998, 4009, 40, 50],
            [1998, 4010, 50, 60],
            [1998, 4012, 120, 90],
            [1998, 4013, 120, 90],
            [1998, 4014, 120, 90],
            [1998, 4015, 120, 90],
            [1998, 4016, 21, 33],
            [1998, 4017, 70, 70],
            [1998, 4018, 70, 70],
            [1998, 4019, 40, 50],
            [1998, 4021, 70, 70],
            [1998, 4022, 70, 70],
            [1998, 4023, 27.39, 27.85],
            [1998, 4024, 120, 90],
            [1998, 4025, 70, 70],
            [1998, 4026, 70, 70],
            [1998, 4027, 120, 90],
            [1998, 4028, 70, 70],
            [1998, 4031, 28.52, 48.27],
            [1998, 4033, 70, 70],
            [1998, 4034, 120, 90],
            [1998, 4035, 17.68, 13.86],
            [1998, 4038, 120, 90],
            [1998, 4040, 85.79, 70.07],
            [1998, 4041, 120, 90],
            [1998, 4043, 70, 70],
            [1998, 4045, 10.74, 9.07],
            [1998, 4047, 44.52, 35.91],
            [1998, 4048, 50, 60],
            [1998, 4049, 70, 70],
            [1998, 4051, 120, 90],
            [1998, 4053, 70, 70],
            [1998, 4057, 50, 60],
            [1998, 4059, 70, 70],
            [1998, 4062, 70, 70],
            [1998, 4063, 50, 60],
            [1998, 4065, 50, 60],
            [1998, 4066, 70, 70],
            [1998, 4067, 70, 70],
            [1998, 4068, 120, 90],
            [1998, 4069, 50, 60],
            [1998, 4070, 70, 70],
            [1998, 4071, 70, 70],
            [1998, 4072, 120, 90],
            [1998, 4073, 30, 45],
            [1998, 4074, 70, 70],
            [1998, 4076, 120, 90],
            [1998, 4080, 120, 90],
            [1998, 4081, 120, 90],
            [1998, 4082, 120, 90],
            [1998, 4083, 120, 90],
            [1998, 4084, 14, 13.72],
            [1998, 4085, 70, 70],
            [1998, 4087, 120, 90],
            [1998, 4088, 120, 90],
            [1998, 4089, 120, 90],
            [1998, 4090, 120, 90],
            [1998, 4091, 70, 70],
            [1998, 4092, 70, 70],
            [1998, 4093, 120, 90],
            [1998, 4094, 32.24, 21.39],
            [1998, 4095, 37.45, 42.54],
            [1998, 4096, 37.85, 49.46],
            [1998, 4097, 120, 90],
            [1998, 4100, 50, 60],
            [1998, 4101, 120, 90],
            [1998, 4102, 70, 70],
            [1998, 4103, 70, 70],
            [1998, 4104, 70, 70],
            [1998, 4105, 120, 90],
            [1998, 4106, 12.41, 18.24],
            [1998, 4107, 120, 90],
            [1998, 4108, 120, 90],
            [1998, 4109, 11.09, 23.39],
            [1998, 4110, 70, 70],
            [1998, 4111, 53.38, 47.38],
            [1998, 4112, 40, 50],
            [1998, 4115, 120, 90],
            [1998, 4116, 31.55, 32.55],
            [1998, 4117, 50, 60],
            [1998, 4118, 41.47, 35.71],
            [1998, 4119, 35.02, 25.49],
            [1998, 4120, 27.58, 30.03],
            [1998, 4121, 70, 70],
            [1998, 4122, 120, 90],
            [1998, 4124, 46.81, 38.06],
            [1998, 4125, 70, 70],
            [1998, 4128, 70, 70],
            [1998, 4129, 14.49, 12.39],
            [1998, 4131, 16.41, 11.51],
            [1998, 4133, 70, 70],
            [1998, 4134, 79.03, 44.3],
            [1998, 4136, 50, 60],
            [1998, 4137, 120, 90],
            [1998, 4138, 11.77, 6.96],
            [1998, 4139, 30, 45],
            [1998, 4140, 70, 70],
            [1998, 4142, 70, 70],
            [1998, 4143, 50, 60],
            [1998, 4145, 120, 90],
            [1998, 4146, 6.49, 5.75],
            [1998, 4147, 120, 90],
            [1998, 4149, 50, 60],
            [1998, 4150, 70, 70],
            [1998, 4152, 106.07, 54.99],
            [1998, 4154, 120, 90],
            [1998, 4155, 70, 70],
            [1998, 4156, 76.31, 53.54],
            [1998, 4157, 70, 70],
            [1998, 4158, 120, 90],
            [1998, 4159, 6.8, 6.9],
            [1998, 4162, 120, 90],
            [1998, 4164, 20.48, 22.01],
            [1998, 4165, 120, 90],
            [1998, 4166, 30, 45],
            [1998, 4167, 70, 70],
            [1998, 4168, 37.5, 45],
            [1998, 4169, 35.25, 45.76],
            [1998, 4173, 50, 60],
            [1998, 4175, 40, 50],
            [1998, 4176, 50, 60],
            [1998, 4177, 40.07, 56.69],
            [1998, 4178, 120, 90],
            [1998, 4179, 23.41, 16.69],
            [1998, 4180, 14.1, 9.29],
            [1998, 4181, 70, 70],
            [1998, 4182, 76.84, 36.41],
            [1998, 4185, 27.78, 27.06],
            [1998, 4186, 50, 60],
            [1998, 4188, 120, 90],
            [1998, 4189, 50, 60],
            [1998, 4190, 120, 90],
            [1998, 4192, 50, 60],
            [1998, 4193, 120, 90],
            [1998, 4194, 120, 90],
            [1998, 4197, 50, 60],
            [1998, 4199, 78.4, 74.93],
            [1998, 4200, 13.33, 9.28],
            [1998, 4203, 62.98, 58.18],
            [1998, 4204, 50, 60],
            [1998, 4205, 120, 90],
            [1998, 4206, 40, 50],
            [1998, 4207, 50, 60],
            [1998, 4208, 120, 90],
            [1998, 4209, 120, 90],
            [1998, 4210, 40, 50],
            [1998, 4211, 120, 90],
            [1998, 4213, 70, 70],
            [1998, 4215, 35.02, 25.49],
            [1998, 4216, 120, 90],
            [1998, 4219, 30, 45],
            [1998, 4220, 120, 90],
            [1998, 4221, 32.24, 21.39],
            [1998, 4222, 120, 90],
            [1998, 4223, 9.96, 8.54],
            [1998, 4224, 70, 70],
            [1998, 4225, 120, 90],
            [1998, 4226, 73.7, 42.65],
            [1998, 4229, 36.01, 22.9],
            [1998, 4230, 70, 70],
            [1998, 4231, 70, 70],
            [1998, 4232, 40, 50],
            [1998, 4233, 40, 50],
            [1998, 4234, 50, 60],
            [1998, 4235, 13.03, 13.29],
            [1998, 4236, 70, 70],
            [1998, 4237, 120, 90],
            [1998, 4238, 120, 90],
            [1998, 4239, 120, 90],
            [1998, 4241, 120, 90],
            [1998, 4242, 46.74, 74.49],
            [1998, 4244, 11.58, 16.71],
            [1998, 4245, 50, 60],
            [1998, 4246, 23.77, 36.35],
            [1998, 4248, 70, 70],
            [1998, 4249, 120, 90],
            [1998, 4250, 120, 90],
            [1998, 4251, 120, 90],
            [1998, 4252, 11.19, 9.3],
            [1998, 4256, 50, 60],
            [1998, 4257, 40, 50],
            [1998, 4258, 50, 60],
            [1998, 4259, 12.25, 12.29],
            [1998, 4260, 120, 90],
            [1998, 4261, 20, 24],
            [1998, 4264, 13.05, 10.17],
            [1998, 4265, 70, 70],
            [1998, 4266, 120, 90],
            [1998, 4269, 120, 90],
            [1998, 4270, 120, 90],
            [1998, 4272, 98.28, 54.81],
            [1998, 4273, 120, 90],
            [1998, 4274, 120, 90],
            [1998, 4275, 70, 70],
            [1998, 4279, 25.11, 25.86],
            [1998, 4281, 70, 70],
            [1998, 4282, 50, 60],
            [1998, 4283, 19.15, 24.03],
            [1998, 4284, 120, 90],
            [1998, 4285, 50, 60],
            [1998, 4286, 120, 90],
            [1998, 4287, 25.96, 16.87],
            [1998, 4288, 120, 90],
            [1998, 4289, 64.74, 40.71],
            [1998, 4290, 50, 60],
            [1998, 4291, 50, 60],
            [1998, 4293, 9.17, 7.22],
            [1998, 4294, 120, 90],
            [1998, 4295, 120, 90],
            [1998, 4296, 120, 90],
            [1998, 4297, 70, 70],
            [1998, 4298, 120, 90],
            [1998, 4299, 70, 70],
            [1998, 4301, 70, 70],
            [1998, 4302, 26.64, 23.08],
            [1998, 4305, 70, 70],
            [1998, 4307, 120, 90],
            [1998, 4308, 120, 90],
            [1998, 4309, 50, 60],
            [1998, 4310, 50, 60],
            [1998, 4312, 70, 70],
            [1998, 4313, 120, 90],
            [1998, 4317, 50, 60],
            [1998, 4318, 44.5, 31.24],
            [1998, 4320, 70, 70],
            [1998, 4323, 30, 45],
            [1998, 4325, 29.6, 19.97],
            [1998, 4326, 40, 50],
            [1998, 4328, 70, 70],
            [1998, 4329, 24.49, 21.37],
            [1998, 4330, 70, 70],
            [1998, 4333, 17.64, 32.54],
            [1998, 4334, 120, 90],
            [1998, 4337, 40, 50],
            [1998, 4338, 19.83, 26.04],
            [1998, 4339, 30, 45],
            [1998, 4340, 120, 90],
            [1998, 4341, 120, 90],
            [1998, 4343, 120, 90],
            [1998, 4345, 64.97, 47.25],
            [1998, 4346, 70, 70],
            [1998, 4347, 120, 90],
            [1998, 4349, 19.92, 20.51],
            [1998, 4350, 45.83, 36.77],
            [1998, 4352, 27.75, 35.04],
            [1998, 4353, 40.7, 33.52],
            [1998, 4355, 120, 90],
            [1998, 4356, 40, 50],
            [1998, 4358, 23.24, 26.31],
            [1998, 4360, 70, 70],
            [1998, 4362, 57.64, 39.46],
            [1998, 4363, 70, 70],
            [1998, 4364, 60.02, 38.25],
            [1998, 4365, 120, 90],
            [1998, 4366, 70, 70],
            [1998, 4367, 120, 90],
            [1998, 4372, 70, 70],
            [1998, 4374, 40, 50],
            [1998, 4375, 70, 70],
            [1998, 4376, 120, 90],
            [1998, 4377, 70, 70],
            [1998, 4378, 70, 70],
            [1998, 4380, 70, 70],
            [1998, 4382, 70, 70],
            [1998, 4383, 70, 70],
            [1998, 4384, 41.7, 25.8],
            [1998, 4386, 70, 70],
            [1998, 4387, 120, 90],
            [1998, 4389, 70, 70],
            [1998, 4390, 35.02, 25.49],
            [1998, 4391, 21.62, 31.72],
            [1998, 4392, 70, 70],
            [1998, 4394, 70, 70],
            [1998, 4395, 70, 70],
            [1998, 4396, 70, 70],
            [1998, 4397, 10.73, 9.29],
            [1998, 4398, 70, 70],
            [1998, 4399, 50, 60],
            [1998, 4400, 120, 90],
            [1998, 4402, 40, 50],
            [1998, 4404, 120, 90],
            [1998, 4405, 6.35, 4.6],
            [1998, 4406, 63.31, 68.07],
            [1998, 4407, 70, 70],
            [1998, 4408, 120, 90],
            [1998, 4409, 120, 90],
            [1998, 4410, 70, 70],
            [1998, 4411, 120, 90],
            [1998, 4412, 120, 90],
            [1998, 4413, 50, 60],
            [1998, 4414, 70, 70],
            [1998, 4415, 126.64, 97.53],
            [1998, 4416, 70, 70],
            [1998, 4417, 50, 60],
            [1998, 4418, 70, 70],
            [1998, 4419, 70, 70],
            [1998, 4420, 7.46, 6.7],
            [1998, 4421, 76.43, 44.44],
            [1998, 4426, 70, 70],
            [1998, 4427, 40, 50],
            [1998, 4428, 32.24, 21.39],
            [1998, 4432, 32.24, 21.39],
            [1998, 4433, 120, 90],
            [1998, 4436, 40, 50],
            [1998, 4438, 50, 60],
            [1998, 4439, 40, 50],
            [1998, 4440, 70, 70],
            [1998, 4441, 120, 90],
            [1998, 4442, 70, 70],
            [1998, 4443, 70, 70],
            [1998, 4444, 120, 90],
            [1998, 4445, 70, 70],
            [1998, 4446, 34.09, 21.45],
            [1998, 4448, 70, 70],
            [1998, 4450, 120, 90],
            [1998, 4453, 70, 70],
            [1998, 4454, 25.13, 30.27],
            [1998, 4455, 70, 70],
            [1998, 4456, 70, 70],
            [1998, 4457, 40, 50],
            [1998, 4460, 120, 90],
            [1998, 4461, 25.09, 25.72],
            [1998, 4463, 50, 60],
            [1998, 4464, 44.69, 25.78],
            [1998, 4465, 70, 70],
            [1998, 4466, 70, 70],
            [1998, 4467, 120, 90],
            [1998, 4468, 70, 70],
            [1998, 4470, 50, 60],
            [1998, 4471, 135.92, 55.65],
            [1998, 4473, 32.24, 21.39],
            [1998, 4477, 37.5, 45],
            [1998, 4479, 120, 90],
            [1998, 4481, 120, 90],
            [1998, 4482, 120, 90],
            [1998, 4483, 120, 90],
            [1998, 4484, 120, 90],
            [1998, 4486, 120, 90],
            [1998, 4487, 50, 60],
            [1998, 4488, 70, 70],
            [1998, 4489, 11.71, 6.08],
            [1998, 4490, 120, 90],
            [1998, 4491, 70, 70],
            [1998, 4493, 70, 70],
            [1998, 4494, 120, 90],
            [1998, 4495, 82.86, 52.5],
            [1998, 4497, 50, 60],
            [1998, 4498, 70, 70],
            [1998, 4500, 17.11, 23.93],
            [1998, 4501, 120, 90],
            [1998, 4502, 50, 60],
            [1998, 4504, 29.9, 16.62],
            [1998, 4505, 70, 70],
            [1998, 4506, 32.1, 29.68],
            [1998, 4508, 120, 90],
            [1998, 4509, 120, 90],
            [1998, 4510, 33.56, 26.64],
            [1998, 4511, 70, 70],
            [1998, 4512, 12.38, 7.83],
            [1998, 4513, 120, 90],
            [1998, 4514, 120, 90],
            [1998, 4515, 33.39, 72.42],
            [1998, 4517, 50, 60],
            [1998, 4518, 72.62, 43.09],
            [1998, 4520, 50, 60],
            [1998, 4521, 115.81, 56],
            [1998, 4523, 50, 60],
            [1998, 4524, 25.93, 22.72],
            [1998, 4525, 50, 60],
            [1998, 4526, 9.64, 9.7],
            [1998, 4527, 120, 90],
            [1998, 4530, 13.96, 9.89],
            [1998, 4531, 120, 90],
            [1998, 4532, 66.87, 50.91],
            [1998, 4533, 70, 70],
            [1998, 4534, 70, 70],
            [1998, 4535, 120, 90],
            [1998, 4536, 70, 70],
            [1998, 4538, 70, 70],
            [1998, 4539, 40, 50],
            [1998, 4540, 10.59, 6.68],
            [1998, 4541, 120, 90],
            [1998, 4542, 70, 70],
            [1998, 4543, 37.5, 45],
            [1998, 4545, 70, 70],
            [1998, 4546, 120, 90],
            [1998, 4548, 20.54, 15.72],
            [1998, 4549, 40, 50],
            [1998, 4550, 65.66, 48.34],
            [1998, 4551, 120, 90],
            [1998, 4552, 55.6, 45.56],
            [1998, 4553, 120, 90],
            [1998, 4555, 120, 90],
            [1998, 4556, 120, 90],
            [1998, 4558, 120, 90],
            [1998, 4560, 120, 90],
            [1998, 4563, 53.86, 28.78],
            [1998, 4565, 70, 70],
            [1998, 4566, 70, 70],
            [1998, 4568, 70, 70],
            [1998, 4569, 70, 70],
            [1998, 4571, 70, 70],
            [1998, 4572, 105.72, 48.73],
            [1998, 4576, 120, 90],
            [1998, 4577, 16.43, 13.85],
            [1998, 4578, 70, 70],
            [1998, 4579, 9.23, 6.62],
            [1998, 4580, 50, 60],
            [1998, 4582, 70, 70],
            [1998, 4584, 40, 50],
            [1998, 4585, 70, 70],
            [1998, 4587, 120, 90],
            [1998, 4590, 70, 70],
            [1998, 4591, 38.76, 40.37],
            [1998, 4593, 7.89, 6.27],
            [1998, 4597, 120, 90],
            [1998, 4598, 120, 90],
            [1998, 4599, 35.02, 25.49],
            [1998, 4600, 50, 60],
            [1998, 4601, 33.72, 42.28],
            [1998, 4602, 36.28, 36.4],
            [1998, 4603, 120, 90],
            [1998, 4604, 120, 90],
            [1998, 4605, 50, 60],
            [1998, 4606, 35.1, 31.57],
            [1998, 4607, 120, 90],
            [1998, 4608, 50, 60],
            [1998, 4610, 70, 70],
            [1998, 4611, 62.95, 50.94],
            [1998, 4612, 120, 90],
            [1998, 4613, 70, 70],
            [1998, 4614, 70, 70],
            [1998, 4615, 120, 90],
            [1998, 4616, 27.98, 41.56],
            [1998, 4617, 95.75, 69.39],
            [1998, 4618, 70, 70],
            [1998, 4619, 70, 70],
            [1998, 4620, 70, 70],
            [1998, 4621, 50, 60],
            [1998, 4622, 120, 90],
            [1998, 4623, 70, 70],
            [1998, 4626, 40, 50],
            [1998, 4627, 70, 70],
            [1998, 4628, 120, 90],
            [1998, 4629, 70, 70],
            [1998, 4630, 120, 90],
            [1998, 4631, 20.43, 22.07],
            [1998, 4633, 28.23, 35.68],
            [1998, 4634, 70, 70],
            [1998, 4635, 16.11, 11.7],
            [1998, 4636, 120, 90],
            [1998, 4637, 70, 70],
            [1998, 4638, 54.7, 34.62],
            [1998, 4641, 15.54, 8.85],
            [1998, 4643, 120, 90],
            [1998, 4644, 70, 70],
            [1998, 4645, 32.24, 21.39],
            [1998, 4648, 50, 60],
            [1998, 4649, 50, 60],
            [1998, 4651, 70, 70],
            [1998, 4652, 50, 60],
            [1998, 4653, 120, 90],
            [1998, 4655, 120, 90],
            [1998, 4657, 120, 90],
            [1998, 4658, 70, 70],
            [1998, 4660, 70, 70],
            [1998, 4661, 32.24, 21.39],
            [1998, 4662, 70, 70],
            [1998, 4664, 10.86, 8.78],
            [1998, 4665, 120, 90],
            [1998, 4666, 120, 90],
            [1998, 4667, 70, 70],
            [1998, 4668, 62.61, 42.44],
            [1998, 4670, 70, 70],
            [1998, 4671, 120, 90],
            [1998, 4674, 15, 20],
            [1998, 4675, 50, 60],
            [1998, 4676, 13.79, 18.19],
            [1998, 4677, 70, 70],
            [1998, 4679, 120, 90],
            [1998, 4680, 120, 90],
            [1998, 4682, 120, 90],
            [1998, 4684, 39.81, 23.32],
            [1998, 4685, 61.3, 38.03],
            [1998, 4687, 120, 90],
            [1998, 4688, 17.49, 12.85],
            [1998, 4689, 70, 70],
            [1998, 4690, 32.24, 21.39],
            [1998, 4691, 40, 50],
            [1998, 4692, 70, 70],
            [1998, 4693, 119.12, 52.9],
            [1998, 4694, 58.28, 38.29],
            [1998, 4695, 70, 70],
            [1998, 4696, 120, 90],
            [1998, 4697, 120, 90],
            [1998, 4698, 70, 70],
            [1998, 4699, 120, 90],
            [1998, 4701, 70, 70],
            [1998, 4702, 120, 90],
            [1998, 4703, 23.69, 36.87],
            [1998, 4704, 120, 90],
            [1998, 4705, 120, 90],
            [1998, 4708, 70, 70],
            [1998, 4709, 120, 90],
            [1998, 4710, 10.6, 9.61],
            [1998, 4711, 120, 90],
            [1998, 4712, 50.55, 38.31],
            [1998, 4713, 50, 60],
            [1998, 4716, 35.02, 25.49],
            [1998, 4717, 29.78, 34.18],
            [1998, 4718, 120, 90],
            [1998, 4720, 50, 60],
            [1998, 4722, 120, 90],
            [1998, 4724, 50, 60],
            [1998, 4725, 8.65, 7.78],
            [1998, 4726, 120, 90],
            [1998, 4728, 25.36, 23.41],
            [1998, 4729, 68.67, 36.75],
            [1998, 4731, 4.74, 5.56],
            [1998, 4732, 50, 60],
            [1998, 4733, 70, 70],
            [1998, 4734, 40, 50],
            [1998, 4736, 32.24, 21.39],
            [1998, 4737, 120, 90],
            [1998, 4738, 120, 90],
            [1998, 4740, 70, 70],
            [1998, 4741, 70, 70],
            [1998, 4742, 120, 90],
            [1998, 4743, 32.24, 21.39],
            [1998, 4744, 40, 50],
            [1998, 4745, 40, 50],
            [1998, 4747, 55.87, 35.31],
            [1998, 4749, 70, 70],
            [1998, 4750, 9.46, 11.76],
            [1998, 4751, 50, 60],
            [1998, 4752, 70, 70],
            [1998, 4753, 88.11, 37.86],
            [1998, 4754, 120, 90],
            [1998, 4755, 14.14, 10.28],
            [1998, 4756, 40, 50],
            [1998, 4757, 120, 90],
            [1998, 4760, 120, 90],
            [1998, 4761, 22.44, 14.33],
            [1998, 4762, 52.5, 52.5],
            [1998, 4764, 120, 90],
            [1998, 4765, 50, 60],
            [1998, 4771, 70, 70],
            [1998, 4772, 70, 70],
            [1998, 4775, 32.24, 21.39],
            [1998, 4776, 37.5, 45],
            [1998, 4777, 24.04, 33.32],
            [1998, 4778, 50, 60],
            [1998, 4779, 70, 70],
            [1998, 4780, 110.99, 50.6],
            [1998, 4781, 30, 37.5],
            [1998, 4782, 70, 70],
            [1998, 4784, 120, 90],
            [1998, 4785, 120, 90],
            [1998, 4786, 120, 90],
            [1998, 4788, 50, 60],
            [1998, 4789, 70, 70],
            [1998, 4790, 70, 70],
            [1998, 4791, 48.77, 79.01],
            [1998, 4792, 70, 70],
            [1998, 4793, 120, 90],
            [1998, 4794, 70, 70],
            [1998, 4797, 50, 60],
            [1998, 4799, 70, 70],
            [1998, 4800, 17.87, 23.42],
            [1998, 4801, 70, 70],
            [1998, 4802, 128.4, 56.12],
            [1998, 4803, 70, 70],
            [1998, 4805, 70, 70],
            [1998, 4806, 70, 70],
            [1998, 4807, 50, 60],
            [1998, 4809, 120, 90],
            [1998, 4810, 120, 90],
            [1998, 4811, 50, 60],
            [1998, 4812, 120, 90],
            [1998, 4813, 50, 60],
            [1998, 4814, 120, 90],
            [1998, 4815, 39.69, 32.93],
            [1998, 4816, 70, 70],
            [1998, 4818, 120, 90],
            [1998, 4819, 57.44, 40.47],
            [1998, 4820, 70, 70],
            [1998, 4821, 120, 90],
            [1998, 4825, 120, 90],
            [1998, 4826, 28.39, 26.06],
            [1998, 4828, 70, 70],
            [1998, 4829, 45.03, 39.57],
            [1998, 4831, 9.72, 8.44],
            [1998, 4832, 70, 70],
            [1998, 4834, 120, 90],
            [1998, 4835, 51.6, 40.69],
            [1998, 4838, 40, 50],
            [1998, 4839, 37.82, 38.91],
            [1998, 4840, 70, 70],
            [1998, 4841, 120, 90],
            [1998, 4842, 120, 90],
            [1998, 4844, 49.21, 40.22],
            [1998, 4846, 120, 90],
            [1998, 4848, 120, 90],
            [1998, 4849, 40, 50],
            [1998, 4851, 120, 90],
            [1998, 4852, 70, 70],
            [1998, 4853, 70, 70],
            [1998, 4854, 120, 90],
            [1998, 4856, 120, 90],
            [1998, 4863, 70, 70],
            [1998, 4864, 8.85, 15.97],
            [1998, 4865, 40, 50],
            [1998, 4866, 15, 25],
            [1998, 4867, 120, 90],
            [1998, 4869, 120, 90],
            [1998, 4871, 21.01, 27.1],
            [1998, 4872, 26.5, 30.18],
            [1998, 4875, 70, 70],
            [1998, 4876, 40, 50],
            [1998, 4877, 18.65, 29.18],
            [1998, 4878, 50, 60],
            [1998, 4879, 120, 90],
            [1998, 4880, 70, 70],
            [1998, 4881, 32.11, 49.85],
            [1998, 4882, 120, 90],
            [1998, 4885, 120, 90],
            [1998, 4887, 120, 90],
            [1998, 4888, 70, 70],
            [1998, 4893, 50, 60],
            [1998, 4894, 50, 60],
            [1998, 4895, 120, 90],
            [1998, 4896, 70, 70],
            [1998, 4897, 22.65, 32.49],
            [1998, 4902, 70, 70],
            [1998, 4905, 40, 50],
            [1998, 4906, 40, 50],
            [1998, 4907, 70, 70],
            [1998, 4909, 40, 50],
            [1998, 4910, 16.17, 15.54],
            [1998, 4911, 11.82, 7.07],
            [1998, 4912, 12.39, 15.28],
            [1998, 4914, 120, 90],
            [1998, 4915, 12.81, 25.88],
            [1998, 4916, 70, 70],
            [1998, 4918, 29.8, 29.23],
            [1998, 4920, 50, 60],
            [1998, 4922, 68.28, 37.1],
            [1998, 4923, 120, 90],
            [1998, 4926, 120, 90],
            [1998, 4927, 28.01, 18.8],
            [1998, 4928, 70, 70],
            [1998, 4929, 70, 70],
            [1998, 4930, 70, 70],
            [1998, 4931, 34.13, 33.6],
            [1998, 4934, 70, 70],
            [1998, 4936, 120, 90],
            [1998, 4939, 28.05, 30.31],
            [1998, 4940, 95.48, 82.93],
            [1998, 4942, 50, 60],
            [1998, 4944, 70, 70],
            [1998, 4945, 120, 90],
            [1998, 4946, 120, 90],
            [1998, 4949, 50, 60],
            [1998, 4950, 70.53, 51.44],
            [1998, 4951, 70, 70],
            [1998, 4953, 35.02, 25.49],
            [1998, 4954, 70, 70],
            [1998, 4955, 25.46, 23.67],
            [1998, 4956, 32.24, 21.39],
            [1998, 4957, 64.8, 59.23],
            [1998, 4958, 120, 90],
            [1998, 4960, 101.39, 50.61],
            [1998, 4962, 70, 70],
            [1998, 4963, 70, 70],
            [1998, 4964, 7.37, 6.44],
            [1998, 4965, 50, 60],
            [1998, 4966, 70, 70],
            [1998, 4968, 120, 90],
            [1998, 4971, 32.24, 21.39],
            [1998, 4972, 35.02, 25.49],
            [1998, 4973, 70, 70],
            [1998, 4974, 50, 60],
            [1998, 4975, 49.84, 42.61],
            [1998, 4976, 40, 50],
            [1998, 4977, 120, 90],
            [1998, 4978, 120, 90],
            [1998, 4979, 56.77, 40.85],
            [1998, 4981, 50, 60],
            [1998, 4983, 29.76, 20.92],
            [1998, 4984, 40, 50],
            [1998, 4985, 6.45, 5.95],
            [1998, 4987, 55.01, 32.18],
            [1998, 4988, 70, 70],
            [1998, 4989, 120, 90],
            [1998, 4990, 106.41, 53.31],
            [1998, 4992, 45.11, 33.84],
            [1998, 4994, 120, 90],
            [1998, 4995, 23.94, 28.78],
            [1998, 4996, 16.69, 30.91],
            [1998, 4997, 78.17, 40.51],
            [1998, 4998, 49.03, 43.06],
            [1998, 5000, 13.36, 12.29],
            [1998, 5001, 70, 70],
            [1998, 5002, 120, 90],
            [1998, 5003, 120, 90],
            [1998, 5005, 18.06, 19.95],
            [1998, 5006, 120, 90],
            [1998, 5007, 120, 90],
            [1998, 5008, 126.38, 53.28],
            [1998, 5009, 18.59, 27.74],
            [1998, 5010, 8.39, 5.61],
            [1998, 5011, 15.78, 16.19],
            [1998, 5012, 39.94, 45.98],
            [1998, 5013, 46.69, 34.25],
            [1998, 5014, 70, 70],
            [1998, 5017, 9.26, 20.62],
            [1998, 5019, 70, 70],
            [1998, 5020, 40, 50],
            [1998, 5022, 137.19, 88.29],
            [1998, 5023, 70, 70],
            [1998, 5025, 120, 90],
            [1998, 5026, 120, 90],
            [1998, 5027, 32.18, 30.47],
            [1998, 5031, 40, 50],
            [1998, 5032, 26.02, 40.08],
            [1998, 5033, 73.53, 35.42],
            [1998, 5034, 120, 90],
            [1998, 5035, 32.19, 33.94],
            [1998, 5036, 120, 90],
            [1998, 5037, 91.49, 46.75],
            [1998, 5038, 70, 70],
            [1998, 5041, 120, 90],
            [1998, 5043, 50, 60],
            [1998, 5044, 70, 70],
            [1998, 5046, 29.35, 32.47],
            [1998, 5048, 70, 70],
            [1998, 5049, 120, 90],
            [1998, 5050, 50, 60],
            [1998, 5051, 50, 60],
            [1998, 5053, 77.54, 45.07],
            [1998, 5054, 120, 90],
            [1998, 5056, 120, 90],
            [1998, 5057, 120, 90],
            [1998, 5058, 48.62, 42.89],
            [1998, 5060, 120, 90],
            [1998, 5061, 120, 90],
            [1998, 5062, 70, 70],
            [1998, 5063, 40, 50],
            [1998, 5064, 20.75, 20.03],
            [1998, 5065, 100.18, 69.74],
            [1998, 5066, 120, 90],
            [1998, 5068, 164.36, 62.76],
            [1998, 5069, 149.63, 54.69],
            [1998, 5070, 15.65, 30],
            [1998, 5071, 33.7, 31.78],
            [1998, 5072, 120, 90],
            [1998, 5073, 50, 60],
            [1998, 5075, 21.04, 24.86],
            [1998, 5077, 40, 50],
            [1998, 5079, 61.44, 42.57],
            [1998, 5081, 120, 90],
            [1998, 5082, 12.57, 13.41],
            [1998, 5083, 6.36, 5.53],
            [1998, 5084, 50, 60],
            [1998, 5085, 50, 60],
            [1998, 5087, 120, 90],
            [1998, 5088, 120, 90],
            [1998, 5091, 120, 90],
            [1998, 5092, 50, 60],
            [1998, 5093, 50, 60],
            [1998, 5094, 40, 50],
            [1998, 5095, 50, 60],
            [1998, 5097, 120, 90],
            [1998, 5098, 47.1, 29.63],
            [1998, 5099, 70, 70],
            [1998, 5100, 120, 90],
            [1998, 5101, 5.93, 6.65],
            [1998, 5102, 120, 90],
            [1998, 5103, 89.21, 43],
            [1998, 5104, 120, 90],
            [1998, 5107, 120, 90],
            [1998, 5108, 70, 70],
            [1998, 5109, 93.01, 45.96],
            [1998, 5111, 35.02, 25.49],
            [1998, 5114, 4.87, 4],
            [1998, 5115, 120, 90],
            [1998, 5116, 22.23, 21.49],
            [1998, 5117, 40, 50],
            [1998, 5119, 120, 90],
            [1998, 5121, 30.65, 46.26],
            [1998, 5122, 21.51, 31.21],
            [1998, 5123, 15.99, 15.06],
            [1998, 5124, 70, 70],
            [1998, 5126, 26.81, 24.11],
            [1998, 5127, 32.57, 20.36],
            [1998, 5128, 32.24, 21.39],
            [1998, 5130, 50, 60],
            [1998, 5132, 120, 90],
            [1998, 5135, 50, 60],
            [1998, 5136, 11.5, 8.4],
            [1998, 5137, 120, 90],
            [1998, 5138, 120, 90],
            [1998, 5141, 50, 60],
            [1998, 5143, 70, 70],
            [1998, 5145, 35.02, 25.49],
            [1998, 5149, 120, 90],
            [1998, 5150, 52.83, 33.37],
            [1998, 5153, 179.52, 59.91],
            [1998, 5154, 120, 90],
            [1998, 5155, 70, 70],
            [1998, 5156, 40, 50],
            [1998, 5157, 50, 60],
            [1998, 5159, 52.86, 48.43],
            [1998, 5160, 120, 90],
            [1998, 5161, 50, 60],
            [1998, 5162, 65.6, 46.34],
            [1998, 5163, 120, 90],
            [1998, 5164, 120, 90],
            [1998, 5165, 70, 70],
            [1998, 5166, 50, 60],
            [1998, 5167, 120, 90],
            [1998, 5169, 120, 90],
            [1998, 5171, 120, 90],
            [1998, 5172, 70, 70],
            [1998, 5173, 46.38, 41.15],
            [1998, 5174, 70, 70],
            [1998, 5178, 120, 90],
            [1998, 5180, 86.39, 54.81],
            [1998, 5181, 120, 90],
            [1998, 5182, 16.01, 20.04],
            [1998, 5183, 30.09, 35.52],
            [1998, 5184, 120, 90],
            [1998, 5185, 70, 70],
            [1998, 5186, 70, 70],
            [1998, 5187, 70, 70],
            [1998, 5188, 70, 70],
            [1998, 5189, 40, 50],
            [1998, 5191, 70, 70],
            [1998, 5192, 15, 25],
            [1998, 5193, 15, 25],
            [1998, 5194, 15, 25],
            [1998, 5195, 15, 25],
            [1998, 5196, 15, 25],
            [1998, 5197, 15, 25],
            [1998, 5198, 15, 25],
            [1998, 5199, 15, 25],
            [1998, 5200, 15, 25],
            [1998, 5201, 15, 25],
            [1998, 5202, 15, 25],
            [1998, 5203, 15, 25],
            [1998, 5204, 40, 50],
            [1998, 5205, 15, 25],
            [1998, 5206, 15, 25],
            [1998, 5207, 15, 25],
            [1998, 5208, 15, 25],
            [1998, 5209, 15, 25],
            [1998, 5210, 15, 25],
            [1998, 5211, 15, 25],
            [1998, 5212, 15, 25],
            [1998, 5213, 15, 25],
            [1998, 5214, 15, 25],
            [1998, 5215, 15, 25],
            [1998, 5216, 15, 25],
            [1998, 5217, 70, 70],
            [1998, 5219, 70, 70],
            [1998, 5220, 70, 70],
            [1998, 5221, 40, 50],
            [1998, 5222, 120, 90],
            [1998, 5223, 70, 70],
            [1998, 5224, 120, 90],
            [1998, 5225, 70, 70],
            [1998, 5226, 70, 70],
            [1998, 5227, 70, 70],
            [1998, 5228, 120, 90],
            [1998, 5229, 70, 70],
            [1998, 5230, 70, 70],
            [1998, 5231, 50, 60],
            [1998, 5232, 70, 70],
            [1998, 5233, 120, 90],
            [1998, 5234, 40, 50],
            [1998, 5235, 70, 70],
            [1998, 5236, 50, 60],
            [1998, 5237, 70, 70],
            [1998, 5238, 50, 60],
            [1998, 5239, 70, 70],
            [1998, 5240, 120, 90],
            [1998, 5241, 70, 70],
            [1998, 5242, 50, 60],
            [1998, 5243, 70, 70],
            [1998, 5244, 120, 90],
            [1998, 5245, 70, 70],
            [1998, 5249, 19.35, 11.59],
            [1998, 5250, 20.93, 10.99],
            [1998, 5251, 14.65, 13.08],
            [1998, 5252, 30, 16.56],
            [1998, 5253, 17.35, 10.66],
            [1998, 5254, 25.65, 16.32],
            [1998, 5255, 24.23, 14.71],
            [1998, 5256, 24.56, 17.38],
            [1998, 5257, 15.4, 13.96],
            [1998, 5258, 23.85, 19.14],
            [1998, 5259, 10.2, 9.75],
            [1998, 5260, 14.55, 9.36],
            [1998, 5261, 26.17, 17.95],
            [1998, 5263, 19.45, 15.67],
            [1998, 5264, 70, 50.86],
            [1998, 5265, 9.6, 16.73],
            [1998, 5266, 29.56, 17.86],
            [1998, 5267, 21.83, 15.71],
            [1998, 5268, 15.77, 15],
            [1998, 5269, 14.5, 9.26],
            [1998, 5270, 18.93, 17.93],
            [1998, 5271, 70, 70],
            [1998, 5272, 49.88, 21.16],
            [1998, 5273, 70, 70],
            [1998, 5274, 70, 70],
            [1998, 5275, 70, 70],
            [1998, 5276, 70, 70],
            [1998, 5277, 50, 60],
            [1998, 5278, 70, 70],
            [1998, 5279, 70, 70],
            [1998, 5280, 70, 70],
            [1998, 5281, 50, 60],
            [1998, 5282, 70, 70],
            [1998, 5283, 70, 70],
            [1998, 5284, 70, 70],
            [1998, 5285, 50, 60],
            [1998, 5286, 70, 70],
            [1998, 5287, 40, 50],
            [1998, 5288, 40, 50],
            [1998, 5289, 50, 60],
            [1998, 5290, 70, 70],
            [1998, 5291, 40, 50],
            [1998, 5292, 120, 90],
            [1998, 5293, 50, 60],
            [1998, 5294, 50, 60],
            [1998, 5295, 50, 60],
            [1998, 5296, 120, 90],
            [1998, 5297, 70, 70],
            [1998, 5298, 50, 60],
            [1998, 5299, 50, 60],
            [1998, 5300, 70, 70],
            [1998, 5301, 70, 70],
            [1998, 5302, 70, 70],
            [1998, 5303, 70, 70],
            [1998, 5304, 70, 70],
            [1998, 5305, 70, 70],
            [1998, 5306, 70, 70],
            [1998, 5307, 70, 70],
            [1998, 5308, 120, 90],
            [1998, 5309, 70, 70],
            [1998, 5310, 70, 70],
            [1998, 5311, 120, 90],
            [1998, 5312, 50, 60],
            [1998, 5313, 50, 60],
            [1998, 5314, 70, 70],
            [1998, 5315, 70, 70],
            [1998, 5316, 70, 70],
            [1998, 5317, 70, 70],
            [1998, 5318, 70, 70],
            [1998, 5319, 40, 50],
            [1998, 5320, 70, 70],
            [1998, 5321, 70, 70],
            [1998, 5322, 50, 60],
            [1998, 5323, 70, 70],
            [1998, 5324, 50, 60],
            [1998, 5325, 70, 70],
            [1998, 5326, 70, 70],
            [1998, 5327, 30, 45],
            [1998, 5328, 40, 50],
            [1998, 5329, 70, 70],
            [1998, 5330, 70, 70],
            [1998, 5331, 70, 70],
            [1998, 5332, 50, 60],
            [1998, 5333, 40, 50],
            [1998, 5334, 70, 70],
            [1998, 5335, 50, 60],
            [1998, 5336, 50, 60],
            [1998, 5337, 50, 60],
            [1998, 5338, 70, 70],
            [1998, 5339, 120, 90],
            [1998, 5340, 70, 70],
            [1998, 5341, 70, 70],
            [1998, 5342, 120, 90],
            [1998, 5343, 50, 60],
            [1998, 5344, 70, 70],
            [1998, 5345, 50, 60],
            [1998, 5346, 30, 45],
            [1998, 5347, 70, 70],
            [1998, 5348, 50, 60],
            [1998, 5349, 70, 70],
            [1998, 5350, 70, 70],
            [1998, 5351, 70, 70],
            [1998, 5352, 70, 70],
            [1998, 5353, 50, 60],
            [1998, 5354, 120, 90],
            [1998, 5355, 50, 60],
            [1998, 5356, 70, 70],
            [1998, 5357, 50, 60],
            [1998, 5358, 70, 70],
            [1998, 5359, 70, 70],
            [1998, 5360, 70, 70],
            [1998, 5361, 120, 90],
            [1998, 5362, 70, 70],
            [1998, 5363, 30, 45],
            [1998, 5364, 70, 70],
            [1998, 5365, 40, 50],
            [1998, 5366, 70, 70],
            [1998, 5367, 50, 60],
            [1998, 5368, 70, 70],
            [1998, 5369, 50, 60],
            [1998, 5370, 70, 70],
            [1998, 5371, 70, 70],
            [1998, 5372, 70, 70],
            [1998, 5373, 70, 70],
            [1998, 5374, 120, 90],
            [1998, 5375, 50, 60],
            [1998, 5376, 120, 90],
            [1998, 5377, 50, 60],
            [1998, 5378, 70, 70],
            [1998, 5379, 40, 50],
            [1998, 5380, 70, 70],
            [1998, 5381, 70, 70],
            [1998, 5382, 70, 70],
            [1998, 5383, 50, 60],
            [1998, 5384, 70, 70],
            [1998, 5385, 70, 70],
            [1998, 5386, 70, 70],
            [1998, 5387, 40, 50],
            [1998, 5388, 70, 70],
            [1998, 5389, 70, 70],
            [1998, 5390, 70, 70],
            [1998, 5391, 70, 70],
            [1998, 5392, 70, 70],
            [1998, 5393, 70, 70],
            [1998, 5394, 120, 90],
            [1998, 5395, 120, 90],
            [1998, 5396, 40, 50],
            [1998, 5397, 70, 70],
            [1998, 5398, 70, 70],
            [1998, 5399, 50, 60],
            [1998, 5400, 50, 60],
            [1998, 5401, 70, 70],
            [1998, 5402, 70, 70],
            [1998, 5403, 70, 70],
            [1998, 5404, 70, 70],
            [1998, 5405, 50, 60],
            [1998, 5406, 120, 90],
            [1998, 5407, 70, 70],
            [1998, 5408, 70, 70],
            [1998, 5409, 70, 70],
            [1998, 5410, 70, 70],
            [1998, 5411, 50, 60],
            [1998, 5412, 50, 60],
            [1998, 5413, 70, 70],
            [1998, 5414, 50, 60],
            [1998, 5415, 70, 70],
            [1998, 5416, 30, 45],
            [1998, 5417, 70, 70],
            [1998, 5418, 70, 70],
            [1998, 5419, 50, 60],
            [1998, 5420, 50, 60],
            [1998, 5421, 50, 60],
            [1998, 5422, 70, 70],
            [1998, 5423, 70, 70],
            [1998, 5424, 50, 60],
            [1998, 5425, 70, 70],
            [1998, 5426, 50, 60],
            [1998, 5427, 70, 70],
            [1998, 5428, 70, 70],
            [1998, 5429, 30, 45],
            [1998, 5430, 120, 90],
            [1998, 5431, 70, 70],
            [1998, 5432, 70, 70],
            [1998, 5433, 70, 70],
            [1998, 5434, 40, 50],
            [1998, 5435, 70, 70],
            [1998, 5436, 40, 50],
            [1998, 5437, 70, 70],
            [1998, 5438, 70, 70],
            [1998, 5439, 70, 70],
            [1998, 5440, 70, 70],
            [1998, 5441, 70, 70],
            [1998, 5442, 70, 70],
            [1998, 5443, 70, 70],
            [1998, 5444, 70, 70],
            [1998, 5445, 50, 60],
            [1998, 5446, 70, 70],
            [1998, 5447, 50, 60],
            [1998, 5448, 70, 70],
            [1998, 5449, 70, 70],
            [1998, 5450, 70, 70],
            [1998, 5451, 70, 70],
            [1998, 5452, 70, 70],
            [1998, 5453, 70, 70],
            [1998, 5454, 50, 60],
            [1998, 5455, 50, 60],
            [1998, 5456, 70, 70],
            [1998, 5457, 50, 60],
            [1998, 5458, 70, 70],
            [1998, 5459, 70, 70],
            [1998, 5460, 40, 50],
            [1998, 5461, 40, 50],
            [1998, 5462, 70, 70],
            [1998, 5463, 40, 50],
            [1998, 5464, 70, 70],
            [1998, 5465, 70, 70],
            [1998, 5466, 70, 70],
            [1998, 5467, 70, 70],
            [1998, 5468, 70, 70],
            [1998, 5469, 70, 70],
            [1998, 5470, 70, 70],
            [1998, 5471, 50, 60],
            [1998, 5472, 50, 60],
            [1998, 5473, 50, 60],
            [1998, 5474, 120, 90],
            [1998, 5475, 70, 70],
            [1998, 5476, 70, 70],
            [1998, 5477, 30, 45],
            [1998, 5478, 70, 70],
            [1998, 5479, 70, 70],
            [1998, 5480, 70, 70],
            [1998, 5481, 50, 60],
            [1998, 5482, 70, 70],
            [1998, 5483, 50, 60],
            [1998, 5484, 70, 70],
            [1998, 5485, 50, 60],
            [1998, 5486, 70, 70],
            [1998, 5487, 50, 60],
            [1998, 5488, 70, 70],
            [1998, 5489, 70, 70],
            [1998, 5490, 70, 70],
            [1998, 5491, 50, 60],
            [1998, 5492, 70, 70],
            [1998, 5493, 50, 60],
            [1998, 5494, 70, 70],
            [1998, 5495, 50, 60],
            [1998, 5496, 70, 70],
            [1998, 5497, 50, 60],
            [1998, 5498, 70, 70],
            [1998, 5499, 70, 70],
            [1998, 5500, 70, 70],
            [1998, 5501, 70, 70],
            [1998, 5502, 70, 70],
            [1998, 5503, 70, 70],
            [1998, 5504, 70, 70],
            [1998, 5505, 70, 70],
            [1998, 5506, 70, 70],
            [1998, 5507, 70, 70],
            [1998, 5508, 70, 70],
            [1998, 5509, 70, 70],
            [1998, 5510, 70, 70],
            [1998, 5511, 50, 60],
            [1998, 5512, 50, 60],
            [1998, 5513, 70, 70],
            [1998, 5514, 70, 70],
            [1998, 5515, 70, 70],
            [1998, 5516, 70, 70],
            [1998, 5517, 70, 70],
            [1998, 5518, 50, 60],
            [1998, 5519, 70, 70],
            [1998, 5520, 70, 70],
            [1998, 5521, 70, 70],
            [1998, 5522, 40, 50],
            [1998, 5523, 50, 60],
            [1998, 5524, 50, 60],
            [1998, 5525, 70, 70],
            [1998, 5526, 70, 70],
            [1998, 5527, 70, 70],
            [1998, 5528, 40, 50],
            [1998, 5529, 120, 90],
            [1998, 5530, 70, 70],
            [1998, 5531, 70, 70],
            [1998, 5532, 70, 70],
            [1998, 5533, 70, 70],
            [1998, 5534, 50, 60],
            [1998, 5535, 70, 70],
            [1998, 5536, 15, 20],
            [1998, 5537, 120, 90],
            [1998, 5538, 70, 70],
            [1998, 5539, 70, 70],
            [1998, 5540, 70, 70],
            [1998, 5541, 70, 70],
            [1998, 5542, 40, 50],
            [1998, 5543, 40, 50],
            [1998, 5544, 70, 70],
            [1998, 5545, 70, 70],
            [1998, 5546, 70, 70],
            [1998, 5547, 70, 70],
            [1998, 5548, 70, 70],
            [1998, 5549, 40, 50],
            [1998, 5550, 70, 70],
            [1998, 5551, 70, 70],
            [1998, 5552, 70, 70],
            [1998, 5553, 70, 70],
            [1998, 5554, 70, 70],
            [1998, 5555, 70, 70],
            [1998, 5556, 50, 60],
            [1998, 5557, 40, 50],
            [1998, 5558, 40, 50],
            [1998, 5559, 70, 70],
            [1998, 5560, 120, 90],
            [1998, 5561, 120, 90],
            [1998, 5562, 120, 90],
            [1998, 5563, 70, 70],
            [1998, 5564, 70, 70],
            [1998, 5565, 70, 70],
            [1998, 5566, 70, 70],
            [1998, 5567, 70, 70],
            [1998, 5568, 120, 90],
            [1998, 5569, 70, 70],
            [1998, 5570, 120, 90],
            [1998, 5571, 50, 60],
            [1998, 5572, 70, 70],
            [1998, 5573, 0, 0],
            [1998, 5590, 70, 70],
            [1998, 5600, 120, 90],
            [1998, 5618, 120, 90],
            [1998, 5621, 120, 90],
            [1998, 5624, 120, 90],
            [1998, 5625, 120, 90],
            [1998, 5627, 70, 70],
            [1998, 5632, 120, 90],
            [1998, 5636, 120, 90],
            [1998, 5638, 50, 60],
            [1998, 5646, 120, 90],
            [1998, 5648, 120, 90],
            [1998, 5649, 70, 70],
            [1998, 5659, 7.31, 6.79],
            [1998, 5660, 9.41, 9.76],
            [1998, 5661, 70, 70],
            [1998, 5663, 120, 90],
            [1998, 5666, 120, 90],
            [1998, 5672, 70, 70],
            [1998, 5675, 50, 60],
            [1998, 5677, 120, 90],
            [1998, 5681, 70, 70],
            [1998, 5683, 120, 90],
            [1998, 5689, 120, 90],
            [1998, 5706, 120, 90],
            [1998, 5715, 70, 70],
            [1998, 5717, 120, 90],
            [1998, 5720, 70, 70],
            [1998, 5726, 120, 90],
            [1998, 5728, 120, 90],
            [1998, 5737, 120, 90],
            [1998, 5738, 120, 90],
            [1998, 5745, 70, 70],
            [1998, 5747, 120, 90],
            [1998, 5757, 40, 50],
            [1998, 5758, 70, 70],
            [1998, 5764, 50, 60],
            [1998, 5768, 70, 70],
            [1998, 5777, 120, 90],
            [1998, 5789, 40, 50],
            [1998, 5796, 120, 90],
            [1998, 5805, 120, 90],
            [1998, 5808, 70, 70],
            [1998, 5811, 120, 90],
            [1998, 5819, 120, 90],
            [1998, 5824, 70, 70],
            [1998, 5830, 70, 70],
            [1998, 5833, 120, 90],
            [1998, 5840, 120, 90],
            [1998, 5841, 120, 90],
            [1998, 5846, 120, 90],
            [1998, 5848, 120, 90],
            [1998, 5851, 120, 90],
            [1998, 5855, 50, 60],
            [1998, 5856, 40, 50],
            [1998, 5861, 120, 90],
            [1998, 5868, 120, 90],
            [1998, 5869, 120, 90],
            [1998, 5876, 120, 90],
            [1998, 5877, 120, 90],
            [1998, 5880, 50, 60],
            [1998, 5881, 70, 70],
            [1998, 5882, 70, 70],
            [1998, 5884, 120, 90],
            [1998, 5887, 70, 70],
            [1998, 5889, 70, 70],
            [1998, 5898, 120, 90],
            [1998, 5903, 70, 70],
            [1998, 5911, 120, 90],
            [1998, 5917, 120, 90],
            [1998, 5918, 120, 90],
            [1998, 5919, 70, 70],
            [1998, 5931, 70, 70],
            [1998, 5933, 40, 50],
            [1998, 5936, 70, 70],
            [1998, 5939, 120, 90],
            [1998, 5940, 120, 90],
            [1998, 5941, 120, 90],
            [1998, 5942, 120, 90],
            [1998, 5943, 120, 90],
            [1998, 5944, 40, 50],
            [1998, 5945, 40, 50],
            [1998, 5946, 40, 50],
            [1998, 5947, 120, 90],
            [1998, 5948, 40, 50],
            [1998, 5949, 120, 90],
            [1998, 5950, 120, 90],
            [1998, 5951, 120, 90],
            [1998, 5953, 40, 50],
            [1998, 5954, 120, 90],
            [1998, 5955, 120, 90],
            [1998, 5956, 120, 90],
            [1998, 5957, 120, 90],
            [1998, 5958, 50, 60],
            [1998, 5959, 50, 60],
            [1998, 5960, 120, 90],
            [1998, 5961, 40, 50],
            [1998, 5964, 120, 90],
            [1998, 5965, 120, 90],
            [1998, 5966, 50, 60],
            [1998, 5967, 70, 70],
            [1998, 5968, 120, 90],
            [1998, 5969, 70, 70],
            [1998, 5970, 70, 70],
            [1998, 5985, 15, 25],
            [1998, 5986, 50, 60],
            [1998, 5987, 15, 25],
            [1998, 5988, 21, 33],
            [1998, 5994, 50, 60],
            [1998, 5995, 70, 70],
            [1998, 5996, 70, 70],
            [1998, 5997, 70, 70],
            [1998, 5998, 120, 90],
            [1998, 5999, 50, 60],
            [1998, 6049, 120, 90],
            [1998, 6050, 70, 70],
            [1998, 6051, 70, 70],
            [1998, 6052, 120, 90],
            [1998, 6053, 120, 90],
            [1998, 6054, 120, 90],
            [1998, 6068, 120, 90],
            [1998, 6069, 70, 70],
            [1998, 6070, 70, 70],
            [1998, 6071, 70, 70],
            [1998, 6072, 40, 50],
            [1998, 6073, 70, 70],
            [1998, 6074, 70, 70],
            [1998, 6075, 70, 70],
            [1998, 6076, 50, 60],
            [1998, 6077, 70, 70],
            [1998, 6078, 50, 60],
            [1998, 6079, 70, 70],
            [1998, 6080, 70, 70],
            [1998, 6081, 50, 60],
            [1998, 6082, 70, 70],
            [1998, 6083, 120, 90],
            [1998, 6084, 120, 90],
            [1998, 6085, 120, 90],
            [1998, 6086, 70, 70],
            [1998, 6087, 70, 70],
            [1998, 6088, 70, 70],
            [1998, 6089, 70, 70],
            [1998, 6090, 120, 90],
            [1998, 6091, 70, 70],
            [1998, 6092, 70, 70],
            [1998, 6093, 120, 90],
            [1998, 6094, 70, 70],
            [1998, 6095, 50, 60],
            [1998, 6096, 120, 90],
            [1998, 6097, 120, 90],
            [1998, 6098, 120, 90],
            [1998, 6099, 120, 90],
            [1998, 6100, 70, 70],
            [1998, 6101, 70, 70],
            [1998, 6102, 70, 70],
            [1998, 6103, 70, 70],
            [1998, 6104, 120, 90],
            [1998, 6105, 120, 90],
            [1998, 6106, 70, 70],
            [1998, 6107, 70, 70],
            [1998, 6108, 70, 70],
            [1998, 6109, 50, 60],
            [1998, 6110, 70, 70],
            [1998, 6111, 30, 45],
            [1998, 6112, 70, 70],
            [1998, 6113, 70, 70],
            [1998, 6114, 50, 60],
            [1998, 6115, 50, 60],
            [1998, 6116, 70, 70],
            [1998, 6117, 70, 70],
            [1998, 6118, 70, 70],
            [1998, 6119, 70, 70],
            [1998, 6120, 40, 50],
            [1998, 6121, 70, 70],
            [1998, 6122, 70, 70],
            [1998, 6123, 70, 70],
            [1998, 6124, 70, 70],
            [1998, 6125, 70, 70],
            [1998, 6126, 70, 70],
            [1998, 6127, 70, 70],
            [1998, 6128, 70, 70],
            [1998, 6129, 40, 50],
            [1998, 6130, 70, 70],
            [1998, 6131, 70, 70],
            [1998, 6132, 70, 70],
            [1998, 6133, 70, 70],
            [1998, 6134, 70, 70],
            [1998, 6135, 70, 70],
            [1998, 6136, 70, 70],
            [1998, 6137, 40, 50],
            [1998, 6138, 50, 60],
            [1998, 6139, 70, 70],
            [1998, 6140, 40, 50],
            [1998, 6141, 50, 60],
            [1998, 6142, 50, 60],
            [1998, 6143, 70, 70],
            [1998, 6144, 70, 70],
            [1998, 6145, 70, 70],
            [1998, 6146, 30, 45],
            [1998, 6147, 40, 50],
            [1998, 6148, 40, 50],
            [1998, 6149, 70, 70],
            [1998, 6150, 50, 60],
            [1998, 6151, 70, 70],
            [1998, 6152, 40, 50],
            [1998, 6153, 50, 60],
            [1998, 6154, 70, 70],
            [1998, 6155, 40, 50],
            [1998, 6156, 50, 60],
            [1998, 6157, 50, 60],
            [1998, 6158, 50, 60],
            [1998, 6159, 70, 70],
            [1998, 6160, 70, 70],
            [1998, 6161, 40, 50],
            [1998, 6162, 50, 60],
            [1998, 6163, 50, 60],
            [1998, 6164, 70, 70],
            [1998, 6165, 70, 70],
            [1998, 6166, 70, 70],
            [1998, 6167, 70, 70],
            [1998, 6168, 30, 45],
            [1998, 6169, 30, 45],
            [1998, 6170, 30, 45],
            [1998, 6248, 30, 45],
            [1998, 6252, 50, 60],
            [1998, 6253, 120, 90],
            [1998, 6255, 70, 70],
            [1998, 6256, 50, 60],
            [1998, 6258, 50, 60],
            [1998, 6259, 120, 90],
            [1998, 6260, 120, 90],
            [1998, 6261, 70, 70],
            [1998, 6262, 70, 70],
            [1998, 6263, 120, 90],
            [1998, 6264, 70, 70],
            [1998, 6265, 70, 70],
            [1998, 6266, 50, 60],
            [1998, 6267, 50, 60],
            [1998, 6268, 70, 70],
            [1998, 6269, 50, 60],
            [1998, 6270, 50, 60],
            [1998, 6271, 70, 70],
            [1998, 6272, 40, 50],
            [1998, 6274, 70, 70],
            [1998, 6275, 70, 70],
            [1998, 6276, 50, 60],
            [1998, 6277, 120, 90],
            [1998, 6278, 70, 70],
            [1998, 6279, 70, 70],
            [1998, 6280, 70, 70],
            [1998, 6281, 70, 70],
            [1998, 6282, 50, 60],
            [1998, 6283, 70, 70],
            [1998, 6284, 50, 60],
            [1998, 6286, 70, 70],
            [1998, 6287, 50, 60],
            [1998, 6288, 70, 70],
            [1998, 6289, 50, 60],
            [1998, 6290, 120, 90],
            [1998, 6292, 70, 70],
            [1998, 6293, 70, 70],
            [1998, 6294, 120, 90],
            [1998, 6295, 120, 90],
            [1998, 6296, 70, 70],
            [1998, 6297, 120, 90],
            [1998, 6299, 70, 70],
            [1998, 6300, 70, 70],
            [1998, 6301, 70, 70],
            [1998, 6302, 70, 70],
            [1998, 6303, 70, 70],
            [1998, 6305, 120, 90],
            [1998, 6306, 70, 70],
            [1998, 6307, 120, 90],
            [1998, 6308, 120, 90],
            [1998, 6309, 70, 70],
            [1998, 6310, 50, 60],
            [1998, 6312, 120, 90],
            [1998, 6313, 70, 70],
            [1998, 6314, 120, 90],
            [1998, 6315, 70, 70],
            [1998, 6316, 70, 70],
            [1998, 6317, 70, 70],
            [1998, 6319, 50, 60],
            [1998, 6320, 70, 70],
            [1998, 6321, 70, 70],
            [1998, 6323, 50, 60],
            [1998, 6324, 50, 60],
            [1998, 6325, 120, 90],
            [1998, 6326, 70, 70],
            [1998, 6327, 50, 60],
            [1998, 6328, 120, 90],
            [1998, 6330, 120, 90],
            [1998, 6331, 50, 60],
            [1998, 6333, 120, 90],
            [1998, 6334, 27.92, 22.8],
            [1998, 6335, 36.36, 27.35],
            [1998, 6336, 50, 35.7],
            [1998, 6337, 28.8, 13.04],
            [1998, 6338, 50, 33.77],
            [1998, 6339, 20.96, 16.45],
            [1998, 6340, 50, 36.94],
            [1998, 6341, 40, 23.08],
            [1998, 6342, 23.49, 10.98],
            [1998, 6343, 22.07, 18.41],
            [1998, 6344, 19.93, 9.57],
            [1998, 6345, 50, 21.26],
            [1998, 6346, 40, 25.58],
            [1998, 6347, 30.77, 13.81],
            [1998, 6348, 40, 23.23],
            [1998, 6349, 26.83, 18.14],
            [1998, 6350, 30.1, 29.64],
            [1998, 6351, 37.29, 18.38],
            [1999, 1, 50, 60],
            [1999, 2, 120, 90],
            [1999, 3, 70, 70],
            [1999, 7, 35.26, 21.02],
            [1999, 13, 120, 90],
            [1999, 14, 120, 90],
            [1999, 15, 70, 70],
            [1999, 16, 70, 70],
            [1999, 17, 120, 90],
            [1999, 18, 70, 70],
            [1999, 19, 70, 70],
            [1999, 20, 120, 90],
            [1999, 21, 70, 70],
            [1999, 22, 3.02, 9.75],
            [1999, 23, 120, 90],
            [1999, 25, 13.55, 9.36],
            [1999, 26, 70, 70],
            [1999, 27, 120, 90],
            [1999, 28, 50, 60],
            [1999, 29, 120, 90],
            [1999, 30, 26.05, 16.78],
            [1999, 31, 11.48, 9.38],
            [1999, 32, 120, 90],
            [1999, 33, 60.79, 35],
            [1999, 35, 120, 90],
            [1999, 37, 70, 70],
            [1999, 38, 120, 90],
            [1999, 40, 70, 133],
            [1999, 42, 49.3, 31.8],
            [1999, 43, 120, 90],
            [1999, 44, 120, 90],
            [1999, 47, 50, 60],
            [1999, 48, 70, 70],
            [1999, 49, 37.5, 45],
            [1999, 50, 120, 90],
            [1999, 51, 15.57, 18.15],
            [1999, 53, 40, 50],
            [1999, 56, 120, 90],
            [1999, 57, 120, 90],
            [1999, 58, 61.93, 49.09],
            [1999, 61, 70, 70],
            [1999, 62, 27.9, 27.4],
            [1999, 63, 70, 70],
            [1999, 64, 29.97, 42.64],
            [1999, 65, 50, 42.55],
            [1999, 66, 20, 25],
            [1999, 68, 70, 70],
            [1999, 69, 70, 70],
            [1999, 70, 50, 60],
            [1999, 71, 120, 90],
            [1999, 72, 120, 90],
            [1999, 73, 120, 90],
            [1999, 75, 50, 60],
            [1999, 77, 120, 90],
            [1999, 78, 59.13, 56.03],
            [1999, 81, 70, 70],
            [1999, 82, 12, 28.91],
            [1999, 83, 40, 37.5],
            [1999, 84, 120, 90],
            [1999, 87, 140.68, 39.98],
            [1999, 88, 10.85, 7.56],
            [1999, 89, 70, 70],
            [1999, 91, 40, 50],
            [1999, 93, 8.27, 9.25],
            [1999, 94, 120, 90],
            [1999, 96, 17.85, 27],
            [1999, 99, 15.91, 13.12],
            [1999, 100, 8.29, 8.86],
            [1999, 101, 70, 70],
            [1999, 103, 120, 90],
            [1999, 105, 40, 50],
            [1999, 106, 70, 70],
            [1999, 109, 40, 50],
            [1999, 110, 120, 90],
            [1999, 113, 86.12, 35.5],
            [1999, 119, 70, 70],
            [1999, 121, 13.82, 8.38],
            [1999, 122, 42.72, 53.2],
            [1999, 123, 120, 90],
            [1999, 125, 24.22, 37.94],
            [1999, 128, 70, 70],
            [1999, 133, 120, 90],
            [1999, 135, 24.22, 25.06],
            [1999, 136, 120, 90],
            [1999, 138, 83.99, 31.46],
            [1999, 140, 50, 60],
            [1999, 141, 5, 5.95],
            [1999, 142, 114, 273],
            [1999, 144, 50, 60],
            [1999, 145, 10.42, 7.09],
            [1999, 146, 120, 90],
            [1999, 147, 70, 70],
            [1999, 149, 50, 33.8],
            [1999, 150, 50, 60],
            [1999, 151, 47.04, 30.27],
            [1999, 153, 30, 45],
            [1999, 156, 120, 90],
            [1999, 157, 120, 90],
            [1999, 158, 120, 90],
            [1999, 160, 120, 90],
            [1999, 161, 47.65, 26.01],
            [1999, 162, 40, 50],
            [1999, 163, 32.08, 38.15],
            [1999, 164, 120, 90],
            [1999, 165, 70, 70],
            [1999, 166, 31.35, 44.44],
            [1999, 169, 97.7, 41.85],
            [1999, 170, 120, 90],
            [1999, 171, 35.55, 35],
            [1999, 175, 70, 70],
            [1999, 177, 70, 70],
            [1999, 181, 120, 90],
            [1999, 182, 120, 90],
            [1999, 183, 70, 70],
            [1999, 184, 120, 90],
            [1999, 186, 42.55, 28.63],
            [1999, 187, 50, 60],
            [1999, 188, 34.84, 17.18],
            [1999, 189, 120, 90],
            [1999, 190, 41.9, 24.53],
            [1999, 192, 12, 18],
            [1999, 194, 36.1, 33],
            [1999, 195, 25.2, 22.5],
            [1999, 196, 8.64, 9.03],
            [1999, 197, 120, 90],
            [1999, 199, 120, 90],
            [1999, 200, 50, 60],
            [1999, 203, 70, 70],
            [1999, 204, 16.64, 27],
            [1999, 206, 120, 90],
            [1999, 207, 50, 60],
            [1999, 210, 120, 90],
            [1999, 211, 42.5, 64.2],
            [1999, 212, 70, 70],
            [1999, 213, 70, 70],
            [1999, 214, 120, 90],
            [1999, 215, 39.31, 26.34],
            [1999, 216, 72.31, 55.31],
            [1999, 217, 120, 90],
            [1999, 218, 53.89, 34.22],
            [1999, 220, 23.35, 19.12],
            [1999, 222, 9.57, 9.57],
            [1999, 225, 37.5, 45],
            [1999, 226, 13.66, 15.31],
            [1999, 227, 120, 90],
            [1999, 228, 18.5, 27.7],
            [1999, 230, 30, 37.5],
            [1999, 231, 70, 70],
            [1999, 233, 22.4, 15.4],
            [1999, 234, 12, 19.36],
            [1999, 235, 34.93, 21.66],
            [1999, 236, 70, 70],
            [1999, 237, 10.83, 7.57],
            [1999, 239, 57.35, 74.71],
            [1999, 240, 35.9, 29.8],
            [1999, 241, 46.4, 41.28],
            [1999, 242, 164.4, 59.03],
            [1999, 243, 118.04, 58],
            [1999, 244, 120, 90],
            [1999, 245, 120, 90],
            [1999, 246, 60.21, 33.65],
            [1999, 247, 120, 90],
            [1999, 248, 60.9, 49.22],
            [1999, 249, 70, 70],
            [1999, 250, 50, 60],
            [1999, 253, 120, 90],
            [1999, 256, 50, 60],
            [1999, 257, 120, 90],
            [1999, 260, 70, 70],
            [1999, 264, 50, 60],
            [1999, 265, 120, 90],
            [1999, 267, 120, 90],
            [1999, 268, 120, 90],
            [1999, 269, 120, 90],
            [1999, 270, 102.9, 57.89],
            [1999, 272, 120, 90],
            [1999, 273, 25.7, 35.52],
            [1999, 282, 70, 70],
            [1999, 283, 120, 90],
            [1999, 284, 70, 70],
            [1999, 285, 62.31, 50.39],
            [1999, 286, 33.37, 83.43],
            [1999, 287, 40, 37.5],
            [1999, 289, 120, 90],
            [1999, 291, 70, 70],
            [1999, 292, 50, 60],
            [1999, 294, 96.24, 38.52],
            [1999, 295, 120, 90],
            [1999, 296, 36.57, 16.84],
            [1999, 297, 120, 90],
            [1999, 298, 70, 70],
            [1999, 299, 56.16, 71.39],
            [1999, 302, 120, 90],
            [1999, 303, 60.81, 32.84],
            [1999, 305, 21.98, 26],
            [1999, 306, 53.16, 39.53],
            [1999, 307, 70, 70],
            [1999, 308, 22.69, 32.81],
            [1999, 309, 120, 90],
            [1999, 310, 20.76, 23.58],
            [1999, 311, 70, 70],
            [1999, 312, 98.14, 57.65],
            [1999, 313, 50, 60],
            [1999, 314, 28.98, 30.23],
            [1999, 315, 120, 90],
            [1999, 317, 34.9, 28.91],
            [1999, 320, 40.8, 42.3],
            [1999, 321, 120, 90],
            [1999, 322, 120, 90],
            [1999, 324, 37.5, 45],
            [1999, 325, 120, 90],
            [1999, 326, 28.63, 19.82],
            [1999, 327, 52.96, 62.65],
            [1999, 328, 70, 70],
            [1999, 329, 70, 70],
            [1999, 330, 24.63, 27.62],
            [1999, 332, 101.6, 71.83],
            [1999, 333, 120, 90],
            [1999, 334, 14.71, 16.26],
            [1999, 337, 19.61, 30.02],
            [1999, 339, 74, 62.86],
            [1999, 340, 120, 90],
            [1999, 342, 70, 70],
            [1999, 343, 120, 90],
            [1999, 344, 89.38, 44.91],
            [1999, 346, 56.18, 44.76],
            [1999, 347, 70, 70],
            [1999, 348, 120, 90],
            [1999, 350, 70, 70],
            [1999, 351, 70, 70],
            [1999, 353, 50, 60],
            [1999, 354, 37.5, 45],
            [1999, 355, 70, 70],
            [1999, 356, 120, 90],
            [1999, 358, 70, 70],
            [1999, 361, 41.38, 37.74],
            [1999, 362, 50, 60],
            [1999, 365, 120, 90],
            [1999, 367, 60, 167],
            [1999, 368, 50, 60],
            [1999, 369, 5.88, 5.27],
            [1999, 370, 70, 70],
            [1999, 371, 72.52, 67.5],
            [1999, 372, 16.36, 13.13],
            [1999, 374, 50, 60],
            [1999, 376, 22.12, 15.96],
            [1999, 377, 25.09, 17.45],
            [1999, 378, 31.66, 30.53],
            [1999, 379, 11.67, 16.73],
            [1999, 382, 70, 70],
            [1999, 383, 25.5, 21.6],
            [1999, 385, 120, 90],
            [1999, 386, 50, 60],
            [1999, 387, 70, 70],
            [1999, 389, 37.5, 45],
            [1999, 390, 70, 70],
            [1999, 391, 70, 70],
            [1999, 392, 72.06, 47.49],
            [1999, 394, 50, 60],
            [1999, 396, 120, 90],
            [1999, 398, 70, 70],
            [1999, 399, 70, 70],
            [1999, 400, 50, 60],
            [1999, 401, 70, 70],
            [1999, 402, 120, 90],
            [1999, 403, 25.72, 27.84],
            [1999, 405, 70, 70],
            [1999, 406, 120, 90],
            [1999, 409, 50, 60],
            [1999, 411, 120, 90],
            [1999, 412, 120, 90],
            [1999, 413, 30, 45],
            [1999, 415, 120, 90],
            [1999, 416, 50, 60],
            [1999, 418, 37.33, 36.38],
            [1999, 419, 120, 90],
            [1999, 422, 120, 90],
            [1999, 424, 32.02, 28.67],
            [1999, 425, 12.16, 14.12],
            [1999, 426, 120, 90],
            [1999, 427, 40, 50],
            [1999, 428, 13.52, 12.14],
            [1999, 429, 70, 70],
            [1999, 430, 27, 24],
            [1999, 432, 60.55, 31.38],
            [1999, 434, 70, 70],
            [1999, 436, 20.72, 16.74],
            [1999, 437, 40, 50],
            [1999, 439, 70, 70],
            [1999, 443, 120, 90],
            [1999, 444, 50, 60],
            [1999, 445, 120, 90],
            [1999, 446, 70, 70],
            [1999, 450, 120, 90],
            [1999, 451, 50, 60],
            [1999, 452, 120, 90],
            [1999, 453, 70, 70],
            [1999, 454, 120, 90],
            [1999, 455, 71.93, 65.93],
            [1999, 457, 40, 50],
            [1999, 458, 70, 70],
            [1999, 459, 120, 90],
            [1999, 460, 70, 70],
            [1999, 461, 50, 60],
            [1999, 463, 10.14, 8.58],
            [1999, 464, 21.08, 14.31],
            [1999, 465, 50, 60],
            [1999, 466, 120, 90],
            [1999, 467, 120, 90],
            [1999, 468, 120, 90],
            [1999, 469, 120, 90],
            [1999, 470, 120, 90],
            [1999, 471, 29.42, 44.44],
            [1999, 473, 120, 90],
            [1999, 474, 70, 70],
            [1999, 476, 120, 90],
            [1999, 477, 120, 90],
            [1999, 478, 120, 90],
            [1999, 479, 70, 70],
            [1999, 480, 70, 70],
            [1999, 481, 70, 70],
            [1999, 482, 70, 70],
            [1999, 484, 70, 70],
            [1999, 485, 120, 90],
            [1999, 486, 50, 60],
            [1999, 487, 22.74, 35.74],
            [1999, 488, 70, 70],
            [1999, 490, 70, 70],
            [1999, 493, 120, 90],
            [1999, 494, 16.23, 19.49],
            [1999, 495, 120, 90],
            [1999, 496, 77, 84],
            [1999, 497, 20.34, 27.7],
            [1999, 498, 50, 60],
            [1999, 500, 70, 70],
            [1999, 501, 70, 70],
            [1999, 503, 70, 24.56],
            [1999, 504, 14.4, 17.19],
            [1999, 505, 24.91, 27.22],
            [1999, 507, 120, 90],
            [1999, 508, 70, 70],
            [1999, 509, 5.13, 4.64],
            [1999, 510, 40, 50],
            [1999, 512, 30, 40],
            [1999, 513, 70, 70],
            [1999, 515, 75, 45],
            [1999, 518, 120, 90],
            [1999, 519, 26.44, 21.57],
            [1999, 520, 120, 90],
            [1999, 521, 120, 90],
            [1999, 522, 70, 70],
            [1999, 523, 120, 90],
            [1999, 524, 70, 70],
            [1999, 525, 31.78, 60.44],
            [1999, 526, 70.03, 60],
            [1999, 527, 82, 95],
            [1999, 528, 50, 60],
            [1999, 531, 10.37, 9.91],
            [1999, 532, 85.36, 50.72],
            [1999, 534, 41.02, 29.31],
            [1999, 535, 40, 50],
            [1999, 536, 18.74, 29.58],
            [1999, 540, 70, 70],
            [1999, 541, 61.04, 50.11],
            [1999, 543, 120, 90],
            [1999, 545, 35.62, 43.31],
            [1999, 547, 12, 18],
            [1999, 548, 120, 90],
            [1999, 549, 45, 24.58],
            [1999, 550, 70, 70],
            [1999, 551, 120, 90],
            [1999, 553, 120, 90],
            [1999, 554, 15, 25],
            [1999, 555, 120, 90],
            [1999, 556, 120, 90],
            [1999, 557, 40, 50],
            [1999, 558, 120, 90],
            [1999, 559, 70, 70],
            [1999, 561, 120, 90],
            [1999, 563, 70, 70],
            [1999, 564, 12.02, 6.99],
            [1999, 565, 24.89, 19.74],
            [1999, 568, 44.41, 35.25],
            [1999, 569, 106.46, 58.13],
            [1999, 570, 77.63, 49.89],
            [1999, 571, 70, 70],
            [1999, 572, 30, 45],
            [1999, 573, 34.75, 26.58],
            [1999, 574, 70, 70],
            [1999, 577, 32.7, 38.7],
            [1999, 579, 40, 50],
            [1999, 581, 30, 45],
            [1999, 582, 120, 90],
            [1999, 583, 70, 70],
            [1999, 584, 21.39, 10.39],
            [1999, 585, 70, 70],
            [1999, 586, 50, 60],
            [1999, 588, 12, 22.5],
            [1999, 589, 120, 90],
            [1999, 590, 53.52, 61.02],
            [1999, 591, 120, 90],
            [1999, 593, 65, 51.92],
            [1999, 594, 70, 70],
            [1999, 595, 62.54, 30.08],
            [1999, 596, 8.9, 17.2],
            [1999, 597, 40.93, 18.93],
            [1999, 599, 37.1, 32.34],
            [1999, 600, 120, 90],
            [1999, 601, 70, 70],
            [1999, 604, 77.66, 49.79],
            [1999, 606, 70, 70],
            [1999, 607, 50, 60],
            [1999, 608, 54.37, 25.93],
            [1999, 610, 50, 60],
            [1999, 611, 50, 60],
            [1999, 612, 45.76, 60.33],
            [1999, 614, 28.93, 29.68],
            [1999, 615, 120, 90],
            [1999, 616, 120, 90],
            [1999, 618, 30, 37.5],
            [1999, 619, 120, 90],
            [1999, 621, 120, 90],
            [1999, 623, 8.39, 6.11],
            [1999, 625, 51.68, 25.98],
            [1999, 626, 40, 50],
            [1999, 627, 50, 60],
            [1999, 628, 20.36, 23.58],
            [1999, 629, 18.8, 33.4],
            [1999, 630, 70, 70],
            [1999, 631, 43.54, 34.8],
            [1999, 633, 120, 90],
            [1999, 635, 70, 70],
            [1999, 636, 21.1, 50.2],
            [1999, 637, 7.79, 7.02],
            [1999, 639, 70, 70],
            [1999, 641, 120, 90],
            [1999, 645, 97.67, 37.44],
            [1999, 647, 70, 70],
            [1999, 648, 70, 70],
            [1999, 649, 70, 70],
            [1999, 650, 120, 90],
            [1999, 651, 120, 90],
            [1999, 653, 70, 70],
            [1999, 654, 12.52, 17.79],
            [1999, 656, 120, 90],
            [1999, 657, 120, 90],
            [1999, 659, 7.56, 7.64],
            [1999, 660, 24.24, 22.96],
            [1999, 662, 120, 90],
            [1999, 663, 69.14, 36.97],
            [1999, 664, 70, 70],
            [1999, 665, 120, 90],
            [1999, 666, 120, 90],
            [1999, 669, 50, 30.85],
            [1999, 670, 70, 70],
            [1999, 672, 70, 70],
            [1999, 673, 120, 90],
            [1999, 675, 70, 70],
            [1999, 678, 47.55, 39.99],
            [1999, 679, 120, 90],
            [1999, 680, 10.1, 8.13],
            [1999, 681, 70, 70],
            [1999, 682, 8.1, 6.18],
            [1999, 683, 9.08, 9.76],
            [1999, 686, 16.9, 21.27],
            [1999, 687, 120, 90],
            [1999, 688, 120, 90],
            [1999, 690, 40, 50],
            [1999, 691, 18.17, 15.1],
            [1999, 692, 70, 70],
            [1999, 693, 70, 70],
            [1999, 694, 50, 42.14],
            [1999, 695, 74.53, 49.3],
            [1999, 697, 120, 90],
            [1999, 698, 70, 70],
            [1999, 700, 70, 70],
            [1999, 701, 120, 90],
            [1999, 702, 70, 70],
            [1999, 703, 12, 18],
            [1999, 704, 55.7, 36.5],
            [1999, 705, 30, 45],
            [1999, 706, 70, 70],
            [1999, 708, 70, 70],
            [1999, 709, 32.88, 46.39],
            [1999, 710, 120, 90],
            [1999, 711, 50, 60],
            [1999, 714, 50, 60],
            [1999, 715, 120, 90],
            [1999, 716, 70, 70],
            [1999, 717, 36.27, 32.74],
            [1999, 718, 50, 60],
            [1999, 719, 120, 90],
            [1999, 720, 87.15, 35.16],
            [1999, 721, 50, 60],
            [1999, 722, 120, 90],
            [1999, 723, 50, 60],
            [1999, 724, 29.85, 64.97],
            [1999, 727, 50, 45],
            [1999, 730, 120, 90],
            [1999, 731, 41.75, 21.4],
            [1999, 734, 18.45, 34.92],
            [1999, 737, 10.58, 13.69],
            [1999, 738, 120, 90],
            [1999, 740, 18, 27],
            [1999, 741, 120, 90],
            [1999, 742, 25, 15.29],
            [1999, 745, 120, 90],
            [1999, 746, 40, 50],
            [1999, 747, 85.74, 47.21],
            [1999, 748, 70, 70],
            [1999, 749, 50, 60],
            [1999, 750, 133.42, 46.75],
            [1999, 751, 70, 70],
            [1999, 753, 50, 60],
            [1999, 754, 36.5, 31.71],
            [1999, 756, 83, 140],
            [1999, 759, 70, 70],
            [1999, 762, 70, 70],
            [1999, 763, 70, 70],
            [1999, 766, 100.6, 37.63],
            [1999, 767, 70, 70],
            [1999, 769, 37.94, 60],
            [1999, 771, 120, 90],
            [1999, 772, 70, 70],
            [1999, 773, 64.93, 30.4],
            [1999, 775, 70, 70],
            [1999, 776, 120, 90],
            [1999, 778, 120, 90],
            [1999, 779, 50, 60],
            [1999, 781, 71.84, 33.52],
            [1999, 782, 120, 90],
            [1999, 783, 50, 45],
            [1999, 784, 33.43, 46.1],
            [1999, 785, 120, 90],
            [1999, 787, 18, 23.03],
            [1999, 789, 70, 70],
            [1999, 790, 60.28, 19.43],
            [1999, 795, 120, 90],
            [1999, 796, 70, 70],
            [1999, 799, 50, 60],
            [1999, 801, 35.37, 49.96],
            [1999, 802, 120, 90],
            [1999, 803, 42.57, 40],
            [1999, 804, 120, 90],
            [1999, 805, 13.65, 18.71],
            [1999, 806, 120, 90],
            [1999, 807, 9.12, 12.1],
            [1999, 811, 120, 90],
            [1999, 812, 50, 60],
            [1999, 813, 8.07, 6.92],
            [1999, 814, 120, 90],
            [1999, 815, 30.9, 14.34],
            [1999, 818, 70, 70],
            [1999, 819, 120, 90],
            [1999, 820, 50, 65],
            [1999, 821, 24.1, 26.31],
            [1999, 822, 18.48, 22.65],
            [1999, 823, 120, 90],
            [1999, 824, 120, 90],
            [1999, 825, 70, 70],
            [1999, 826, 17.52, 8.25],
            [1999, 827, 12, 18],
            [1999, 829, 8.45, 6.52],
            [1999, 830, 120, 90],
            [1999, 831, 120, 90],
            [1999, 833, 120, 90],
            [1999, 835, 69.3, 61.77],
            [1999, 836, 120, 90],
            [1999, 837, 70, 70],
            [1999, 840, 120, 90],
            [1999, 842, 50, 60],
            [1999, 843, 50.2, 42.1],
            [1999, 844, 117.83, 54.95],
            [1999, 845, 79.17, 68.36],
            [1999, 846, 120, 90],
            [1999, 847, 70, 70],
            [1999, 848, 9.12, 11.53],
            [1999, 850, 40, 50],
            [1999, 851, 18.96, 12.46],
            [1999, 852, 70, 70],
            [1999, 855, 6.73, 7.13],
            [1999, 857, 120, 90],
            [1999, 860, 70, 70],
            [1999, 863, 13.7, 17.4],
            [1999, 865, 70, 42.13],
            [1999, 867, 120, 90],
            [1999, 869, 70, 70],
            [1999, 871, 16.44, 22.77],
            [1999, 872, 70, 70],
            [1999, 873, 51, 70],
            [1999, 875, 120, 90],
            [1999, 876, 120, 90],
            [1999, 877, 120, 90],
            [1999, 878, 5.59, 4.6],
            [1999, 881, 120, 90],
            [1999, 882, 50, 60],
            [1999, 883, 120, 90],
            [1999, 884, 70, 70],
            [1999, 885, 70, 70],
            [1999, 886, 120, 90],
            [1999, 889, 11.95, 11.28],
            [1999, 890, 62.93, 34.45],
            [1999, 891, 120, 90],
            [1999, 892, 120, 90],
            [1999, 894, 23.13, 17.71],
            [1999, 895, 120, 90],
            [1999, 896, 70, 70],
            [1999, 897, 13.97, 22.37],
            [1999, 899, 120, 90],
            [1999, 900, 6.81, 4.72],
            [1999, 901, 120, 90],
            [1999, 905, 120, 90],
            [1999, 909, 120, 90],
            [1999, 910, 11.75, 7.29],
            [1999, 913, 21.73, 18.25],
            [1999, 914, 120, 90],
            [1999, 915, 38.46, 49.72],
            [1999, 916, 40, 50],
            [1999, 917, 30, 45],
            [1999, 918, 62, 50],
            [1999, 919, 120, 90],
            [1999, 922, 50, 60],
            [1999, 924, 8.93, 9.74],
            [1999, 926, 40.84, 38.58],
            [1999, 927, 70, 70],
            [1999, 928, 120, 90],
            [1999, 929, 120, 90],
            [1999, 930, 50, 60],
            [1999, 931, 70, 70],
            [1999, 934, 37.5, 45],
            [1999, 935, 120, 90],
            [1999, 936, 50, 60],
            [1999, 937, 120, 90],
            [1999, 938, 12, 18],
            [1999, 940, 12, 18],
            [1999, 941, 70, 70],
            [1999, 942, 70, 70],
            [1999, 944, 96.61, 70.21],
            [1999, 945, 50, 60],
            [1999, 946, 50, 60],
            [1999, 948, 31.14, 15],
            [1999, 949, 79.45, 48.51],
            [1999, 950, 13.52, 21.99],
            [1999, 952, 12.6, 9.35],
            [1999, 953, 70, 70],
            [1999, 954, 120, 90],
            [1999, 955, 120, 90],
            [1999, 957, 120, 90],
            [1999, 958, 59.87, 32.44],
            [1999, 960, 50, 60],
            [1999, 961, 120, 90],
            [1999, 963, 70, 70],
            [1999, 964, 12, 15],
            [1999, 965, 50.79, 35],
            [1999, 966, 4.52, 4.32],
            [1999, 969, 52.88, 45.27],
            [1999, 970, 50, 60],
            [1999, 971, 35.72, 14.91],
            [1999, 972, 35.77, 19.67],
            [1999, 974, 30, 45],
            [1999, 976, 8.35, 13.15],
            [1999, 977, 12.22, 8.58],
            [1999, 978, 70, 48.36],
            [1999, 979, 36.64, 34.46],
            [1999, 980, 70, 70],
            [1999, 982, 120, 90],
            [1999, 983, 71.83, 30.1],
            [1999, 985, 194.37, 75.01],
            [1999, 986, 7.84, 7.68],
            [1999, 987, 120, 90],
            [1999, 988, 6.14, 5.32],
            [1999, 990, 71.86, 39.63],
            [1999, 991, 120, 90],
            [1999, 993, 89.04, 64.77],
            [1999, 994, 40, 50],
            [1999, 997, 120, 90],
            [1999, 998, 70, 70],
            [1999, 999, 120, 90],
            [1999, 1000, 40, 50],
            [1999, 1003, 7.76, 5.82],
            [1999, 1004, 70, 70],
            [1999, 1005, 40, 50],
            [1999, 1006, 120, 90],
            [1999, 1007, 28.86, 20.82],
            [1999, 1008, 37.5, 45],
            [1999, 1009, 120, 90],
            [1999, 1013, 70, 70],
            [1999, 1015, 70, 70],
            [1999, 1016, 14.94, 23.74],
            [1999, 1017, 50, 60],
            [1999, 1018, 120, 90],
            [1999, 1020, 70, 70],
            [1999, 1021, 70, 70],
            [1999, 1022, 120, 90],
            [1999, 1023, 13.9, 28.3],
            [1999, 1025, 120, 90],
            [1999, 1027, 120, 90],
            [1999, 1028, 50, 60],
            [1999, 1029, 70, 70],
            [1999, 1030, 7, 9.5],
            [1999, 1032, 23, 23.89],
            [1999, 1033, 27.47, 30.75],
            [1999, 1034, 70, 70],
            [1999, 1036, 6.74, 8.62],
            [1999, 1038, 70, 70],
            [1999, 1039, 120, 90],
            [1999, 1042, 120, 90],
            [1999, 1043, 12.3, 25.3],
            [1999, 1044, 120, 90],
            [1999, 1045, 120, 90],
            [1999, 1046, 50, 60],
            [1999, 1047, 70, 70],
            [1999, 1048, 70, 70],
            [1999, 1050, 70, 70],
            [1999, 1051, 92.72, 35.97],
            [1999, 1052, 50, 60],
            [1999, 1053, 50, 60],
            [1999, 1054, 70, 70],
            [1999, 1056, 22.3, 25.8],
            [1999, 1057, 50, 60],
            [1999, 1058, 70, 70],
            [1999, 1059, 65.53, 68.84],
            [1999, 1061, 70, 70],
            [1999, 1062, 7.92, 8.74],
            [1999, 1063, 120, 90],
            [1999, 1064, 50, 60],
            [1999, 1065, 120, 90],
            [1999, 1066, 50, 60],
            [1999, 1067, 120, 90],
            [1999, 1069, 50, 60],
            [1999, 1070, 20.5, 19],
            [1999, 1071, 125.97, 49.26],
            [1999, 1073, 84.92, 72.24],
            [1999, 1075, 6.43, 6.35],
            [1999, 1077, 120, 90],
            [1999, 1078, 120, 90],
            [1999, 1080, 120, 90],
            [1999, 1081, 53.54, 36.15],
            [1999, 1082, 75, 64.64],
            [1999, 1084, 160.19, 70.76],
            [1999, 1087, 130.51, 58.25],
            [1999, 1090, 120, 90],
            [1999, 1091, 40, 50],
            [1999, 1092, 12, 18],
            [1999, 1093, 50, 60],
            [1999, 1094, 23.66, 23.15],
            [1999, 1095, 34.76, 26.62],
            [1999, 1096, 120, 90],
            [1999, 1097, 8.07, 10.33],
            [1999, 1099, 13.78, 13.14],
            [1999, 1100, 55.33, 47.25],
            [1999, 1102, 20.14, 33.65],
            [1999, 1104, 70, 70],
            [1999, 1106, 70, 70],
            [1999, 1108, 120, 90],
            [1999, 1109, 71.26, 34.85],
            [1999, 1110, 120, 90],
            [1999, 1111, 68.1, 60.82],
            [1999, 1113, 120, 90],
            [1999, 1114, 120, 90],
            [1999, 1117, 50, 60],
            [1999, 1118, 50, 60],
            [1999, 1119, 50, 60],
            [1999, 1120, 120, 90],
            [1999, 1121, 120, 90],
            [1999, 1122, 120, 90],
            [1999, 1124, 33.6, 22.42],
            [1999, 1125, 120, 90],
            [1999, 1126, 70, 70],
            [1999, 1127, 120, 90],
            [1999, 1128, 70, 70],
            [1999, 1129, 50, 60],
            [1999, 1130, 120, 90],
            [1999, 1131, 19.62, 27.9],
            [1999, 1132, 12, 18],
            [1999, 1136, 64.79, 64.92],
            [1999, 1137, 120, 90],
            [1999, 1138, 166, 148],
            [1999, 1139, 70, 70],
            [1999, 1140, 50, 45],
            [1999, 1141, 151.96, 55.04],
            [1999, 1142, 87.4, 44.91],
            [1999, 1144, 70.4, 75.66],
            [1999, 1145, 120, 90],
            [1999, 1147, 12.27, 6.99],
            [1999, 1149, 53.28, 35.03],
            [1999, 1150, 50, 60],
            [1999, 1152, 36.81, 97.97],
            [1999, 1153, 120, 90],
            [1999, 1154, 120, 90],
            [1999, 1155, 12.52, 12.5],
            [1999, 1156, 50, 60],
            [1999, 1157, 40.32, 25.17],
            [1999, 1158, 50, 60],
            [1999, 1159, 70, 60],
            [1999, 1161, 120, 90],
            [1999, 1163, 19.1, 28.7],
            [1999, 1164, 120, 90],
            [1999, 1165, 120, 90],
            [1999, 1167, 85.7, 63.16],
            [1999, 1168, 120, 90],
            [1999, 1169, 34.55, 69.22],
            [1999, 1170, 70, 70],
            [1999, 1171, 70, 70],
            [1999, 1172, 70, 70],
            [1999, 1173, 50, 60],
            [1999, 1174, 37.2, 58.3],
            [1999, 1175, 28.04, 39.32],
            [1999, 1176, 120, 90],
            [1999, 1177, 70, 70],
            [1999, 1178, 8.86, 7.64],
            [1999, 1180, 15.85, 14.23],
            [1999, 1181, 120, 90],
            [1999, 1186, 15.33, 18],
            [1999, 1187, 120, 90],
            [1999, 1188, 40, 50],
            [1999, 1189, 120, 90],
            [1999, 1190, 70, 70],
            [1999, 1191, 67.28, 35],
            [1999, 1194, 82.38, 42.91],
            [1999, 1195, 120, 90],
            [1999, 1198, 120, 90],
            [1999, 1199, 40, 50],
            [1999, 1200, 27.2, 13.54],
            [1999, 1202, 30, 45],
            [1999, 1203, 15, 25],
            [1999, 1204, 70, 70],
            [1999, 1205, 85.87, 50.11],
            [1999, 1206, 120, 90],
            [1999, 1207, 30, 45],
            [1999, 1209, 40, 50],
            [1999, 1210, 40, 37.5],
            [1999, 1211, 53.75, 32.19],
            [1999, 1212, 70, 70],
            [1999, 1213, 40, 50],
            [1999, 1214, 70, 70],
            [1999, 1216, 50, 60],
            [1999, 1217, 90.55, 46.37],
            [1999, 1219, 116.48, 55.12],
            [1999, 1221, 22.66, 24.86],
            [1999, 1223, 70, 70],
            [1999, 1224, 49.77, 79.26],
            [1999, 1225, 50, 60],
            [1999, 1226, 25.67, 16.67],
            [1999, 1227, 120, 90],
            [1999, 1228, 57.49, 37.38],
            [1999, 1230, 50, 60],
            [1999, 1233, 50, 60],
            [1999, 1234, 12, 18],
            [1999, 1235, 50, 60],
            [1999, 1236, 70, 70],
            [1999, 1237, 37.5, 45],
            [1999, 1238, 14.2, 20.8],
            [1999, 1239, 120, 90],
            [1999, 1240, 120, 90],
            [1999, 1244, 70, 70],
            [1999, 1245, 120, 90],
            [1999, 1246, 70, 70],
            [1999, 1247, 70, 70],
            [1999, 1250, 70, 70],
            [1999, 1251, 70, 70],
            [1999, 1253, 50, 60],
            [1999, 1254, 70, 70],
            [1999, 1255, 120, 90],
            [1999, 1257, 40, 50],
            [1999, 1259, 105.06, 30.34],
            [1999, 1260, 50, 60],
            [1999, 1262, 110.05, 49.65],
            [1999, 1263, 120, 90],
            [1999, 1264, 120, 90],
            [1999, 1265, 13.11, 9.3],
            [1999, 1266, 120, 90],
            [1999, 1268, 30.72, 32.5],
            [1999, 1269, 50, 60],
            [1999, 1271, 85.26, 44.5],
            [1999, 1272, 70, 70],
            [1999, 1275, 36.46, 15.29],
            [1999, 1276, 70, 70],
            [1999, 1278, 18.5, 14.7],
            [1999, 1280, 11.06, 6.23],
            [1999, 1281, 21.65, 27],
            [1999, 1282, 50, 60],
            [1999, 1286, 120, 90],
            [1999, 1287, 70, 70],
            [1999, 1288, 70, 70],
            [1999, 1290, 120, 90],
            [1999, 1292, 70, 70],
            [1999, 1293, 4.01, 4.97],
            [1999, 1295, 70, 70],
            [1999, 1298, 50, 60],
            [1999, 1299, 70, 70],
            [1999, 1301, 70, 70],
            [1999, 1302, 30, 45],
            [1999, 1303, 70, 70],
            [1999, 1305, 17.46, 22.11],
            [1999, 1306, 12.9, 26.6],
            [1999, 1312, 26.57, 15.77],
            [1999, 1313, 120, 90],
            [1999, 1314, 23.54, 16.63],
            [1999, 1315, 120, 90],
            [1999, 1317, 70, 70],
            [1999, 1318, 120, 90],
            [1999, 1319, 46.62, 28.16],
            [1999, 1320, 120, 90],
            [1999, 1321, 48.13, 28.8],
            [1999, 1323, 75.54, 72.3],
            [1999, 1324, 120, 90],
            [1999, 1325, 120, 90],
            [1999, 1326, 70, 70],
            [1999, 1327, 70, 70],
            [1999, 1328, 69.9, 51.49],
            [1999, 1331, 120, 90],
            [1999, 1332, 5.42, 3.32],
            [1999, 1333, 120, 90],
            [1999, 1334, 87.72, 70.36],
            [1999, 1335, 22.9, 24.9],
            [1999, 1337, 5.66, 6.03],
            [1999, 1338, 120, 90],
            [1999, 1339, 11.12, 8.5],
            [1999, 1340, 53.22, 39.25],
            [1999, 1341, 120, 90],
            [1999, 1342, 70, 70],
            [1999, 1345, 40, 50],
            [1999, 1346, 50, 60],
            [1999, 1349, 97, 131],
            [1999, 1350, 70, 70],
            [1999, 1351, 70, 70],
            [1999, 1352, 120, 90],
            [1999, 1353, 70, 70],
            [1999, 1355, 120, 90],
            [1999, 1357, 70, 70],
            [1999, 1358, 120, 90],
            [1999, 1359, 67.94, 52.51],
            [1999, 1360, 18, 27],
            [1999, 1361, 77.94, 60.66],
            [1999, 1363, 83.47, 31.82],
            [1999, 1367, 53.29, 36.48],
            [1999, 1370, 17.21, 28.49],
            [1999, 1371, 70, 70],
            [1999, 1372, 120, 90],
            [1999, 1375, 22.3, 23.87],
            [1999, 1376, 30, 37.5],
            [1999, 1378, 70, 70],
            [1999, 1379, 120, 90],
            [1999, 1380, 70, 70],
            [1999, 1381, 120, 90],
            [1999, 1382, 26.47, 36.84],
            [1999, 1383, 8.45, 7.72],
            [1999, 1385, 70, 70],
            [1999, 1387, 40, 50],
            [1999, 1388, 120, 90],
            [1999, 1391, 120, 90],
            [1999, 1392, 120, 90],
            [1999, 1393, 70, 70],
            [1999, 1395, 70, 70],
            [1999, 1396, 12, 24.84],
            [1999, 1398, 40, 50],
            [1999, 1399, 7.42, 6.96],
            [1999, 1402, 70, 70],
            [1999, 1404, 40, 50],
            [1999, 1405, 120, 90],
            [1999, 1406, 4.67, 5.31],
            [1999, 1410, 70, 70],
            [1999, 1411, 50, 60],
            [1999, 1415, 70, 70],
            [1999, 1417, 120, 90],
            [1999, 1420, 50, 60],
            [1999, 1421, 120, 90],
            [1999, 1422, 120, 90],
            [1999, 1424, 50, 60],
            [1999, 1426, 12.76, 9.29],
            [1999, 1427, 23.02, 15.67],
            [1999, 1428, 8.98, 6.72],
            [1999, 1431, 120, 90],
            [1999, 1432, 6.73, 6.53],
            [1999, 1434, 53.67, 36.6],
            [1999, 1436, 70, 70],
            [1999, 1438, 70, 70],
            [1999, 1439, 120, 90],
            [1999, 1440, 70, 70],
            [1999, 1441, 120, 90],
            [1999, 1442, 70, 70],
            [1999, 1443, 57.46, 26.71],
            [1999, 1444, 120, 90],
            [1999, 1445, 85.92, 19.7],
            [1999, 1448, 70, 70],
            [1999, 1449, 120, 90],
            [1999, 1450, 120, 90],
            [1999, 1451, 120, 90],
            [1999, 1453, 70, 70],
            [1999, 1454, 20.61, 20.28],
            [1999, 1456, 70, 70],
            [1999, 1459, 120, 90],
            [1999, 1460, 78, 74],
            [1999, 1461, 6.14, 6.98],
            [1999, 1464, 50, 60],
            [1999, 1465, 30.3, 26.6],
            [1999, 1466, 50, 60],
            [1999, 1467, 70, 70],
            [1999, 1469, 70, 70],
            [1999, 1470, 35, 45],
            [1999, 1471, 58.78, 40.42],
            [1999, 1472, 120, 90],
            [1999, 1473, 11.99, 10.02],
            [1999, 1474, 18, 27],
            [1999, 1475, 93.38, 40.44],
            [1999, 1476, 39.76, 77.7],
            [1999, 1477, 104.5, 55.33],
            [1999, 1478, 14.96, 11.47],
            [1999, 1479, 40, 50],
            [1999, 1481, 70, 70],
            [1999, 1482, 12.31, 14.89],
            [1999, 1483, 70, 70],
            [1999, 1484, 24.92, 66.54],
            [1999, 1485, 120, 90],
            [1999, 1486, 73.81, 56.6],
            [1999, 1487, 120, 90],
            [1999, 1488, 120, 90],
            [1999, 1490, 35.69, 22.38],
            [1999, 1491, 11.32, 8.34],
            [1999, 1493, 40.01, 20.74],
            [1999, 1503, 120, 90],
            [1999, 1505, 120, 90],
            [1999, 1506, 120, 90],
            [1999, 1507, 70, 70],
            [1999, 1508, 21.47, 18.5],
            [1999, 1509, 120, 90],
            [1999, 1510, 31.13, 26.62],
            [1999, 1511, 21.14, 10.89],
            [1999, 1512, 50, 60],
            [1999, 1513, 70, 70],
            [1999, 1514, 75, 105],
            [1999, 1515, 30, 45],
            [1999, 1516, 70, 70],
            [1999, 1518, 120, 90],
            [1999, 1519, 120, 90],
            [1999, 1520, 70, 70],
            [1999, 1521, 120, 90],
            [1999, 1522, 35.03, 33.83],
            [1999, 1523, 120, 90],
            [1999, 1524, 120, 90],
            [1999, 1525, 30, 37.5],
            [1999, 1526, 19.7, 33.1],
            [1999, 1527, 17.34, 33.26],
            [1999, 1530, 97.88, 79.23],
            [1999, 1533, 70, 70],
            [1999, 1534, 10.96, 7.99],
            [1999, 1536, 30.57, 20.35],
            [1999, 1537, 35.55, 43.28],
            [1999, 1538, 120, 90],
            [1999, 1539, 20, 15],
            [1999, 1540, 40, 50],
            [1999, 1541, 70, 70],
            [1999, 1542, 50, 60],
            [1999, 1544, 120, 90],
            [1999, 1546, 70, 70],
            [1999, 1547, 70, 70],
            [1999, 1548, 120, 90],
            [1999, 1549, 233, 267],
            [1999, 1550, 120, 90],
            [1999, 1552, 30, 45],
            [1999, 1553, 70.57, 50.89],
            [1999, 1555, 30, 37.5],
            [1999, 1556, 27.63, 11.76],
            [1999, 1557, 59.6, 36.82],
            [1999, 1559, 50, 60],
            [1999, 1561, 30.82, 30.34],
            [1999, 1562, 97.79, 51.18],
            [1999, 1565, 120, 90],
            [1999, 1568, 17.56, 11.49],
            [1999, 1571, 70, 70],
            [1999, 1572, 120, 90],
            [1999, 1574, 50, 60],
            [1999, 1575, 124.82, 81.48],
            [1999, 1576, 50, 60],
            [1999, 1577, 50, 60],
            [1999, 1578, 120, 90],
            [1999, 1580, 50, 60],
            [1999, 1581, 17.87, 10.61],
            [1999, 1582, 22.41, 22.97],
            [1999, 1585, 70, 70],
            [1999, 1587, 18, 27],
            [1999, 1589, 70, 70],
            [1999, 1590, 70, 70],
            [1999, 1591, 12.9, 21.1],
            [1999, 1592, 70, 70],
            [1999, 1593, 25.91, 24.87],
            [1999, 1595, 70, 70],
            [1999, 1596, 120, 90],
            [1999, 1597, 70, 70],
            [1999, 1598, 15.38, 8.13],
            [1999, 1600, 120, 90],
            [1999, 1601, 70, 70],
            [1999, 1602, 120, 90],
            [1999, 1603, 50, 60],
            [1999, 1605, 50, 60],
            [1999, 1607, 70, 70],
            [1999, 1609, 120, 90],
            [1999, 1610, 18.25, 11.14],
            [1999, 1612, 120, 90],
            [1999, 1615, 120, 90],
            [1999, 1617, 120, 90],
            [1999, 1619, 8.99, 11.56],
            [1999, 1620, 40, 50],
            [1999, 1621, 70, 70],
            [1999, 1623, 50, 114],
            [1999, 1624, 120, 90],
            [1999, 1625, 70, 70],
            [1999, 1626, 70, 70],
            [1999, 1627, 70, 70],
            [1999, 1628, 50, 60],
            [1999, 1629, 40, 50],
            [1999, 1630, 70.01, 36.62],
            [1999, 1632, 8.5, 7.41],
            [1999, 1634, 70, 70],
            [1999, 1635, 16.96, 17.21],
            [1999, 1637, 120, 90],
            [1999, 1638, 52.95, 70],
            [1999, 1639, 70, 70],
            [1999, 1640, 70, 70],
            [1999, 1641, 50.33, 45.33],
            [1999, 1643, 18.14, 18.53],
            [1999, 1644, 48.21, 38.33],
            [1999, 1645, 70, 70],
            [1999, 1647, 70, 70],
            [1999, 1648, 120, 90],
            [1999, 1649, 120, 90],
            [1999, 1650, 70, 70],
            [1999, 1651, 120, 90],
            [1999, 1652, 57.04, 46.09],
            [1999, 1653, 35, 26.28],
            [1999, 1654, 50, 60],
            [1999, 1656, 8.28, 5.7],
            [1999, 1657, 70, 70],
            [1999, 1658, 120, 90],
            [1999, 1659, 38.85, 38.2],
            [1999, 1660, 134.83, 48.67],
            [1999, 1661, 70, 70],
            [1999, 1662, 20.69, 28.99],
            [1999, 1663, 28.45, 30.94],
            [1999, 1664, 22.26, 19.82],
            [1999, 1665, 28.19, 19.28],
            [1999, 1666, 6.17, 5.14],
            [1999, 1667, 120, 90],
            [1999, 1668, 70, 70],
            [1999, 1669, 120, 90],
            [1999, 1671, 120, 90],
            [1999, 1672, 20.29, 61.88],
            [1999, 1673, 40.58, 28.22],
            [1999, 1674, 70, 70],
            [1999, 1675, 9.08, 16.02],
            [1999, 1679, 33.66, 20.7],
            [1999, 1680, 55.76, 53.89],
            [1999, 1681, 120, 90],
            [1999, 1684, 120, 90],
            [1999, 1685, 37.5, 45],
            [1999, 1686, 120, 90],
            [1999, 1688, 25.71, 34.65],
            [1999, 1689, 120, 90],
            [1999, 1690, 120, 90],
            [1999, 1692, 120, 90],
            [1999, 1694, 120, 90],
            [1999, 1695, 120, 90],
            [1999, 1697, 70, 70],
            [1999, 1701, 70, 70],
            [1999, 1702, 70, 70],
            [1999, 1704, 32.73, 29.33],
            [1999, 1705, 70, 70],
            [1999, 1706, 40, 50],
            [1999, 1707, 30, 17.24],
            [1999, 1709, 16, 15.44],
            [1999, 1711, 70, 70],
            [1999, 1713, 50, 60],
            [1999, 1715, 120, 90],
            [1999, 1717, 70, 70],
            [1999, 1720, 4.58, 3.57],
            [1999, 1722, 120, 90],
            [1999, 1724, 31.04, 29.1],
            [1999, 1726, 120, 90],
            [1999, 1728, 120, 90],
            [1999, 1729, 36.89, 30.28],
            [1999, 1730, 12, 18],
            [1999, 1734, 17.03, 13.98],
            [1999, 1737, 70, 70],
            [1999, 1739, 70, 70],
            [1999, 1740, 50, 60],
            [1999, 1741, 70, 70],
            [1999, 1742, 120, 90],
            [1999, 1743, 70, 70],
            [1999, 1744, 48.44, 41.98],
            [1999, 1745, 34.11, 14.96],
            [1999, 1746, 70, 70],
            [1999, 1748, 109.42, 45.47],
            [1999, 1749, 50, 60],
            [1999, 1750, 70, 70],
            [1999, 1752, 120, 90],
            [1999, 1753, 25.17, 15.07],
            [1999, 1754, 120, 90],
            [1999, 1756, 47.81, 29.86],
            [1999, 1757, 70, 70],
            [1999, 1758, 70, 70],
            [1999, 1760, 12.98, 21.4],
            [1999, 1763, 43.44, 47.84],
            [1999, 1764, 131, 250],
            [1999, 1765, 50, 60],
            [1999, 1766, 120, 90],
            [1999, 1767, 120, 88.81],
            [1999, 1769, 70, 60.5],
            [1999, 1770, 80, 70],
            [1999, 1771, 19.39, 23.78],
            [1999, 1772, 25.48, 41.18],
            [1999, 1773, 50, 60],
            [1999, 1774, 17.87, 21.37],
            [1999, 1775, 70, 70],
            [1999, 1776, 35.63, 37.22],
            [1999, 1778, 120, 90],
            [1999, 1779, 38.19, 95.28],
            [1999, 1780, 37.79, 33.06],
            [1999, 1781, 113.83, 52.58],
            [1999, 1783, 12.6, 22.4],
            [1999, 1784, 70, 70],
            [1999, 1785, 120, 90],
            [1999, 1786, 40.8, 58.18],
            [1999, 1787, 120, 90],
            [1999, 1788, 120, 90],
            [1999, 1789, 120, 90],
            [1999, 1790, 48.09, 38.27],
            [1999, 1792, 25.36, 24.69],
            [1999, 1793, 70, 70],
            [1999, 1794, 42.48, 37.47],
            [1999, 1795, 13.2, 9.9],
            [1999, 1796, 50, 60],
            [1999, 1797, 70, 70],
            [1999, 1798, 70, 70],
            [1999, 1799, 4.8, 5.01],
            [1999, 1800, 9.59, 5.61],
            [1999, 1801, 70, 70],
            [1999, 1802, 120, 90],
            [1999, 1803, 120, 90],
            [1999, 1804, 105.47, 52.76],
            [1999, 1806, 120, 90],
            [1999, 1809, 120, 90],
            [1999, 1811, 120, 90],
            [1999, 1812, 43.07, 42.87],
            [1999, 1814, 40, 50],
            [1999, 1815, 15.67, 9.13],
            [1999, 1816, 83.79, 61.8],
            [1999, 1817, 90.35, 31.74],
            [1999, 1818, 27.25, 18.05],
            [1999, 1819, 70, 70],
            [1999, 1822, 70, 70],
            [1999, 1824, 50, 65],
            [1999, 1825, 50.4, 52.17],
            [1999, 1827, 70, 70],
            [1999, 1829, 23.1, 41.1],
            [1999, 1832, 70, 70],
            [1999, 1833, 120, 90],
            [1999, 1834, 120, 90],
            [1999, 1837, 120, 90],
            [1999, 1839, 70, 70],
            [1999, 1841, 70, 70],
            [1999, 1843, 14.6, 12.44],
            [1999, 1844, 30, 45],
            [1999, 1845, 20.52, 19.97],
            [1999, 1846, 120, 90],
            [1999, 1847, 50, 60],
            [1999, 1848, 66.18, 60.25],
            [1999, 1849, 120, 90],
            [1999, 1850, 7.35, 6.92],
            [1999, 1851, 7.82, 10.41],
            [1999, 1852, 40.34, 32.16],
            [1999, 1853, 120, 90],
            [1999, 1855, 120, 90],
            [1999, 1856, 30, 45],
            [1999, 1857, 70, 70],
            [1999, 1859, 120, 90],
            [1999, 1860, 120, 90],
            [1999, 1863, 16.62, 11.53],
            [1999, 1864, 94.1, 90],
            [1999, 1866, 70, 70],
            [1999, 1868, 120, 90],
            [1999, 1869, 40, 37.5],
            [1999, 1870, 70, 70],
            [1999, 1873, 70, 70],
            [1999, 1875, 40, 50],
            [1999, 1876, 35.35, 35.59],
            [1999, 1877, 120, 90],
            [1999, 1879, 43.02, 40.39],
            [1999, 1881, 55.94, 67.39],
            [1999, 1882, 104.15, 43.17],
            [1999, 1883, 120, 90],
            [1999, 1884, 50, 60],
            [1999, 1885, 70, 70],
            [1999, 1886, 50, 60],
            [1999, 1887, 70, 70],
            [1999, 1888, 120, 90],
            [1999, 1889, 70, 70],
            [1999, 1890, 120, 90],
            [1999, 1891, 33.58, 60],
            [1999, 1892, 70, 70],
            [1999, 1894, 50, 60],
            [1999, 1895, 79.91, 49.67],
            [1999, 1896, 120, 90],
            [1999, 1897, 13.67, 11.12],
            [1999, 1898, 8.67, 4.23],
            [1999, 1899, 70, 70],
            [1999, 1900, 30, 45],
            [1999, 1901, 27.52, 29.78],
            [1999, 1903, 70, 70],
            [1999, 1904, 120, 90],
            [1999, 1906, 19.49, 10.43],
            [1999, 1909, 120, 90],
            [1999, 1910, 120, 90],
            [1999, 1912, 70, 70],
            [1999, 1914, 120, 90],
            [1999, 1915, 57.34, 41.55],
            [1999, 1916, 120, 90],
            [1999, 1917, 120, 90],
            [1999, 1919, 120, 90],
            [1999, 1920, 70, 70],
            [1999, 1921, 28.17, 26.56],
            [1999, 1924, 120, 90],
            [1999, 1925, 59.83, 43.65],
            [1999, 1928, 120, 90],
            [1999, 1929, 6.5, 4.93],
            [1999, 1930, 10.76, 8.15],
            [1999, 1933, 12.42, 12.39],
            [1999, 1937, 70, 70],
            [1999, 1938, 120, 90],
            [1999, 1940, 151, 263],
            [1999, 1941, 120, 90],
            [1999, 1945, 45.16, 27.63],
            [1999, 1946, 70, 70],
            [1999, 1948, 26.6, 21.6],
            [1999, 1949, 120, 90],
            [1999, 1950, 42.96, 58.04],
            [1999, 1952, 92.32, 71.14],
            [1999, 1955, 50, 60],
            [1999, 1956, 40, 50],
            [1999, 1957, 70, 70],
            [1999, 1959, 120, 90],
            [1999, 1961, 120, 90],
            [1999, 1962, 15.89, 20.58],
            [1999, 1963, 7.89, 5.56],
            [1999, 1964, 79.54, 41.58],
            [1999, 1965, 50, 59.43],
            [1999, 1967, 70, 70],
            [1999, 1969, 70, 70],
            [1999, 1972, 8.68, 7.21],
            [1999, 1974, 70, 70],
            [1999, 1976, 9.37, 9.9],
            [1999, 1978, 70, 70],
            [1999, 1979, 50, 60],
            [1999, 1980, 120, 90],
            [1999, 1981, 70, 70],
            [1999, 1982, 70, 70],
            [1999, 1984, 70, 70],
            [1999, 1986, 120, 90],
            [1999, 1989, 63, 120],
            [1999, 1991, 11.55, 8.24],
            [1999, 1992, 50.97, 29.55],
            [1999, 1995, 39.6, 34.17],
            [1999, 1996, 120, 90],
            [1999, 1997, 120, 90],
            [1999, 1998, 7.33, 8.42],
            [1999, 2000, 32.3, 7.9],
            [1999, 2001, 63.05, 65.31],
            [1999, 2002, 50, 60],
            [1999, 2004, 8.73, 6.08],
            [1999, 2005, 117.44, 37.08],
            [1999, 2006, 34.13, 29.15],
            [1999, 2007, 70, 70],
            [1999, 2008, 70, 70],
            [1999, 2009, 67, 176],
            [1999, 2011, 12, 18],
            [1999, 2012, 70, 70],
            [1999, 2013, 38.69, 111.03],
            [1999, 2015, 20.41, 16.91],
            [1999, 2016, 50, 60],
            [1999, 2017, 40, 37.5],
            [1999, 2018, 12, 18],
            [1999, 2020, 70, 70],
            [1999, 2021, 91.08, 54.55],
            [1999, 2022, 120, 90],
            [1999, 2023, 12.93, 13.98],
            [1999, 2025, 47.08, 35.03],
            [1999, 2026, 122.65, 67.48],
            [1999, 2027, 120, 90],
            [1999, 2028, 120, 90],
            [1999, 2029, 30.65, 35.97],
            [1999, 2030, 50, 60],
            [1999, 2031, 6.44, 5.6],
            [1999, 2032, 29.96, 39.24],
            [1999, 2034, 120, 90],
            [1999, 2035, 70, 70],
            [1999, 2038, 120, 90],
            [1999, 2040, 120, 90],
            [1999, 2041, 120, 90],
            [1999, 2042, 25.88, 9.57],
            [1999, 2043, 16.14, 25.13],
            [1999, 2044, 120, 90],
            [1999, 2046, 50, 60],
            [1999, 2048, 13.1, 28.8],
            [1999, 2049, 70, 70],
            [1999, 2050, 11, 25],
            [1999, 2051, 120, 90],
            [1999, 2052, 120, 90],
            [1999, 2053, 70, 70],
            [1999, 2054, 21.44, 20.37],
            [1999, 2055, 70, 70],
            [1999, 2056, 50, 60],
            [1999, 2057, 120, 90],
            [1999, 2058, 7.15, 5.43],
            [1999, 2059, 11.86, 8.19],
            [1999, 2060, 70, 70],
            [1999, 2061, 70, 70],
            [1999, 2062, 120, 90],
            [1999, 2063, 70, 70],
            [1999, 2064, 61.23, 37.87],
            [1999, 2066, 120, 90],
            [1999, 2068, 70, 70],
            [1999, 2070, 19.34, 6.55],
            [1999, 2071, 120, 90],
            [1999, 2072, 120, 90],
            [1999, 2073, 120, 90],
            [1999, 2074, 70, 70],
            [1999, 2075, 45, 70],
            [1999, 2076, 70, 70],
            [1999, 2077, 120, 90],
            [1999, 2081, 57.1, 44.75],
            [1999, 2083, 120, 90],
            [1999, 2084, 23.59, 36.63],
            [1999, 2085, 9.03, 8.79],
            [1999, 2087, 70, 70],
            [1999, 2089, 50, 60],
            [1999, 2090, 120, 90],
            [1999, 2091, 120, 90],
            [1999, 2095, 70, 70],
            [1999, 2096, 120, 90],
            [1999, 2097, 50, 60],
            [1999, 2098, 40, 50],
            [1999, 2099, 89.29, 46.57],
            [1999, 2100, 71.04, 24.35],
            [1999, 2101, 30.58, 16.13],
            [1999, 2103, 11.08, 12.74],
            [1999, 2104, 111.3, 45.15],
            [1999, 2105, 120, 90],
            [1999, 2106, 40.17, 51.44],
            [1999, 2107, 120, 90],
            [1999, 2110, 40, 50],
            [1999, 2112, 70, 70],
            [1999, 2115, 70, 70],
            [1999, 2116, 50, 60],
            [1999, 2119, 7.29, 9.02],
            [1999, 2121, 28, 32.4],
            [1999, 2122, 70, 70],
            [1999, 2125, 120, 90],
            [1999, 2126, 50, 60],
            [1999, 2127, 44.84, 32.36],
            [1999, 2128, 29.14, 12.62],
            [1999, 2130, 120, 90],
            [1999, 2131, 65.5, 56.7],
            [1999, 2132, 19.44, 12.24],
            [1999, 2134, 70, 70],
            [1999, 2135, 22.3, 28.8],
            [1999, 2136, 70, 70],
            [1999, 2137, 70, 70],
            [1999, 2138, 38.63, 26.61],
            [1999, 2139, 70, 70],
            [1999, 2140, 40, 50],
            [1999, 2142, 5.59, 1.96],
            [1999, 2144, 37.3, 75.7],
            [1999, 2146, 70, 70],
            [1999, 2147, 120, 90],
            [1999, 2148, 70, 70],
            [1999, 2149, 120, 90],
            [1999, 2150, 120, 90],
            [1999, 2151, 40.63, 26.2],
            [1999, 2152, 120, 90],
            [1999, 2154, 120, 90],
            [1999, 2155, 120, 90],
            [1999, 2156, 43.59, 31.42],
            [1999, 2159, 120, 90],
            [1999, 2161, 50, 60],
            [1999, 2162, 34.02, 34.24],
            [1999, 2163, 120, 90],
            [1999, 2164, 22, 26.1],
            [1999, 2166, 120, 90],
            [1999, 2167, 10.33, 10.88],
            [1999, 2169, 70, 70],
            [1999, 2170, 50.17, 28.05],
            [1999, 2171, 120, 90],
            [1999, 2174, 40.28, 40.83],
            [1999, 2177, 8.15, 8.97],
            [1999, 2178, 16.1, 27],
            [1999, 2179, 26, 37.8],
            [1999, 2180, 14.38, 10.62],
            [1999, 2181, 58.9, 76.35],
            [1999, 2182, 120, 90],
            [1999, 2184, 40, 50],
            [1999, 2186, 50, 60],
            [1999, 2187, 120, 90],
            [1999, 2190, 70, 70],
            [1999, 2191, 120, 90],
            [1999, 2197, 120, 90],
            [1999, 2198, 40, 50],
            [1999, 2199, 120, 90],
            [1999, 2200, 70, 70],
            [1999, 2201, 23.77, 27.53],
            [1999, 2203, 11.11, 8.84],
            [1999, 2204, 14.98, 8.4],
            [1999, 2205, 120, 90],
            [1999, 2208, 81.25, 48.76],
            [1999, 2212, 70, 70],
            [1999, 2213, 50, 60],
            [1999, 2214, 1.27, 0.88],
            [1999, 2216, 34.36, 17.02],
            [1999, 2217, 120, 90],
            [1999, 2219, 120, 90],
            [1999, 2220, 37.11, 22.57],
            [1999, 2223, 40, 50],
            [1999, 2224, 29.41, 34.07],
            [1999, 2225, 50, 60],
            [1999, 2226, 120, 90],
            [1999, 2227, 39.22, 33.66],
            [1999, 2228, 50, 101],
            [1999, 2230, 120, 90],
            [1999, 2231, 120, 90],
            [1999, 2232, 17.94, 39.15],
            [1999, 2233, 22.35, 13.45],
            [1999, 2235, 50, 60],
            [1999, 2236, 26.79, 29.04],
            [1999, 2237, 120, 90],
            [1999, 2238, 26.85, 29.25],
            [1999, 2239, 21.85, 11.47],
            [1999, 2240, 120, 90],
            [1999, 2241, 14.63, 9.52],
            [1999, 2242, 70, 70],
            [1999, 2243, 120, 90],
            [1999, 2244, 38, 31.98],
            [1999, 2245, 70, 70],
            [1999, 2247, 50, 60],
            [1999, 2248, 40, 50],
            [1999, 2249, 120, 90],
            [1999, 2250, 50, 60],
            [1999, 2252, 50, 60],
            [1999, 2253, 14.51, 10.23],
            [1999, 2254, 70, 70],
            [1999, 2255, 22.3, 61.32],
            [1999, 2256, 70, 70],
            [1999, 2258, 42.22, 34.38],
            [1999, 2259, 2, 1],
            [1999, 2260, 70, 70],
            [1999, 2262, 70, 70],
            [1999, 2265, 120, 90],
            [1999, 2267, 7.26, 3.97],
            [1999, 2268, 120, 90],
            [1999, 2269, 70, 70],
            [1999, 2270, 120, 90],
            [1999, 2271, 6.34, 5.21],
            [1999, 2273, 70, 70],
            [1999, 2274, 70, 70],
            [1999, 2277, 50, 33.82],
            [1999, 2280, 8.57, 5.83],
            [1999, 2281, 120, 90],
            [1999, 2282, 34.6, 40.1],
            [1999, 2283, 120, 90],
            [1999, 2284, 70, 70],
            [1999, 2285, 40, 50],
            [1999, 2286, 70, 70],
            [1999, 2289, 120, 90],
            [1999, 2290, 120, 90],
            [1999, 2292, 120, 90],
            [1999, 2293, 109.99, 52.3],
            [1999, 2294, 50, 60],
            [1999, 2295, 120, 90],
            [1999, 2297, 153.15, 64.3],
            [1999, 2300, 50, 60],
            [1999, 2301, 70, 70],
            [1999, 2302, 120, 90],
            [1999, 2303, 56.37, 41.39],
            [1999, 2304, 70, 70],
            [1999, 2305, 120, 90],
            [1999, 2306, 50, 60],
            [1999, 2311, 45, 45],
            [1999, 2312, 33.27, 33.84],
            [1999, 2314, 120, 90],
            [1999, 2316, 70, 70],
            [1999, 2317, 120, 90],
            [1999, 2319, 50, 60],
            [1999, 2320, 8.59, 8.74],
            [1999, 2321, 120, 90],
            [1999, 2323, 70, 70],
            [1999, 2325, 120, 90],
            [1999, 2326, 120, 90],
            [1999, 2327, 120, 90],
            [1999, 2328, 70, 70],
            [1999, 2332, 30.96, 25.63],
            [1999, 2335, 85.28, 79.59],
            [1999, 2336, 120, 90],
            [1999, 2337, 120, 90],
            [1999, 2338, 70, 70],
            [1999, 2339, 120, 90],
            [1999, 2340, 120, 90],
            [1999, 2341, 73, 177],
            [1999, 2342, 70, 70],
            [1999, 2343, 57.74, 26.83],
            [1999, 2346, 70, 70],
            [1999, 2347, 120, 90],
            [1999, 2349, 70, 70],
            [1999, 2352, 50, 60],
            [1999, 2356, 226.56, 56.42],
            [1999, 2359, 50, 60],
            [1999, 2363, 30.54, 20.65],
            [1999, 2364, 70, 70],
            [1999, 2366, 16.78, 17.31],
            [1999, 2367, 59.45, 50.23],
            [1999, 2368, 70, 70],
            [1999, 2371, 70, 70],
            [1999, 2372, 30, 45],
            [1999, 2373, 70, 70],
            [1999, 2374, 12.45, 9.91],
            [1999, 2375, 120, 90],
            [1999, 2378, 20.26, 18.12],
            [1999, 2382, 70, 70],
            [1999, 2383, 96.19, 48.48],
            [1999, 2384, 30, 45],
            [1999, 2385, 70, 70],
            [1999, 2387, 40, 50],
            [1999, 2388, 70, 70],
            [1999, 2390, 121, 178],
            [1999, 2391, 70, 70],
            [1999, 2392, 7.85, 7.64],
            [1999, 2394, 50, 60],
            [1999, 2396, 120, 90],
            [1999, 2397, 120, 90],
            [1999, 2398, 120, 90],
            [1999, 2399, 120, 90],
            [1999, 2401, 9.42, 9.69],
            [1999, 2402, 70, 70],
            [1999, 2404, 120, 90],
            [1999, 2405, 22.61, 36.11],
            [1999, 2406, 120, 90],
            [1999, 2407, 120, 90],
            [1999, 2408, 50, 60],
            [1999, 2409, 9.5, 15.2],
            [1999, 2410, 70, 70],
            [1999, 2411, 9.59, 8.49],
            [1999, 2412, 6.63, 7.08],
            [1999, 2413, 120, 90],
            [1999, 2414, 8.64, 7.09],
            [1999, 2416, 120, 90],
            [1999, 2420, 120, 90],
            [1999, 2423, 70, 70],
            [1999, 2424, 120, 90],
            [1999, 2425, 52.54, 35],
            [1999, 2428, 10.11, 12.8],
            [1999, 2429, 12, 18],
            [1999, 2430, 70, 70],
            [1999, 2433, 70, 70],
            [1999, 2434, 134, 205],
            [1999, 2435, 22.35, 18.73],
            [1999, 2436, 17.93, 15],
            [1999, 2437, 9.73, 8.67],
            [1999, 2438, 120, 90],
            [1999, 2439, 70, 70],
            [1999, 2440, 5.64, 5.78],
            [1999, 2441, 120, 90],
            [1999, 2442, 12, 18],
            [1999, 2443, 70, 70],
            [1999, 2444, 120, 90],
            [1999, 2447, 25.21, 17.4],
            [1999, 2448, 120, 90],
            [1999, 2449, 120, 90],
            [1999, 2452, 70, 70],
            [1999, 2454, 120, 90],
            [1999, 2456, 70, 70],
            [1999, 2458, 42.99, 19.09],
            [1999, 2459, 32.63, 40.69],
            [1999, 2462, 120, 90],
            [1999, 2465, 120, 90],
            [1999, 2466, 120, 90],
            [1999, 2467, 12, 21.72],
            [1999, 2468, 40, 50],
            [1999, 2470, 120, 90],
            [1999, 2471, 120, 90],
            [1999, 2472, 78.4, 34.97],
            [1999, 2473, 120, 90],
            [1999, 2474, 120, 90],
            [1999, 2475, 70, 70],
            [1999, 2476, 120, 90],
            [1999, 2477, 70, 70],
            [1999, 2478, 120, 90],
            [1999, 2479, 50, 60],
            [1999, 2480, 25.72, 16.26],
            [1999, 2481, 50, 60],
            [1999, 2482, 120, 90],
            [1999, 2483, 120, 90],
            [1999, 2484, 120, 90],
            [1999, 2485, 26.73, 30.59],
            [1999, 2486, 70, 70],
            [1999, 2487, 70, 70],
            [1999, 2488, 53.21, 52.23],
            [1999, 2490, 70, 70],
            [1999, 2493, 104.76, 45.88],
            [1999, 2494, 57.1, 29.4],
            [1999, 2495, 40, 50],
            [1999, 2496, 120, 90],
            [1999, 2497, 40.2, 11.31],
            [1999, 2499, 13.19, 8.58],
            [1999, 2500, 14.55, 14.52],
            [1999, 2501, 70, 70],
            [1999, 2504, 120, 90],
            [1999, 2505, 70, 70],
            [1999, 2507, 120, 90],
            [1999, 2508, 70, 70],
            [1999, 2509, 21.55, 18.6],
            [1999, 2510, 70, 70],
            [1999, 2511, 120, 90],
            [1999, 2512, 120, 90],
            [1999, 2513, 7, 18.7],
            [1999, 2514, 120, 90],
            [1999, 2515, 50, 60],
            [1999, 2516, 40.7, 39.93],
            [1999, 2518, 74.82, 43.44],
            [1999, 2519, 120, 90],
            [1999, 2520, 104, 174],
            [1999, 2521, 50, 60],
            [1999, 2524, 10.39, 13.16],
            [1999, 2525, 70, 70],
            [1999, 2526, 70, 70],
            [1999, 2527, 49.14, 44.47],
            [1999, 2528, 120, 90],
            [1999, 2529, 43.73, 38.98],
            [1999, 2530, 70, 70],
            [1999, 2532, 70, 70],
            [1999, 2533, 23.69, 46.33],
            [1999, 2534, 120, 90],
            [1999, 2535, 5.38, 6.5],
            [1999, 2536, 5.45, 5.06],
            [1999, 2537, 120, 90],
            [1999, 2539, 70, 30.72],
            [1999, 2540, 40.04, 38.42],
            [1999, 2542, 34.79, 22.79],
            [1999, 2543, 27.67, 25],
            [1999, 2545, 40, 50],
            [1999, 2546, 70, 70],
            [1999, 2547, 17.63, 16.94],
            [1999, 2548, 70, 70],
            [1999, 2549, 70, 70],
            [1999, 2551, 71.76, 36.27],
            [1999, 2553, 70, 70],
            [1999, 2554, 16.72, 26.29],
            [1999, 2555, 52.5, 52.5],
            [1999, 2558, 40, 50],
            [1999, 2562, 111.85, 42.43],
            [1999, 2563, 61.13, 37.95],
            [1999, 2564, 40.56, 78.59],
            [1999, 2565, 40, 50],
            [1999, 2566, 10.13, 8.41],
            [1999, 2568, 70, 70],
            [1999, 2569, 34.08, 20.39],
            [1999, 2571, 50, 60],
            [1999, 2572, 120, 90],
            [1999, 2574, 107.79, 57.67],
            [1999, 2575, 70, 70],
            [1999, 2576, 70, 70],
            [1999, 2577, 16.06, 11.33],
            [1999, 2578, 70, 70],
            [1999, 2580, 120, 90],
            [1999, 2582, 70, 70],
            [1999, 2584, 120, 90],
            [1999, 2585, 70, 58.43],
            [1999, 2587, 66.78, 50.99],
            [1999, 2589, 70, 70],
            [1999, 2590, 120, 90],
            [1999, 2591, 120, 90],
            [1999, 2592, 120, 105],
            [1999, 2593, 109.49, 44.64],
            [1999, 2595, 70, 70],
            [1999, 2596, 120, 90],
            [1999, 2597, 40, 50],
            [1999, 2598, 70, 70],
            [1999, 2600, 50, 60],
            [1999, 2601, 70, 70],
            [1999, 2603, 120, 90],
            [1999, 2604, 14.91, 16.67],
            [1999, 2606, 18.48, 15.38],
            [1999, 2607, 14.85, 16.55],
            [1999, 2608, 70, 70],
            [1999, 2610, 70, 70],
            [1999, 2612, 19.02, 24.51],
            [1999, 2613, 120, 90],
            [1999, 2615, 80.55, 54.14],
            [1999, 2617, 17.59, 35.03],
            [1999, 2619, 57.48, 50.98],
            [1999, 2620, 60, 60],
            [1999, 2621, 120, 90],
            [1999, 2622, 22.29, 20.66],
            [1999, 2623, 36.98, 28.35],
            [1999, 2624, 120, 90],
            [1999, 2627, 70, 70],
            [1999, 2628, 47.2, 82.28],
            [1999, 2630, 120, 90],
            [1999, 2631, 70, 70],
            [1999, 2632, 22.83, 26.19],
            [1999, 2633, 36.95, 67.11],
            [1999, 2634, 120, 90],
            [1999, 2635, 12, 22.39],
            [1999, 2636, 70, 70],
            [1999, 2638, 70, 70],
            [1999, 2639, 9.66, 9.9],
            [1999, 2642, 120, 90],
            [1999, 2644, 71.93, 71.93],
            [1999, 2646, 30, 45],
            [1999, 2647, 51.91, 54.1],
            [1999, 2649, 50, 60],
            [1999, 2650, 120, 90],
            [1999, 2651, 32.4, 19.95],
            [1999, 2652, 37.5, 45],
            [1999, 2653, 70, 70],
            [1999, 2655, 40, 50],
            [1999, 2656, 69.06, 43.42],
            [1999, 2658, 40.97, 26.68],
            [1999, 2660, 40, 50],
            [1999, 2661, 70, 70],
            [1999, 2663, 50, 60],
            [1999, 2664, 11, 16.7],
            [1999, 2665, 70, 70],
            [1999, 2667, 63.81, 52.19],
            [1999, 2668, 39.53, 31.14],
            [1999, 2669, 75, 64.66],
            [1999, 2670, 70, 70],
            [1999, 2671, 50, 45],
            [1999, 2672, 13.43, 14.62],
            [1999, 2677, 70, 70],
            [1999, 2681, 70, 70],
            [1999, 2682, 178, 216],
            [1999, 2683, 9.17, 6.35],
            [1999, 2684, 70.83, 69.48],
            [1999, 2685, 50, 60],
            [1999, 2686, 9.12, 8.12],
            [1999, 2687, 94.14, 34.56],
            [1999, 2691, 50, 60],
            [1999, 2692, 70, 70],
            [1999, 2694, 120, 90],
            [1999, 2695, 12, 18],
            [1999, 2696, 70, 70],
            [1999, 2697, 120, 90],
            [1999, 2703, 50, 60],
            [1999, 2704, 10.96, 9.94],
            [1999, 2706, 120, 90],
            [1999, 2707, 70, 70],
            [1999, 2710, 18.57, 12.32],
            [1999, 2711, 50, 60],
            [1999, 2712, 70, 70],
            [1999, 2714, 50, 60],
            [1999, 2716, 70, 70],
            [1999, 2719, 70, 70],
            [1999, 2720, 46, 38.9],
            [1999, 2722, 120, 90],
            [1999, 2723, 70, 70],
            [1999, 2725, 70, 70],
            [1999, 2726, 120.52, 25.63],
            [1999, 2728, 120, 90],
            [1999, 2730, 50, 60],
            [1999, 2731, 120, 90],
            [1999, 2734, 50, 60],
            [1999, 2735, 6.21, 6.8],
            [1999, 2736, 30, 45],
            [1999, 2737, 40, 50],
            [1999, 2738, 40, 37.5],
            [1999, 2739, 50, 60],
            [1999, 2740, 120, 90],
            [1999, 2741, 88, 114],
            [1999, 2743, 30.71, 32.21],
            [1999, 2746, 70, 70],
            [1999, 2747, 63.12, 31.83],
            [1999, 2748, 123.58, 59.04],
            [1999, 2750, 30, 45],
            [1999, 2752, 70, 70],
            [1999, 2753, 50, 60],
            [1999, 2755, 120, 90],
            [1999, 2756, 77, 96],
            [1999, 2757, 120, 90],
            [1999, 2758, 36.94, 36.69],
            [1999, 2759, 120, 90],
            [1999, 2760, 120, 90],
            [1999, 2762, 120, 90],
            [1999, 2763, 120, 90],
            [1999, 2764, 70, 70],
            [1999, 2765, 120, 90],
            [1999, 2766, 8.32, 6.64],
            [1999, 2767, 120, 90],
            [1999, 2768, 120, 90],
            [1999, 2770, 120, 90],
            [1999, 2772, 70, 70],
            [1999, 2773, 50, 60],
            [1999, 2774, 120, 90],
            [1999, 2775, 70, 70],
            [1999, 2778, 70, 70],
            [1999, 2781, 9.91, 6.13],
            [1999, 2782, 50, 60],
            [1999, 2783, 70, 70],
            [1999, 2784, 70, 70],
            [1999, 2785, 5.56, 14],
            [1999, 2786, 70, 70],
            [1999, 2787, 64.37, 35.05],
            [1999, 2788, 96.68, 56.26],
            [1999, 2791, 30, 37.5],
            [1999, 2792, 120, 90],
            [1999, 2793, 40, 50],
            [1999, 2795, 70, 70],
            [1999, 2796, 70, 70],
            [1999, 2797, 38.38, 16.45],
            [1999, 2798, 12, 21.53],
            [1999, 2800, 70, 70],
            [1999, 2801, 120, 90],
            [1999, 2804, 16.93, 11.94],
            [1999, 2806, 70, 70],
            [1999, 2807, 36.77, 11.92],
            [1999, 2808, 50, 60],
            [1999, 2809, 120, 90],
            [1999, 2811, 34.31, 28.04],
            [1999, 2813, 34.06, 29.31],
            [1999, 2814, 120, 90],
            [1999, 2818, 9.74, 14.61],
            [1999, 2819, 11.84, 8.58],
            [1999, 2820, 70, 70],
            [1999, 2821, 70, 70],
            [1999, 2822, 40, 50],
            [1999, 2823, 59.27, 44.08],
            [1999, 2826, 40, 50],
            [1999, 2827, 21.89, 30.71],
            [1999, 2831, 120, 90],
            [1999, 2832, 23.2, 22.2],
            [1999, 2833, 65.79, 46.49],
            [1999, 2834, 50, 60],
            [1999, 2835, 37.5, 45],
            [1999, 2836, 36.81, 31.39],
            [1999, 2837, 120, 90],
            [1999, 2838, 120, 90],
            [1999, 2839, 120, 90],
            [1999, 2841, 120, 90],
            [1999, 2844, 70, 70],
            [1999, 2845, 120, 90],
            [1999, 2846, 40, 23.06],
            [1999, 2847, 30, 45],
            [1999, 2850, 50, 60],
            [1999, 2851, 75.14, 53.01],
            [1999, 2852, 37.5, 45],
            [1999, 2853, 70, 70],
            [1999, 2854, 25.17, 19.72],
            [1999, 2856, 124.74, 77.59],
            [1999, 2857, 120, 90],
            [1999, 2861, 50, 60],
            [1999, 2862, 70, 70],
            [1999, 2863, 25.3, 31],
            [1999, 2864, 120, 90],
            [1999, 2865, 120, 90],
            [1999, 2866, 50, 60],
            [1999, 2867, 120, 90],
            [1999, 2869, 5.93, 4.86],
            [1999, 2871, 120, 90],
            [1999, 2872, 31.07, 14.75],
            [1999, 2876, 101.18, 75.84],
            [1999, 2877, 120, 90],
            [1999, 2878, 120, 90],
            [1999, 2879, 50, 60],
            [1999, 2880, 39, 52.5],
            [1999, 2882, 120, 90],
            [1999, 2883, 48.97, 31.48],
            [1999, 2884, 70.14, 48.85],
            [1999, 2885, 70, 70],
            [1999, 2886, 70, 70],
            [1999, 2887, 70, 70],
            [1999, 2889, 70, 70],
            [1999, 2890, 70, 70],
            [1999, 2891, 120, 90],
            [1999, 2893, 120, 90],
            [1999, 2894, 120, 90],
            [1999, 2897, 120, 90],
            [1999, 2899, 70, 70],
            [1999, 2900, 50, 60],
            [1999, 2901, 107.65, 88.66],
            [1999, 2902, 120, 90],
            [1999, 2903, 120, 90],
            [1999, 2904, 65, 40.54],
            [1999, 2905, 50, 60],
            [1999, 2906, 120, 90],
            [1999, 2907, 11.65, 11.52],
            [1999, 2908, 70, 70],
            [1999, 2910, 49.02, 40.47],
            [1999, 2911, 120, 90],
            [1999, 2914, 70, 70],
            [1999, 2916, 70, 70],
            [1999, 2917, 50, 60],
            [1999, 2918, 17.8, 10.33],
            [1999, 2919, 120, 90],
            [1999, 2921, 120, 90],
            [1999, 2922, 16, 18],
            [1999, 2923, 26.73, 30.82],
            [1999, 2924, 120, 90],
            [1999, 2925, 120, 90],
            [1999, 2928, 70, 70],
            [1999, 2929, 50.7, 47.79],
            [1999, 2930, 155, 210],
            [1999, 2931, 70, 70],
            [1999, 2932, 30, 24.3],
            [1999, 2933, 70, 70],
            [1999, 2934, 85.78, 39.36],
            [1999, 2935, 120, 90],
            [1999, 2936, 90.08, 68.66],
            [1999, 2937, 120, 90],
            [1999, 2940, 120, 90],
            [1999, 2942, 70, 70],
            [1999, 2943, 120, 90],
            [1999, 2944, 50, 60],
            [1999, 2946, 117.5, 74.87],
            [1999, 2948, 50, 60],
            [1999, 2950, 110.01, 49.26],
            [1999, 2951, 120, 90],
            [1999, 2952, 70, 70],
            [1999, 2955, 70, 70],
            [1999, 2956, 30.2, 34.9],
            [1999, 2957, 120, 90],
            [1999, 2958, 70, 70],
            [1999, 2960, 50, 60],
            [1999, 2961, 70, 70],
            [1999, 2962, 40, 50],
            [1999, 2963, 120, 90],
            [1999, 2964, 50, 60],
            [1999, 2965, 120, 90],
            [1999, 2969, 15.24, 25.59],
            [1999, 2971, 70, 70],
            [1999, 2972, 120, 90],
            [1999, 2973, 70, 65],
            [1999, 2974, 22.89, 34.75],
            [1999, 2975, 70, 70],
            [1999, 2976, 120, 90],
            [1999, 2978, 24.61, 18.48],
            [1999, 2979, 27.1, 18.5],
            [1999, 2980, 21.22, 18.94],
            [1999, 2982, 40, 50],
            [1999, 2984, 13.6, 13.23],
            [1999, 2985, 50, 60],
            [1999, 2986, 120, 90],
            [1999, 2988, 120, 90],
            [1999, 2989, 50, 60],
            [1999, 2991, 50, 60],
            [1999, 2995, 36.26, 41.54],
            [1999, 2997, 11.88, 8.2],
            [1999, 2999, 6.02, 5.8],
            [1999, 3000, 50, 60],
            [1999, 3001, 56.14, 45.79],
            [1999, 3002, 70, 70],
            [1999, 3003, 120, 90],
            [1999, 3004, 48.58, 95.54],
            [1999, 3006, 70, 70],
            [1999, 3008, 28.3, 32.4],
            [1999, 3009, 50, 60],
            [1999, 3011, 13.6, 28.86],
            [1999, 3012, 70, 70],
            [1999, 3014, 120, 90],
            [1999, 3015, 30, 37.5],
            [1999, 3016, 22.14, 18.78],
            [1999, 3017, 120, 90],
            [1999, 3019, 50, 60],
            [1999, 3022, 120, 90],
            [1999, 3024, 70, 70],
            [1999, 3025, 70, 70],
            [1999, 3026, 12.16, 8.01],
            [1999, 3027, 22, 43.41],
            [1999, 3031, 50, 60],
            [1999, 3033, 120, 90],
            [1999, 3035, 29.76, 27.35],
            [1999, 3037, 50, 60],
            [1999, 3041, 52.5, 52.5],
            [1999, 3042, 5.83, 5.64],
            [1999, 3043, 70, 70],
            [1999, 3044, 70, 70],
            [1999, 3045, 120, 90],
            [1999, 3046, 50.66, 21.51],
            [1999, 3047, 50, 60],
            [1999, 3048, 101.09, 97.17],
            [1999, 3049, 120, 90],
            [1999, 3050, 27.97, 29.63],
            [1999, 3051, 120, 90],
            [1999, 3052, 50, 60],
            [1999, 3053, 70, 70],
            [1999, 3054, 50, 60],
            [1999, 3055, 120, 90],
            [1999, 3056, 15.98, 16.7],
            [1999, 3057, 70, 70],
            [1999, 3058, 70, 70],
            [1999, 3059, 120, 90],
            [1999, 3060, 70, 70],
            [1999, 3061, 128.24, 46.52],
            [1999, 3063, 70, 70],
            [1999, 3064, 121, 253],
            [1999, 3066, 70, 70],
            [1999, 3069, 120, 90],
            [1999, 3070, 56.43, 49.17],
            [1999, 3073, 120, 90],
            [1999, 3076, 120, 90],
            [1999, 3077, 39.42, 34.65],
            [1999, 3078, 70, 70],
            [1999, 3079, 70, 70],
            [1999, 3084, 70, 70],
            [1999, 3085, 50, 60],
            [1999, 3086, 97.92, 38.7],
            [1999, 3087, 70, 70],
            [1999, 3089, 38.17, 24],
            [1999, 3090, 50, 60],
            [1999, 3091, 19.67, 20.1],
            [1999, 3092, 70, 70],
            [1999, 3095, 120, 90],
            [1999, 3098, 20.76, 58.98],
            [1999, 3100, 120, 90],
            [1999, 3101, 120, 90],
            [1999, 3104, 7.73, 6.59],
            [1999, 3105, 70, 70],
            [1999, 3106, 34.5, 25.1],
            [1999, 3107, 120, 90],
            [1999, 3109, 50, 60],
            [1999, 3112, 79.98, 40.43],
            [1999, 3113, 50, 60],
            [1999, 3114, 120, 90],
            [1999, 3115, 120, 90],
            [1999, 3117, 50, 60],
            [1999, 3118, 120, 90],
            [1999, 3119, 12.2, 16.8],
            [1999, 3121, 69.55, 32.33],
            [1999, 3122, 63.25, 33.78],
            [1999, 3123, 120, 90],
            [1999, 3126, 70, 70],
            [1999, 3127, 9.37, 9.65],
            [1999, 3128, 62, 50],
            [1999, 3129, 37.84, 31.71],
            [1999, 3130, 12, 10],
            [1999, 3131, 8.27, 8.03],
            [1999, 3132, 120, 90],
            [1999, 3133, 72.02, 36.75],
            [1999, 3134, 50, 45],
            [1999, 3135, 120, 90],
            [1999, 3136, 40, 50],
            [1999, 3137, 12.56, 13.35],
            [1999, 3138, 120, 90],
            [1999, 3139, 5.88, 5.48],
            [1999, 3140, 70, 70],
            [1999, 3141, 50, 60],
            [1999, 3142, 40, 50],
            [1999, 3143, 70, 70],
            [1999, 3144, 120, 90],
            [1999, 3148, 33.08, 29.22],
            [1999, 3149, 120, 90],
            [1999, 3151, 120, 90],
            [1999, 3152, 50, 60],
            [1999, 3154, 87.45, 60.56],
            [1999, 3155, 98.27, 51.32],
            [1999, 3158, 18, 18],
            [1999, 3160, 37.27, 60.05],
            [1999, 3161, 20.3, 19.5],
            [1999, 3163, 70, 70],
            [1999, 3164, 70, 70],
            [1999, 3165, 70, 45.26],
            [1999, 3166, 0.17, 0.59],
            [1999, 3167, 69.49, 38],
            [1999, 3168, 120, 90],
            [1999, 3171, 40, 50],
            [1999, 3172, 120, 90],
            [1999, 3175, 73.26, 36.41],
            [1999, 3177, 37.5, 45],
            [1999, 3181, 8.14, 6.4],
            [1999, 3182, 22.27, 15.36],
            [1999, 3183, 51.17, 40.2],
            [1999, 3184, 70, 70],
            [1999, 3187, 24.7, 20.1],
            [1999, 3188, 14.43, 16.56],
            [1999, 3189, 192.54, 70.66],
            [1999, 3190, 26.99, 20.03],
            [1999, 3191, 70, 70],
            [1999, 3192, 120, 90],
            [1999, 3195, 22.52, 19.08],
            [1999, 3196, 70, 70],
            [1999, 3197, 99.63, 37.69],
            [1999, 3198, 9.06, 10.25],
            [1999, 3199, 70, 70],
            [1999, 3200, 40, 50],
            [1999, 3203, 12.22, 10.64],
            [1999, 3206, 36.81, 46.42],
            [1999, 3207, 50, 60],
            [1999, 3208, 120, 90],
            [1999, 3211, 70, 70],
            [1999, 3212, 120, 90],
            [1999, 3214, 70, 70],
            [1999, 3216, 120, 90],
            [1999, 3217, 34.82, 34.71],
            [1999, 3219, 10.36, 9.85],
            [1999, 3220, 120, 90],
            [1999, 3221, 70, 70],
            [1999, 3225, 6.02, 7.89],
            [1999, 3227, 25, 20],
            [1999, 3228, 34.26, 35.61],
            [1999, 3229, 120, 90],
            [1999, 3231, 26.42, 28.94],
            [1999, 3234, 37.45, 21.3],
            [1999, 3239, 120, 90],
            [1999, 3240, 120, 90],
            [1999, 3241, 50, 60],
            [1999, 3242, 70, 70],
            [1999, 3243, 12.14, 9.5],
            [1999, 3244, 120, 90],
            [1999, 3246, 65.38, 60.87],
            [1999, 3247, 120, 90],
            [1999, 3248, 40, 17.83],
            [1999, 3249, 120, 90],
            [1999, 3251, 40, 50],
            [1999, 3252, 50, 60],
            [1999, 3253, 70, 70],
            [1999, 3254, 40.73, 38.06],
            [1999, 3255, 70, 70],
            [1999, 3256, 30.27, 22.34],
            [1999, 3257, 50, 60],
            [1999, 3258, 70, 70],
            [1999, 3259, 50, 60],
            [1999, 3260, 10, 13.06],
            [1999, 3262, 70, 70],
            [1999, 3263, 120, 90],
            [1999, 3264, 13.13, 23.21],
            [1999, 3265, 120, 90],
            [1999, 3266, 70, 70],
            [1999, 3267, 50, 60],
            [1999, 3268, 59.2, 40.69],
            [1999, 3270, 17.3, 14.21],
            [1999, 3271, 120, 90],
            [1999, 3272, 106.83, 78.93],
            [1999, 3273, 120, 90],
            [1999, 3274, 45, 32.77],
            [1999, 3275, 120, 90],
            [1999, 3276, 120, 90],
            [1999, 3277, 91.74, 42.99],
            [1999, 3278, 63.11, 20.86],
            [1999, 3279, 70, 70],
            [1999, 3280, 59.87, 41.55],
            [1999, 3283, 12.69, 12.13],
            [1999, 3284, 42.57, 30.98],
            [1999, 3286, 15.7, 9.65],
            [1999, 3287, 50, 60],
            [1999, 3288, 30.42, 23.34],
            [1999, 3289, 85, 70],
            [1999, 3290, 21.59, 14.57],
            [1999, 3292, 120, 90],
            [1999, 3293, 70, 70],
            [1999, 3294, 50, 60],
            [1999, 3295, 120, 90],
            [1999, 3296, 30, 45],
            [1999, 3300, 70, 70],
            [1999, 3301, 70, 70],
            [1999, 3302, 40, 50],
            [1999, 3303, 70, 70],
            [1999, 3305, 120, 90],
            [1999, 3306, 32.44, 29.79],
            [1999, 3308, 70, 70],
            [1999, 3309, 50, 45],
            [1999, 3312, 70, 70],
            [1999, 3313, 120, 90],
            [1999, 3314, 50, 60],
            [1999, 3315, 120, 90],
            [1999, 3316, 120, 90],
            [1999, 3318, 70, 70],
            [1999, 3319, 70, 70],
            [1999, 3320, 120, 90],
            [1999, 3321, 50, 60],
            [1999, 3322, 120, 90],
            [1999, 3324, 9.8, 13.83],
            [1999, 3325, 38.61, 28.27],
            [1999, 3326, 51.15, 39.66],
            [1999, 3327, 98.77, 87.26],
            [1999, 3328, 120, 90],
            [1999, 3329, 8.87, 8.14],
            [1999, 3331, 108.09, 47.79],
            [1999, 3332, 120, 90],
            [1999, 3333, 120, 90],
            [1999, 3334, 8.78, 7.44],
            [1999, 3335, 70, 70],
            [1999, 3336, 46.22, 26.88],
            [1999, 3338, 70, 70],
            [1999, 3340, 50, 60],
            [1999, 3341, 24.19, 12.04],
            [1999, 3342, 70, 70],
            [1999, 3343, 120, 90],
            [1999, 3344, 99.81, 58.02],
            [1999, 3346, 62.21, 43.82],
            [1999, 3347, 120, 90],
            [1999, 3348, 70, 70],
            [1999, 3350, 120, 90],
            [1999, 3351, 120, 90],
            [1999, 3353, 120, 90],
            [1999, 3357, 12.58, 12.94],
            [1999, 3358, 19.2, 17.45],
            [1999, 3359, 120, 90],
            [1999, 3361, 120, 90],
            [1999, 3363, 14.08, 11.88],
            [1999, 3364, 12, 21.69],
            [1999, 3366, 120, 90],
            [1999, 3367, 50, 60],
            [1999, 3369, 120, 90],
            [1999, 3370, 47.38, 71.88],
            [1999, 3371, 70, 60],
            [1999, 3372, 70, 70],
            [1999, 3376, 120, 90],
            [1999, 3378, 9.02, 8.54],
            [1999, 3380, 120, 90],
            [1999, 3381, 120, 90],
            [1999, 3382, 23.2, 25.03],
            [1999, 3384, 70, 70],
            [1999, 3386, 120, 90],
            [1999, 3387, 70, 70],
            [1999, 3388, 120, 90],
            [1999, 3389, 31.29, 20.21],
            [1999, 3390, 120, 90],
            [1999, 3391, 120, 90],
            [1999, 3392, 120, 90],
            [1999, 3393, 120, 90],
            [1999, 3394, 120, 90],
            [1999, 3396, 21.88, 28.51],
            [1999, 3399, 70, 70],
            [1999, 3400, 50, 60],
            [1999, 3402, 120, 90],
            [1999, 3403, 16.87, 10.26],
            [1999, 3404, 41.37, 52.15],
            [1999, 3407, 59.05, 33.48],
            [1999, 3408, 120, 90],
            [1999, 3411, 70, 70],
            [1999, 3414, 50, 60],
            [1999, 3415, 40, 50],
            [1999, 3416, 40, 50],
            [1999, 3417, 70, 70],
            [1999, 3418, 120, 90],
            [1999, 3419, 70, 70],
            [1999, 3420, 70, 70],
            [1999, 3422, 50.99, 25.75],
            [1999, 3423, 120, 90],
            [1999, 3424, 37.5, 45],
            [1999, 3426, 120, 90],
            [1999, 3428, 70, 70],
            [1999, 3429, 46.45, 44.76],
            [1999, 3431, 120, 90],
            [1999, 3432, 70, 70],
            [1999, 3433, 19.6, 20.1],
            [1999, 3434, 6.86, 5.46],
            [1999, 3436, 50, 60],
            [1999, 3437, 70, 70],
            [1999, 3438, 70, 70],
            [1999, 3439, 60.72, 58.05],
            [1999, 3440, 50, 60],
            [1999, 3441, 59.78, 46.81],
            [1999, 3442, 42.15, 37.9],
            [1999, 3444, 17.9, 15.29],
            [1999, 3445, 70, 70],
            [1999, 3448, 5.56, 6.38],
            [1999, 3449, 70, 70],
            [1999, 3450, 70, 70],
            [1999, 3451, 71.38, 68.39],
            [1999, 3452, 120, 90],
            [1999, 3453, 15.33, 23.54],
            [1999, 3454, 18.63, 15.82],
            [1999, 3456, 120, 90],
            [1999, 3457, 120, 90],
            [1999, 3459, 72.5, 55.8],
            [1999, 3461, 68.26, 26.15],
            [1999, 3462, 55.41, 24.77],
            [1999, 3463, 120, 90],
            [1999, 3464, 120, 90],
            [1999, 3468, 73.94, 42.49],
            [1999, 3469, 34.89, 19.21],
            [1999, 3471, 70, 70],
            [1999, 3472, 120, 90],
            [1999, 3473, 12.27, 10.63],
            [1999, 3474, 70, 70],
            [1999, 3476, 40, 50],
            [1999, 3480, 120, 90],
            [1999, 3481, 120, 206],
            [1999, 3482, 70, 70],
            [1999, 3483, 70, 70],
            [1999, 3484, 120, 90],
            [1999, 3485, 52.28, 52.85],
            [1999, 3487, 50, 60],
            [1999, 3488, 23, 23],
            [1999, 3489, 40, 50],
            [1999, 3492, 120, 90],
            [1999, 3493, 70, 70],
            [1999, 3494, 12, 18],
            [1999, 3496, 120, 90],
            [1999, 3497, 120, 90],
            [1999, 3498, 38.68, 34.83],
            [1999, 3499, 120, 90],
            [1999, 3501, 120, 90],
            [1999, 3503, 120, 90],
            [1999, 3504, 70, 70],
            [1999, 3505, 120, 90],
            [1999, 3508, 120, 90],
            [1999, 3509, 40, 60],
            [1999, 3510, 120, 90],
            [1999, 3511, 70, 70],
            [1999, 3514, 18.7, 27],
            [1999, 3515, 70, 70],
            [1999, 3516, 120, 90],
            [1999, 3517, 70, 70],
            [1999, 3518, 120, 90],
            [1999, 3519, 50, 60],
            [1999, 3520, 120, 90],
            [1999, 3521, 120, 90],
            [1999, 3523, 120, 90],
            [1999, 3525, 120, 90],
            [1999, 3527, 120, 90],
            [1999, 3530, 52.8, 38.6],
            [1999, 3531, 70.97, 39.98],
            [1999, 3534, 70, 70],
            [1999, 3535, 30, 45],
            [1999, 3537, 120, 90],
            [1999, 3539, 120, 90],
            [1999, 3541, 42.81, 43.65],
            [1999, 3543, 120, 90],
            [1999, 3545, 120, 90],
            [1999, 3546, 120, 90],
            [1999, 3549, 22.69, 14.17],
            [1999, 3551, 120, 90],
            [1999, 3553, 70, 70],
            [1999, 3554, 50, 60],
            [1999, 3555, 40, 50],
            [1999, 3557, 16.81, 25.35],
            [1999, 3558, 70, 70],
            [1999, 3559, 50, 60],
            [1999, 3560, 120, 90],
            [1999, 3561, 120, 90],
            [1999, 3564, 120, 90],
            [1999, 3566, 17.61, 17.41],
            [1999, 3568, 12.22, 9.98],
            [1999, 3569, 50, 60],
            [1999, 3570, 70, 70],
            [1999, 3571, 70, 70],
            [1999, 3572, 120, 90],
            [1999, 3573, 120, 90],
            [1999, 3575, 120, 90],
            [1999, 3576, 120, 90],
            [1999, 3577, 70, 70],
            [1999, 3579, 22.92, 33.97],
            [1999, 3580, 70, 70],
            [1999, 3581, 120, 90],
            [1999, 3582, 4.45, 5.68],
            [1999, 3585, 70, 70],
            [1999, 3586, 70, 70],
            [1999, 3587, 70, 70],
            [1999, 3588, 120, 90],
            [1999, 3589, 12, 18],
            [1999, 3590, 40, 43.95],
            [1999, 3592, 70, 70],
            [1999, 3593, 35.78, 25.31],
            [1999, 3594, 120, 90],
            [1999, 3595, 120, 90],
            [1999, 3596, 120, 90],
            [1999, 3597, 70, 70],
            [1999, 3598, 22.96, 24.32],
            [1999, 3599, 120, 90],
            [1999, 3600, 49.66, 38.48],
            [1999, 3601, 40, 50],
            [1999, 3602, 51.79, 46.05],
            [1999, 3606, 40, 50],
            [1999, 3607, 12.7, 15.8],
            [1999, 3608, 33.57, 26.7],
            [1999, 3609, 120, 90],
            [1999, 3610, 50, 71],
            [1999, 3611, 156, 211],
            [1999, 3612, 70, 70],
            [1999, 3613, 40, 50],
            [1999, 3614, 9.76, 7.31],
            [1999, 3615, 70, 70],
            [1999, 3617, 70, 70],
            [1999, 3619, 70, 70],
            [1999, 3620, 50, 60],
            [1999, 3621, 50, 60],
            [1999, 3622, 120, 90],
            [1999, 3623, 120, 90],
            [1999, 3624, 16.21, 10.44],
            [1999, 3626, 120, 90],
            [1999, 3627, 120, 90],
            [1999, 3628, 30, 45],
            [1999, 3629, 70, 70],
            [1999, 3631, 70, 70],
            [1999, 3632, 47.16, 37.74],
            [1999, 3633, 70, 70],
            [1999, 3634, 24.1, 17.22],
            [1999, 3635, 50, 60],
            [1999, 3636, 70, 70],
            [1999, 3637, 40, 50],
            [1999, 3639, 120, 90],
            [1999, 3641, 40, 50],
            [1999, 3642, 58.18, 27.21],
            [1999, 3643, 70, 70],
            [1999, 3644, 36.34, 36.78],
            [1999, 3647, 70, 70],
            [1999, 3648, 70, 70],
            [1999, 3649, 120, 90],
            [1999, 3650, 93.96, 49.61],
            [1999, 3651, 40, 50],
            [1999, 3652, 40, 50],
            [1999, 3653, 52.81, 42.1],
            [1999, 3656, 16.63, 13.83],
            [1999, 3657, 40, 50],
            [1999, 3659, 45.77, 17.29],
            [1999, 3661, 49.38, 28.07],
            [1999, 3662, 30, 45],
            [1999, 3663, 120, 90],
            [1999, 3665, 120, 90],
            [1999, 3666, 120, 90],
            [1999, 3667, 30.55, 36.38],
            [1999, 3668, 120, 90],
            [1999, 3669, 12, 25.38],
            [1999, 3670, 91.39, 52.48],
            [1999, 3671, 120, 90],
            [1999, 3675, 120, 90],
            [1999, 3676, 120, 90],
            [1999, 3677, 50, 60],
            [1999, 3678, 11.23, 7.28],
            [1999, 3679, 29.5, 43.67],
            [1999, 3681, 70, 70],
            [1999, 3683, 7.87, 11.07],
            [1999, 3685, 120, 90],
            [1999, 3686, 120, 90],
            [1999, 3687, 70, 70],
            [1999, 3688, 120, 90],
            [1999, 3690, 120, 90],
            [1999, 3691, 13.11, 11.71],
            [1999, 3692, 50, 60],
            [1999, 3694, 70, 70],
            [1999, 3695, 120, 90],
            [1999, 3696, 70, 70],
            [1999, 3698, 120, 90],
            [1999, 3700, 25.38, 59.21],
            [1999, 3701, 29.01, 18.72],
            [1999, 3702, 16.7, 11.85],
            [1999, 3703, 175.88, 66.13],
            [1999, 3705, 30, 45],
            [1999, 3707, 70, 70],
            [1999, 3708, 70, 70],
            [1999, 3710, 50, 60],
            [1999, 3711, 9.31, 9.41],
            [1999, 3713, 70, 70],
            [1999, 3714, 120, 90],
            [1999, 3716, 120, 90],
            [1999, 3718, 70, 70],
            [1999, 3719, 120, 90],
            [1999, 3720, 95.89, 30.16],
            [1999, 3722, 40, 50],
            [1999, 3723, 30, 45],
            [1999, 3724, 12.29, 10.32],
            [1999, 3726, 12, 18],
            [1999, 3728, 120, 90],
            [1999, 3729, 120, 90],
            [1999, 3731, 40, 25.08],
            [1999, 3733, 120, 90],
            [1999, 3738, 30, 45],
            [1999, 3741, 120, 90],
            [1999, 3745, 120, 90],
            [1999, 3747, 33.24, 30.21],
            [1999, 3748, 120, 90],
            [1999, 3749, 120, 90],
            [1999, 3751, 27.22, 22.15],
            [1999, 3752, 120, 90],
            [1999, 3753, 50, 60],
            [1999, 3755, 31.04, 34.22],
            [1999, 3756, 120, 90],
            [1999, 3758, 50, 60],
            [1999, 3759, 70, 70],
            [1999, 3761, 36.17, 17.01],
            [1999, 3762, 49.07, 30.08],
            [1999, 3763, 70, 70],
            [1999, 3764, 56.14, 29.13],
            [1999, 3765, 36.87, 29.24],
            [1999, 3766, 50, 60],
            [1999, 3768, 70, 70],
            [1999, 3769, 120, 90],
            [1999, 3775, 16.7, 21.1],
            [1999, 3776, 120, 90],
            [1999, 3777, 64.75, 33.71],
            [1999, 3780, 70, 70],
            [1999, 3781, 120, 90],
            [1999, 3782, 33.84, 17.76],
            [1999, 3783, 70, 70],
            [1999, 3785, 120, 90],
            [1999, 3786, 10.14, 9.72],
            [1999, 3791, 120, 90],
            [1999, 3793, 70, 70],
            [1999, 3795, 28.93, 71.01],
            [1999, 3796, 34.35, 19.61],
            [1999, 3797, 50, 60],
            [1999, 3799, 50, 60],
            [1999, 3800, 70, 70],
            [1999, 3801, 120, 90],
            [1999, 3802, 50, 60],
            [1999, 3804, 70, 70],
            [1999, 3807, 23.88, 19.39],
            [1999, 3811, 50, 60],
            [1999, 3812, 120, 90],
            [1999, 3814, 121, 70],
            [1999, 3815, 8.38, 6.36],
            [1999, 3816, 120, 90],
            [1999, 3820, 50, 60],
            [1999, 3821, 18.9, 24.5],
            [1999, 3822, 120, 90],
            [1999, 3824, 70, 70],
            [1999, 3826, 70, 70],
            [1999, 3827, 104.49, 49.9],
            [1999, 3828, 48.71, 27.21],
            [1999, 3830, 6.73, 6.06],
            [1999, 3832, 58.73, 69.61],
            [1999, 3833, 30, 45],
            [1999, 3834, 82.66, 53.29],
            [1999, 3837, 70, 70],
            [1999, 3839, 120, 90],
            [1999, 3840, 120, 90],
            [1999, 3841, 115.85, 58.55],
            [1999, 3842, 70, 70],
            [1999, 3843, 4.12, 8.93],
            [1999, 3845, 16.28, 21.19],
            [1999, 3846, 70, 70],
            [1999, 3849, 70, 70],
            [1999, 3850, 28.31, 33.02],
            [1999, 3851, 120, 90],
            [1999, 3853, 120, 90],
            [1999, 3854, 20.59, 23],
            [1999, 3855, 120, 90],
            [1999, 3856, 16.7, 22.9],
            [1999, 3858, 120, 90],
            [1999, 3859, 12, 23.21],
            [1999, 3862, 70, 70],
            [1999, 3863, 50, 60],
            [1999, 3865, 120, 90],
            [1999, 3866, 14.49, 13.27],
            [1999, 3867, 120, 90],
            [1999, 3868, 120, 90],
            [1999, 3869, 50, 60],
            [1999, 3870, 113.75, 53.42],
            [1999, 3871, 46.79, 28.4],
            [1999, 3873, 120, 90],
            [1999, 3874, 41.13, 34.16],
            [1999, 3877, 70, 70],
            [1999, 3879, 120, 90],
            [1999, 3880, 15.73, 17.34],
            [1999, 3881, 50, 60],
            [1999, 3882, 120, 90],
            [1999, 3883, 57.22, 73.4],
            [1999, 3884, 50, 60],
            [1999, 3886, 70, 70],
            [1999, 3887, 120, 90],
            [1999, 3889, 70, 70],
            [1999, 3890, 10.56, 9.46],
            [1999, 3891, 17.06, 21.5],
            [1999, 3892, 70, 70],
            [1999, 3896, 70, 70],
            [1999, 3897, 46.88, 27.21],
            [1999, 3898, 120, 90],
            [1999, 3899, 120, 90],
            [1999, 3900, 50.61, 29.08],
            [1999, 3901, 70, 70],
            [1999, 3903, 50, 60],
            [1999, 3905, 90.98, 55.27],
            [1999, 3906, 70, 70],
            [1999, 3909, 120, 90],
            [1999, 3910, 70, 70],
            [1999, 3915, 30, 45],
            [1999, 3916, 120, 90],
            [1999, 3918, 8.88, 7.78],
            [1999, 3919, 120, 90],
            [1999, 3921, 34.37, 32.04],
            [1999, 3922, 120, 90],
            [1999, 3923, 70, 70],
            [1999, 3924, 11.01, 5.63],
            [1999, 3925, 87.13, 64.34],
            [1999, 3927, 70, 70],
            [1999, 3928, 15.78, 11.76],
            [1999, 3929, 120, 90],
            [1999, 3930, 70, 70],
            [1999, 3931, 70, 70],
            [1999, 3932, 32.72, 42.52],
            [1999, 3933, 70, 70],
            [1999, 3935, 120, 90],
            [1999, 3936, 70, 70],
            [1999, 3937, 50, 60],
            [1999, 3938, 50, 60],
            [1999, 3939, 40, 50],
            [1999, 3940, 53.79, 32.63],
            [1999, 3941, 120, 90],
            [1999, 3942, 32.24, 20.58],
            [1999, 3943, 16.04, 19.53],
            [1999, 3944, 120, 90],
            [1999, 3946, 9.98, 9.98],
            [1999, 3947, 120, 90],
            [1999, 3950, 120, 90],
            [1999, 3951, 120, 90],
            [1999, 3952, 120, 90],
            [1999, 3953, 130.15, 56.8],
            [1999, 3954, 120, 90],
            [1999, 3956, 56.24, 62.52],
            [1999, 3958, 13.07, 12.08],
            [1999, 3959, 107.55, 47.75],
            [1999, 3960, 26.79, 20.82],
            [1999, 3961, 8.09, 5.91],
            [1999, 3963, 24.93, 29.76],
            [1999, 3964, 70, 70],
            [1999, 3966, 70, 70],
            [1999, 3968, 26.82, 32.61],
            [1999, 3969, 73.5, 49.04],
            [1999, 3970, 22.45, 62.54],
            [1999, 3971, 120, 90],
            [1999, 3972, 120, 86],
            [1999, 3976, 12, 24.6],
            [1999, 3978, 70, 70],
            [1999, 3979, 70, 70],
            [1999, 3980, 50, 60],
            [1999, 3981, 70, 70],
            [1999, 3982, 120, 90],
            [1999, 3983, 30, 45],
            [1999, 3985, 36, 28],
            [1999, 3988, 33.8, 45.99],
            [1999, 3990, 70, 70],
            [1999, 3991, 120, 90],
            [1999, 3992, 53.73, 58.98],
            [1999, 3993, 12, 18],
            [1999, 3994, 120, 90],
            [1999, 3996, 70, 95],
            [1999, 3997, 120, 90],
            [1999, 3998, 120, 90],
            [1999, 3999, 29.09, 38.47],
            [1999, 4001, 120, 90],
            [1999, 4002, 120, 90],
            [1999, 4003, 70, 70],
            [1999, 4004, 70, 70],
            [1999, 4005, 51.86, 17.81],
            [1999, 4007, 120, 90],
            [1999, 4008, 70, 70],
            [1999, 4010, 8.6, 12.5],
            [1999, 4012, 120, 90],
            [1999, 4013, 120, 90],
            [1999, 4014, 120, 90],
            [1999, 4015, 120, 90],
            [1999, 4016, 21, 33],
            [1999, 4017, 84.3, 28.73],
            [1999, 4018, 50, 60],
            [1999, 4019, 40, 50],
            [1999, 4021, 70, 70],
            [1999, 4022, 70, 70],
            [1999, 4023, 27.39, 27.85],
            [1999, 4024, 120, 90],
            [1999, 4026, 36.65, 22.13],
            [1999, 4027, 120, 90],
            [1999, 4028, 70, 70],
            [1999, 4031, 28.52, 48.27],
            [1999, 4034, 120, 90],
            [1999, 4035, 17.68, 13.86],
            [1999, 4038, 120, 90],
            [1999, 4040, 85.79, 70.07],
            [1999, 4041, 120, 90],
            [1999, 4043, 20, 20],
            [1999, 4045, 10.39, 9.07],
            [1999, 4047, 44.52, 35.91],
            [1999, 4048, 14.6, 19.7],
            [1999, 4049, 70, 70],
            [1999, 4051, 120, 90],
            [1999, 4053, 64.92, 33.42],
            [1999, 4057, 50, 60],
            [1999, 4059, 70, 70],
            [1999, 4062, 70, 70],
            [1999, 4063, 50, 60],
            [1999, 4065, 70, 70],
            [1999, 4066, 70, 70],
            [1999, 4067, 102.05, 42.28],
            [1999, 4068, 169, 150],
            [1999, 4069, 58.37, 31.62],
            [1999, 4070, 70, 70],
            [1999, 4071, 70, 70],
            [1999, 4072, 120, 90],
            [1999, 4073, 30, 45],
            [1999, 4074, 70, 70],
            [1999, 4076, 120, 90],
            [1999, 4080, 120, 90],
            [1999, 4081, 120, 90],
            [1999, 4082, 120, 90],
            [1999, 4083, 120, 90],
            [1999, 4084, 14, 13.72],
            [1999, 4085, 70, 70],
            [1999, 4087, 120, 90],
            [1999, 4088, 120, 90],
            [1999, 4089, 39.55, 33.1],
            [1999, 4090, 120, 90],
            [1999, 4091, 70, 70],
            [1999, 4092, 70, 70],
            [1999, 4093, 120, 90],
            [1999, 4094, 50, 60],
            [1999, 4095, 37.45, 42.54],
            [1999, 4096, 37.85, 49.46],
            [1999, 4097, 120, 90],
            [1999, 4100, 50, 60],
            [1999, 4102, 70, 70],
            [1999, 4103, 70, 70],
            [1999, 4104, 70, 70],
            [1999, 4105, 120, 90],
            [1999, 4106, 12.41, 18.24],
            [1999, 4107, 120, 90],
            [1999, 4109, 11.09, 23.39],
            [1999, 4110, 70, 70],
            [1999, 4111, 53.38, 47.38],
            [1999, 4112, 40, 50],
            [1999, 4115, 120, 90],
            [1999, 4116, 31.55, 32.55],
            [1999, 4117, 50, 60],
            [1999, 4118, 41.47, 35.71],
            [1999, 4119, 120, 90],
            [1999, 4120, 27.58, 30.03],
            [1999, 4121, 70, 70],
            [1999, 4122, 103.31, 86.3],
            [1999, 4124, 46.81, 38.06],
            [1999, 4125, 12, 18],
            [1999, 4128, 28, 24.17],
            [1999, 4129, 14.06, 10.13],
            [1999, 4131, 16.41, 11.2],
            [1999, 4133, 70, 70],
            [1999, 4134, 79.03, 44.3],
            [1999, 4136, 50, 60],
            [1999, 4137, 120, 90],
            [1999, 4138, 11.77, 6.96],
            [1999, 4139, 30, 45],
            [1999, 4140, 49.79, 34.67],
            [1999, 4142, 70, 70],
            [1999, 4143, 50, 60],
            [1999, 4145, 120, 90],
            [1999, 4146, 6.49, 5.75],
            [1999, 4147, 120, 90],
            [1999, 4149, 50, 60],
            [1999, 4150, 70, 70],
            [1999, 4152, 106.07, 54.99],
            [1999, 4154, 120, 90],
            [1999, 4155, 70, 70],
            [1999, 4156, 76.31, 53.54],
            [1999, 4157, 70, 70],
            [1999, 4158, 120, 90],
            [1999, 4159, 6.8, 6.65],
            [1999, 4162, 120, 90],
            [1999, 4164, 20.48, 22.01],
            [1999, 4165, 120, 90],
            [1999, 4166, 30, 45],
            [1999, 4167, 70, 70],
            [1999, 4168, 37.5, 45],
            [1999, 4169, 35.25, 45.76],
            [1999, 4173, 12, 24.28],
            [1999, 4175, 51.01, 25.06],
            [1999, 4176, 12, 18],
            [1999, 4177, 40.07, 56.69],
            [1999, 4178, 120, 90],
            [1999, 4179, 23.41, 16.69],
            [1999, 4180, 14.1, 8.76],
            [1999, 4181, 70, 70],
            [1999, 4182, 76.84, 36.41],
            [1999, 4185, 27.78, 27.06],
            [1999, 4186, 50, 60],
            [1999, 4188, 120, 90],
            [1999, 4189, 24.6, 36],
            [1999, 4190, 120, 90],
            [1999, 4192, 50, 60],
            [1999, 4193, 120, 90],
            [1999, 4194, 120, 90],
            [1999, 4197, 50, 60],
            [1999, 4199, 78.4, 74.93],
            [1999, 4200, 12.14, 9.28],
            [1999, 4203, 62.98, 58.18],
            [1999, 4205, 120, 90],
            [1999, 4206, 12.5, 12],
            [1999, 4207, 60.24, 34.36],
            [1999, 4208, 120, 90],
            [1999, 4209, 22.23, 20.17],
            [1999, 4210, 56.87, 36.84],
            [1999, 4211, 120, 90],
            [1999, 4213, 40.9, 35.4],
            [1999, 4215, 120, 90],
            [1999, 4216, 120, 90],
            [1999, 4219, 30, 45],
            [1999, 4220, 101, 196],
            [1999, 4221, 70, 70],
            [1999, 4222, 120, 90],
            [1999, 4223, 5.37, 4.59],
            [1999, 4224, 42.19, 39.65],
            [1999, 4225, 120, 90],
            [1999, 4226, 73.7, 42.65],
            [1999, 4229, 36.01, 22.9],
            [1999, 4230, 70, 70],
            [1999, 4231, 70, 70],
            [1999, 4232, 40, 50],
            [1999, 4233, 40, 50],
            [1999, 4234, 70, 70],
            [1999, 4235, 6.53, 5.13],
            [1999, 4236, 139, 137],
            [1999, 4237, 120, 90],
            [1999, 4238, 120, 90],
            [1999, 4239, 120, 90],
            [1999, 4241, 120, 90],
            [1999, 4242, 46.74, 74.49],
            [1999, 4244, 11.58, 16.71],
            [1999, 4245, 64, 70],
            [1999, 4246, 23.77, 36.35],
            [1999, 4248, 70, 70],
            [1999, 4249, 120, 90],
            [1999, 4250, 120, 90],
            [1999, 4251, 120, 90],
            [1999, 4252, 7.87, 9.28],
            [1999, 4256, 50, 60],
            [1999, 4257, 40, 50],
            [1999, 4258, 17, 38.5],
            [1999, 4259, 12.25, 12.29],
            [1999, 4260, 120, 90],
            [1999, 4261, 50, 60],
            [1999, 4264, 8.46, 8.46],
            [1999, 4265, 70, 70],
            [1999, 4266, 120, 90],
            [1999, 4269, 120, 90],
            [1999, 4270, 120, 90],
            [1999, 4272, 98.28, 54.81],
            [1999, 4273, 120, 90],
            [1999, 4274, 120, 90],
            [1999, 4275, 70, 70],
            [1999, 4279, 25.11, 25.86],
            [1999, 4281, 70, 70],
            [1999, 4282, 50, 60],
            [1999, 4283, 19.15, 24.03],
            [1999, 4284, 120, 90],
            [1999, 4285, 36.64, 28.69],
            [1999, 4286, 120, 90],
            [1999, 4287, 14.84, 10.96],
            [1999, 4288, 120, 90],
            [1999, 4289, 43.54, 28.73],
            [1999, 4291, 50, 60],
            [1999, 4293, 7.15, 6.68],
            [1999, 4294, 79.07, 70],
            [1999, 4295, 70, 70],
            [1999, 4296, 120, 90],
            [1999, 4297, 70, 70],
            [1999, 4298, 120, 85],
            [1999, 4299, 70, 48.52],
            [1999, 4301, 60.86, 37.6],
            [1999, 4302, 26.64, 23.08],
            [1999, 4305, 70, 70],
            [1999, 4307, 120, 90],
            [1999, 4308, 120, 90],
            [1999, 4309, 11.7, 18],
            [1999, 4310, 50, 60],
            [1999, 4312, 70, 70],
            [1999, 4313, 120, 90],
            [1999, 4317, 50, 60],
            [1999, 4318, 44.5, 31.24],
            [1999, 4320, 46.9, 37],
            [1999, 4323, 24.53, 33.29],
            [1999, 4325, 29.6, 19.97],
            [1999, 4326, 11.3, 11.2],
            [1999, 4328, 70, 70],
            [1999, 4329, 24.49, 21.37],
            [1999, 4330, 70, 70],
            [1999, 4333, 17.64, 32.54],
            [1999, 4334, 120, 90],
            [1999, 4337, 30.93, 37.77],
            [1999, 4338, 19.83, 26.04],
            [1999, 4339, 21.74, 15.6],
            [1999, 4340, 13.6, 21.8],
            [1999, 4341, 120, 90],
            [1999, 4343, 120, 90],
            [1999, 4345, 64.97, 47.25],
            [1999, 4346, 50, 60],
            [1999, 4347, 120, 90],
            [1999, 4349, 19.92, 20.51],
            [1999, 4350, 45.83, 36.77],
            [1999, 4352, 27.75, 35.04],
            [1999, 4353, 40.7, 33.52],
            [1999, 4355, 120, 90],
            [1999, 4356, 12.68, 15.44],
            [1999, 4358, 23.24, 26.31],
            [1999, 4360, 70, 70],
            [1999, 4362, 57.64, 39.46],
            [1999, 4363, 70, 70],
            [1999, 4364, 60.02, 38.25],
            [1999, 4365, 120, 90],
            [1999, 4366, 70, 70],
            [1999, 4367, 120, 90],
            [1999, 4372, 70, 70],
            [1999, 4374, 52, 51],
            [1999, 4375, 70, 70],
            [1999, 4376, 120, 90],
            [1999, 4377, 70, 70],
            [1999, 4378, 70, 70],
            [1999, 4380, 66.47, 40.12],
            [1999, 4382, 70, 65],
            [1999, 4383, 70, 70],
            [1999, 4384, 41.7, 25.8],
            [1999, 4386, 16.95, 21.6],
            [1999, 4387, 120, 90],
            [1999, 4389, 70, 70],
            [1999, 4390, 120, 90],
            [1999, 4391, 21.62, 31.72],
            [1999, 4392, 70, 70],
            [1999, 4394, 70, 70],
            [1999, 4395, 70, 70],
            [1999, 4396, 70, 70],
            [1999, 4397, 7.76, 8.86],
            [1999, 4398, 70, 70],
            [1999, 4399, 50, 60],
            [1999, 4400, 120, 90],
            [1999, 4402, 40, 50],
            [1999, 4404, 120, 90],
            [1999, 4405, 6.29, 4.6],
            [1999, 4406, 63.31, 68.07],
            [1999, 4407, 70, 70],
            [1999, 4408, 18, 27],
            [1999, 4409, 120, 90],
            [1999, 4410, 70, 70],
            [1999, 4411, 120, 90],
            [1999, 4412, 120, 90],
            [1999, 4413, 26.66, 14.26],
            [1999, 4414, 18.02, 27],
            [1999, 4415, 126.64, 97.53],
            [1999, 4416, 70, 70],
            [1999, 4417, 50, 60],
            [1999, 4418, 70, 70],
            [1999, 4419, 70, 70],
            [1999, 4420, 5.73, 6.7],
            [1999, 4421, 76.43, 44.44],
            [1999, 4426, 12, 18],
            [1999, 4427, 40, 50],
            [1999, 4428, 70, 70],
            [1999, 4432, 70, 70],
            [1999, 4433, 120, 90],
            [1999, 4436, 40, 50],
            [1999, 4438, 50, 50],
            [1999, 4439, 40, 50],
            [1999, 4440, 70, 70],
            [1999, 4441, 16.95, 12.33],
            [1999, 4442, 18, 27],
            [1999, 4443, 41.1, 27.5],
            [1999, 4444, 70, 70],
            [1999, 4445, 70, 70],
            [1999, 4446, 34.09, 21.45],
            [1999, 4448, 70, 70],
            [1999, 4450, 120, 90],
            [1999, 4453, 50, 60],
            [1999, 4454, 25.13, 30.27],
            [1999, 4455, 70, 70],
            [1999, 4456, 15.9, 14.4],
            [1999, 4457, 40, 50],
            [1999, 4460, 70, 70],
            [1999, 4461, 25.09, 25.72],
            [1999, 4463, 38.22, 20.51],
            [1999, 4464, 44.69, 25.78],
            [1999, 4465, 70, 70],
            [1999, 4466, 70, 70],
            [1999, 4467, 120, 90],
            [1999, 4468, 70, 70],
            [1999, 4470, 50, 60],
            [1999, 4471, 135.92, 55.65],
            [1999, 4473, 70, 70],
            [1999, 4477, 37.5, 45],
            [1999, 4479, 120, 90],
            [1999, 4481, 120, 90],
            [1999, 4482, 120, 90],
            [1999, 4484, 120, 90],
            [1999, 4486, 120, 90],
            [1999, 4487, 44.33, 51.92],
            [1999, 4488, 70, 70],
            [1999, 4489, 11.71, 6.08],
            [1999, 4490, 120, 90],
            [1999, 4491, 70, 70],
            [1999, 4493, 35.69, 81.75],
            [1999, 4494, 19.4, 18.2],
            [1999, 4495, 82.86, 52.5],
            [1999, 4498, 70, 70],
            [1999, 4500, 17.11, 23.93],
            [1999, 4501, 120, 90],
            [1999, 4502, 50, 60],
            [1999, 4504, 29.9, 16.62],
            [1999, 4505, 70, 70],
            [1999, 4506, 32.1, 29.68],
            [1999, 4508, 43.63, 35.85],
            [1999, 4509, 120, 90],
            [1999, 4510, 33.56, 26.64],
            [1999, 4511, 70, 70],
            [1999, 4512, 12.38, 7.83],
            [1999, 4513, 40, 50],
            [1999, 4514, 120, 90],
            [1999, 4515, 33.39, 72.42],
            [1999, 4517, 29.39, 25.61],
            [1999, 4518, 72.62, 43.09],
            [1999, 4520, 22.49, 21.03],
            [1999, 4521, 115.81, 56],
            [1999, 4523, 50, 60],
            [1999, 4524, 25.93, 22.72],
            [1999, 4525, 50, 60],
            [1999, 4526, 7.23, 8.94],
            [1999, 4527, 120, 90],
            [1999, 4530, 13.96, 9.89],
            [1999, 4531, 120, 90],
            [1999, 4532, 66.87, 50.91],
            [1999, 4533, 70, 70],
            [1999, 4534, 70, 70],
            [1999, 4535, 70, 70],
            [1999, 4536, 7.2, 20.3],
            [1999, 4538, 18, 18],
            [1999, 4539, 78.64, 44.85],
            [1999, 4540, 10.59, 6.68],
            [1999, 4541, 120, 90],
            [1999, 4542, 65, 35],
            [1999, 4543, 37.5, 45],
            [1999, 4545, 70, 70],
            [1999, 4546, 16.6, 24.9],
            [1999, 4548, 20.54, 15.72],
            [1999, 4549, 23.8, 26.7],
            [1999, 4550, 65.66, 48.34],
            [1999, 4551, 70, 70],
            [1999, 4552, 55.6, 45.56],
            [1999, 4553, 120, 90],
            [1999, 4555, 11.6, 15.4],
            [1999, 4556, 120, 90],
            [1999, 4558, 90.79, 78.09],
            [1999, 4560, 120, 90],
            [1999, 4563, 53.86, 28.78],
            [1999, 4566, 70, 70],
            [1999, 4568, 50, 60],
            [1999, 4569, 70, 70],
            [1999, 4571, 70, 70],
            [1999, 4572, 105.72, 48.73],
            [1999, 4576, 28.7, 23.7],
            [1999, 4577, 13.21, 11.61],
            [1999, 4578, 70, 70],
            [1999, 4579, 8.36, 6.62],
            [1999, 4580, 50, 60],
            [1999, 4582, 70, 70],
            [1999, 4584, 40, 50],
            [1999, 4585, 70, 70],
            [1999, 4587, 120, 90],
            [1999, 4590, 70, 70],
            [1999, 4591, 38.76, 40.37],
            [1999, 4593, 6.78, 5.29],
            [1999, 4597, 120, 90],
            [1999, 4598, 120, 90],
            [1999, 4599, 120, 90],
            [1999, 4600, 50, 60],
            [1999, 4601, 33.72, 42.28],
            [1999, 4602, 36.28, 36.4],
            [1999, 4603, 120, 90],
            [1999, 4604, 120, 90],
            [1999, 4605, 9.5, 15.6],
            [1999, 4606, 35.1, 31.57],
            [1999, 4607, 120, 90],
            [1999, 4608, 38.4, 32.2],
            [1999, 4610, 70, 70],
            [1999, 4611, 62.95, 50.94],
            [1999, 4612, 105, 166],
            [1999, 4613, 120, 77.8],
            [1999, 4614, 70, 70],
            [1999, 4615, 120, 90],
            [1999, 4616, 27.98, 41.56],
            [1999, 4617, 95.75, 69.39],
            [1999, 4618, 70, 70],
            [1999, 4619, 70, 70],
            [1999, 4620, 70, 70],
            [1999, 4621, 40, 50],
            [1999, 4622, 120, 90],
            [1999, 4623, 18, 27],
            [1999, 4626, 40, 50],
            [1999, 4627, 70, 70],
            [1999, 4628, 120, 90],
            [1999, 4629, 70, 70],
            [1999, 4630, 120, 90],
            [1999, 4631, 20.43, 22.07],
            [1999, 4633, 28.23, 35.68],
            [1999, 4634, 34.71, 35.52],
            [1999, 4635, 16.11, 11.7],
            [1999, 4636, 120, 90],
            [1999, 4637, 70, 70],
            [1999, 4638, 54.7, 34.62],
            [1999, 4641, 15.53, 8.78],
            [1999, 4643, 120, 90],
            [1999, 4644, 15.8, 15.4],
            [1999, 4645, 50, 60],
            [1999, 4648, 50, 60],
            [1999, 4649, 50, 60],
            [1999, 4651, 70, 70],
            [1999, 4652, 50, 60],
            [1999, 4653, 120, 90],
            [1999, 4655, 120, 90],
            [1999, 4657, 120, 90],
            [1999, 4658, 70, 70],
            [1999, 4660, 70, 70],
            [1999, 4661, 70, 70],
            [1999, 4662, 70, 70],
            [1999, 4664, 10.86, 8.78],
            [1999, 4665, 120, 90],
            [1999, 4666, 120, 90],
            [1999, 4667, 70, 70],
            [1999, 4668, 62.61, 42.44],
            [1999, 4670, 70, 70],
            [1999, 4671, 120, 90],
            [1999, 4674, 15, 20],
            [1999, 4675, 19.2, 19.5],
            [1999, 4676, 13.79, 18.19],
            [1999, 4677, 70, 70],
            [1999, 4679, 120, 90],
            [1999, 4682, 120, 90],
            [1999, 4684, 39.81, 23.32],
            [1999, 4685, 60.96, 34.44],
            [1999, 4687, 14.2, 21.3],
            [1999, 4688, 17.49, 12.85],
            [1999, 4689, 50, 60],
            [1999, 4690, 70, 70],
            [1999, 4691, 27.06, 17.14],
            [1999, 4692, 3.57, 3.82],
            [1999, 4693, 119.12, 52.9],
            [1999, 4694, 58.28, 38.29],
            [1999, 4695, 70, 70],
            [1999, 4696, 120, 90],
            [1999, 4697, 120, 90],
            [1999, 4698, 70, 70],
            [1999, 4699, 120, 90],
            [1999, 4701, 70, 70],
            [1999, 4702, 120, 90],
            [1999, 4703, 23.69, 36.87],
            [1999, 4704, 120, 90],
            [1999, 4705, 120, 90],
            [1999, 4708, 70, 70],
            [1999, 4709, 120, 90],
            [1999, 4710, 8.73, 6.69],
            [1999, 4711, 34.53, 20.2],
            [1999, 4712, 50.55, 38.31],
            [1999, 4713, 50, 60],
            [1999, 4716, 120, 90],
            [1999, 4717, 29.78, 34.18],
            [1999, 4718, 120, 90],
            [1999, 4720, 49.72, 35.65],
            [1999, 4722, 120, 90],
            [1999, 4724, 47.15, 28.88],
            [1999, 4725, 8.6, 7.78],
            [1999, 4726, 120, 90],
            [1999, 4728, 25.36, 23.41],
            [1999, 4729, 68.67, 36.75],
            [1999, 4731, 4.74, 5.39],
            [1999, 4732, 50, 60],
            [1999, 4733, 70, 70],
            [1999, 4734, 20, 20],
            [1999, 4736, 70, 70],
            [1999, 4737, 120, 90],
            [1999, 4738, 50.45, 38.8],
            [1999, 4740, 70, 70],
            [1999, 4741, 50, 60],
            [1999, 4742, 120, 90],
            [1999, 4743, 70, 70],
            [1999, 4744, 40, 50],
            [1999, 4745, 40, 50],
            [1999, 4747, 55.87, 35.31],
            [1999, 4749, 70, 70],
            [1999, 4750, 9.46, 10.97],
            [1999, 4751, 50, 60],
            [1999, 4752, 70, 70],
            [1999, 4753, 88.11, 37.86],
            [1999, 4754, 120, 90],
            [1999, 4755, 13.77, 7.34],
            [1999, 4756, 40, 50],
            [1999, 4757, 120, 90],
            [1999, 4760, 120, 90],
            [1999, 4761, 15.75, 12.37],
            [1999, 4762, 52.5, 52.5],
            [1999, 4764, 46.9, 75],
            [1999, 4765, 50, 60],
            [1999, 4771, 70, 70],
            [1999, 4772, 70, 70],
            [1999, 4775, 70, 70],
            [1999, 4776, 37.5, 45],
            [1999, 4777, 24.04, 33.32],
            [1999, 4778, 50, 60],
            [1999, 4779, 50, 60],
            [1999, 4780, 110.99, 50.6],
            [1999, 4781, 30, 37.5],
            [1999, 4782, 70, 70],
            [1999, 4784, 120, 90],
            [1999, 4785, 120, 90],
            [1999, 4786, 120, 90],
            [1999, 4788, 6.3, 12.1],
            [1999, 4789, 70, 70],
            [1999, 4790, 70, 70],
            [1999, 4791, 48.77, 79.01],
            [1999, 4792, 70, 70],
            [1999, 4793, 120, 90],
            [1999, 4794, 41.99, 22.03],
            [1999, 4797, 20.25, 21.58],
            [1999, 4799, 70, 70],
            [1999, 4800, 17.87, 23.42],
            [1999, 4801, 21, 27],
            [1999, 4802, 128.4, 56.12],
            [1999, 4803, 70, 70],
            [1999, 4805, 16.75, 18],
            [1999, 4806, 70, 70],
            [1999, 4807, 50, 60],
            [1999, 4809, 120, 90],
            [1999, 4810, 120, 90],
            [1999, 4811, 50, 60],
            [1999, 4812, 120, 90],
            [1999, 4814, 120, 90],
            [1999, 4815, 39.69, 32.93],
            [1999, 4816, 70, 70],
            [1999, 4818, 120, 90],
            [1999, 4819, 57.44, 40.47],
            [1999, 4820, 70, 70],
            [1999, 4821, 120, 90],
            [1999, 4825, 120, 90],
            [1999, 4826, 28.39, 26.06],
            [1999, 4828, 47.32, 22.66],
            [1999, 4829, 45.03, 39.57],
            [1999, 4831, 7.24, 8.44],
            [1999, 4832, 12, 18],
            [1999, 4834, 120, 90],
            [1999, 4835, 51.6, 40.69],
            [1999, 4838, 39.63, 29.51],
            [1999, 4839, 37.82, 38.91],
            [1999, 4840, 70, 70],
            [1999, 4841, 120, 90],
            [1999, 4842, 120, 90],
            [1999, 4844, 49.21, 40.22],
            [1999, 4846, 12.98, 17.47],
            [1999, 4848, 120, 90],
            [1999, 4849, 14.83, 14.22],
            [1999, 4851, 120, 90],
            [1999, 4852, 70, 70],
            [1999, 4853, 10.34, 10.99],
            [1999, 4854, 120, 90],
            [1999, 4856, 12, 18],
            [1999, 4863, 70, 70],
            [1999, 4864, 8.85, 15.97],
            [1999, 4865, 40, 50],
            [1999, 4866, 12, 18],
            [1999, 4867, 38.67, 22.56],
            [1999, 4869, 120, 90],
            [1999, 4871, 21.01, 27.1],
            [1999, 4872, 26.5, 30.18],
            [1999, 4875, 11.1, 18.8],
            [1999, 4876, 40, 50],
            [1999, 4877, 18.65, 29.18],
            [1999, 4878, 50, 60],
            [1999, 4879, 120, 90],
            [1999, 4880, 23.1, 15.3],
            [1999, 4881, 32.11, 49.85],
            [1999, 4882, 120, 90],
            [1999, 4885, 18, 23.69],
            [1999, 4887, 120, 90],
            [1999, 4888, 70, 70],
            [1999, 4893, 53.46, 31.32],
            [1999, 4894, 50, 60],
            [1999, 4895, 120, 90],
            [1999, 4896, 18.2, 35.8],
            [1999, 4897, 22.65, 32.49],
            [1999, 4902, 70, 70],
            [1999, 4905, 44, 67],
            [1999, 4906, 40, 50],
            [1999, 4907, 70, 70],
            [1999, 4909, 17.42, 19.96],
            [1999, 4910, 16.17, 15.54],
            [1999, 4911, 11.82, 7.07],
            [1999, 4912, 12.39, 15.28],
            [1999, 4914, 120, 90],
            [1999, 4915, 12.81, 25.88],
            [1999, 4916, 70, 70],
            [1999, 4918, 29.8, 29.23],
            [1999, 4920, 40, 50],
            [1999, 4922, 68.28, 37.1],
            [1999, 4923, 120, 90],
            [1999, 4926, 55.14, 28.19],
            [1999, 4927, 28.01, 18.8],
            [1999, 4928, 70, 70],
            [1999, 4929, 70, 70],
            [1999, 4930, 70, 70],
            [1999, 4931, 34.13, 33.6],
            [1999, 4934, 51.99, 38.18],
            [1999, 4936, 120, 90],
            [1999, 4939, 28.05, 30.31],
            [1999, 4940, 95.48, 82.93],
            [1999, 4942, 50, 60],
            [1999, 4944, 18, 18],
            [1999, 4946, 120, 90],
            [1999, 4949, 50, 60],
            [1999, 4950, 70.53, 51.44],
            [1999, 4951, 66.71, 36.01],
            [1999, 4953, 120, 90],
            [1999, 4954, 104, 179],
            [1999, 4955, 25.46, 23.67],
            [1999, 4956, 70, 70],
            [1999, 4957, 64.8, 59.23],
            [1999, 4958, 120, 90],
            [1999, 4960, 101.39, 50.61],
            [1999, 4962, 70, 70],
            [1999, 4963, 50, 66],
            [1999, 4964, 7.37, 6.44],
            [1999, 4965, 42.65, 79.28],
            [1999, 4966, 70, 70],
            [1999, 4968, 120, 90],
            [1999, 4971, 70, 70],
            [1999, 4972, 120, 90],
            [1999, 4973, 34.33, 57.8],
            [1999, 4974, 50, 60],
            [1999, 4975, 49.84, 42.61],
            [1999, 4976, 12, 22.97],
            [1999, 4977, 120, 90],
            [1999, 4978, 120, 90],
            [1999, 4979, 56.77, 40.85],
            [1999, 4981, 50, 60],
            [1999, 4983, 29.76, 20.92],
            [1999, 4984, 20, 13.27],
            [1999, 4985, 6.45, 5.95],
            [1999, 4987, 55.01, 32.18],
            [1999, 4988, 84, 107],
            [1999, 4989, 120, 90],
            [1999, 4990, 106.41, 53.31],
            [1999, 4992, 45.11, 33.84],
            [1999, 4994, 120, 90],
            [1999, 4995, 23.94, 28.78],
            [1999, 4996, 16.69, 30.91],
            [1999, 4997, 78.17, 40.51],
            [1999, 4998, 49.03, 43.06],
            [1999, 5000, 13.36, 12.29],
            [1999, 5001, 70, 70],
            [1999, 5002, 120, 90],
            [1999, 5003, 120, 90],
            [1999, 5005, 18.06, 19.95],
            [1999, 5006, 112, 90],
            [1999, 5007, 120, 90],
            [1999, 5008, 126.38, 53.28],
            [1999, 5009, 18.59, 27.74],
            [1999, 5010, 8.39, 5.61],
            [1999, 5011, 15.78, 16.19],
            [1999, 5012, 39.94, 45.98],
            [1999, 5013, 46.69, 34.25],
            [1999, 5014, 61.9, 35.6],
            [1999, 5017, 9.26, 20.62],
            [1999, 5019, 70, 45.82],
            [1999, 5020, 32.11, 40.08],
            [1999, 5022, 137.19, 88.29],
            [1999, 5023, 70, 70],
            [1999, 5025, 120, 90],
            [1999, 5026, 120, 90],
            [1999, 5027, 32.18, 30.47],
            [1999, 5031, 12, 18],
            [1999, 5032, 26.02, 40.08],
            [1999, 5033, 73.53, 35.42],
            [1999, 5035, 32.19, 33.94],
            [1999, 5037, 91.49, 46.75],
            [1999, 5038, 18, 27],
            [1999, 5041, 70, 70],
            [1999, 5043, 50, 60],
            [1999, 5044, 70, 70],
            [1999, 5046, 29.35, 32.47],
            [1999, 5048, 17.82, 19.75],
            [1999, 5049, 120, 90],
            [1999, 5050, 20.33, 12.35],
            [1999, 5051, 12, 18],
            [1999, 5053, 77.54, 45.07],
            [1999, 5054, 45.4, 28.5],
            [1999, 5056, 120, 90],
            [1999, 5057, 120, 90],
            [1999, 5058, 48.62, 42.89],
            [1999, 5060, 120, 90],
            [1999, 5061, 120, 90],
            [1999, 5062, 67.65, 70],
            [1999, 5063, 20.35, 50],
            [1999, 5064, 20.75, 20.03],
            [1999, 5065, 100.18, 69.74],
            [1999, 5066, 120, 90],
            [1999, 5068, 164.36, 62.76],
            [1999, 5069, 149.63, 54.69],
            [1999, 5070, 15.65, 30],
            [1999, 5071, 33.7, 31.78],
            [1999, 5072, 120, 90],
            [1999, 5073, 50, 60],
            [1999, 5075, 21.04, 24.86],
            [1999, 5077, 40, 50],
            [1999, 5079, 61.44, 42.57],
            [1999, 5081, 120, 90],
            [1999, 5082, 9.69, 9.33],
            [1999, 5083, 5.36, 5.53],
            [1999, 5084, 50, 60],
            [1999, 5085, 41.13, 26.96],
            [1999, 5091, 40.5, 33.65],
            [1999, 5092, 12, 18],
            [1999, 5093, 50, 60],
            [1999, 5094, 36.74, 43],
            [1999, 5095, 13.3, 17.3],
            [1999, 5097, 120, 90],
            [1999, 5098, 47.1, 29.63],
            [1999, 5099, 58.83, 35.89],
            [1999, 5100, 120, 90],
            [1999, 5101, 5.93, 6.13],
            [1999, 5102, 35.03, 31.53],
            [1999, 5103, 89.21, 43],
            [1999, 5104, 120, 90],
            [1999, 5107, 70, 65],
            [1999, 5108, 25, 40],
            [1999, 5109, 93.01, 45.96],
            [1999, 5111, 120, 90],
            [1999, 5114, 4.87, 4],
            [1999, 5115, 12.26, 31.18],
            [1999, 5116, 22.23, 21.49],
            [1999, 5117, 40, 50],
            [1999, 5119, 120, 90],
            [1999, 5121, 30.65, 46.26],
            [1999, 5122, 21.51, 31.21],
            [1999, 5123, 11.8, 11.02],
            [1999, 5124, 56.09, 43.95],
            [1999, 5126, 26.81, 24.11],
            [1999, 5127, 32.57, 20.36],
            [1999, 5128, 70, 70],
            [1999, 5130, 50, 60],
            [1999, 5132, 120, 90],
            [1999, 5135, 68.8, 41.77],
            [1999, 5136, 10.18, 8.06],
            [1999, 5137, 120, 90],
            [1999, 5138, 15.14, 13.83],
            [1999, 5141, 24.58, 21.45],
            [1999, 5143, 70, 70],
            [1999, 5145, 120, 90],
            [1999, 5149, 120, 90],
            [1999, 5150, 52.83, 33.37],
            [1999, 5153, 179.52, 59.91],
            [1999, 5154, 96, 141],
            [1999, 5155, 70, 70],
            [1999, 5156, 40, 50],
            [1999, 5157, 50, 60],
            [1999, 5159, 52.86, 48.43],
            [1999, 5160, 120, 90],
            [1999, 5161, 17.42, 15.54],
            [1999, 5162, 65.6, 46.34],
            [1999, 5163, 120, 90],
            [1999, 5164, 120, 90],
            [1999, 5165, 3.38, 5.47],
            [1999, 5166, 33.73, 21.58],
            [1999, 5167, 179, 220],
            [1999, 5169, 56.5, 44.9],
            [1999, 5171, 249.75, 64.69],
            [1999, 5172, 70, 70],
            [1999, 5173, 46.38, 41.15],
            [1999, 5174, 143.07, 72.47],
            [1999, 5178, 120, 90],
            [1999, 5180, 86.39, 54.81],
            [1999, 5181, 120, 90],
            [1999, 5182, 16.01, 20.04],
            [1999, 5183, 30.09, 35.52],
            [1999, 5184, 120, 90],
            [1999, 5185, 70, 70],
            [1999, 5186, 12, 18],
            [1999, 5187, 12, 18],
            [1999, 5188, 12, 18],
            [1999, 5189, 32, 40],
            [1999, 5191, 50, 25],
            [1999, 5192, 15, 25],
            [1999, 5193, 15, 25],
            [1999, 5194, 15, 25],
            [1999, 5195, 15, 25],
            [1999, 5196, 15, 25],
            [1999, 5197, 15, 25],
            [1999, 5198, 15, 25],
            [1999, 5199, 15, 25],
            [1999, 5200, 15, 25],
            [1999, 5201, 15, 25],
            [1999, 5202, 15, 25],
            [1999, 5203, 15, 25],
            [1999, 5204, 40, 50],
            [1999, 5205, 15, 25],
            [1999, 5206, 15, 25],
            [1999, 5207, 15, 25],
            [1999, 5208, 15, 25],
            [1999, 5209, 15, 25],
            [1999, 5210, 15, 25],
            [1999, 5211, 15, 25],
            [1999, 5212, 15, 25],
            [1999, 5213, 15, 25],
            [1999, 5214, 15, 25],
            [1999, 5215, 15, 25],
            [1999, 5216, 15, 25],
            [1999, 5217, 70, 70],
            [1999, 5218, 50, 60],
            [1999, 5219, 20.7, 31.7],
            [1999, 5220, 12.6, 25.3],
            [1999, 5221, 14.8, 27.6],
            [1999, 5222, 23, 18.2],
            [1999, 5223, 10.5, 15.3],
            [1999, 5224, 16.8, 30.5],
            [1999, 5225, 21.5, 24.2],
            [1999, 5226, 8.5, 20.2],
            [1999, 5227, 55.9, 46.8],
            [1999, 5228, 18.7, 32.7],
            [1999, 5229, 7, 15.8],
            [1999, 5230, 15.5, 13.1],
            [1999, 5231, 15.2, 18.9],
            [1999, 5232, 26.7, 34.4],
            [1999, 5233, 22.9, 36.3],
            [1999, 5234, 10.9, 17.5],
            [1999, 5235, 43.7, 39.9],
            [1999, 5236, 15.6, 18.9],
            [1999, 5237, 27.3, 31.4],
            [1999, 5238, 23.1, 25.3],
            [1999, 5239, 23.3, 28.2],
            [1999, 5240, 17, 31.3],
            [1999, 5241, 26.1, 21.4],
            [1999, 5242, 25.2, 23.2],
            [1999, 5243, 28.2, 26.9],
            [1999, 5244, 20.5, 30],
            [1999, 5245, 21.3, 30],
            [1999, 5247, 80, 60],
            [1999, 5248, 80, 60],
            [1999, 5249, 18.79, 11.59],
            [1999, 5250, 20.93, 10.99],
            [1999, 5251, 9.51, 7.03],
            [1999, 5252, 30, 16.56],
            [1999, 5253, 10.32, 10.66],
            [1999, 5254, 24.49, 16.32],
            [1999, 5255, 22.02, 14.56],
            [1999, 5256, 24.56, 17.38],
            [1999, 5257, 15.4, 13.96],
            [1999, 5258, 22.79, 18.26],
            [1999, 5259, 10.2, 9.75],
            [1999, 5260, 14.4, 8.76],
            [1999, 5261, 24.99, 12.73],
            [1999, 5263, 19.45, 15.67],
            [1999, 5264, 70, 38.11],
            [1999, 5265, 7.43, 6.83],
            [1999, 5266, 23.79, 12.6],
            [1999, 5267, 21.83, 11.15],
            [1999, 5268, 15.77, 12.82],
            [1999, 5269, 14.5, 9.26],
            [1999, 5270, 13.02, 16.2],
            [1999, 5271, 70, 70],
            [1999, 5272, 49.88, 21.16],
            [1999, 5273, 27.17, 19.34],
            [1999, 5274, 21.56, 23.35],
            [1999, 5275, 21.89, 20.99],
            [1999, 5276, 33.57, 69.59],
            [1999, 5277, 33.53, 44.16],
            [1999, 5278, 17.61, 19.46],
            [1999, 5279, 22.19, 26.31],
            [1999, 5280, 54.9, 42.95],
            [1999, 5281, 23.97, 21.11],
            [1999, 5282, 18.86, 21.15],
            [1999, 5283, 14.72, 24.85],
            [1999, 5284, 19.82, 21.97],
            [1999, 5285, 12.98, 10.05],
            [1999, 5286, 21.47, 25.37],
            [1999, 5287, 12.95, 13.1],
            [1999, 5288, 15.79, 13.5],
            [1999, 5289, 14.72, 18.53],
            [1999, 5290, 23.09, 21.92],
            [1999, 5291, 13.74, 15.42],
            [1999, 5292, 27.71, 17.72],
            [1999, 5293, 31.42, 28.8],
            [1999, 5294, 27.26, 35.13],
            [1999, 5295, 17.19, 14.3],
            [1999, 5296, 37.77, 51.52],
            [1999, 5297, 36.44, 42.37],
            [1999, 5298, 13.26, 13.27],
            [1999, 5299, 18.16, 20.87],
            [1999, 5300, 19.04, 16.88],
            [1999, 5301, 42.73, 37.25],
            [1999, 5302, 9.07, 5.65],
            [1999, 5303, 36.15, 21.1],
            [1999, 5304, 19.35, 28.15],
            [1999, 5305, 28.21, 24.21],
            [1999, 5306, 30.08, 35.59],
            [1999, 5307, 28.82, 42.89],
            [1999, 5308, 30.68, 46.96],
            [1999, 5309, 22.98, 21.99],
            [1999, 5310, 18.38, 19.26],
            [1999, 5311, 14.95, 17.32],
            [1999, 5312, 24.78, 19.47],
            [1999, 5313, 14.05, 18.92],
            [1999, 5314, 22.31, 24.96],
            [1999, 5315, 19.95, 27.16],
            [1999, 5316, 34.5, 42.49],
            [1999, 5317, 47.68, 75.34],
            [1999, 5318, 30.3, 21.67],
            [1999, 5319, 13.84, 14.27],
            [1999, 5320, 53.44, 55.56],
            [1999, 5321, 21.43, 22.1],
            [1999, 5322, 21.86, 31.16],
            [1999, 5323, 13.54, 22.48],
            [1999, 5324, 28.56, 35.07],
            [1999, 5325, 16.07, 19.54],
            [1999, 5326, 34.56, 41.14],
            [1999, 5327, 16.58, 21.05],
            [1999, 5328, 21.03, 21.33],
            [1999, 5329, 17.44, 17.44],
            [1999, 5330, 28.89, 22.93],
            [1999, 5331, 20.27, 21.28],
            [1999, 5332, 24.04, 29.18],
            [1999, 5333, 13.04, 16.32],
            [1999, 5334, 14.81, 13.78],
            [1999, 5335, 19.89, 15.44],
            [1999, 5336, 16.38, 19.14],
            [1999, 5337, 17.09, 17.7],
            [1999, 5338, 33.77, 26.64],
            [1999, 5339, 21.48, 24.94],
            [1999, 5340, 31.28, 38.93],
            [1999, 5341, 21.6, 30.78],
            [1999, 5342, 67.33, 44.59],
            [1999, 5343, 16.6, 14.81],
            [1999, 5344, 47.23, 50.54],
            [1999, 5345, 17.36, 20.76],
            [1999, 5346, 12.53, 15.06],
            [1999, 5347, 20.45, 23.78],
            [1999, 5348, 18.99, 19.54],
            [1999, 5349, 23.6, 27.71],
            [1999, 5350, 17.87, 30.23],
            [1999, 5351, 25.6, 34.49],
            [1999, 5352, 12.65, 19.75],
            [1999, 5353, 20.64, 26.6],
            [1999, 5354, 15.47, 9.25],
            [1999, 5355, 24.3, 42.86],
            [1999, 5356, 15.64, 19.61],
            [1999, 5357, 30.99, 21.01],
            [1999, 5358, 18.44, 20.69],
            [1999, 5359, 17.32, 25.16],
            [1999, 5360, 14.69, 9.66],
            [1999, 5361, 25.44, 28.51],
            [1999, 5362, 22.78, 37.54],
            [1999, 5363, 17.15, 20.75],
            [1999, 5364, 27.13, 35.08],
            [1999, 5365, 14.15, 16.33],
            [1999, 5366, 31.71, 24.96],
            [1999, 5367, 18.39, 19.03],
            [1999, 5368, 25.49, 33.82],
            [1999, 5369, 17.87, 17.73],
            [1999, 5370, 26.37, 19.9],
            [1999, 5371, 34.48, 40.39],
            [1999, 5372, 23.31, 23.21],
            [1999, 5373, 39.81, 52.34],
            [1999, 5374, 38.4, 30.66],
            [1999, 5375, 20.13, 18.67],
            [1999, 5376, 39.93, 36.29],
            [1999, 5377, 17.78, 19.64],
            [1999, 5378, 44.16, 54.79],
            [1999, 5379, 17.59, 16],
            [1999, 5380, 19.5, 24.07],
            [1999, 5381, 24.54, 27.3],
            [1999, 5382, 27.26, 39.02],
            [1999, 5383, 24.98, 28.96],
            [1999, 5384, 32.06, 28.26],
            [1999, 5385, 35.75, 25.11],
            [1999, 5386, 12.39, 14.93],
            [1999, 5387, 16.52, 16.08],
            [1999, 5388, 28.27, 31.03],
            [1999, 5389, 21.28, 32.3],
            [1999, 5390, 27.81, 21.8],
            [1999, 5391, 15.92, 17.92],
            [1999, 5392, 18.92, 29.5],
            [1999, 5393, 21.42, 30.33],
            [1999, 5394, 25.56, 27.95],
            [1999, 5395, 15.36, 21.7],
            [1999, 5396, 24.37, 24.45],
            [1999, 5397, 37.72, 55.15],
            [1999, 5398, 22.54, 21.56],
            [1999, 5399, 30.96, 24.28],
            [1999, 5400, 13.97, 12.67],
            [1999, 5401, 27.87, 36.25],
            [1999, 5402, 25.63, 36.95],
            [1999, 5403, 24.28, 25.06],
            [1999, 5404, 24.46, 24.68],
            [1999, 5405, 17.96, 16.23],
            [1999, 5406, 26.71, 28.04],
            [1999, 5407, 20.69, 24.62],
            [1999, 5408, 18.11, 22.5],
            [1999, 5409, 31.73, 36.57],
            [1999, 5410, 58.51, 46.49],
            [1999, 5411, 27.68, 21.48],
            [1999, 5412, 23.04, 18.15],
            [1999, 5413, 23.32, 18.19],
            [1999, 5414, 9.91, 15.09],
            [1999, 5415, 51.57, 56.26],
            [1999, 5416, 12.77, 13.87],
            [1999, 5417, 23.61, 19.35],
            [1999, 5418, 28.79, 36.91],
            [1999, 5419, 27.19, 25.1],
            [1999, 5420, 16.27, 16.14],
            [1999, 5421, 18.76, 15.11],
            [1999, 5422, 25.14, 34.37],
            [1999, 5423, 35.81, 32.77],
            [1999, 5424, 17.07, 19.91],
            [1999, 5425, 16.63, 19.74],
            [1999, 5426, 22.35, 32.83],
            [1999, 5427, 30.13, 36.75],
            [1999, 5428, 18.88, 25.12],
            [1999, 5429, 14.33, 16.18],
            [1999, 5430, 35.21, 32.17],
            [1999, 5431, 21.98, 23.51],
            [1999, 5432, 22.49, 30.65],
            [1999, 5433, 22.03, 25.8],
            [1999, 5434, 15.65, 16.63],
            [1999, 5435, 28.65, 36.45],
            [1999, 5436, 22.2, 26.91],
            [1999, 5437, 28.46, 24.42],
            [1999, 5438, 26.15, 45.07],
            [1999, 5439, 23.1, 32.12],
            [1999, 5440, 42.61, 31.07],
            [1999, 5441, 31.6, 43.27],
            [1999, 5442, 27.28, 31.24],
            [1999, 5443, 27.08, 44.53],
            [1999, 5444, 21.92, 35.18],
            [1999, 5445, 16.8, 20.91],
            [1999, 5446, 28.06, 29.76],
            [1999, 5447, 20.25, 23.23],
            [1999, 5448, 18.61, 19.97],
            [1999, 5449, 26.78, 33.16],
            [1999, 5450, 28.76, 31.21],
            [1999, 5451, 36.55, 47.48],
            [1999, 5452, 22.51, 34.53],
            [1999, 5453, 28.94, 32.53],
            [1999, 5454, 12.32, 16.18],
            [1999, 5455, 28.32, 21.25],
            [1999, 5456, 21.35, 24.85],
            [1999, 5457, 16.87, 25.48],
            [1999, 5458, 18.67, 22.48],
            [1999, 5459, 25.03, 25.93],
            [1999, 5460, 15.43, 17.97],
            [1999, 5461, 18.92, 17.99],
            [1999, 5462, 22.52, 26.38],
            [1999, 5463, 14.28, 17.95],
            [1999, 5464, 18.6, 18.27],
            [1999, 5465, 23.82, 23.85],
            [1999, 5466, 18.5, 23.11],
            [1999, 5467, 21.73, 26.16],
            [1999, 5468, 48, 73.78],
            [1999, 5469, 28.95, 22.5],
            [1999, 5470, 18.2, 26.19],
            [1999, 5471, 21.88, 24.32],
            [1999, 5472, 24.34, 29.62],
            [1999, 5473, 18.21, 24.01],
            [1999, 5474, 15.15, 14.65],
            [1999, 5475, 19.39, 18.75],
            [1999, 5476, 15.52, 20.64],
            [1999, 5477, 11.66, 13.63],
            [1999, 5478, 18.69, 21.99],
            [1999, 5479, 20.66, 18.21],
            [1999, 5480, 38.45, 32.17],
            [1999, 5481, 15.98, 18.15],
            [1999, 5482, 17.06, 18.76],
            [1999, 5483, 25.35, 27.15],
            [1999, 5484, 22.09, 21.1],
            [1999, 5485, 22.02, 23.57],
            [1999, 5486, 22.14, 21.65],
            [1999, 5487, 17.97, 21.38],
            [1999, 5488, 24.02, 25.06],
            [1999, 5489, 34.19, 66.05],
            [1999, 5490, 28.94, 32.56],
            [1999, 5491, 15.88, 20.08],
            [1999, 5492, 22.58, 38.47],
            [1999, 5493, 27.68, 21.75],
            [1999, 5494, 25.82, 30.23],
            [1999, 5495, 33.94, 27.03],
            [1999, 5496, 74.87, 78.15],
            [1999, 5497, 18.35, 22.55],
            [1999, 5498, 27.02, 39.89],
            [1999, 5499, 33.57, 24.3],
            [1999, 5500, 22.47, 23.4],
            [1999, 5501, 27.13, 46.22],
            [1999, 5502, 29.4, 31.24],
            [1999, 5503, 25.48, 24.22],
            [1999, 5504, 29.82, 41.45],
            [1999, 5505, 19.44, 30.38],
            [1999, 5506, 19.55, 18.02],
            [1999, 5507, 8.92, 15.03],
            [1999, 5508, 25.07, 35.23],
            [1999, 5509, 25.6, 36.32],
            [1999, 5510, 23.88, 39.9],
            [1999, 5511, 27.52, 24.5],
            [1999, 5512, 11.13, 11.46],
            [1999, 5513, 20.91, 23.63],
            [1999, 5514, 17.98, 18.09],
            [1999, 5515, 38.99, 31.52],
            [1999, 5516, 24.35, 34.55],
            [1999, 5517, 22.32, 28.37],
            [1999, 5518, 19.91, 18.99],
            [1999, 5519, 31.61, 40.04],
            [1999, 5520, 22.33, 22.91],
            [1999, 5521, 33.45, 39.31],
            [1999, 5522, 20.71, 22.53],
            [1999, 5523, 26.18, 29.99],
            [1999, 5524, 21.48, 50.1],
            [1999, 5525, 22.24, 21.41],
            [1999, 5526, 32.51, 26.74],
            [1999, 5527, 30.84, 34.66],
            [1999, 5528, 20.96, 19.72],
            [1999, 5529, 59.13, 37.8],
            [1999, 5530, 19.55, 21.33],
            [1999, 5531, 24.12, 22.95],
            [1999, 5532, 25.42, 24.65],
            [1999, 5533, 14.52, 14.84],
            [1999, 5534, 17.4, 14.87],
            [1999, 5535, 15.5, 12.89],
            [1999, 5536, 2, 2],
            [1999, 5537, 12.2, 8.94],
            [1999, 5538, 37.26, 35.28],
            [1999, 5539, 14.86, 20],
            [1999, 5540, 23.95, 34.62],
            [1999, 5541, 26.12, 21.77],
            [1999, 5542, 12.8, 16.15],
            [1999, 5543, 12.26, 16.58],
            [1999, 5544, 22.77, 32.88],
            [1999, 5545, 16.25, 22.22],
            [1999, 5546, 34.03, 40.31],
            [1999, 5547, 26.1, 25.13],
            [1999, 5548, 38.2, 46.39],
            [1999, 5549, 16.23, 22.79],
            [1999, 5550, 16.66, 17.46],
            [1999, 5551, 47.85, 75.99],
            [1999, 5552, 28.07, 25.33],
            [1999, 5553, 31.7, 29.24],
            [1999, 5554, 26.98, 30.18],
            [1999, 5555, 32.21, 32.76],
            [1999, 5556, 17.16, 17.29],
            [1999, 5557, 15.34, 14.19],
            [1999, 5558, 14.56, 19.66],
            [1999, 5559, 30.04, 31.58],
            [1999, 5560, 74.52, 28.37],
            [1999, 5561, 38.69, 49.15],
            [1999, 5562, 40.29, 56.03],
            [1999, 5563, 33.52, 34.96],
            [1999, 5564, 88.05, 56.53],
            [1999, 5565, 19.45, 18.12],
            [1999, 5566, 24.67, 27.3],
            [1999, 5567, 28.59, 35.72],
            [1999, 5568, 26.89, 35.03],
            [1999, 5569, 51.02, 38.85],
            [1999, 5570, 37.26, 27.17],
            [1999, 5571, 28.9, 21.65],
            [1999, 5572, 20.43, 17.7],
            [1999, 5573, 42.96, 28.46],
            [1999, 5600, 70, 129],
            [1999, 5627, 55, 125],
            [1999, 5632, 50, 70],
            [1999, 5636, 52, 60],
            [1999, 5638, 163, 120],
            [1999, 5646, 120, 104],
            [1999, 5648, 65, 172],
            [1999, 5649, 102, 108],
            [1999, 5659, 5.35, 4.7],
            [1999, 5660, 7.67, 7.45],
            [1999, 5661, 70, 70],
            [1999, 5663, 120, 90],
            [1999, 5666, 120, 90],
            [1999, 5672, 70, 70],
            [1999, 5675, 40, 50],
            [1999, 5677, 120, 90],
            [1999, 5681, 70, 70],
            [1999, 5683, 120, 90],
            [1999, 5689, 120, 90],
            [1999, 5706, 120, 90],
            [1999, 5715, 70, 70],
            [1999, 5717, 120, 90],
            [1999, 5720, 70, 70],
            [1999, 5726, 120, 90],
            [1999, 5728, 120, 90],
            [1999, 5737, 120, 90],
            [1999, 5738, 120, 90],
            [1999, 5745, 70, 70],
            [1999, 5747, 120, 90],
            [1999, 5757, 40, 50],
            [1999, 5758, 70, 70],
            [1999, 5764, 50, 60],
            [1999, 5768, 70, 70],
            [1999, 5777, 120, 90],
            [1999, 5789, 40, 50],
            [1999, 5805, 120, 90],
            [1999, 5808, 70, 70],
            [1999, 5811, 120, 90],
            [1999, 5819, 120, 90],
            [1999, 5824, 70, 70],
            [1999, 5830, 70, 70],
            [1999, 5833, 120, 90],
            [1999, 5840, 120, 90],
            [1999, 5841, 120, 90],
            [1999, 5846, 120, 90],
            [1999, 5848, 120, 90],
            [1999, 5851, 120, 90],
            [1999, 5855, 50, 60],
            [1999, 5856, 40, 50],
            [1999, 5861, 120, 90],
            [1999, 5869, 120, 90],
            [1999, 5876, 120, 90],
            [1999, 5877, 120, 90],
            [1999, 5880, 50, 60],
            [1999, 5881, 40, 50],
            [1999, 5882, 50, 60],
            [1999, 5884, 120, 90],
            [1999, 5889, 70, 70],
            [1999, 5898, 120, 90],
            [1999, 5903, 70, 70],
            [1999, 5911, 120, 90],
            [1999, 5917, 120, 90],
            [1999, 5918, 120, 90],
            [1999, 5919, 70, 70],
            [1999, 5931, 70, 70],
            [1999, 5933, 40, 50],
            [1999, 5936, 70, 70],
            [1999, 5939, 120, 90],
            [1999, 5941, 120, 90],
            [1999, 5942, 120, 90],
            [1999, 5943, 120, 90],
            [1999, 5944, 40, 50],
            [1999, 5945, 40, 50],
            [1999, 5946, 40, 50],
            [1999, 5947, 120, 90],
            [1999, 5948, 120, 90],
            [1999, 5949, 120, 90],
            [1999, 5950, 120, 90],
            [1999, 5951, 120, 90],
            [1999, 5953, 120, 90],
            [1999, 5954, 120, 90],
            [1999, 5955, 120, 90],
            [1999, 5956, 120, 90],
            [1999, 5957, 120, 90],
            [1999, 5958, 40, 50],
            [1999, 5959, 40, 50],
            [1999, 5961, 40, 50],
            [1999, 5962, 50, 60],
            [1999, 5970, 163, 136],
            [1999, 5985, 15, 25],
            [1999, 5986, 50, 60],
            [1999, 5987, 15, 25],
            [1999, 5988, 21, 33],
            [1999, 5989, 50, 60],
            [1999, 5990, 50, 60],
            [1999, 5991, 50, 60],
            [1999, 5992, 50, 60],
            [1999, 5993, 50, 60],
            [1999, 5994, 40, 50],
            [1999, 5995, 70, 70],
            [1999, 5996, 70, 70],
            [1999, 5997, 70, 70],
            [1999, 5998, 120, 90],
            [1999, 5999, 50, 60],
            [1999, 6049, 70, 70],
            [1999, 6050, 70, 70],
            [1999, 6051, 70, 70],
            [1999, 6052, 120, 90],
            [1999, 6053, 120, 90],
            [1999, 6054, 120, 90],
            [1999, 6055, 52.5, 52.5],
            [1999, 6066, 37.5, 45],
            [1999, 6067, 15, 25],
            [1999, 6068, 120, 90],
            [1999, 6069, 70, 70],
            [1999, 6070, 70, 70],
            [1999, 6071, 70, 70],
            [1999, 6072, 40, 50],
            [1999, 6073, 70, 70],
            [1999, 6074, 70, 70],
            [1999, 6075, 70, 70],
            [1999, 6076, 50, 60],
            [1999, 6077, 70, 70],
            [1999, 6078, 50, 60],
            [1999, 6079, 70, 70],
            [1999, 6080, 50, 60],
            [1999, 6081, 50, 60],
            [1999, 6082, 70, 70],
            [1999, 6083, 70, 70],
            [1999, 6084, 120, 90],
            [1999, 6085, 120, 90],
            [1999, 6086, 50, 60],
            [1999, 6087, 70, 70],
            [1999, 6088, 70, 70],
            [1999, 6089, 70, 70],
            [1999, 6090, 120, 90],
            [1999, 6091, 70, 70],
            [1999, 6092, 70, 70],
            [1999, 6093, 70, 70],
            [1999, 6094, 70, 70],
            [1999, 6095, 50, 60],
            [1999, 6096, 70, 70],
            [1999, 6097, 70, 70],
            [1999, 6098, 70, 70],
            [1999, 6099, 120, 90],
            [1999, 6100, 70, 70],
            [1999, 6101, 70, 70],
            [1999, 6102, 50, 60],
            [1999, 6103, 70, 70],
            [1999, 6104, 120, 90],
            [1999, 6105, 120, 90],
            [1999, 6106, 70, 70],
            [1999, 6107, 70, 70],
            [1999, 6108, 70, 70],
            [1999, 6109, 50, 60],
            [1999, 6110, 70, 70],
            [1999, 6111, 30, 45],
            [1999, 6112, 70, 70],
            [1999, 6113, 70, 70],
            [1999, 6114, 50, 60],
            [1999, 6115, 50, 60],
            [1999, 6116, 70, 70],
            [1999, 6117, 70, 70],
            [1999, 6118, 70, 70],
            [1999, 6119, 70, 70],
            [1999, 6120, 40, 50],
            [1999, 6121, 70, 70],
            [1999, 6122, 70, 70],
            [1999, 6123, 70, 70],
            [1999, 6124, 70, 70],
            [1999, 6125, 70, 70],
            [1999, 6126, 70, 70],
            [1999, 6127, 70, 70],
            [1999, 6128, 70, 70],
            [1999, 6129, 40, 50],
            [1999, 6130, 70, 70],
            [1999, 6131, 70, 70],
            [1999, 6132, 70, 70],
            [1999, 6133, 70, 70],
            [1999, 6134, 70, 70],
            [1999, 6135, 70, 70],
            [1999, 6136, 70, 70],
            [1999, 6137, 40, 50],
            [1999, 6138, 50, 60],
            [1999, 6139, 70, 70],
            [1999, 6140, 40, 50],
            [1999, 6141, 50, 60],
            [1999, 6142, 50, 60],
            [1999, 6143, 70, 70],
            [1999, 6144, 70, 70],
            [1999, 6145, 70, 70],
            [1999, 6146, 30, 45],
            [1999, 6147, 40, 50],
            [1999, 6148, 40, 50],
            [1999, 6149, 70, 70],
            [1999, 6150, 40, 50],
            [1999, 6151, 70, 70],
            [1999, 6152, 40, 50],
            [1999, 6153, 40, 50],
            [1999, 6154, 70, 70],
            [1999, 6155, 40, 50],
            [1999, 6156, 50, 60],
            [1999, 6157, 50, 60],
            [1999, 6158, 50, 60],
            [1999, 6159, 70, 70],
            [1999, 6160, 70, 70],
            [1999, 6161, 40, 50],
            [1999, 6162, 50, 60],
            [1999, 6163, 50, 60],
            [1999, 6164, 70, 70],
            [1999, 6165, 50, 60],
            [1999, 6166, 50, 60],
            [1999, 6167, 70, 70],
            [1999, 6168, 30, 45],
            [1999, 6169, 30, 45],
            [1999, 6170, 30, 45],
            [1999, 6227, 120, 90],
            [1999, 6228, 15, 25],
            [1999, 6229, 15, 25],
            [1999, 6230, 50, 60],
            [1999, 6231, 50, 60],
            [1999, 6232, 50, 60],
            [1999, 6233, 70, 70],
            [1999, 6234, 50, 60],
            [1999, 6235, 50, 60],
            [1999, 6236, 50, 60],
            [1999, 6238, 70, 70],
            [1999, 6239, 50, 60],
            [1999, 6240, 50, 60],
            [1999, 6241, 50, 60],
            [1999, 6242, 50, 60],
            [1999, 6243, 70, 70],
            [1999, 6244, 70, 70],
            [1999, 6245, 50, 60],
            [1999, 6246, 70, 70],
            [1999, 6247, 50, 60],
            [1999, 6248, 30, 45],
            [1999, 6252, 50, 60],
            [1999, 6253, 120, 90],
            [1999, 6255, 70, 70],
            [1999, 6256, 50, 60],
            [1999, 6258, 50, 60],
            [1999, 6259, 120, 90],
            [1999, 6260, 120, 90],
            [1999, 6261, 70, 70],
            [1999, 6262, 70, 70],
            [1999, 6263, 120, 90],
            [1999, 6264, 70, 70],
            [1999, 6265, 70, 70],
            [1999, 6266, 50, 60],
            [1999, 6267, 50, 60],
            [1999, 6268, 70, 70],
            [1999, 6269, 50, 60],
            [1999, 6270, 50, 60],
            [1999, 6271, 70, 70],
            [1999, 6272, 40, 50],
            [1999, 6274, 70, 70],
            [1999, 6275, 70, 70],
            [1999, 6276, 50, 60],
            [1999, 6277, 120, 90],
            [1999, 6278, 70, 70],
            [1999, 6279, 70, 70],
            [1999, 6280, 70, 70],
            [1999, 6281, 70, 70],
            [1999, 6282, 50, 60],
            [1999, 6283, 70, 70],
            [1999, 6284, 50, 60],
            [1999, 6286, 70, 70],
            [1999, 6287, 50, 60],
            [1999, 6288, 70, 70],
            [1999, 6289, 50, 60],
            [1999, 6290, 120, 90],
            [1999, 6292, 70, 70],
            [1999, 6293, 70, 70],
            [1999, 6294, 120, 90],
            [1999, 6295, 120, 90],
            [1999, 6296, 70, 70],
            [1999, 6297, 120, 90],
            [1999, 6299, 70, 70],
            [1999, 6300, 70, 70],
            [1999, 6301, 70, 70],
            [1999, 6302, 70, 70],
            [1999, 6303, 70, 70],
            [1999, 6305, 120, 90],
            [1999, 6306, 70, 70],
            [1999, 6307, 120, 90],
            [1999, 6308, 120, 90],
            [1999, 6309, 70, 70],
            [1999, 6310, 50, 60],
            [1999, 6312, 120, 90],
            [1999, 6313, 70, 70],
            [1999, 6314, 120, 90],
            [1999, 6315, 70, 70],
            [1999, 6316, 70, 70],
            [1999, 6317, 70, 70],
            [1999, 6319, 50, 60],
            [1999, 6320, 70, 70],
            [1999, 6321, 70, 70],
            [1999, 6323, 50, 60],
            [1999, 6324, 50, 60],
            [1999, 6325, 120, 90],
            [1999, 6326, 70, 70],
            [1999, 6327, 50, 60],
            [1999, 6328, 120, 90],
            [1999, 6330, 120, 90],
            [1999, 6334, 27.92, 22.8],
            [1999, 6335, 36.36, 27.35],
            [1999, 6336, 50, 35.7],
            [1999, 6337, 28.8, 13.04],
            [1999, 6338, 50, 33.77],
            [1999, 6339, 20.96, 16.45],
            [1999, 6340, 50, 36.94],
            [1999, 6341, 40, 23.08],
            [1999, 6342, 23.49, 10.98],
            [1999, 6343, 22.07, 18.41],
            [1999, 6344, 19.93, 9.57],
            [1999, 6345, 50, 21.26],
            [1999, 6346, 40, 25.58],
            [1999, 6347, 30.77, 13.81],
            [1999, 6348, 28.74, 14.96],
            [1999, 6349, 26.83, 18.14],
            [1999, 6350, 30.1, 29.64],
            [1999, 6351, 37.29, 18.38],
            [1999, 6353, 40, 50],
            [1999, 6354, 40, 50],
            [1999, 6355, 30, 45],
            [1999, 6356, 40, 50],
            [1999, 6357, 40, 50],
            [1999, 6358, 40, 50],
            [1999, 6359, 28.08, 27.32],
            [1999, 6360, 120, 109.36],
            [1999, 6361, 120, 90],
            [1999, 6362, 115.35, 155.44],
            [1999, 6363, 63.74, 113.55],
            [1999, 6364, 120, 108.36],
            [1999, 6365, 120, 90],
            [1999, 6366, 152, 95.28],
            [1999, 6367, 70, 70],
            [1999, 6368, 120, 119.04],
            [1999, 6369, 68.6, 48.47],
            [1999, 6370, 120, 90],
            [1999, 6371, 120, 130.57],
            [1999, 6372, 120, 90],
            [1999, 6373, 120, 90],
            [1999, 6374, 120, 64.08],
            [1999, 6375, 120, 90],
            [1999, 6376, 70, 70],
            [1999, 6377, 120, 90],
            [1999, 6378, 70, 70],
            [1999, 6379, 120, 78.19],
            [1999, 6380, 70, 91.63],
            [1999, 6381, 70, 70],
            [1999, 6382, 120, 108.36],
            [1999, 6383, 70, 70],
            [1999, 6384, 120, 108.36],
            [1999, 6385, 120, 65.11],
            [1999, 6386, 120, 90],
            [1999, 6387, 120, 90],
            [1999, 6388, 120, 90],
            [1999, 6389, 120, 90],
            [1999, 6390, 120, 90],
            [1999, 6391, 78.33, 99.36],
            [1999, 6392, 120, 90],
            [1999, 6393, 120, 90],
            [1999, 6394, 120, 90],
            [1999, 6395, 120, 90],
            [1999, 6396, 120, 117.19],
            [1999, 6397, 120, 90],
            [1999, 6398, 120, 90],
            [1999, 6399, 120, 90],
            [1999, 6400, 120, 109.36],
            [1999, 6401, 70, 70],
            [1999, 6402, 120, 130.57],
            [1999, 6403, 120, 90],
            [1999, 6404, 120, 90],
            [1999, 6405, 120, 90],
            [1999, 6406, 120, 109.36],
            [1999, 6407, 120, 109.36],
            [1999, 6408, 120, 90],
            [1999, 6409, 120, 90],
            [1999, 6410, 120, 90],
            [1999, 6411, 120, 90],
            [1999, 6412, 120, 90],
            [1999, 6413, 120, 90],
            [1999, 6414, 120, 109.36],
            [1999, 6415, 120, 119.04],
            [1999, 6416, 120, 90],
            [1999, 6417, 120, 90],
            [1999, 6418, 120, 90],
            [1999, 6419, 120, 90],
            [1999, 6420, 120, 90],
            [1999, 6421, 120, 117.19],
            [1999, 6422, 120, 109.36],
            [1999, 6423, 42.81, 43.17],
            [1999, 6424, 115.49, 81.33],
            [1999, 6425, 70, 98.36],
            [1999, 6426, 120, 117.19],
            [1999, 6427, 120, 90],
            [1999, 6428, 120, 90],
            [1999, 6429, 120, 90],
            [1999, 6430, 70, 86.89],
            [1999, 6431, 120, 90],
            [1999, 6432, 120, 90],
            [1999, 6433, 63.74, 113.55],
            [1999, 6434, 120, 90],
            [1999, 6435, 78.33, 99.36],
            [1999, 6436, 120, 90],
            [1999, 6437, 120, 90],
            [1999, 6438, 120, 90],
            [1999, 6439, 120, 125.74],
            [1999, 6440, 120, 90],
            [1999, 6441, 120, 109.36],
            [1999, 6442, 70, 70],
            [1999, 6443, 120, 90],
            [1999, 6444, 120, 90],
            [1999, 6445, 120, 90],
            [1999, 6446, 120, 90],
            [1999, 6447, 48.53, 70],
            [1999, 6448, 120, 90],
            [1999, 6449, 120, 90],
            [1999, 6450, 120, 90],
            [1999, 6451, 120, 90],
            [1999, 6452, 120, 90],
            [1999, 6453, 120, 90],
            [1999, 6454, 120, 90],
            [1999, 6455, 120, 90],
            [1999, 6456, 120, 90],
            [1999, 6457, 56.58, 70],
            [1999, 6458, 40, 55.85],
            [1999, 6459, 120, 125.74],
            [1999, 6460, 163.78, 95.28],
            [1999, 6461, 120, 90],
            [1999, 6462, 152, 95.28],
            [1999, 6463, 120, 90],
            [1999, 6464, 120, 90],
            [1999, 6465, 120, 90],
            [1999, 6466, 120, 90],
            [1999, 6467, 120, 90],
            [1999, 6468, 120, 90],
            [1999, 6469, 120, 101.08],
            [1999, 6470, 120, 90],
            [1999, 6471, 120, 109.36],
            [1999, 6472, 120, 108.36],
            [1999, 6473, 120, 90],
            [1999, 6474, 120, 90],
            [1999, 6475, 120, 90],
            [1999, 6476, 120, 108.36],
            [1999, 6477, 120, 90],
            [1999, 6478, 120, 90],
            [1999, 6479, 120, 90],
            [1999, 6480, 120, 90],
            [1999, 6481, 120, 90],
            [1999, 6482, 152, 95.28],
            [1999, 6483, 120, 109.36],
            [1999, 6484, 70, 56.48],
            [1999, 6485, 120, 90],
            [1999, 6486, 120, 90],
            [1999, 6487, 120, 90],
            [1999, 6488, 120, 90],
            [1999, 6489, 120, 90],
            [1999, 6490, 120, 108.36],
            [1999, 6491, 120, 90],
            [1999, 6492, 60.88, 72.65],
            [1999, 6493, 120, 90],
            [1999, 6494, 60.88, 72.65],
            [1999, 6495, 120, 125.74],
            [1999, 6496, 120, 109.36],
            [1999, 6497, 120, 90],
            [1999, 6498, 120, 125.74],
            [1999, 6499, 120, 90],
            [1999, 6500, 80.71, 115.49],
            [1999, 6501, 120, 90],
            [1999, 6502, 120, 78.19],
            [1999, 6503, 120, 109.36],
            [1999, 6504, 120, 130.57],
            [1999, 6505, 120, 91.63],
            [1999, 6506, 120, 90],
            [1999, 6507, 120, 90],
            [1999, 6508, 120, 90],
            [1999, 6509, 120, 119.04],
            [1999, 6510, 120, 90],
            [1999, 6511, 120, 90],
            [1999, 6512, 120, 109.36],
            [1999, 6513, 31.53, 53.27],
            [1999, 6514, 120, 90],
            [1999, 6515, 120, 90],
            [1999, 6516, 73.07, 58.95],
            [1999, 6517, 68.95, 86.89],
            [1999, 6518, 120, 117.19],
            [1999, 6519, 120, 90],
            [1999, 6520, 120, 90],
            [1999, 6521, 56.58, 56.58],
            [1999, 6522, 120, 90],
            [1999, 6523, 120, 90],
            [1999, 6524, 120, 90],
            [1999, 6525, 120, 90],
            [1999, 6526, 120, 90],
            [1999, 6527, 120, 125.74],
            [1999, 6528, 120, 125.74],
            [1999, 6529, 120, 90],
            [1999, 6530, 120, 109.36],
            [1999, 6531, 120, 90],
            [1999, 6532, 120, 125.74],
            [1999, 6533, 120, 91.63],
            [1999, 6534, 120, 119.04],
            [1999, 6535, 120, 90],
            [1999, 6536, 70.23, 106.94],
            [1999, 6537, 120, 90],
            [1999, 6538, 120, 90],
            [1999, 6539, 120, 90],
            [1999, 6540, 120, 90],
            [1999, 6541, 120, 90],
            [1999, 6542, 120, 108.36],
            [1999, 6543, 120, 90],
            [1999, 6544, 120, 90],
            [1999, 6546, 120, 90],
            [1999, 6547, 120, 90],
            [1999, 6548, 120, 90],
            [1999, 6549, 120, 90],
            [1999, 6550, 120, 90],
            [1999, 6551, 120, 90],
            [1999, 6552, 120, 108.36],
            [1999, 6553, 120, 90],
            [1999, 6554, 120, 90],
            [1999, 6555, 120, 90],
            [1999, 6556, 120, 90],
            [1999, 6557, 120, 90],
            [1999, 6558, 120, 90],
            [1999, 6559, 120, 90],
            [1999, 6560, 120, 90],
            [1999, 6561, 120, 90],
            [1999, 6562, 120, 90],
            [1999, 6563, 120, 90],
            [1999, 6564, 120, 90],
            [1999, 6565, 120, 90],
            [1999, 6566, 120, 78.64],
            [1999, 6567, 120, 90],
            [1999, 6568, 120, 109.36],
            [1999, 6569, 120, 90],
            [1999, 6570, 120, 90],
            [1999, 6572, 120, 90],
            [1999, 6573, 120, 90],
            [1999, 6574, 120, 90],
            [1999, 6575, 120, 119.04],
            [1999, 6576, 120, 90],
            [1999, 6577, 120, 90],
            [1999, 6578, 120, 109.36],
            [1999, 6579, 120, 90],
            [1999, 6580, 120, 90],
            [1999, 6581, 120, 90],
            [1999, 6582, 120, 90],
            [1999, 6583, 120, 90],
            [1999, 6584, 120, 90],
            [1999, 6585, 120, 109.36],
            [1999, 6586, 120, 130.57],
            [1999, 6587, 120, 90],
            [1999, 6588, 120, 109.36],
            [1999, 6589, 120, 90],
            [1999, 6590, 120, 90],
            [1999, 6591, 120, 90],
            [1999, 6592, 120, 90],
            [1999, 6593, 120, 90],
            [1999, 6594, 120, 90],
            [1999, 6595, 120, 90],
            [1999, 6596, 120, 90],
            [1999, 6597, 120, 90],
            [1999, 6598, 120, 90],
            [1999, 6599, 120, 90],
            [1999, 6600, 120, 90],
            [1999, 6601, 120, 90],
            [1999, 6602, 120, 125.74],
            [1999, 6603, 70, 70],
            [1999, 6604, 120, 119.04],
            [1999, 6605, 120, 108.36],
            [1999, 6606, 120, 90],
            [1999, 6607, 120, 125.74],
            [1999, 6608, 120, 109.36],
            [1999, 6609, 120, 90],
            [1999, 6610, 120, 90],
            [1999, 6611, 70, 91.63],
            [1999, 6612, 120, 119.04],
            [1999, 6613, 120, 90],
            [1999, 6614, 50, 101.08],
            [1999, 6615, 120, 130.57],
            [1999, 6616, 120, 90],
            [1999, 6617, 39.9, 34.9],
            [1999, 6618, 120, 90],
            [1999, 6619, 120, 90],
            [1999, 6620, 120, 90],
            [1999, 6621, 120, 90],
            [1999, 6622, 120, 90],
            [1999, 6623, 152, 95.28],
            [1999, 6624, 120, 108.36],
            [1999, 6625, 120, 90],
            [1999, 6626, 120, 90],
            [1999, 6627, 120, 90],
            [1999, 6628, 120, 90],
            [1999, 6629, 70, 70],
            [1999, 6630, 70, 70],
            [1999, 6631, 50, 60],
            [1999, 6632, 40, 50],
            [1999, 6633, 50, 60],
            [1999, 6634, 70, 70],
            [1999, 6635, 120, 90],
            [1999, 6636, 70, 70],
            [1999, 6637, 120, 90],
            [1999, 6638, 70, 70],
            [1999, 6639, 120, 90],
            [1999, 6640, 50, 60],
            [1999, 6641, 70, 70],
            [1999, 6642, 40, 50],
            [1999, 6643, 30, 40],
            [1999, 6648, 120, 90],
            [1999, 6649, 120, 90],
            [1999, 6650, 120, 90],
            [1999, 6651, 120, 90],
            [1999, 6652, 120, 90],
            [1999, 6653, 70, 70],
            [1999, 6654, 70, 70],
            [1999, 6655, 70, 70],
            [1999, 6656, 70, 70],
            [1999, 6657, 70, 70],
            [1999, 6660, 70, 70],
            [1999, 6661, 70, 70],
            [1999, 6662, 70, 70],
            [1999, 6663, 70, 70],
            [1999, 6664, 70, 70],
            [1999, 6665, 70, 70],
            [1999, 6666, 70, 70],
            [1999, 6667, 70, 70],
            [1999, 6668, 70, 70],
            [1999, 6669, 70, 70],
            [1999, 6670, 70, 70],
            [1999, 6671, 70, 70],
            [1999, 6672, 70, 70],
            [1999, 6673, 70, 70],
            [1999, 6674, 70, 70],
            [1999, 6675, 70, 70],
            [1999, 6676, 70, 70],
            [1999, 6677, 70, 70],
            [1999, 6678, 70, 70],
            [1999, 6679, 70, 70],
            [1999, 6680, 70, 70],
            [1999, 6682, 70, 70],
            [1999, 6683, 70, 70],
            [1999, 6684, 70, 70],
            [1999, 6685, 50, 60],
            [1999, 6686, 50, 60],
            [1999, 6687, 50, 60],
            [1999, 6688, 50, 60],
            [1999, 6689, 50, 60],
            [1999, 6690, 50, 60],
            [1999, 6691, 120, 90],
            [1999, 6692, 120, 90],
            [1999, 6697, 40, 50],
            [1999, 6698, 70, 70],
            [1999, 6699, 70, 70],
            [1999, 6700, 120, 90],
            [1999, 6701, 70, 70],
            [1999, 6702, 70, 70],
            [1999, 6703, 30, 40],
            [1999, 6704, 70, 70],
            [1999, 6705, 70, 70],
            [1999, 6706, 70, 70],
            [1999, 6707, 120, 90],
            [1999, 6708, 70, 70],
            [1999, 6709, 30, 40],
            [1999, 6710, 50, 60],
            [1999, 6711, 70, 70],
            [1999, 6712, 50, 60],
            [1999, 6713, 70, 70],
            [1999, 6714, 50, 60],
            [1999, 6715, 120, 90],
            [1999, 6716, 70, 70],
            [1999, 6717, 70, 70],
            [1999, 6718, 70, 70],
            [1999, 6719, 70, 70],
            [1999, 6720, 70, 70],
            [1999, 6721, 50, 60],
            [1999, 6722, 30, 40],
            [1999, 6723, 70, 70],
            [1999, 6724, 70, 70],
            [1999, 6725, 70, 70],
            [1999, 6726, 70, 70],
            [1999, 6727, 70, 70],
            [1999, 6728, 70, 70],
            [1999, 6729, 70, 70],
            [1999, 6730, 120, 90],
            [1999, 6731, 70, 70],
            [1999, 6732, 70, 70],
            [1999, 6733, 70, 70],
            [1999, 6734, 70, 70],
            [1999, 6735, 70, 70],
            [1999, 6736, 50, 60],
            [1999, 6737, 70, 70],
            [1999, 6738, 70, 70],
            [1999, 6739, 50, 60],
            [1999, 6740, 18, 27],
            [1999, 6741, 18, 27],
            [1999, 6742, 18, 27],
            [1999, 6743, 18, 27],
            [1999, 6746, 50, 60],
            [1999, 6748, 70, 70],
            [1999, 6749, 70, 70],
            [1999, 6750, 50, 60],
            [1999, 6752, 50, 60],
            [1999, 6753, 120, 90],
            [1999, 6754, 70, 70],
            [1999, 6755, 70, 70],
            [1999, 6756, 70, 70],
            [1999, 6757, 70, 70],
            [1999, 6758, 70, 70],
            [1999, 6759, 50, 60],
            [1999, 6760, 70, 70],
            [1999, 6761, 70, 70],
            [1999, 6762, 70, 70],
            [1999, 6763, 50, 60],
            [1999, 6764, 70, 70],
            [1999, 6766, 120, 90],
            [1999, 6767, 70, 70],
            [1999, 6768, 70, 70],
            [1999, 6769, 120, 90],
            [1999, 6770, 70, 70],
            [1999, 6771, 70, 70],
            [1999, 6772, 50, 60],
            [1999, 6773, 120, 90],
            [1999, 6777, 70, 70],
            [1999, 6778, 40, 50],
            [1999, 6779, 50, 60],
            [1999, 6780, 70, 70],
            [1999, 6781, 70, 70],
            [1999, 6782, 120, 90],
            [1999, 6783, 70, 70],
            [1999, 6784, 70, 70],
            [1999, 6785, 70, 70],
            [1999, 6786, 70, 70],
            [1999, 6787, 70, 70],
            [1999, 6789, 50, 60],
            [1999, 6824, 120, 90],
            [1999, 6825, 120, 90],
            [1999, 6826, 50, 60],
            [1999, 6827, 50, 60],
            [1999, 6828, 50, 60],
            [1999, 6829, 70, 70],
            [1999, 6830, 70, 70],
            [1999, 6831, 120, 90],
            [1999, 6832, 70, 70],
            [2000, 1, 50, 60],
            [2000, 2, 120, 90],
            [2000, 3, 70, 70],
            [2000, 7, 35.26, 21.02],
            [2000, 9, 70, 70],
            [2000, 13, 120, 90],
            [2000, 14, 120, 90],
            [2000, 15, 70, 70],
            [2000, 16, 70, 70],
            [2000, 17, 120, 90],
            [2000, 18, 70, 70],
            [2000, 19, 70, 70],
            [2000, 20, 120, 90],
            [2000, 21, 70, 70],
            [2000, 22, 3.02, 9.75],
            [2000, 23, 120, 90],
            [2000, 25, 13.55, 9.36],
            [2000, 26, 98.66, 77.21],
            [2000, 27, 120, 90],
            [2000, 28, 50, 60],
            [2000, 29, 120, 90],
            [2000, 30, 26.05, 16.78],
            [2000, 31, 11.48, 9.38],
            [2000, 32, 120, 90],
            [2000, 33, 60.79, 35],
            [2000, 35, 120, 90],
            [2000, 37, 120, 90],
            [2000, 38, 120, 90],
            [2000, 40, 70, 70],
            [2000, 42, 49.3, 31.8],
            [2000, 43, 120, 90],
            [2000, 44, 120, 90],
            [2000, 47, 50, 60],
            [2000, 48, 70, 70],
            [2000, 49, 37.5, 45],
            [2000, 50, 120, 90],
            [2000, 51, 15.57, 18.15],
            [2000, 53, 40, 50],
            [2000, 56, 120, 90],
            [2000, 57, 120, 90],
            [2000, 58, 61.93, 49.09],
            [2000, 61, 70, 70],
            [2000, 62, 27.9, 27.4],
            [2000, 63, 70, 70],
            [2000, 64, 29.97, 42.64],
            [2000, 65, 50, 42.55],
            [2000, 66, 20, 25],
            [2000, 68, 98.54, 77.15],
            [2000, 69, 70, 70],
            [2000, 70, 50, 60],
            [2000, 71, 120, 90],
            [2000, 72, 120, 90],
            [2000, 73, 120, 90],
            [2000, 75, 50, 60],
            [2000, 77, 120, 90],
            [2000, 78, 59.13, 56.03],
            [2000, 81, 70, 70],
            [2000, 82, 12, 28.91],
            [2000, 83, 40, 37.5],
            [2000, 84, 120, 90],
            [2000, 87, 140.68, 39.98],
            [2000, 88, 10.85, 7.56],
            [2000, 89, 70, 70],
            [2000, 91, 40, 50],
            [2000, 93, 8.27, 9.25],
            [2000, 94, 120, 90],
            [2000, 96, 17.85, 27],
            [2000, 99, 31.13, 26.62],
            [2000, 100, 8.29, 8.86],
            [2000, 101, 70, 70],
            [2000, 103, 120, 90],
            [2000, 105, 40, 50],
            [2000, 106, 70, 70],
            [2000, 109, 40, 50],
            [2000, 110, 120, 90],
            [2000, 113, 86.12, 35.5],
            [2000, 119, 70, 70],
            [2000, 121, 13.82, 8.38],
            [2000, 122, 42.72, 53.2],
            [2000, 123, 120, 90],
            [2000, 125, 24.22, 37.94],
            [2000, 128, 74.95, 70],
            [2000, 133, 120, 90],
            [2000, 135, 24.22, 25.06],
            [2000, 136, 120, 90],
            [2000, 138, 89.29, 46.57],
            [2000, 140, 50, 60],
            [2000, 141, 5, 5.95],
            [2000, 142, 70, 70],
            [2000, 144, 50, 60],
            [2000, 145, 10.42, 7.09],
            [2000, 146, 120, 90],
            [2000, 147, 70, 70],
            [2000, 149, 50, 33.8],
            [2000, 150, 80.09, 63.64],
            [2000, 151, 47.04, 30.27],
            [2000, 153, 30, 45],
            [2000, 156, 120, 90],
            [2000, 157, 120, 90],
            [2000, 158, 120, 90],
            [2000, 160, 120, 90],
            [2000, 161, 47.65, 26.01],
            [2000, 162, 40, 50],
            [2000, 163, 32.08, 38.15],
            [2000, 164, 120, 90],
            [2000, 165, 70, 70],
            [2000, 166, 31.35, 44.44],
            [2000, 169, 97.7, 41.85],
            [2000, 170, 120, 90],
            [2000, 171, 35.55, 35],
            [2000, 175, 70, 70],
            [2000, 177, 71.36, 70],
            [2000, 181, 120, 90],
            [2000, 182, 120, 90],
            [2000, 183, 70, 70],
            [2000, 184, 120, 90],
            [2000, 186, 16.63, 13.83],
            [2000, 187, 50, 60],
            [2000, 188, 34.84, 17.18],
            [2000, 189, 120, 90],
            [2000, 190, 41.9, 24.53],
            [2000, 192, 12, 18],
            [2000, 194, 36.1, 33],
            [2000, 195, 25.2, 22.5],
            [2000, 196, 8.64, 9.03],
            [2000, 197, 120, 90],
            [2000, 199, 120, 90],
            [2000, 200, 50, 60],
            [2000, 203, 70, 70],
            [2000, 204, 16.64, 27],
            [2000, 206, 120, 90],
            [2000, 207, 50, 60],
            [2000, 210, 120, 90],
            [2000, 211, 42.5, 64.2],
            [2000, 212, 70, 70],
            [2000, 213, 70, 70],
            [2000, 214, 120, 90],
            [2000, 215, 44.5, 31.24],
            [2000, 216, 98.28, 54.81],
            [2000, 217, 120, 90],
            [2000, 218, 53.89, 34.22],
            [2000, 220, 23.35, 19.12],
            [2000, 222, 9.57, 9.57],
            [2000, 225, 37.5, 45],
            [2000, 226, 13.66, 15.31],
            [2000, 227, 120, 90],
            [2000, 228, 18.5, 27.7],
            [2000, 230, 30, 37.5],
            [2000, 231, 70, 70],
            [2000, 233, 22.4, 15.4],
            [2000, 234, 10, 19.36],
            [2000, 235, 34.93, 21.66],
            [2000, 236, 70, 70],
            [2000, 237, 10.83, 7.57],
            [2000, 239, 58.9, 76.35],
            [2000, 240, 35.9, 29.8],
            [2000, 241, 46.4, 41.28],
            [2000, 242, 164.4, 59.03],
            [2000, 243, 118.04, 58],
            [2000, 244, 120, 90],
            [2000, 245, 120, 90],
            [2000, 246, 60.21, 33.65],
            [2000, 247, 120, 90],
            [2000, 248, 60.9, 49.22],
            [2000, 249, 70, 70],
            [2000, 250, 50, 60],
            [2000, 253, 120, 90],
            [2000, 256, 50, 60],
            [2000, 257, 120, 90],
            [2000, 260, 70, 70],
            [2000, 264, 50, 60],
            [2000, 265, 120, 90],
            [2000, 267, 120, 90],
            [2000, 268, 120, 90],
            [2000, 269, 120, 90],
            [2000, 270, 70.14, 48.85],
            [2000, 272, 120, 90],
            [2000, 273, 25.7, 35.52],
            [2000, 282, 70, 70],
            [2000, 283, 120, 90],
            [2000, 284, 70, 70],
            [2000, 285, 62.31, 50.39],
            [2000, 286, 33.37, 83.43],
            [2000, 287, 40, 37.5],
            [2000, 289, 120, 90],
            [2000, 291, 70, 70],
            [2000, 292, 53.52, 70],
            [2000, 294, 96.24, 38.52],
            [2000, 295, 120, 90],
            [2000, 296, 36.57, 16.84],
            [2000, 297, 120, 90],
            [2000, 298, 70, 70],
            [2000, 299, 26.73, 30.82],
            [2000, 302, 120, 90],
            [2000, 303, 60.81, 32.84],
            [2000, 305, 15.78, 16.19],
            [2000, 306, 53.16, 39.53],
            [2000, 307, 70, 70],
            [2000, 308, 22.69, 32.81],
            [2000, 309, 120, 90],
            [2000, 310, 20.52, 19.97],
            [2000, 311, 70, 70],
            [2000, 312, 98.14, 57.65],
            [2000, 313, 50, 60],
            [2000, 314, 28.98, 30.23],
            [2000, 315, 120, 90],
            [2000, 317, 31.04, 29.1],
            [2000, 320, 40.8, 42.3],
            [2000, 321, 120, 90],
            [2000, 322, 120, 90],
            [2000, 324, 37.5, 45],
            [2000, 325, 120, 90],
            [2000, 326, 28.63, 19.82],
            [2000, 327, 52.96, 62.65],
            [2000, 328, 70, 70],
            [2000, 329, 70, 70],
            [2000, 330, 26.79, 29.04],
            [2000, 332, 101.6, 71.83],
            [2000, 333, 120, 90],
            [2000, 334, 14.71, 16.26],
            [2000, 337, 19.61, 30.02],
            [2000, 339, 74, 62.86],
            [2000, 340, 120, 90],
            [2000, 342, 86.2, 70],
            [2000, 343, 120, 90],
            [2000, 344, 79.03, 44.3],
            [2000, 346, 56.18, 44.76],
            [2000, 347, 70, 70],
            [2000, 348, 120, 90],
            [2000, 350, 70, 70],
            [2000, 351, 70, 70],
            [2000, 353, 50, 60],
            [2000, 354, 37.5, 45],
            [2000, 355, 70, 70],
            [2000, 356, 120, 90],
            [2000, 358, 70, 70],
            [2000, 361, 49.02, 40.47],
            [2000, 362, 50, 60],
            [2000, 365, 120, 90],
            [2000, 367, 40, 50],
            [2000, 368, 50, 60],
            [2000, 369, 5.88, 5.27],
            [2000, 370, 70, 70],
            [2000, 371, 72.52, 67.5],
            [2000, 372, 16.36, 13.13],
            [2000, 374, 50, 60],
            [2000, 376, 22.12, 15.96],
            [2000, 377, 25.09, 17.45],
            [2000, 378, 31.04, 34.22],
            [2000, 379, 11.67, 16.73],
            [2000, 382, 70, 70],
            [2000, 383, 25.5, 21.6],
            [2000, 385, 120, 90],
            [2000, 386, 50, 60],
            [2000, 387, 70, 70],
            [2000, 389, 37.5, 45],
            [2000, 390, 70, 70],
            [2000, 391, 70, 70],
            [2000, 392, 34.26, 35.61],
            [2000, 394, 50, 60],
            [2000, 396, 120, 90],
            [2000, 398, 70, 70],
            [2000, 399, 70, 70],
            [2000, 400, 50, 60],
            [2000, 401, 70, 70],
            [2000, 402, 120, 90],
            [2000, 403, 27.52, 29.78],
            [2000, 405, 70, 70],
            [2000, 406, 120, 90],
            [2000, 409, 50, 60],
            [2000, 411, 120, 90],
            [2000, 412, 120, 90],
            [2000, 413, 30, 45],
            [2000, 415, 120, 90],
            [2000, 416, 50, 60],
            [2000, 418, 36.34, 36.78],
            [2000, 419, 120, 90],
            [2000, 422, 120, 90],
            [2000, 424, 36.5, 31.71],
            [2000, 425, 12.16, 14.12],
            [2000, 426, 120, 90],
            [2000, 427, 40, 50],
            [2000, 428, 8.07, 10.33],
            [2000, 429, 70, 70],
            [2000, 430, 27, 24],
            [2000, 432, 72.02, 36.75],
            [2000, 434, 70, 70],
            [2000, 436, 20.72, 16.74],
            [2000, 437, 40, 50],
            [2000, 439, 70, 70],
            [2000, 443, 120, 90],
            [2000, 444, 50, 60],
            [2000, 445, 120, 90],
            [2000, 446, 70, 70],
            [2000, 450, 120, 90],
            [2000, 451, 50, 60],
            [2000, 452, 120, 90],
            [2000, 453, 70, 70],
            [2000, 454, 120, 90],
            [2000, 455, 71.93, 65.93],
            [2000, 457, 40, 50],
            [2000, 458, 92.61, 76.03],
            [2000, 459, 120, 90],
            [2000, 460, 70, 70],
            [2000, 461, 50, 60],
            [2000, 463, 10.14, 8.58],
            [2000, 464, 21.08, 14.31],
            [2000, 465, 50, 60],
            [2000, 466, 120, 90],
            [2000, 467, 120, 90],
            [2000, 468, 120, 90],
            [2000, 469, 120, 90],
            [2000, 470, 120, 90],
            [2000, 471, 29.42, 44.44],
            [2000, 473, 120, 90],
            [2000, 474, 70, 70],
            [2000, 476, 120, 90],
            [2000, 477, 120, 90],
            [2000, 478, 120, 90],
            [2000, 479, 70, 70],
            [2000, 480, 70, 70],
            [2000, 481, 70, 70],
            [2000, 482, 70, 70],
            [2000, 484, 70, 70],
            [2000, 485, 120, 90],
            [2000, 486, 50, 60],
            [2000, 487, 29.5, 43.67],
            [2000, 488, 70, 70],
            [2000, 490, 70, 70],
            [2000, 493, 120, 90],
            [2000, 494, 16.23, 19.49],
            [2000, 495, 120, 90],
            [2000, 496, 70, 70],
            [2000, 497, 20.34, 27.7],
            [2000, 498, 50, 60],
            [2000, 500, 70, 70],
            [2000, 501, 70, 70],
            [2000, 503, 70, 24.56],
            [2000, 504, 14.4, 17.19],
            [2000, 505, 32.44, 29.79],
            [2000, 507, 120, 90],
            [2000, 508, 70, 70],
            [2000, 509, 5.13, 4.64],
            [2000, 510, 40, 50],
            [2000, 512, 30, 35],
            [2000, 513, 70, 70],
            [2000, 515, 75, 45],
            [2000, 518, 120, 90],
            [2000, 519, 22.23, 21.49],
            [2000, 520, 120, 90],
            [2000, 521, 120, 90],
            [2000, 522, 70, 70],
            [2000, 523, 120, 90],
            [2000, 524, 122.06, 81.71],
            [2000, 525, 31.78, 60.44],
            [2000, 526, 70.03, 60],
            [2000, 527, 70, 70],
            [2000, 528, 50, 50],
            [2000, 531, 10.37, 9.91],
            [2000, 532, 85.36, 50.72],
            [2000, 534, 41.02, 29.31],
            [2000, 535, 40, 50],
            [2000, 536, 17.11, 23.93],
            [2000, 540, 70, 70],
            [2000, 541, 61.04, 50.11],
            [2000, 543, 120, 90],
            [2000, 545, 50.7, 47.79],
            [2000, 547, 12, 18],
            [2000, 548, 120, 90],
            [2000, 549, 45, 24.58],
            [2000, 550, 70, 70],
            [2000, 551, 120, 90],
            [2000, 553, 120, 90],
            [2000, 554, 15, 25],
            [2000, 555, 120, 90],
            [2000, 556, 120, 90],
            [2000, 557, 40, 50],
            [2000, 558, 120, 90],
            [2000, 559, 70, 70],
            [2000, 561, 120, 90],
            [2000, 563, 78.2, 70],
            [2000, 564, 12.02, 6.99],
            [2000, 565, 24.89, 19.74],
            [2000, 568, 22.14, 18.78],
            [2000, 569, 106.46, 58.13],
            [2000, 570, 77.63, 49.89],
            [2000, 571, 70, 70],
            [2000, 572, 30, 45],
            [2000, 573, 34.75, 26.58],
            [2000, 574, 70, 70],
            [2000, 577, 32.7, 38.7],
            [2000, 579, 40, 50],
            [2000, 581, 30, 45],
            [2000, 582, 120, 90],
            [2000, 583, 70, 70],
            [2000, 584, 21.39, 10.39],
            [2000, 585, 70, 70],
            [2000, 586, 50, 60],
            [2000, 588, 12, 22.5],
            [2000, 589, 120, 90],
            [2000, 590, 53.52, 61.02],
            [2000, 591, 120, 90],
            [2000, 593, 65, 51.92],
            [2000, 594, 70, 70],
            [2000, 595, 104.15, 43.17],
            [2000, 596, 8.9, 17.2],
            [2000, 597, 40.93, 18.93],
            [2000, 599, 37.1, 32.34],
            [2000, 600, 120, 90],
            [2000, 601, 70, 70],
            [2000, 604, 77.66, 49.79],
            [2000, 606, 70, 70],
            [2000, 607, 50, 60],
            [2000, 608, 54.37, 25.93],
            [2000, 610, 50, 60],
            [2000, 611, 50, 60],
            [2000, 612, 45.76, 60.33],
            [2000, 614, 20.59, 23],
            [2000, 615, 120, 90],
            [2000, 616, 120, 90],
            [2000, 618, 30, 37.5],
            [2000, 619, 120, 90],
            [2000, 621, 120, 90],
            [2000, 623, 8.39, 6.11],
            [2000, 625, 51.68, 25.98],
            [2000, 626, 40, 50],
            [2000, 627, 50, 60],
            [2000, 628, 34.13, 29.15],
            [2000, 629, 18.8, 33.4],
            [2000, 630, 70, 70],
            [2000, 631, 39.6, 34.17],
            [2000, 633, 120, 90],
            [2000, 635, 70, 70],
            [2000, 636, 21.1, 50.2],
            [2000, 637, 7.79, 7.02],
            [2000, 639, 70, 70],
            [2000, 641, 120, 90],
            [2000, 645, 97.67, 37.44],
            [2000, 647, 108.04, 87.9],
            [2000, 648, 70, 70],
            [2000, 649, 70, 70],
            [2000, 650, 120, 90],
            [2000, 651, 120, 90],
            [2000, 653, 70, 70],
            [2000, 654, 12.52, 17.79],
            [2000, 656, 120, 90],
            [2000, 657, 120, 90],
            [2000, 659, 7.56, 7.64],
            [2000, 660, 38.63, 26.61],
            [2000, 662, 120, 90],
            [2000, 663, 69.14, 36.97],
            [2000, 664, 70, 70],
            [2000, 665, 120, 90],
            [2000, 666, 120, 90],
            [2000, 669, 50, 30.85],
            [2000, 670, 70, 70],
            [2000, 672, 70, 70],
            [2000, 673, 120, 90],
            [2000, 675, 70, 70],
            [2000, 678, 32.19, 33.94],
            [2000, 679, 120, 90],
            [2000, 680, 10.1, 8.13],
            [2000, 681, 70, 70],
            [2000, 682, 8.1, 6.18],
            [2000, 683, 9.08, 9.76],
            [2000, 686, 16.9, 21.27],
            [2000, 687, 120, 90],
            [2000, 688, 120, 90],
            [2000, 690, 40, 50],
            [2000, 691, 18.17, 15.1],
            [2000, 692, 70, 70],
            [2000, 693, 70, 70],
            [2000, 694, 50, 42.14],
            [2000, 695, 82.86, 52.5],
            [2000, 697, 120, 90],
            [2000, 698, 70, 70],
            [2000, 700, 70, 70],
            [2000, 701, 120, 90],
            [2000, 702, 70, 70],
            [2000, 703, 12, 18],
            [2000, 704, 93.01, 45.96],
            [2000, 705, 30, 45],
            [2000, 706, 70, 70],
            [2000, 708, 70, 70],
            [2000, 709, 32.88, 46.39],
            [2000, 710, 120, 90],
            [2000, 711, 50, 60],
            [2000, 714, 50, 60],
            [2000, 715, 120, 90],
            [2000, 716, 70, 70],
            [2000, 717, 36.27, 32.74],
            [2000, 718, 79.28, 72.56],
            [2000, 719, 120, 90],
            [2000, 720, 83.47, 31.82],
            [2000, 721, 50, 60],
            [2000, 722, 120, 90],
            [2000, 723, 50, 60],
            [2000, 724, 20.76, 58.98],
            [2000, 727, 50, 45],
            [2000, 730, 120, 90],
            [2000, 731, 41.75, 21.4],
            [2000, 732, 151, 158],
            [2000, 734, 18.45, 34.92],
            [2000, 737, 10.58, 13.69],
            [2000, 738, 120, 90],
            [2000, 740, 18, 27],
            [2000, 741, 120, 90],
            [2000, 742, 25, 15.29],
            [2000, 745, 120, 90],
            [2000, 746, 40, 50],
            [2000, 747, 85.74, 47.21],
            [2000, 748, 120, 90],
            [2000, 749, 50, 60],
            [2000, 750, 133.42, 46.75],
            [2000, 751, 70, 70],
            [2000, 753, 50, 60],
            [2000, 754, 32.02, 28.67],
            [2000, 756, 70, 70],
            [2000, 759, 70, 70],
            [2000, 762, 70, 70],
            [2000, 763, 70, 70],
            [2000, 766, 100.6, 37.63],
            [2000, 767, 70, 70],
            [2000, 769, 37.94, 60],
            [2000, 771, 120, 90],
            [2000, 772, 70, 70],
            [2000, 773, 69.55, 32.33],
            [2000, 775, 70, 70],
            [2000, 776, 120, 90],
            [2000, 778, 120, 90],
            [2000, 779, 50, 60],
            [2000, 781, 71.26, 34.85],
            [2000, 782, 120, 90],
            [2000, 783, 50, 45],
            [2000, 784, 33.43, 46.1],
            [2000, 785, 120, 90],
            [2000, 787, 18, 23.03],
            [2000, 789, 70, 70],
            [2000, 790, 60.28, 19.43],
            [2000, 795, 120, 90],
            [2000, 796, 70, 70],
            [2000, 799, 50, 60],
            [2000, 801, 32.11, 49.85],
            [2000, 802, 120, 90],
            [2000, 803, 42.57, 40],
            [2000, 804, 120, 90],
            [2000, 805, 13.65, 18.71],
            [2000, 806, 120, 90],
            [2000, 807, 9.12, 12.1],
            [2000, 811, 120, 90],
            [2000, 812, 50, 60],
            [2000, 813, 8.07, 6.92],
            [2000, 814, 120, 90],
            [2000, 815, 30.9, 14.34],
            [2000, 818, 70, 70],
            [2000, 819, 120, 90],
            [2000, 820, 50, 65],
            [2000, 821, 32.18, 30.47],
            [2000, 822, 18.48, 22.65],
            [2000, 823, 120, 90],
            [2000, 824, 120, 90],
            [2000, 825, 70, 70],
            [2000, 826, 32.3, 7.9],
            [2000, 827, 12, 18],
            [2000, 829, 8.45, 6.52],
            [2000, 830, 120, 90],
            [2000, 831, 120, 90],
            [2000, 833, 120, 90],
            [2000, 835, 69.3, 61.77],
            [2000, 836, 120, 90],
            [2000, 837, 70, 70],
            [2000, 840, 120, 90],
            [2000, 842, 50, 50],
            [2000, 843, 69.06, 43.42],
            [2000, 844, 117.83, 54.95],
            [2000, 845, 79.17, 68.36],
            [2000, 846, 120, 90],
            [2000, 847, 70, 70],
            [2000, 848, 9.12, 11.53],
            [2000, 850, 26.43, 37.47],
            [2000, 851, 18.96, 12.46],
            [2000, 852, 70, 70],
            [2000, 855, 6.73, 7.13],
            [2000, 857, 120, 90],
            [2000, 860, 70, 70],
            [2000, 863, 13.7, 17.4],
            [2000, 865, 70, 42.13],
            [2000, 867, 120, 90],
            [2000, 869, 70, 70],
            [2000, 871, 16.44, 22.77],
            [2000, 872, 70, 70],
            [2000, 873, 48, 70],
            [2000, 875, 120, 90],
            [2000, 876, 120, 90],
            [2000, 877, 120, 90],
            [2000, 878, 5.59, 4.6],
            [2000, 881, 120, 90],
            [2000, 882, 50, 60],
            [2000, 883, 120, 90],
            [2000, 884, 70, 70],
            [2000, 885, 70, 70],
            [2000, 886, 120, 90],
            [2000, 889, 11.95, 11.28],
            [2000, 890, 63.25, 33.78],
            [2000, 891, 120, 90],
            [2000, 892, 120, 90],
            [2000, 894, 23.13, 17.71],
            [2000, 895, 120, 90],
            [2000, 896, 70, 70],
            [2000, 897, 13.97, 22.37],
            [2000, 899, 120, 90],
            [2000, 900, 6.81, 4.72],
            [2000, 901, 120, 90],
            [2000, 905, 120, 90],
            [2000, 909, 120, 90],
            [2000, 910, 11.75, 7.29],
            [2000, 913, 21.73, 18.25],
            [2000, 914, 120, 90],
            [2000, 915, 38.46, 49.72],
            [2000, 916, 40, 50],
            [2000, 917, 30, 45],
            [2000, 918, 47, 50],
            [2000, 919, 120, 90],
            [2000, 922, 50, 60],
            [2000, 924, 8.93, 9.74],
            [2000, 926, 40.84, 38.58],
            [2000, 927, 70, 70],
            [2000, 928, 120, 90],
            [2000, 929, 120, 90],
            [2000, 930, 50, 60],
            [2000, 931, 70, 70],
            [2000, 934, 37.5, 45],
            [2000, 935, 120, 90],
            [2000, 936, 50, 60],
            [2000, 937, 120, 90],
            [2000, 938, 12, 18],
            [2000, 940, 12, 18],
            [2000, 941, 70, 70],
            [2000, 942, 70, 70],
            [2000, 944, 96.61, 70.21],
            [2000, 945, 50, 60],
            [2000, 946, 50, 60],
            [2000, 948, 31.14, 15],
            [2000, 949, 79.45, 48.51],
            [2000, 950, 9.26, 20.62],
            [2000, 952, 12.6, 9.35],
            [2000, 953, 70, 70],
            [2000, 954, 120, 90],
            [2000, 955, 120, 90],
            [2000, 957, 120, 90],
            [2000, 958, 59.87, 32.44],
            [2000, 960, 50, 60],
            [2000, 961, 120, 90],
            [2000, 963, 70, 70],
            [2000, 964, 12, 15],
            [2000, 965, 50.79, 35],
            [2000, 966, 4.52, 4.32],
            [2000, 969, 52.88, 45.27],
            [2000, 970, 50, 60],
            [2000, 971, 35.72, 14.91],
            [2000, 972, 35.77, 19.67],
            [2000, 974, 30, 45],
            [2000, 976, 8.35, 13.15],
            [2000, 977, 12.22, 8.58],
            [2000, 978, 70, 48.36],
            [2000, 979, 25.93, 22.72],
            [2000, 980, 70, 70],
            [2000, 982, 120, 90],
            [2000, 983, 71.83, 30.1],
            [2000, 985, 194.37, 75.01],
            [2000, 986, 7.84, 7.68],
            [2000, 987, 120, 90],
            [2000, 988, 6.14, 5.32],
            [2000, 990, 71.86, 39.63],
            [2000, 991, 120, 90],
            [2000, 993, 89.04, 64.77],
            [2000, 994, 40, 50],
            [2000, 997, 120, 90],
            [2000, 998, 70, 70],
            [2000, 999, 120, 90],
            [2000, 1000, 40, 50],
            [2000, 1003, 7.76, 5.82],
            [2000, 1004, 70, 70],
            [2000, 1005, 40, 50],
            [2000, 1006, 120, 90],
            [2000, 1007, 28.86, 20.82],
            [2000, 1008, 37.5, 45],
            [2000, 1009, 120, 90],
            [2000, 1013, 120, 90],
            [2000, 1015, 70, 70],
            [2000, 1016, 14.94, 23.74],
            [2000, 1017, 50, 60],
            [2000, 1018, 120, 90],
            [2000, 1020, 70, 70],
            [2000, 1021, 70, 70],
            [2000, 1022, 120, 90],
            [2000, 1023, 13.9, 28.3],
            [2000, 1025, 120, 90],
            [2000, 1027, 120, 90],
            [2000, 1028, 50, 60],
            [2000, 1029, 70, 70],
            [2000, 1030, 7, 9.5],
            [2000, 1032, 23, 23.89],
            [2000, 1033, 30.71, 32.21],
            [2000, 1034, 70, 70],
            [2000, 1036, 6.74, 8.62],
            [2000, 1038, 70, 70],
            [2000, 1039, 120, 90],
            [2000, 1042, 120, 90],
            [2000, 1043, 12.3, 25.3],
            [2000, 1044, 120, 90],
            [2000, 1045, 120, 90],
            [2000, 1046, 50, 60],
            [2000, 1047, 70, 70],
            [2000, 1048, 70, 70],
            [2000, 1050, 70, 70],
            [2000, 1051, 92.72, 35.97],
            [2000, 1052, 50, 60],
            [2000, 1053, 50, 60],
            [2000, 1054, 70, 70],
            [2000, 1056, 22.3, 25.8],
            [2000, 1057, 50, 60],
            [2000, 1058, 70, 70],
            [2000, 1059, 65.53, 68.84],
            [2000, 1061, 70, 70],
            [2000, 1062, 7.92, 8.74],
            [2000, 1063, 115.77, 70],
            [2000, 1064, 50, 60],
            [2000, 1065, 120, 90],
            [2000, 1066, 50, 60],
            [2000, 1067, 120, 90],
            [2000, 1069, 50, 60],
            [2000, 1070, 20.5, 19],
            [2000, 1071, 125.97, 49.26],
            [2000, 1073, 84.92, 72.24],
            [2000, 1075, 6.43, 6.35],
            [2000, 1077, 120, 90],
            [2000, 1078, 120, 90],
            [2000, 1080, 120, 90],
            [2000, 1081, 53.54, 36.15],
            [2000, 1082, 75, 64.64],
            [2000, 1084, 160.19, 70.76],
            [2000, 1087, 130.51, 58.25],
            [2000, 1090, 120, 70],
            [2000, 1091, 40, 50],
            [2000, 1092, 12, 18],
            [2000, 1093, 50, 60],
            [2000, 1094, 20.61, 20.28],
            [2000, 1095, 27.39, 27.85],
            [2000, 1096, 120, 90],
            [2000, 1097, 13.52, 12.14],
            [2000, 1099, 13.78, 13.14],
            [2000, 1100, 55.33, 47.25],
            [2000, 1102, 20.14, 33.65],
            [2000, 1104, 70, 70],
            [2000, 1106, 70, 70],
            [2000, 1108, 120, 90],
            [2000, 1109, 71.84, 33.52],
            [2000, 1110, 120, 90],
            [2000, 1111, 68.1, 60.82],
            [2000, 1113, 120, 90],
            [2000, 1114, 120, 90],
            [2000, 1117, 50, 60],
            [2000, 1118, 21.27, 36.09],
            [2000, 1119, 50, 60],
            [2000, 1120, 120, 90],
            [2000, 1121, 120, 90],
            [2000, 1122, 120, 90],
            [2000, 1124, 33.6, 22.42],
            [2000, 1125, 120, 90],
            [2000, 1126, 72.51, 70],
            [2000, 1127, 120, 90],
            [2000, 1128, 70, 70],
            [2000, 1129, 50, 60],
            [2000, 1130, 120, 90],
            [2000, 1131, 40.04, 38.42],
            [2000, 1132, 12, 18],
            [2000, 1136, 64.79, 64.92],
            [2000, 1137, 120, 90],
            [2000, 1138, 120, 90],
            [2000, 1139, 89.3, 90],
            [2000, 1140, 50, 45],
            [2000, 1141, 151.96, 55.04],
            [2000, 1142, 79.98, 40.43],
            [2000, 1144, 70.4, 75.66],
            [2000, 1145, 120, 90],
            [2000, 1147, 12.27, 6.99],
            [2000, 1149, 53.28, 35.03],
            [2000, 1150, 50, 60],
            [2000, 1152, 38.19, 95.28],
            [2000, 1153, 120, 90],
            [2000, 1154, 120, 90],
            [2000, 1155, 12.52, 12.5],
            [2000, 1156, 50, 60],
            [2000, 1157, 40.32, 25.17],
            [2000, 1158, 50, 60],
            [2000, 1159, 70, 60],
            [2000, 1161, 120, 90],
            [2000, 1163, 19.1, 28.7],
            [2000, 1164, 120, 90],
            [2000, 1165, 120, 90],
            [2000, 1167, 66.18, 60.25],
            [2000, 1168, 120, 90],
            [2000, 1169, 24.92, 66.54],
            [2000, 1170, 70, 70],
            [2000, 1171, 89.52, 90],
            [2000, 1172, 70, 70],
            [2000, 1173, 50, 60],
            [2000, 1174, 37.2, 58.3],
            [2000, 1175, 29.09, 38.47],
            [2000, 1176, 120, 90],
            [2000, 1177, 70, 70],
            [2000, 1178, 8.86, 7.64],
            [2000, 1180, 15.85, 14.23],
            [2000, 1181, 120, 90],
            [2000, 1186, 15.33, 18],
            [2000, 1187, 120, 90],
            [2000, 1188, 40, 50],
            [2000, 1189, 120, 90],
            [2000, 1190, 70, 70],
            [2000, 1191, 67.28, 35],
            [2000, 1194, 82.38, 42.91],
            [2000, 1195, 120, 90],
            [2000, 1198, 120, 90],
            [2000, 1199, 40, 50],
            [2000, 1200, 27.2, 13.54],
            [2000, 1202, 30, 45],
            [2000, 1203, 15, 25],
            [2000, 1204, 108.29, 90],
            [2000, 1205, 37.85, 49.46],
            [2000, 1206, 120, 90],
            [2000, 1207, 30, 45],
            [2000, 1209, 40, 50],
            [2000, 1210, 40, 37.5],
            [2000, 1211, 53.75, 32.19],
            [2000, 1212, 70, 70],
            [2000, 1213, 40, 50],
            [2000, 1214, 70, 70],
            [2000, 1216, 50, 60],
            [2000, 1217, 90.55, 46.37],
            [2000, 1219, 110.01, 49.26],
            [2000, 1221, 22.66, 24.86],
            [2000, 1223, 70, 70],
            [2000, 1224, 47.2, 82.28],
            [2000, 1225, 50, 60],
            [2000, 1226, 25.67, 16.67],
            [2000, 1227, 120, 90],
            [2000, 1228, 57.49, 37.38],
            [2000, 1230, 50, 60],
            [2000, 1233, 50, 60],
            [2000, 1234, 12, 18],
            [2000, 1235, 50, 60],
            [2000, 1236, 85.05, 70.88],
            [2000, 1237, 37.5, 45],
            [2000, 1238, 14.2, 20.8],
            [2000, 1239, 120, 90],
            [2000, 1240, 120, 90],
            [2000, 1244, 70, 70],
            [2000, 1245, 120, 90],
            [2000, 1246, 70, 70],
            [2000, 1247, 70, 70],
            [2000, 1250, 70, 70],
            [2000, 1251, 70, 70],
            [2000, 1253, 50, 60],
            [2000, 1254, 70, 70],
            [2000, 1255, 120, 90],
            [2000, 1257, 40, 50],
            [2000, 1259, 105.06, 30.34],
            [2000, 1260, 50, 60],
            [2000, 1262, 110.05, 49.65],
            [2000, 1263, 120, 90],
            [2000, 1264, 120, 90],
            [2000, 1265, 13.11, 9.3],
            [2000, 1266, 120, 90],
            [2000, 1268, 30.72, 32.5],
            [2000, 1269, 50, 60],
            [2000, 1271, 85.26, 44.5],
            [2000, 1272, 70, 70],
            [2000, 1275, 36.46, 15.29],
            [2000, 1276, 70, 70],
            [2000, 1278, 18.5, 14.7],
            [2000, 1280, 11.06, 6.23],
            [2000, 1281, 21.65, 27],
            [2000, 1282, 50, 60],
            [2000, 1286, 120, 90],
            [2000, 1287, 70, 70],
            [2000, 1288, 70, 70],
            [2000, 1290, 120, 90],
            [2000, 1292, 70, 70],
            [2000, 1293, 4.01, 4.97],
            [2000, 1295, 70, 70],
            [2000, 1298, 50, 60],
            [2000, 1299, 70, 70],
            [2000, 1301, 70, 70],
            [2000, 1302, 30, 45],
            [2000, 1303, 70, 70],
            [2000, 1305, 18.06, 19.95],
            [2000, 1306, 12.9, 26.6],
            [2000, 1312, 26.57, 15.77],
            [2000, 1313, 120, 90],
            [2000, 1314, 23.54, 16.63],
            [2000, 1315, 120, 90],
            [2000, 1317, 70, 70],
            [2000, 1318, 120, 90],
            [2000, 1319, 46.62, 28.16],
            [2000, 1320, 120, 90],
            [2000, 1321, 48.13, 28.8],
            [2000, 1323, 75.54, 72.3],
            [2000, 1324, 120, 90],
            [2000, 1325, 120, 90],
            [2000, 1326, 70, 70],
            [2000, 1327, 70, 70],
            [2000, 1328, 69.9, 51.49],
            [2000, 1331, 120, 90],
            [2000, 1332, 5.42, 3.32],
            [2000, 1333, 120, 90],
            [2000, 1334, 55.76, 53.89],
            [2000, 1335, 22.9, 24.9],
            [2000, 1337, 5.66, 6.03],
            [2000, 1338, 120, 90],
            [2000, 1339, 11.12, 8.5],
            [2000, 1340, 53.22, 39.25],
            [2000, 1341, 120, 90],
            [2000, 1342, 70, 70],
            [2000, 1345, 40, 50],
            [2000, 1346, 50, 60],
            [2000, 1349, 70, 70],
            [2000, 1350, 70, 70],
            [2000, 1351, 97.23, 70],
            [2000, 1352, 120, 90],
            [2000, 1353, 70, 70],
            [2000, 1355, 120, 90],
            [2000, 1357, 70, 70],
            [2000, 1358, 120, 90],
            [2000, 1359, 67.94, 52.51],
            [2000, 1360, 18, 27],
            [2000, 1361, 77.94, 60.66],
            [2000, 1363, 87.15, 35.16],
            [2000, 1367, 37.84, 31.71],
            [2000, 1370, 17.21, 28.49],
            [2000, 1371, 118.59, 70],
            [2000, 1372, 120, 90],
            [2000, 1375, 17.87, 23.42],
            [2000, 1376, 30, 37.5],
            [2000, 1378, 70, 70],
            [2000, 1379, 120, 90],
            [2000, 1380, 70, 70],
            [2000, 1381, 120, 90],
            [2000, 1382, 26.47, 36.84],
            [2000, 1383, 8.45, 7.72],
            [2000, 1385, 70, 70],
            [2000, 1387, 40, 50],
            [2000, 1388, 120, 90],
            [2000, 1391, 120, 90],
            [2000, 1392, 120, 90],
            [2000, 1393, 70, 70],
            [2000, 1395, 70, 70],
            [2000, 1396, 12, 24.84],
            [2000, 1398, 40, 50],
            [2000, 1399, 7.42, 6.96],
            [2000, 1402, 70, 70],
            [2000, 1404, 40, 50],
            [2000, 1405, 120, 90],
            [2000, 1406, 4.67, 5.31],
            [2000, 1410, 70, 70],
            [2000, 1411, 50, 60],
            [2000, 1415, 70, 70],
            [2000, 1417, 120, 90],
            [2000, 1420, 50, 60],
            [2000, 1421, 120, 90],
            [2000, 1422, 120, 90],
            [2000, 1424, 50, 60],
            [2000, 1426, 12.76, 9.29],
            [2000, 1427, 23.02, 15.67],
            [2000, 1428, 8.98, 6.72],
            [2000, 1431, 120, 90],
            [2000, 1432, 6.73, 6.53],
            [2000, 1434, 53.67, 36.6],
            [2000, 1436, 70, 70],
            [2000, 1438, 70, 70],
            [2000, 1439, 120, 90],
            [2000, 1440, 70, 70],
            [2000, 1441, 120, 90],
            [2000, 1442, 70, 70],
            [2000, 1443, 57.46, 26.71],
            [2000, 1444, 120, 90],
            [2000, 1445, 85.92, 19.7],
            [2000, 1448, 70, 70],
            [2000, 1449, 120, 90],
            [2000, 1450, 120, 90],
            [2000, 1451, 120, 90],
            [2000, 1453, 70, 70],
            [2000, 1454, 23.66, 23.15],
            [2000, 1456, 70, 70],
            [2000, 1459, 120, 90],
            [2000, 1460, 49, 58],
            [2000, 1461, 6.14, 6.98],
            [2000, 1464, 50, 60],
            [2000, 1465, 30.3, 26.6],
            [2000, 1466, 50, 60],
            [2000, 1467, 70, 70],
            [2000, 1469, 70, 70],
            [2000, 1470, 30, 45],
            [2000, 1471, 58.28, 38.29],
            [2000, 1472, 120, 90],
            [2000, 1473, 11.99, 10.02],
            [2000, 1474, 18, 27],
            [2000, 1475, 93.38, 40.44],
            [2000, 1476, 48.77, 79.01],
            [2000, 1477, 104.49, 49.9],
            [2000, 1478, 14.96, 11.47],
            [2000, 1479, 40, 50],
            [2000, 1481, 70, 70],
            [2000, 1482, 12.31, 14.89],
            [2000, 1483, 70, 70],
            [2000, 1484, 34.55, 69.22],
            [2000, 1485, 120, 90],
            [2000, 1486, 73.81, 56.6],
            [2000, 1487, 120, 90],
            [2000, 1488, 120, 90],
            [2000, 1490, 35.69, 22.38],
            [2000, 1491, 11.32, 8.34],
            [2000, 1493, 40.01, 20.74],
            [2000, 1503, 120, 90],
            [2000, 1505, 120, 90],
            [2000, 1506, 120, 90],
            [2000, 1507, 70, 70],
            [2000, 1508, 23.88, 19.39],
            [2000, 1509, 120, 90],
            [2000, 1510, 15.91, 13.12],
            [2000, 1511, 27.25, 18.05],
            [2000, 1512, 50, 60],
            [2000, 1513, 70, 70],
            [2000, 1514, 70, 70],
            [2000, 1515, 30, 45],
            [2000, 1516, 70, 70],
            [2000, 1518, 120, 90],
            [2000, 1519, 120, 90],
            [2000, 1520, 70, 70],
            [2000, 1521, 120, 90],
            [2000, 1522, 12.41, 18.24],
            [2000, 1523, 120, 90],
            [2000, 1524, 120, 90],
            [2000, 1525, 30, 37.5],
            [2000, 1526, 19.7, 33.1],
            [2000, 1527, 17.34, 33.26],
            [2000, 1530, 97.88, 79.23],
            [2000, 1533, 70, 70],
            [2000, 1534, 10.96, 7.99],
            [2000, 1536, 30.57, 20.35],
            [2000, 1537, 39.94, 45.98],
            [2000, 1538, 120, 90],
            [2000, 1539, 20, 15],
            [2000, 1540, 40, 50],
            [2000, 1541, 70, 70],
            [2000, 1542, 50, 60],
            [2000, 1544, 120, 90],
            [2000, 1546, 70, 70],
            [2000, 1547, 70, 70],
            [2000, 1548, 120, 90],
            [2000, 1549, 50, 60],
            [2000, 1550, 120, 90],
            [2000, 1552, 30, 45],
            [2000, 1553, 70.57, 50.89],
            [2000, 1555, 30, 37.5],
            [2000, 1556, 27.63, 11.76],
            [2000, 1557, 59.6, 36.82],
            [2000, 1559, 50, 60],
            [2000, 1561, 37.45, 42.54],
            [2000, 1562, 97.79, 51.18],
            [2000, 1565, 120, 90],
            [2000, 1567, 120, 90],
            [2000, 1568, 17.56, 11.49],
            [2000, 1571, 70, 70],
            [2000, 1572, 120, 90],
            [2000, 1574, 50, 60],
            [2000, 1575, 124.82, 81.48],
            [2000, 1576, 50, 60],
            [2000, 1577, 50, 60],
            [2000, 1578, 120, 90],
            [2000, 1580, 50, 60],
            [2000, 1581, 17.87, 10.61],
            [2000, 1582, 22.41, 22.97],
            [2000, 1585, 70, 70],
            [2000, 1587, 18, 27],
            [2000, 1589, 70, 70],
            [2000, 1590, 70, 70],
            [2000, 1591, 12.9, 21.1],
            [2000, 1592, 70, 70],
            [2000, 1593, 25.91, 24.87],
            [2000, 1595, 152.2, 70],
            [2000, 1596, 120, 90],
            [2000, 1597, 70, 70],
            [2000, 1598, 15.38, 8.13],
            [2000, 1600, 120, 90],
            [2000, 1601, 70, 70],
            [2000, 1602, 120, 90],
            [2000, 1603, 50, 60],
            [2000, 1605, 50, 60],
            [2000, 1607, 70, 70],
            [2000, 1609, 120, 90],
            [2000, 1610, 32.57, 20.36],
            [2000, 1612, 120, 90],
            [2000, 1615, 120, 90],
            [2000, 1617, 120, 90],
            [2000, 1619, 8.99, 11.56],
            [2000, 1620, 40, 50],
            [2000, 1621, 70, 70],
            [2000, 1623, 50, 60],
            [2000, 1624, 120, 90],
            [2000, 1625, 70, 70],
            [2000, 1626, 70, 70],
            [2000, 1627, 70, 70],
            [2000, 1628, 50, 60],
            [2000, 1629, 40, 50],
            [2000, 1630, 70.01, 36.62],
            [2000, 1632, 8.5, 7.41],
            [2000, 1634, 70, 70],
            [2000, 1635, 16.96, 17.21],
            [2000, 1637, 120, 90],
            [2000, 1638, 52.95, 70],
            [2000, 1639, 74.31, 70],
            [2000, 1640, 70, 70],
            [2000, 1641, 50.33, 45.33],
            [2000, 1643, 18.14, 18.53],
            [2000, 1644, 135.92, 55.65],
            [2000, 1645, 70, 70],
            [2000, 1647, 70, 70],
            [2000, 1648, 120, 90],
            [2000, 1649, 120, 90],
            [2000, 1650, 70, 70],
            [2000, 1651, 120, 90],
            [2000, 1652, 57.04, 46.09],
            [2000, 1653, 35, 26.28],
            [2000, 1654, 50, 60],
            [2000, 1656, 8.28, 5.7],
            [2000, 1657, 70, 70],
            [2000, 1658, 120, 90],
            [2000, 1659, 38.85, 38.2],
            [2000, 1660, 134.83, 48.67],
            [2000, 1661, 70, 70],
            [2000, 1662, 20.69, 28.99],
            [2000, 1663, 35.1, 31.57],
            [2000, 1664, 22.26, 19.82],
            [2000, 1665, 28.19, 19.28],
            [2000, 1666, 6.17, 5.14],
            [2000, 1667, 120, 90],
            [2000, 1668, 84.95, 70],
            [2000, 1669, 120, 90],
            [2000, 1671, 120, 90],
            [2000, 1672, 20.29, 61.88],
            [2000, 1673, 40.58, 28.22],
            [2000, 1674, 70, 70],
            [2000, 1675, 9.08, 16.02],
            [2000, 1679, 33.66, 20.7],
            [2000, 1680, 87.72, 70.36],
            [2000, 1681, 120, 90],
            [2000, 1684, 120, 90],
            [2000, 1685, 37.5, 45],
            [2000, 1686, 120, 90],
            [2000, 1688, 25.71, 34.65],
            [2000, 1689, 120, 90],
            [2000, 1690, 120, 90],
            [2000, 1692, 120, 90],
            [2000, 1694, 120, 90],
            [2000, 1695, 120, 90],
            [2000, 1697, 70, 70],
            [2000, 1701, 70, 70],
            [2000, 1702, 70, 70],
            [2000, 1704, 32.73, 29.33],
            [2000, 1705, 70, 70],
            [2000, 1706, 40, 50],
            [2000, 1707, 30, 17.24],
            [2000, 1709, 16, 15.44],
            [2000, 1711, 70, 70],
            [2000, 1713, 50, 60],
            [2000, 1715, 120, 90],
            [2000, 1717, 70, 70],
            [2000, 1720, 4.58, 3.57],
            [2000, 1722, 120, 90],
            [2000, 1724, 34.9, 28.91],
            [2000, 1726, 120, 90],
            [2000, 1728, 120, 90],
            [2000, 1729, 36.89, 30.28],
            [2000, 1730, 12, 18],
            [2000, 1734, 17.03, 13.98],
            [2000, 1737, 70, 70],
            [2000, 1739, 70, 70],
            [2000, 1740, 50, 60],
            [2000, 1741, 70, 70],
            [2000, 1742, 120, 90],
            [2000, 1743, 70, 70],
            [2000, 1744, 64.97, 47.25],
            [2000, 1745, 34.11, 14.96],
            [2000, 1746, 90.45, 70],
            [2000, 1748, 104.76, 45.88],
            [2000, 1749, 50, 60],
            [2000, 1750, 70, 70],
            [2000, 1752, 120, 90],
            [2000, 1753, 25.17, 15.07],
            [2000, 1754, 120, 90],
            [2000, 1756, 47.1, 29.63],
            [2000, 1757, 70, 70],
            [2000, 1758, 70, 70],
            [2000, 1760, 12.98, 21.4],
            [2000, 1763, 43.44, 47.84],
            [2000, 1764, 70, 70],
            [2000, 1765, 50, 60],
            [2000, 1766, 120, 90],
            [2000, 1767, 120, 88.81],
            [2000, 1769, 70, 60.5],
            [2000, 1770, 48, 62],
            [2000, 1771, 19.39, 23.78],
            [2000, 1772, 25.48, 41.18],
            [2000, 1773, 50, 60],
            [2000, 1774, 17.87, 21.37],
            [2000, 1775, 70, 70],
            [2000, 1776, 35.63, 37.22],
            [2000, 1778, 120, 90],
            [2000, 1779, 35.69, 81.75],
            [2000, 1780, 35.35, 35.59],
            [2000, 1781, 113.83, 52.58],
            [2000, 1783, 12.6, 22.4],
            [2000, 1784, 70, 70],
            [2000, 1785, 120, 90],
            [2000, 1786, 40.8, 58.18],
            [2000, 1787, 120, 90],
            [2000, 1788, 120, 90],
            [2000, 1789, 120, 90],
            [2000, 1790, 47.16, 37.74],
            [2000, 1792, 25.36, 24.69],
            [2000, 1793, 99.43, 70],
            [2000, 1794, 42.48, 37.47],
            [2000, 1795, 13.2, 9.9],
            [2000, 1796, 50, 60],
            [2000, 1797, 70, 70],
            [2000, 1798, 70, 70],
            [2000, 1799, 4.8, 5.01],
            [2000, 1800, 9.59, 5.61],
            [2000, 1801, 70, 70],
            [2000, 1802, 120, 90],
            [2000, 1803, 120, 90],
            [2000, 1804, 105.47, 52.76],
            [2000, 1806, 120, 90],
            [2000, 1809, 120, 90],
            [2000, 1811, 120, 90],
            [2000, 1812, 43.07, 42.87],
            [2000, 1814, 40, 50],
            [2000, 1815, 15.67, 9.13],
            [2000, 1816, 83.79, 61.8],
            [2000, 1817, 90.35, 31.74],
            [2000, 1818, 21.14, 10.89],
            [2000, 1819, 70, 70],
            [2000, 1822, 70, 70],
            [2000, 1824, 50, 65],
            [2000, 1825, 50.4, 52.17],
            [2000, 1827, 70, 70],
            [2000, 1829, 23.1, 41.1],
            [2000, 1832, 70, 70],
            [2000, 1833, 120, 90],
            [2000, 1834, 120, 90],
            [2000, 1837, 120, 90],
            [2000, 1839, 70, 70],
            [2000, 1841, 70, 70],
            [2000, 1843, 14.6, 12.44],
            [2000, 1844, 30, 45],
            [2000, 1845, 20.76, 23.58],
            [2000, 1846, 120, 90],
            [2000, 1847, 50, 60],
            [2000, 1848, 85.7, 63.16],
            [2000, 1849, 120, 90],
            [2000, 1850, 7.35, 6.92],
            [2000, 1851, 7.82, 10.41],
            [2000, 1852, 40.34, 32.16],
            [2000, 1853, 120, 90],
            [2000, 1855, 120, 90],
            [2000, 1856, 30, 45],
            [2000, 1857, 70, 70],
            [2000, 1859, 120, 90],
            [2000, 1860, 120, 90],
            [2000, 1863, 16.62, 11.53],
            [2000, 1864, 94.1, 90],
            [2000, 1866, 70, 70],
            [2000, 1868, 120, 90],
            [2000, 1869, 40, 37.5],
            [2000, 1870, 70, 70],
            [2000, 1873, 70, 70],
            [2000, 1875, 40, 50],
            [2000, 1876, 37.79, 33.06],
            [2000, 1877, 120, 90],
            [2000, 1879, 43.02, 40.39],
            [2000, 1881, 50, 60],
            [2000, 1882, 62.54, 30.08],
            [2000, 1883, 120, 90],
            [2000, 1884, 50, 60],
            [2000, 1885, 70, 70],
            [2000, 1886, 50, 60],
            [2000, 1887, 70, 70],
            [2000, 1888, 120, 90],
            [2000, 1889, 70, 70],
            [2000, 1890, 120, 90],
            [2000, 1891, 33.58, 60],
            [2000, 1892, 70, 70],
            [2000, 1894, 50, 60],
            [2000, 1895, 79.91, 49.67],
            [2000, 1896, 120, 90],
            [2000, 1897, 13.67, 11.12],
            [2000, 1898, 8.67, 4.23],
            [2000, 1899, 70, 70],
            [2000, 1900, 34.8, 47.81],
            [2000, 1901, 25.72, 27.84],
            [2000, 1903, 70, 70],
            [2000, 1904, 120, 90],
            [2000, 1906, 19.49, 10.43],
            [2000, 1909, 120, 90],
            [2000, 1910, 120, 90],
            [2000, 1912, 70, 70],
            [2000, 1914, 120, 90],
            [2000, 1915, 57.34, 41.55],
            [2000, 1916, 120, 90],
            [2000, 1917, 120, 90],
            [2000, 1919, 120, 90],
            [2000, 1920, 70, 70],
            [2000, 1921, 28.17, 26.56],
            [2000, 1924, 120, 90],
            [2000, 1925, 49.21, 40.22],
            [2000, 1928, 120, 90],
            [2000, 1929, 6.5, 4.93],
            [2000, 1930, 10.76, 8.15],
            [2000, 1933, 12.42, 12.39],
            [2000, 1937, 70, 70],
            [2000, 1938, 120, 90],
            [2000, 1940, 120, 90],
            [2000, 1941, 120, 90],
            [2000, 1945, 41.7, 25.8],
            [2000, 1946, 70, 70],
            [2000, 1948, 26.6, 21.6],
            [2000, 1949, 120, 90],
            [2000, 1950, 42.96, 58.04],
            [2000, 1952, 92.32, 71.14],
            [2000, 1955, 50, 60],
            [2000, 1956, 40, 50],
            [2000, 1957, 70, 70],
            [2000, 1959, 120, 90],
            [2000, 1961, 120, 90],
            [2000, 1962, 15.89, 20.58],
            [2000, 1963, 7.89, 5.56],
            [2000, 1964, 79.54, 41.58],
            [2000, 1965, 50, 59.43],
            [2000, 1967, 70, 70],
            [2000, 1969, 70, 70],
            [2000, 1972, 8.68, 7.21],
            [2000, 1974, 70, 70],
            [2000, 1976, 9.37, 9.9],
            [2000, 1978, 70, 70],
            [2000, 1979, 50, 60],
            [2000, 1980, 120, 90],
            [2000, 1981, 70.08, 70],
            [2000, 1982, 70, 70],
            [2000, 1984, 70, 70],
            [2000, 1986, 120, 90],
            [2000, 1989, 50, 60],
            [2000, 1991, 11.55, 8.24],
            [2000, 1992, 50.97, 29.55],
            [2000, 1995, 43.54, 34.8],
            [2000, 1996, 120, 90],
            [2000, 1997, 120, 90],
            [2000, 1998, 7.33, 8.42],
            [2000, 2000, 17.52, 8.25],
            [2000, 2001, 63.05, 65.31],
            [2000, 2002, 50, 60],
            [2000, 2004, 8.73, 6.08],
            [2000, 2005, 117.44, 37.08],
            [2000, 2006, 20.36, 23.58],
            [2000, 2007, 70, 70],
            [2000, 2008, 70, 70],
            [2000, 2009, 58, 70],
            [2000, 2011, 12, 18],
            [2000, 2012, 70, 70],
            [2000, 2013, 38.69, 111.03],
            [2000, 2015, 20.41, 16.91],
            [2000, 2016, 50, 60],
            [2000, 2017, 40, 37.5],
            [2000, 2018, 12, 18],
            [2000, 2020, 70, 70],
            [2000, 2021, 91.08, 54.55],
            [2000, 2022, 120, 90],
            [2000, 2023, 12.93, 13.98],
            [2000, 2025, 47.08, 35.03],
            [2000, 2026, 122.65, 67.48],
            [2000, 2027, 120, 90],
            [2000, 2028, 120, 90],
            [2000, 2029, 61.44, 42.57],
            [2000, 2030, 50, 60],
            [2000, 2031, 6.44, 5.6],
            [2000, 2032, 29.96, 39.24],
            [2000, 2034, 120, 90],
            [2000, 2035, 70, 70],
            [2000, 2038, 120, 90],
            [2000, 2040, 120, 90],
            [2000, 2041, 120, 90],
            [2000, 2042, 27.63, 11.76],
            [2000, 2044, 120, 90],
            [2000, 2046, 50, 60],
            [2000, 2048, 13.1, 28.8],
            [2000, 2049, 70, 70],
            [2000, 2050, 11, 25],
            [2000, 2051, 120, 90],
            [2000, 2052, 120, 90],
            [2000, 2053, 70, 70],
            [2000, 2054, 21.44, 20.37],
            [2000, 2055, 70, 70],
            [2000, 2056, 50, 60],
            [2000, 2057, 120, 90],
            [2000, 2058, 7.15, 5.43],
            [2000, 2059, 11.86, 8.19],
            [2000, 2060, 70, 70],
            [2000, 2061, 70, 70],
            [2000, 2062, 120, 90],
            [2000, 2063, 84.41, 70],
            [2000, 2064, 61.23, 37.87],
            [2000, 2066, 120, 90],
            [2000, 2068, 70, 70],
            [2000, 2070, 19.34, 6.55],
            [2000, 2071, 120, 90],
            [2000, 2072, 120, 90],
            [2000, 2073, 120, 90],
            [2000, 2074, 70, 70],
            [2000, 2075, 45, 70],
            [2000, 2076, 70, 70],
            [2000, 2077, 120, 90],
            [2000, 2081, 41.13, 34.16],
            [2000, 2083, 120, 90],
            [2000, 2084, 23.59, 36.63],
            [2000, 2085, 9.03, 8.79],
            [2000, 2087, 70, 70],
            [2000, 2089, 50, 60],
            [2000, 2090, 120, 90],
            [2000, 2091, 120, 90],
            [2000, 2095, 70, 70],
            [2000, 2096, 120, 90],
            [2000, 2097, 50, 60],
            [2000, 2098, 40, 50],
            [2000, 2099, 83.99, 31.46],
            [2000, 2100, 71.04, 24.35],
            [2000, 2101, 30.58, 16.13],
            [2000, 2103, 11.08, 12.74],
            [2000, 2104, 111.3, 45.15],
            [2000, 2105, 120, 90],
            [2000, 2106, 40.17, 51.44],
            [2000, 2107, 120, 90],
            [2000, 2110, 40, 50],
            [2000, 2112, 70, 70],
            [2000, 2115, 70, 70],
            [2000, 2116, 50, 60],
            [2000, 2119, 7.29, 9.02],
            [2000, 2121, 28, 32.4],
            [2000, 2122, 70, 70],
            [2000, 2125, 120, 90],
            [2000, 2126, 50, 60],
            [2000, 2127, 19.02, 24.51],
            [2000, 2128, 32.1, 29.68],
            [2000, 2130, 120, 90],
            [2000, 2131, 65.5, 56.7],
            [2000, 2132, 19.44, 12.24],
            [2000, 2134, 70, 70],
            [2000, 2135, 22.3, 28.8],
            [2000, 2136, 70, 70],
            [2000, 2137, 70, 70],
            [2000, 2138, 24.24, 22.96],
            [2000, 2139, 70, 70],
            [2000, 2140, 40, 50],
            [2000, 2142, 5.59, 1.96],
            [2000, 2144, 37.3, 75.7],
            [2000, 2146, 70, 70],
            [2000, 2147, 120, 90],
            [2000, 2148, 95.28, 70],
            [2000, 2149, 120, 90],
            [2000, 2150, 120, 90],
            [2000, 2151, 40.63, 26.2],
            [2000, 2152, 120, 90],
            [2000, 2154, 120, 90],
            [2000, 2155, 120, 90],
            [2000, 2156, 43.59, 31.42],
            [2000, 2159, 120, 90],
            [2000, 2161, 50, 60],
            [2000, 2162, 27.58, 30.03],
            [2000, 2163, 120, 90],
            [2000, 2164, 22, 26.1],
            [2000, 2166, 120, 90],
            [2000, 2167, 10.33, 10.88],
            [2000, 2169, 70, 70],
            [2000, 2170, 50.17, 28.05],
            [2000, 2171, 120, 90],
            [2000, 2174, 40.28, 40.83],
            [2000, 2177, 8.15, 8.97],
            [2000, 2178, 16.1, 27],
            [2000, 2179, 26, 37.8],
            [2000, 2180, 31.07, 14.75],
            [2000, 2181, 57.35, 74.71],
            [2000, 2182, 120, 90],
            [2000, 2184, 40, 50],
            [2000, 2186, 50, 60],
            [2000, 2187, 120, 90],
            [2000, 2190, 70, 70],
            [2000, 2191, 120, 90],
            [2000, 2197, 120, 90],
            [2000, 2198, 40, 50],
            [2000, 2199, 120, 90],
            [2000, 2200, 85.49, 90],
            [2000, 2201, 23.77, 27.53],
            [2000, 2203, 11.11, 8.84],
            [2000, 2204, 14.98, 8.4],
            [2000, 2205, 120, 90],
            [2000, 2208, 81.25, 48.76],
            [2000, 2212, 70, 70],
            [2000, 2213, 50, 60],
            [2000, 2214, 1.27, 0.88],
            [2000, 2216, 25.21, 17.4],
            [2000, 2217, 120, 90],
            [2000, 2219, 120, 90],
            [2000, 2220, 34.09, 21.45],
            [2000, 2223, 40, 50],
            [2000, 2224, 36.28, 36.4],
            [2000, 2225, 50, 60],
            [2000, 2226, 120, 90],
            [2000, 2227, 39.22, 33.66],
            [2000, 2228, 50, 60],
            [2000, 2230, 120, 90],
            [2000, 2231, 120, 90],
            [2000, 2232, 28.52, 48.27],
            [2000, 2233, 22.35, 13.45],
            [2000, 2235, 50, 60],
            [2000, 2236, 24.63, 27.62],
            [2000, 2237, 120, 90],
            [2000, 2238, 45.83, 36.77],
            [2000, 2239, 21.85, 11.47],
            [2000, 2240, 120, 90],
            [2000, 2241, 14.63, 9.52],
            [2000, 2242, 91.6, 70],
            [2000, 2243, 120, 90],
            [2000, 2244, 38, 31.98],
            [2000, 2245, 70, 70],
            [2000, 2247, 50, 60],
            [2000, 2248, 40, 50],
            [2000, 2249, 120, 90],
            [2000, 2250, 50, 60],
            [2000, 2252, 70, 70],
            [2000, 2253, 14.51, 10.23],
            [2000, 2254, 70, 70],
            [2000, 2255, 37.27, 60.05],
            [2000, 2256, 70, 70],
            [2000, 2258, 70.97, 39.98],
            [2000, 2259, 2, 1],
            [2000, 2260, 70, 70],
            [2000, 2262, 70, 70],
            [2000, 2265, 120, 90],
            [2000, 2267, 7.26, 3.97],
            [2000, 2268, 120, 90],
            [2000, 2269, 70, 70],
            [2000, 2270, 120, 90],
            [2000, 2271, 6.34, 5.21],
            [2000, 2273, 92.69, 76.05],
            [2000, 2274, 70, 70],
            [2000, 2277, 50, 33.82],
            [2000, 2280, 8.57, 5.83],
            [2000, 2281, 120, 90],
            [2000, 2282, 34.6, 40.1],
            [2000, 2283, 120, 90],
            [2000, 2284, 70, 70],
            [2000, 2285, 40, 50],
            [2000, 2286, 70, 70],
            [2000, 2289, 120, 90],
            [2000, 2290, 120, 90],
            [2000, 2292, 120, 90],
            [2000, 2293, 109.99, 52.3],
            [2000, 2294, 50, 60],
            [2000, 2295, 120, 90],
            [2000, 2297, 153.15, 64.3],
            [2000, 2300, 50, 60],
            [2000, 2301, 92.47, 70],
            [2000, 2302, 120, 90],
            [2000, 2303, 56.37, 41.39],
            [2000, 2304, 70, 70],
            [2000, 2305, 120, 90],
            [2000, 2306, 50, 60],
            [2000, 2311, 45, 45],
            [2000, 2312, 40.7, 39.93],
            [2000, 2314, 120, 90],
            [2000, 2316, 70, 70],
            [2000, 2317, 120, 90],
            [2000, 2319, 50, 60],
            [2000, 2320, 8.59, 8.74],
            [2000, 2321, 120, 90],
            [2000, 2323, 70, 70],
            [2000, 2325, 120, 90],
            [2000, 2326, 120, 90],
            [2000, 2327, 120, 90],
            [2000, 2328, 70, 70],
            [2000, 2332, 30.96, 25.63],
            [2000, 2335, 57.22, 73.4],
            [2000, 2336, 120, 90],
            [2000, 2337, 120, 90],
            [2000, 2338, 70, 70],
            [2000, 2339, 120, 90],
            [2000, 2340, 120, 90],
            [2000, 2341, 70, 70],
            [2000, 2342, 70, 70],
            [2000, 2343, 57.74, 26.83],
            [2000, 2346, 70, 70],
            [2000, 2347, 120, 90],
            [2000, 2348, 37, 70],
            [2000, 2349, 92.7, 76.05],
            [2000, 2352, 50, 60],
            [2000, 2356, 226.56, 56.42],
            [2000, 2359, 50, 60],
            [2000, 2363, 30.54, 20.65],
            [2000, 2364, 70, 70],
            [2000, 2366, 16.78, 17.31],
            [2000, 2367, 59.45, 50.23],
            [2000, 2368, 70, 70],
            [2000, 2371, 70, 70],
            [2000, 2372, 30, 45],
            [2000, 2373, 70, 70],
            [2000, 2374, 12.45, 9.91],
            [2000, 2375, 120, 90],
            [2000, 2378, 20.26, 18.12],
            [2000, 2382, 70, 70],
            [2000, 2383, 91.39, 52.48],
            [2000, 2384, 30, 45],
            [2000, 2385, 70, 70],
            [2000, 2387, 40, 50],
            [2000, 2388, 70, 70],
            [2000, 2390, 120, 90],
            [2000, 2391, 70, 70],
            [2000, 2392, 7.85, 7.64],
            [2000, 2394, 50, 60],
            [2000, 2396, 120, 90],
            [2000, 2397, 120, 90],
            [2000, 2398, 120, 90],
            [2000, 2399, 120, 90],
            [2000, 2401, 9.42, 9.69],
            [2000, 2402, 70, 70],
            [2000, 2404, 120, 90],
            [2000, 2405, 22.61, 36.11],
            [2000, 2406, 120, 90],
            [2000, 2407, 120, 90],
            [2000, 2408, 50, 60],
            [2000, 2409, 9.5, 15.2],
            [2000, 2410, 55.09, 24],
            [2000, 2411, 9.59, 8.49],
            [2000, 2412, 6.63, 7.08],
            [2000, 2413, 120, 90],
            [2000, 2414, 8.64, 7.09],
            [2000, 2416, 120, 90],
            [2000, 2420, 120, 90],
            [2000, 2423, 70, 70],
            [2000, 2424, 70, 90],
            [2000, 2425, 52.54, 35],
            [2000, 2428, 10.11, 12.8],
            [2000, 2429, 12, 18],
            [2000, 2430, 70, 70],
            [2000, 2433, 70, 70],
            [2000, 2434, 70, 70],
            [2000, 2435, 22.35, 18.73],
            [2000, 2436, 17.93, 15],
            [2000, 2437, 9.73, 8.67],
            [2000, 2438, 120, 90],
            [2000, 2439, 70, 70],
            [2000, 2440, 5.64, 5.78],
            [2000, 2441, 120, 90],
            [2000, 2442, 12, 18],
            [2000, 2443, 70, 70],
            [2000, 2444, 120, 90],
            [2000, 2447, 34.36, 17.02],
            [2000, 2448, 120, 90],
            [2000, 2449, 120, 90],
            [2000, 2452, 70, 70],
            [2000, 2454, 120, 90],
            [2000, 2456, 70, 70],
            [2000, 2458, 42.99, 19.09],
            [2000, 2459, 32.63, 40.69],
            [2000, 2462, 120, 90],
            [2000, 2465, 120, 90],
            [2000, 2466, 120, 90],
            [2000, 2467, 12, 21.72],
            [2000, 2468, 22.08, 35.99],
            [2000, 2470, 120, 90],
            [2000, 2471, 120, 90],
            [2000, 2472, 78.4, 34.97],
            [2000, 2473, 120, 90],
            [2000, 2474, 120, 90],
            [2000, 2475, 123.12, 70],
            [2000, 2476, 120, 90],
            [2000, 2477, 70, 70],
            [2000, 2478, 120, 90],
            [2000, 2479, 50, 60],
            [2000, 2480, 25.72, 16.26],
            [2000, 2481, 50, 60],
            [2000, 2482, 120, 90],
            [2000, 2483, 120, 90],
            [2000, 2484, 120, 90],
            [2000, 2485, 26.73, 30.59],
            [2000, 2486, 70, 70],
            [2000, 2487, 70, 70],
            [2000, 2488, 53.21, 52.23],
            [2000, 2490, 70.38, 70],
            [2000, 2493, 109.42, 45.47],
            [2000, 2494, 85.78, 39.36],
            [2000, 2495, 40, 50],
            [2000, 2496, 120, 90],
            [2000, 2497, 40.2, 11.31],
            [2000, 2499, 13.19, 8.58],
            [2000, 2500, 14.55, 14.52],
            [2000, 2501, 70, 70],
            [2000, 2503, 40, 60],
            [2000, 2504, 120, 90],
            [2000, 2505, 70, 70],
            [2000, 2507, 120, 90],
            [2000, 2508, 70, 70],
            [2000, 2509, 21.55, 18.6],
            [2000, 2510, 70, 70],
            [2000, 2511, 120, 90],
            [2000, 2512, 120, 90],
            [2000, 2513, 7, 18.7],
            [2000, 2514, 120, 90],
            [2000, 2515, 50, 60],
            [2000, 2516, 33.27, 33.84],
            [2000, 2518, 74.82, 43.44],
            [2000, 2519, 120, 90],
            [2000, 2520, 70, 70],
            [2000, 2521, 50, 60],
            [2000, 2524, 10.39, 13.16],
            [2000, 2525, 70, 70],
            [2000, 2526, 70, 70],
            [2000, 2527, 46.45, 44.76],
            [2000, 2528, 120, 90],
            [2000, 2529, 43.73, 38.98],
            [2000, 2530, 70, 70],
            [2000, 2532, 70, 70],
            [2000, 2533, 23.69, 46.33],
            [2000, 2534, 120, 90],
            [2000, 2535, 5.38, 6.5],
            [2000, 2536, 5.45, 5.06],
            [2000, 2537, 120, 90],
            [2000, 2539, 70, 30.72],
            [2000, 2540, 19.62, 27.9],
            [2000, 2542, 34.79, 22.79],
            [2000, 2543, 27.67, 25],
            [2000, 2545, 40, 50],
            [2000, 2546, 70, 70],
            [2000, 2547, 17.63, 16.94],
            [2000, 2548, 70, 70],
            [2000, 2549, 70, 70],
            [2000, 2551, 71.76, 36.27],
            [2000, 2553, 70, 70],
            [2000, 2554, 16.72, 26.29],
            [2000, 2555, 52.5, 52.5],
            [2000, 2558, 40, 50],
            [2000, 2562, 111.85, 42.43],
            [2000, 2563, 61.13, 37.95],
            [2000, 2564, 33.39, 72.42],
            [2000, 2565, 40, 50],
            [2000, 2566, 10.13, 8.41],
            [2000, 2568, 70, 70],
            [2000, 2569, 34.08, 20.39],
            [2000, 2571, 50, 60],
            [2000, 2572, 120, 90],
            [2000, 2574, 107.79, 57.67],
            [2000, 2575, 70, 70],
            [2000, 2576, 70, 70],
            [2000, 2577, 16.06, 11.33],
            [2000, 2578, 28.35, 12.83],
            [2000, 2580, 120, 90],
            [2000, 2582, 70, 70],
            [2000, 2584, 120, 90],
            [2000, 2585, 70, 58.43],
            [2000, 2587, 66.78, 50.99],
            [2000, 2589, 70, 70],
            [2000, 2590, 120, 90],
            [2000, 2591, 120, 90],
            [2000, 2592, 120, 90],
            [2000, 2593, 109.49, 44.64],
            [2000, 2595, 70, 70],
            [2000, 2596, 120, 90],
            [2000, 2597, 40, 50],
            [2000, 2598, 70, 70],
            [2000, 2600, 50, 60],
            [2000, 2601, 70, 70],
            [2000, 2603, 120, 90],
            [2000, 2604, 27.78, 27.06],
            [2000, 2606, 18.48, 15.38],
            [2000, 2607, 14.85, 16.55],
            [2000, 2608, 70, 70],
            [2000, 2610, 70, 70],
            [2000, 2612, 44.84, 32.36],
            [2000, 2613, 120, 90],
            [2000, 2615, 80.55, 54.14],
            [2000, 2617, 17.59, 35.03],
            [2000, 2619, 57.48, 50.98],
            [2000, 2620, 50, 60],
            [2000, 2621, 120, 90],
            [2000, 2622, 22.29, 20.66],
            [2000, 2623, 36.98, 28.35],
            [2000, 2624, 120, 90],
            [2000, 2627, 70, 70],
            [2000, 2628, 49.77, 79.26],
            [2000, 2630, 120, 90],
            [2000, 2631, 70, 70],
            [2000, 2632, 22.83, 26.19],
            [2000, 2633, 30.65, 46.26],
            [2000, 2634, 130.51, 90],
            [2000, 2635, 12, 22.39],
            [2000, 2636, 105.09, 70],
            [2000, 2638, 70, 70],
            [2000, 2639, 9.66, 9.9],
            [2000, 2642, 120, 90],
            [2000, 2644, 71.93, 71.93],
            [2000, 2646, 30, 45],
            [2000, 2647, 51.91, 54.1],
            [2000, 2649, 50, 60],
            [2000, 2650, 120, 90],
            [2000, 2651, 32.4, 19.95],
            [2000, 2652, 37.5, 45],
            [2000, 2653, 70, 70],
            [2000, 2655, 40, 50],
            [2000, 2656, 50.2, 42.1],
            [2000, 2658, 73.53, 35.42],
            [2000, 2660, 40, 50],
            [2000, 2661, 70, 70],
            [2000, 2663, 50, 60],
            [2000, 2664, 11, 16.7],
            [2000, 2665, 70, 70],
            [2000, 2667, 63.81, 52.19],
            [2000, 2668, 50.55, 38.31],
            [2000, 2669, 75, 64.66],
            [2000, 2670, 70, 70],
            [2000, 2671, 50, 45],
            [2000, 2672, 13.43, 14.62],
            [2000, 2677, 70, 70],
            [2000, 2681, 70, 70],
            [2000, 2682, 120, 90],
            [2000, 2683, 9.17, 6.35],
            [2000, 2684, 70.83, 69.48],
            [2000, 2685, 50, 60],
            [2000, 2686, 9.12, 8.12],
            [2000, 2687, 94.14, 34.56],
            [2000, 2691, 50, 60],
            [2000, 2692, 70, 70],
            [2000, 2694, 120, 90],
            [2000, 2695, 12, 18],
            [2000, 2696, 70, 70],
            [2000, 2697, 120, 90],
            [2000, 2703, 50, 60],
            [2000, 2704, 10.96, 9.94],
            [2000, 2706, 120, 90],
            [2000, 2707, 70, 70],
            [2000, 2710, 18.57, 12.32],
            [2000, 2711, 50, 60],
            [2000, 2712, 87.13, 70],
            [2000, 2713, 80, 145],
            [2000, 2714, 50, 60],
            [2000, 2716, 70, 70],
            [2000, 2719, 70, 70],
            [2000, 2720, 46, 38.9],
            [2000, 2722, 120, 90],
            [2000, 2723, 70, 70],
            [2000, 2725, 70, 70],
            [2000, 2726, 120.52, 25.63],
            [2000, 2728, 120, 90],
            [2000, 2730, 76.1, 66.81],
            [2000, 2731, 120, 90],
            [2000, 2734, 50, 50],
            [2000, 2735, 6.21, 6.8],
            [2000, 2736, 30, 45],
            [2000, 2737, 40, 50],
            [2000, 2738, 40, 37.5],
            [2000, 2739, 50, 60],
            [2000, 2740, 120, 90],
            [2000, 2741, 70, 70],
            [2000, 2743, 27.47, 30.75],
            [2000, 2746, 70, 70],
            [2000, 2747, 59.05, 33.48],
            [2000, 2748, 123.58, 59.04],
            [2000, 2750, 30, 45],
            [2000, 2752, 70, 70],
            [2000, 2753, 50, 60],
            [2000, 2755, 120, 90],
            [2000, 2756, 67, 70],
            [2000, 2757, 120, 90],
            [2000, 2758, 36.94, 36.69],
            [2000, 2759, 120, 90],
            [2000, 2760, 120, 90],
            [2000, 2762, 120, 90],
            [2000, 2763, 120, 90],
            [2000, 2764, 70, 70],
            [2000, 2765, 120, 90],
            [2000, 2766, 8.32, 6.64],
            [2000, 2767, 120, 90],
            [2000, 2768, 120, 90],
            [2000, 2770, 120, 90],
            [2000, 2772, 70, 70],
            [2000, 2773, 50, 60],
            [2000, 2774, 120, 90],
            [2000, 2775, 70, 70],
            [2000, 2778, 70, 70],
            [2000, 2781, 9.91, 6.13],
            [2000, 2782, 64.72, 61.32],
            [2000, 2783, 70, 70],
            [2000, 2784, 103.9, 81.72],
            [2000, 2785, 5.56, 14],
            [2000, 2786, 70, 70],
            [2000, 2787, 64.37, 35.05],
            [2000, 2788, 99.81, 58.02],
            [2000, 2791, 30, 37.5],
            [2000, 2792, 120, 90],
            [2000, 2793, 40, 50],
            [2000, 2795, 70, 70],
            [2000, 2796, 70, 70],
            [2000, 2797, 38.38, 16.45],
            [2000, 2798, 12, 21.53],
            [2000, 2800, 85.82, 80.02],
            [2000, 2801, 120, 90],
            [2000, 2804, 16.93, 11.94],
            [2000, 2806, 70, 70],
            [2000, 2807, 36.77, 11.92],
            [2000, 2808, 50, 60],
            [2000, 2809, 120, 90],
            [2000, 2811, 34.31, 28.04],
            [2000, 2813, 34.06, 29.31],
            [2000, 2814, 120, 90],
            [2000, 2818, 9.74, 14.61],
            [2000, 2819, 11.84, 8.58],
            [2000, 2820, 70, 70],
            [2000, 2821, 70, 70],
            [2000, 2822, 40, 50],
            [2000, 2823, 29.35, 32.47],
            [2000, 2826, 40, 50],
            [2000, 2827, 13.13, 23.21],
            [2000, 2831, 120, 90],
            [2000, 2832, 23.2, 22.2],
            [2000, 2833, 65.79, 46.49],
            [2000, 2834, 50, 60],
            [2000, 2835, 37.5, 45],
            [2000, 2836, 36.81, 31.39],
            [2000, 2837, 120, 90],
            [2000, 2838, 120, 90],
            [2000, 2839, 120, 90],
            [2000, 2841, 120, 90],
            [2000, 2844, 70, 70],
            [2000, 2845, 120, 90],
            [2000, 2846, 40, 23.06],
            [2000, 2847, 30, 45],
            [2000, 2850, 50, 60],
            [2000, 2851, 75.14, 53.01],
            [2000, 2852, 37.5, 45],
            [2000, 2853, 79.31, 70],
            [2000, 2854, 14.43, 16.56],
            [2000, 2856, 124.74, 77.59],
            [2000, 2857, 120, 90],
            [2000, 2861, 50, 60],
            [2000, 2862, 70, 70],
            [2000, 2863, 25.3, 31],
            [2000, 2864, 120, 90],
            [2000, 2865, 120, 90],
            [2000, 2866, 50, 60],
            [2000, 2867, 120, 90],
            [2000, 2869, 5.93, 4.86],
            [2000, 2871, 120, 90],
            [2000, 2872, 14.38, 10.62],
            [2000, 2876, 106.83, 78.93],
            [2000, 2877, 120, 90],
            [2000, 2878, 120, 90],
            [2000, 2879, 50, 60],
            [2000, 2880, 39, 52.5],
            [2000, 2882, 120, 90],
            [2000, 2883, 48.97, 31.48],
            [2000, 2884, 102.9, 57.89],
            [2000, 2885, 164.05, 83.42],
            [2000, 2886, 70, 70],
            [2000, 2887, 70, 70],
            [2000, 2889, 70, 70],
            [2000, 2890, 120, 90],
            [2000, 2891, 120, 90],
            [2000, 2893, 120, 90],
            [2000, 2894, 120, 90],
            [2000, 2897, 120, 90],
            [2000, 2899, 98.66, 70],
            [2000, 2900, 50, 60],
            [2000, 2901, 107.65, 88.66],
            [2000, 2902, 120, 90],
            [2000, 2903, 120, 90],
            [2000, 2904, 65, 40.54],
            [2000, 2905, 50, 60],
            [2000, 2906, 120, 90],
            [2000, 2907, 11.65, 11.52],
            [2000, 2908, 70, 70],
            [2000, 2910, 41.38, 37.74],
            [2000, 2911, 120, 90],
            [2000, 2914, 70, 70],
            [2000, 2916, 70, 70],
            [2000, 2917, 50, 60],
            [2000, 2918, 17.8, 10.33],
            [2000, 2919, 120, 90],
            [2000, 2921, 120, 90],
            [2000, 2922, 16, 18],
            [2000, 2923, 56.16, 71.39],
            [2000, 2924, 120, 90],
            [2000, 2925, 120, 90],
            [2000, 2928, 70, 70],
            [2000, 2929, 35.62, 43.31],
            [2000, 2930, 70, 70],
            [2000, 2931, 70, 70],
            [2000, 2932, 30, 24.3],
            [2000, 2933, 70, 70],
            [2000, 2934, 57.1, 29.4],
            [2000, 2935, 120, 90],
            [2000, 2936, 90.08, 68.66],
            [2000, 2937, 120, 90],
            [2000, 2940, 120, 90],
            [2000, 2942, 70, 70],
            [2000, 2943, 120, 90],
            [2000, 2944, 50, 60],
            [2000, 2946, 117.5, 74.87],
            [2000, 2948, 61.55, 60],
            [2000, 2950, 116.48, 55.12],
            [2000, 2951, 120, 90],
            [2000, 2952, 70, 70],
            [2000, 2955, 70, 70],
            [2000, 2956, 30.2, 34.9],
            [2000, 2957, 120, 90],
            [2000, 2958, 70, 70],
            [2000, 2960, 50, 60],
            [2000, 2961, 50, 60],
            [2000, 2962, 40, 50],
            [2000, 2963, 120, 90],
            [2000, 2964, 50, 60],
            [2000, 2965, 120, 90],
            [2000, 2969, 15.24, 25.59],
            [2000, 2971, 70, 70],
            [2000, 2972, 120, 90],
            [2000, 2973, 70, 65],
            [2000, 2974, 22.89, 34.75],
            [2000, 2975, 70, 70],
            [2000, 2976, 120, 90],
            [2000, 2978, 24.61, 18.48],
            [2000, 2979, 27.1, 18.5],
            [2000, 2980, 21.22, 18.94],
            [2000, 2982, 40, 50],
            [2000, 2984, 13.6, 13.23],
            [2000, 2985, 50, 60],
            [2000, 2986, 120, 90],
            [2000, 2988, 120, 90],
            [2000, 2989, 50, 60],
            [2000, 2991, 50, 60],
            [2000, 2995, 26.5, 30.18],
            [2000, 2997, 11.88, 8.2],
            [2000, 2999, 6.02, 5.8],
            [2000, 3000, 53.82, 60],
            [2000, 3001, 56.14, 45.79],
            [2000, 3002, 126.06, 90],
            [2000, 3003, 120, 90],
            [2000, 3004, 36.81, 97.97],
            [2000, 3006, 70, 70],
            [2000, 3008, 28.3, 32.4],
            [2000, 3009, 50, 60],
            [2000, 3011, 15.65, 30],
            [2000, 3012, 70, 70],
            [2000, 3014, 120, 90],
            [2000, 3015, 30, 37.5],
            [2000, 3016, 44.41, 35.25],
            [2000, 3017, 120, 90],
            [2000, 3019, 50, 60],
            [2000, 3022, 120, 90],
            [2000, 3024, 70, 70],
            [2000, 3025, 70, 70],
            [2000, 3026, 12.16, 8.01],
            [2000, 3027, 22, 43.41],
            [2000, 3031, 50, 60],
            [2000, 3033, 120, 90],
            [2000, 3035, 25.46, 23.67],
            [2000, 3037, 50, 60],
            [2000, 3041, 52.5, 52.5],
            [2000, 3042, 5.83, 5.64],
            [2000, 3043, 74.42, 70],
            [2000, 3044, 70, 70],
            [2000, 3045, 120, 90],
            [2000, 3046, 50.66, 21.51],
            [2000, 3047, 50, 60],
            [2000, 3048, 101.09, 97.17],
            [2000, 3049, 120, 90],
            [2000, 3050, 27.97, 29.63],
            [2000, 3051, 120, 90],
            [2000, 3052, 50, 60],
            [2000, 3053, 70, 70],
            [2000, 3054, 50, 60],
            [2000, 3055, 120, 90],
            [2000, 3056, 15.98, 16.7],
            [2000, 3057, 70, 70],
            [2000, 3058, 71.08, 70],
            [2000, 3059, 120, 90],
            [2000, 3060, 70, 70],
            [2000, 3061, 128.24, 46.52],
            [2000, 3063, 70, 70],
            [2000, 3064, 50, 60],
            [2000, 3066, 70, 70],
            [2000, 3069, 120, 90],
            [2000, 3070, 56.43, 49.17],
            [2000, 3073, 120, 90],
            [2000, 3076, 120, 90],
            [2000, 3077, 39.42, 34.65],
            [2000, 3078, 70, 70],
            [2000, 3079, 70, 70],
            [2000, 3084, 70, 70],
            [2000, 3085, 50, 50],
            [2000, 3086, 97.92, 38.7],
            [2000, 3087, 70, 70],
            [2000, 3089, 38.17, 24],
            [2000, 3090, 50, 60],
            [2000, 3091, 19.67, 20.1],
            [2000, 3092, 70, 70],
            [2000, 3095, 120, 90],
            [2000, 3098, 29.85, 64.97],
            [2000, 3100, 120, 90],
            [2000, 3101, 120, 90],
            [2000, 3104, 7.73, 6.59],
            [2000, 3105, 70, 70],
            [2000, 3106, 34.5, 25.1],
            [2000, 3107, 120, 90],
            [2000, 3109, 50, 60],
            [2000, 3112, 87.4, 44.91],
            [2000, 3113, 50, 60],
            [2000, 3114, 120, 90],
            [2000, 3115, 120, 90],
            [2000, 3117, 50, 60],
            [2000, 3118, 120, 90],
            [2000, 3119, 12.2, 16.8],
            [2000, 3121, 64.93, 30.4],
            [2000, 3122, 62.93, 34.45],
            [2000, 3123, 120, 90],
            [2000, 3126, 70, 70],
            [2000, 3127, 9.37, 9.65],
            [2000, 3128, 47, 50],
            [2000, 3129, 53.29, 36.48],
            [2000, 3130, 12, 10],
            [2000, 3131, 8.27, 8.03],
            [2000, 3132, 120, 90],
            [2000, 3133, 60.55, 31.38],
            [2000, 3134, 50, 45],
            [2000, 3135, 120, 90],
            [2000, 3136, 40, 50],
            [2000, 3137, 20.3, 19.5],
            [2000, 3138, 120, 90],
            [2000, 3139, 5.88, 5.48],
            [2000, 3140, 70, 70],
            [2000, 3141, 50, 60],
            [2000, 3142, 40, 50],
            [2000, 3143, 70, 70],
            [2000, 3144, 120, 90],
            [2000, 3148, 33.08, 29.22],
            [2000, 3149, 120, 90],
            [2000, 3151, 120, 90],
            [2000, 3152, 50, 60],
            [2000, 3154, 87.45, 60.56],
            [2000, 3155, 98.27, 51.32],
            [2000, 3158, 18, 18],
            [2000, 3160, 22.3, 61.32],
            [2000, 3161, 12.56, 13.35],
            [2000, 3163, 70, 70],
            [2000, 3164, 70, 70],
            [2000, 3165, 70, 45.26],
            [2000, 3166, 0.17, 0.59],
            [2000, 3167, 29.9, 16.62],
            [2000, 3168, 120, 90],
            [2000, 3171, 40, 50],
            [2000, 3172, 120, 90],
            [2000, 3175, 73.26, 36.41],
            [2000, 3177, 37.5, 45],
            [2000, 3181, 8.14, 6.4],
            [2000, 3182, 22.27, 15.36],
            [2000, 3183, 51.17, 40.2],
            [2000, 3184, 70, 70],
            [2000, 3187, 24.7, 20.1],
            [2000, 3188, 25.17, 19.72],
            [2000, 3189, 192.54, 70.66],
            [2000, 3190, 26.99, 20.03],
            [2000, 3191, 70, 70],
            [2000, 3192, 120, 90],
            [2000, 3195, 24.49, 21.37],
            [2000, 3196, 70, 70],
            [2000, 3197, 99.63, 37.69],
            [2000, 3198, 9.06, 10.25],
            [2000, 3199, 70, 70],
            [2000, 3200, 40, 50],
            [2000, 3203, 12.22, 10.64],
            [2000, 3206, 60.72, 58.05],
            [2000, 3207, 50, 60],
            [2000, 3208, 120, 90],
            [2000, 3211, 70, 70],
            [2000, 3212, 120, 90],
            [2000, 3214, 70, 70],
            [2000, 3216, 120, 90],
            [2000, 3217, 42.15, 37.9],
            [2000, 3219, 10.36, 9.85],
            [2000, 3220, 120, 90],
            [2000, 3221, 70, 70],
            [2000, 3225, 6.02, 7.89],
            [2000, 3227, 25, 20],
            [2000, 3228, 72.06, 47.49],
            [2000, 3229, 120, 90],
            [2000, 3231, 19.83, 26.04],
            [2000, 3234, 37.45, 21.3],
            [2000, 3239, 120, 90],
            [2000, 3240, 120, 90],
            [2000, 3241, 50, 60],
            [2000, 3242, 70, 70],
            [2000, 3243, 12.14, 9.5],
            [2000, 3244, 120, 90],
            [2000, 3246, 65.38, 60.87],
            [2000, 3247, 120, 90],
            [2000, 3248, 40, 17.83],
            [2000, 3249, 120, 90],
            [2000, 3251, 40, 50],
            [2000, 3252, 50, 60],
            [2000, 3253, 70, 70],
            [2000, 3254, 40.73, 38.06],
            [2000, 3255, 70, 70],
            [2000, 3256, 30.27, 22.34],
            [2000, 3257, 50, 60],
            [2000, 3258, 70, 70],
            [2000, 3259, 50, 60],
            [2000, 3260, 10, 13.06],
            [2000, 3262, 70, 70],
            [2000, 3263, 120, 90],
            [2000, 3264, 21.89, 30.71],
            [2000, 3265, 120, 90],
            [2000, 3266, 86.9, 70],
            [2000, 3267, 50, 60],
            [2000, 3268, 60.02, 38.25],
            [2000, 3270, 17.3, 14.21],
            [2000, 3271, 120, 90],
            [2000, 3272, 101.18, 75.84],
            [2000, 3273, 120, 90],
            [2000, 3274, 45, 32.77],
            [2000, 3275, 120, 90],
            [2000, 3276, 120, 90],
            [2000, 3277, 91.74, 42.99],
            [2000, 3278, 63.11, 20.86],
            [2000, 3279, 70, 70],
            [2000, 3280, 59.87, 41.55],
            [2000, 3283, 12.69, 12.13],
            [2000, 3284, 42.57, 30.98],
            [2000, 3286, 15.7, 9.65],
            [2000, 3287, 50, 60],
            [2000, 3288, 30.42, 23.34],
            [2000, 3289, 85, 70],
            [2000, 3290, 21.59, 14.57],
            [2000, 3292, 120, 90],
            [2000, 3293, 70, 70],
            [2000, 3294, 50, 60],
            [2000, 3295, 120, 90],
            [2000, 3296, 30, 45],
            [2000, 3300, 70, 70],
            [2000, 3301, 70, 70],
            [2000, 3302, 40, 50],
            [2000, 3303, 70, 70],
            [2000, 3305, 120, 90],
            [2000, 3306, 24.91, 27.22],
            [2000, 3308, 70, 70],
            [2000, 3309, 50, 45],
            [2000, 3312, 70, 70],
            [2000, 3313, 120, 90],
            [2000, 3314, 50, 60],
            [2000, 3315, 120, 90],
            [2000, 3316, 120, 90],
            [2000, 3318, 70, 70],
            [2000, 3319, 70, 70],
            [2000, 3320, 120, 90],
            [2000, 3321, 50, 60],
            [2000, 3322, 120, 90],
            [2000, 3324, 9.8, 13.83],
            [2000, 3325, 38.61, 28.27],
            [2000, 3326, 51.15, 39.66],
            [2000, 3327, 98.77, 87.26],
            [2000, 3328, 120, 90],
            [2000, 3329, 8.87, 8.14],
            [2000, 3331, 108.09, 47.79],
            [2000, 3332, 120, 90],
            [2000, 3333, 120, 90],
            [2000, 3334, 8.78, 7.44],
            [2000, 3335, 70, 70],
            [2000, 3336, 46.22, 26.88],
            [2000, 3338, 70, 70],
            [2000, 3340, 50, 60],
            [2000, 3341, 24.19, 12.04],
            [2000, 3342, 70, 70],
            [2000, 3343, 120, 90],
            [2000, 3344, 96.68, 56.26],
            [2000, 3346, 90.98, 55.27],
            [2000, 3347, 120, 90],
            [2000, 3348, 70, 70],
            [2000, 3350, 120, 90],
            [2000, 3351, 120, 90],
            [2000, 3353, 120, 90],
            [2000, 3357, 12.58, 12.94],
            [2000, 3358, 19.2, 17.45],
            [2000, 3359, 120, 90],
            [2000, 3361, 120, 90],
            [2000, 3363, 14.08, 11.88],
            [2000, 3364, 12, 21.69],
            [2000, 3366, 120, 90],
            [2000, 3367, 50, 60],
            [2000, 3369, 120, 90],
            [2000, 3370, 48.58, 95.54],
            [2000, 3371, 70, 60],
            [2000, 3372, 70, 70],
            [2000, 3376, 120, 90],
            [2000, 3378, 9.02, 8.54],
            [2000, 3380, 120, 90],
            [2000, 3381, 120, 90],
            [2000, 3382, 23.2, 25.03],
            [2000, 3384, 70, 70],
            [2000, 3386, 120, 90],
            [2000, 3387, 70, 70],
            [2000, 3388, 120, 90],
            [2000, 3389, 31.29, 20.21],
            [2000, 3390, 59.69, 14.2],
            [2000, 3391, 120, 90],
            [2000, 3392, 120, 90],
            [2000, 3393, 120, 90],
            [2000, 3394, 120, 90],
            [2000, 3396, 21.88, 28.51],
            [2000, 3399, 89.86, 75.76],
            [2000, 3400, 50, 60],
            [2000, 3402, 120, 90],
            [2000, 3403, 16.87, 10.26],
            [2000, 3404, 41.37, 52.15],
            [2000, 3407, 63.12, 31.83],
            [2000, 3408, 120, 90],
            [2000, 3411, 70.12, 70],
            [2000, 3414, 50, 60],
            [2000, 3415, 40, 50],
            [2000, 3416, 40, 50],
            [2000, 3417, 120, 70],
            [2000, 3418, 120, 90],
            [2000, 3419, 70, 70],
            [2000, 3420, 70, 70],
            [2000, 3422, 50.99, 25.75],
            [2000, 3423, 120, 90],
            [2000, 3424, 37.5, 45],
            [2000, 3426, 120, 90],
            [2000, 3428, 70, 70],
            [2000, 3429, 49.14, 44.47],
            [2000, 3431, 120, 90],
            [2000, 3432, 70, 70],
            [2000, 3433, 19.6, 20.1],
            [2000, 3434, 6.86, 5.46],
            [2000, 3436, 50, 60],
            [2000, 3437, 70.24, 70],
            [2000, 3438, 70, 70],
            [2000, 3439, 36.81, 46.42],
            [2000, 3440, 50, 60],
            [2000, 3441, 59.78, 46.81],
            [2000, 3442, 34.82, 34.71],
            [2000, 3444, 17.9, 15.29],
            [2000, 3445, 70, 70],
            [2000, 3448, 5.56, 6.38],
            [2000, 3449, 70, 70],
            [2000, 3450, 70, 70],
            [2000, 3451, 71.38, 68.39],
            [2000, 3452, 120, 90],
            [2000, 3453, 15.33, 23.54],
            [2000, 3454, 18.63, 15.82],
            [2000, 3456, 70, 90],
            [2000, 3457, 120, 90],
            [2000, 3459, 72.5, 55.8],
            [2000, 3461, 68.26, 26.15],
            [2000, 3462, 55.41, 24.77],
            [2000, 3463, 120, 90],
            [2000, 3464, 120, 90],
            [2000, 3468, 76.43, 44.44],
            [2000, 3469, 34.89, 19.21],
            [2000, 3471, 70, 70],
            [2000, 3472, 120, 90],
            [2000, 3473, 12.27, 10.63],
            [2000, 3474, 70, 70],
            [2000, 3476, 40, 50],
            [2000, 3480, 120, 90],
            [2000, 3481, 70, 70],
            [2000, 3482, 70, 70],
            [2000, 3483, 70, 70],
            [2000, 3484, 120, 90],
            [2000, 3485, 52.28, 52.85],
            [2000, 3487, 50, 60],
            [2000, 3488, 23, 23],
            [2000, 3489, 40, 50],
            [2000, 3492, 120, 90],
            [2000, 3493, 70, 70],
            [2000, 3494, 12, 18],
            [2000, 3496, 120, 90],
            [2000, 3497, 120, 90],
            [2000, 3498, 38.68, 34.83],
            [2000, 3499, 120, 90],
            [2000, 3501, 120, 90],
            [2000, 3503, 120, 90],
            [2000, 3504, 70, 70],
            [2000, 3505, 120, 90],
            [2000, 3508, 120, 90],
            [2000, 3509, 40, 60],
            [2000, 3510, 120, 90],
            [2000, 3511, 70, 70],
            [2000, 3514, 18.7, 27],
            [2000, 3515, 70, 70],
            [2000, 3516, 120, 90],
            [2000, 3517, 70, 70],
            [2000, 3518, 120, 90],
            [2000, 3519, 50, 60],
            [2000, 3520, 120, 90],
            [2000, 3521, 120, 90],
            [2000, 3523, 120, 90],
            [2000, 3525, 120, 90],
            [2000, 3527, 120, 90],
            [2000, 3530, 52.8, 38.6],
            [2000, 3531, 42.22, 34.38],
            [2000, 3534, 70, 70],
            [2000, 3535, 30, 45],
            [2000, 3537, 120, 90],
            [2000, 3539, 120, 90],
            [2000, 3541, 42.81, 43.65],
            [2000, 3543, 120, 90],
            [2000, 3545, 120, 90],
            [2000, 3546, 120, 90],
            [2000, 3549, 22.69, 14.17],
            [2000, 3551, 120, 90],
            [2000, 3553, 70, 70],
            [2000, 3554, 50, 60],
            [2000, 3555, 40, 50],
            [2000, 3557, 16.81, 25.35],
            [2000, 3558, 70, 70],
            [2000, 3559, 50, 60],
            [2000, 3560, 120, 90],
            [2000, 3561, 120, 90],
            [2000, 3564, 120, 90],
            [2000, 3566, 17.61, 17.41],
            [2000, 3568, 12.22, 9.98],
            [2000, 3569, 50, 60],
            [2000, 3570, 70, 70],
            [2000, 3571, 70, 70],
            [2000, 3572, 120, 90],
            [2000, 3573, 120, 90],
            [2000, 3575, 120, 90],
            [2000, 3576, 120, 90],
            [2000, 3577, 70, 70],
            [2000, 3579, 22.92, 33.97],
            [2000, 3580, 70, 70],
            [2000, 3581, 120, 90],
            [2000, 3582, 4.45, 5.68],
            [2000, 3585, 70, 70],
            [2000, 3586, 70, 70],
            [2000, 3587, 70, 70],
            [2000, 3588, 120, 90],
            [2000, 3589, 12, 18],
            [2000, 3590, 40, 43.95],
            [2000, 3592, 70, 70],
            [2000, 3593, 35.78, 25.31],
            [2000, 3594, 120, 90],
            [2000, 3595, 70, 90],
            [2000, 3596, 120, 90],
            [2000, 3597, 70, 70],
            [2000, 3598, 22.96, 24.32],
            [2000, 3599, 120, 90],
            [2000, 3600, 49.66, 38.48],
            [2000, 3601, 75.67, 62.54],
            [2000, 3602, 51.79, 46.05],
            [2000, 3606, 40, 50],
            [2000, 3607, 12.7, 15.8],
            [2000, 3608, 33.57, 26.7],
            [2000, 3609, 151.97, 90],
            [2000, 3610, 50, 60],
            [2000, 3611, 70, 70],
            [2000, 3612, 70, 70],
            [2000, 3613, 40, 50],
            [2000, 3614, 9.76, 7.31],
            [2000, 3615, 70, 70],
            [2000, 3617, 70, 70],
            [2000, 3619, 70, 70],
            [2000, 3620, 48, 60],
            [2000, 3621, 50, 60],
            [2000, 3622, 120, 90],
            [2000, 3623, 120, 90],
            [2000, 3624, 16.21, 10.44],
            [2000, 3626, 120, 90],
            [2000, 3627, 120, 90],
            [2000, 3628, 30, 45],
            [2000, 3629, 70, 70],
            [2000, 3631, 70, 70],
            [2000, 3632, 48.09, 38.27],
            [2000, 3633, 71.55, 70],
            [2000, 3634, 24.1, 17.22],
            [2000, 3635, 50, 60],
            [2000, 3636, 70, 70],
            [2000, 3637, 40, 50],
            [2000, 3639, 120, 90],
            [2000, 3641, 40, 50],
            [2000, 3642, 58.18, 27.21],
            [2000, 3643, 70, 70],
            [2000, 3644, 37.33, 36.38],
            [2000, 3647, 70, 70],
            [2000, 3648, 70, 70],
            [2000, 3649, 120, 90],
            [2000, 3650, 93.96, 49.61],
            [2000, 3651, 40, 50],
            [2000, 3652, 40, 50],
            [2000, 3653, 49.84, 42.61],
            [2000, 3656, 42.55, 28.63],
            [2000, 3657, 40, 50],
            [2000, 3659, 45.77, 17.29],
            [2000, 3661, 49.38, 28.07],
            [2000, 3662, 30, 45],
            [2000, 3663, 120, 90],
            [2000, 3665, 120, 90],
            [2000, 3666, 120, 90],
            [2000, 3667, 30.09, 35.52],
            [2000, 3668, 120, 90],
            [2000, 3669, 12, 25.38],
            [2000, 3670, 96.19, 48.48],
            [2000, 3671, 120, 90],
            [2000, 3675, 120, 90],
            [2000, 3676, 120, 90],
            [2000, 3677, 50, 60],
            [2000, 3678, 11.23, 7.28],
            [2000, 3679, 22.74, 35.74],
            [2000, 3681, 70, 70],
            [2000, 3683, 7.87, 11.07],
            [2000, 3685, 120, 90],
            [2000, 3686, 120, 90],
            [2000, 3687, 92.77, 76.03],
            [2000, 3688, 120, 90],
            [2000, 3690, 120, 90],
            [2000, 3691, 13.11, 11.71],
            [2000, 3692, 24.91, 11.38],
            [2000, 3694, 70, 70],
            [2000, 3695, 120, 90],
            [2000, 3696, 70, 70],
            [2000, 3698, 120, 90],
            [2000, 3700, 25.38, 59.21],
            [2000, 3701, 29.01, 18.72],
            [2000, 3702, 16.7, 11.85],
            [2000, 3703, 175.88, 66.13],
            [2000, 3705, 30, 45],
            [2000, 3707, 70, 70],
            [2000, 3708, 70, 70],
            [2000, 3710, 50, 60],
            [2000, 3711, 9.31, 9.41],
            [2000, 3713, 71.95, 70],
            [2000, 3714, 120, 90],
            [2000, 3716, 120, 90],
            [2000, 3718, 70, 70],
            [2000, 3719, 120, 90],
            [2000, 3720, 95.89, 30.16],
            [2000, 3722, 40, 50],
            [2000, 3723, 30, 45],
            [2000, 3724, 12.29, 10.32],
            [2000, 3726, 12, 18],
            [2000, 3728, 120, 90],
            [2000, 3729, 120, 90],
            [2000, 3731, 40, 25.08],
            [2000, 3733, 120, 90],
            [2000, 3738, 30, 45],
            [2000, 3741, 120, 90],
            [2000, 3745, 120, 90],
            [2000, 3747, 33.24, 30.21],
            [2000, 3748, 120, 90],
            [2000, 3749, 120, 90],
            [2000, 3751, 27.22, 22.15],
            [2000, 3752, 38.07, 10.83],
            [2000, 3753, 50, 60],
            [2000, 3755, 31.66, 30.53],
            [2000, 3756, 120, 90],
            [2000, 3758, 50, 60],
            [2000, 3759, 70, 70],
            [2000, 3761, 36.17, 17.01],
            [2000, 3762, 49.07, 30.08],
            [2000, 3763, 70, 70],
            [2000, 3764, 56.14, 29.13],
            [2000, 3765, 36.87, 29.24],
            [2000, 3766, 50, 60],
            [2000, 3768, 72.89, 70],
            [2000, 3769, 120, 90],
            [2000, 3775, 16.7, 21.1],
            [2000, 3776, 120, 90],
            [2000, 3777, 64.75, 33.71],
            [2000, 3780, 70, 70],
            [2000, 3781, 120, 90],
            [2000, 3782, 33.84, 17.76],
            [2000, 3783, 70, 70],
            [2000, 3785, 120, 90],
            [2000, 3786, 10.14, 9.72],
            [2000, 3791, 120, 90],
            [2000, 3793, 70, 70],
            [2000, 3795, 28.93, 71.01],
            [2000, 3796, 34.35, 19.61],
            [2000, 3797, 50, 60],
            [2000, 3799, 50, 60],
            [2000, 3800, 70, 70],
            [2000, 3801, 120, 90],
            [2000, 3802, 50, 60],
            [2000, 3804, 70, 70],
            [2000, 3807, 21.47, 18.5],
            [2000, 3811, 50, 60],
            [2000, 3812, 120, 90],
            [2000, 3814, 70, 70],
            [2000, 3815, 8.38, 6.36],
            [2000, 3816, 120, 90],
            [2000, 3820, 50, 60],
            [2000, 3821, 18.9, 24.5],
            [2000, 3822, 120, 90],
            [2000, 3824, 70, 70],
            [2000, 3826, 114.89, 70],
            [2000, 3827, 104.5, 55.33],
            [2000, 3828, 48.71, 27.21],
            [2000, 3830, 6.73, 6.06],
            [2000, 3832, 40.07, 56.69],
            [2000, 3833, 30, 45],
            [2000, 3834, 82.66, 53.29],
            [2000, 3837, 70, 70],
            [2000, 3839, 120, 90],
            [2000, 3841, 115.85, 58.55],
            [2000, 3842, 70, 70],
            [2000, 3843, 4.12, 8.93],
            [2000, 3845, 29.78, 34.18],
            [2000, 3846, 70, 70],
            [2000, 3849, 70, 70],
            [2000, 3850, 28.31, 33.02],
            [2000, 3851, 120, 90],
            [2000, 3853, 120, 90],
            [2000, 3854, 28.93, 29.68],
            [2000, 3855, 120, 90],
            [2000, 3856, 16.7, 22.9],
            [2000, 3858, 120, 90],
            [2000, 3859, 12, 23.21],
            [2000, 3862, 70, 70],
            [2000, 3863, 50, 60],
            [2000, 3865, 120, 90],
            [2000, 3866, 14.49, 13.27],
            [2000, 3867, 120, 90],
            [2000, 3868, 120, 90],
            [2000, 3869, 50, 60],
            [2000, 3870, 113.75, 53.42],
            [2000, 3871, 46.79, 28.4],
            [2000, 3873, 120, 90],
            [2000, 3874, 57.1, 44.75],
            [2000, 3877, 120, 70],
            [2000, 3879, 120, 90],
            [2000, 3880, 15.73, 17.34],
            [2000, 3881, 50, 60],
            [2000, 3882, 120, 90],
            [2000, 3883, 85.28, 79.59],
            [2000, 3884, 50, 60],
            [2000, 3886, 70, 70],
            [2000, 3887, 120, 90],
            [2000, 3889, 70, 70],
            [2000, 3890, 10.56, 9.46],
            [2000, 3891, 17.06, 21.5],
            [2000, 3892, 70, 70],
            [2000, 3896, 70, 70],
            [2000, 3897, 46.88, 27.21],
            [2000, 3898, 120, 90],
            [2000, 3899, 120, 90],
            [2000, 3900, 50.61, 29.08],
            [2000, 3901, 70, 70],
            [2000, 3903, 50, 60],
            [2000, 3905, 62.21, 43.82],
            [2000, 3906, 70, 70],
            [2000, 3909, 120, 90],
            [2000, 3910, 70, 70],
            [2000, 3915, 30, 45],
            [2000, 3916, 120, 90],
            [2000, 3918, 8.88, 7.78],
            [2000, 3919, 120, 90],
            [2000, 3921, 34.37, 32.04],
            [2000, 3922, 120, 90],
            [2000, 3923, 120, 90],
            [2000, 3924, 11.01, 5.63],
            [2000, 3925, 87.13, 64.34],
            [2000, 3927, 70, 70],
            [2000, 3928, 15.78, 11.76],
            [2000, 3929, 120, 90],
            [2000, 3930, 76.26, 70],
            [2000, 3931, 70, 70],
            [2000, 3932, 32.72, 42.52],
            [2000, 3933, 70, 70],
            [2000, 3935, 120, 90],
            [2000, 3936, 120, 90],
            [2000, 3937, 70, 70],
            [2000, 3938, 40, 50],
            [2000, 3939, 40, 50],
            [2000, 3940, 53.79, 32.63],
            [2000, 3941, 120, 90],
            [2000, 3942, 32.24, 20.58],
            [2000, 3943, 16.04, 19.53],
            [2000, 3944, 120, 90],
            [2000, 3946, 9.98, 9.98],
            [2000, 3947, 120, 90],
            [2000, 3950, 120, 90],
            [2000, 3951, 120, 90],
            [2000, 3952, 120, 90],
            [2000, 3953, 130.15, 56.8],
            [2000, 3954, 120, 90],
            [2000, 3956, 50, 60],
            [2000, 3958, 13.07, 12.08],
            [2000, 3959, 107.55, 47.75],
            [2000, 3960, 78.17, 40.51],
            [2000, 3961, 8.09, 5.91],
            [2000, 3963, 24.93, 29.76],
            [2000, 3964, 70, 70],
            [2000, 3966, 70, 70],
            [2000, 3968, 26.82, 32.61],
            [2000, 3969, 73.5, 49.04],
            [2000, 3970, 46.74, 74.49],
            [2000, 3971, 120, 90],
            [2000, 3972, 120, 86],
            [2000, 3976, 12, 24.6],
            [2000, 3978, 70, 70],
            [2000, 3979, 151.53, 70.45],
            [2000, 3980, 50, 60],
            [2000, 3981, 70, 70],
            [2000, 3982, 120, 90],
            [2000, 3983, 30, 45],
            [2000, 3985, 36, 28],
            [2000, 3988, 33.8, 45.99],
            [2000, 3990, 70, 70],
            [2000, 3991, 120, 90],
            [2000, 3992, 53.73, 58.98],
            [2000, 3993, 12, 18],
            [2000, 3994, 120, 90],
            [2000, 3996, 70, 70],
            [2000, 3997, 120, 90],
            [2000, 3998, 120, 90],
            [2000, 3999, 28.04, 39.32],
            [2000, 4001, 120, 90],
            [2000, 4002, 120, 90],
            [2000, 4003, 86.47, 73.85],
            [2000, 4004, 70, 70],
            [2000, 4005, 51.86, 17.81],
            [2000, 4007, 120, 90],
            [2000, 4008, 70, 70],
            [2000, 4010, 8.6, 12.5],
            [2000, 4012, 120, 90],
            [2000, 4013, 120, 90],
            [2000, 4014, 120, 90],
            [2000, 4015, 120, 90],
            [2000, 4016, 21, 33],
            [2000, 4017, 84.3, 28.73],
            [2000, 4018, 80.65, 70],
            [2000, 4019, 40, 50],
            [2000, 4021, 70, 70],
            [2000, 4022, 70, 70],
            [2000, 4023, 34.76, 26.62],
            [2000, 4024, 120, 90],
            [2000, 4026, 36.65, 22.13],
            [2000, 4027, 120, 90],
            [2000, 4028, 70, 70],
            [2000, 4031, 17.94, 39.15],
            [2000, 4034, 120, 90],
            [2000, 4035, 17.68, 13.86],
            [2000, 4038, 120, 90],
            [2000, 4040, 85.79, 70.07],
            [2000, 4041, 120, 90],
            [2000, 4043, 20, 20],
            [2000, 4045, 10.39, 9.07],
            [2000, 4047, 44.52, 35.91],
            [2000, 4048, 14.6, 19.7],
            [2000, 4049, 70, 70],
            [2000, 4051, 120, 90],
            [2000, 4053, 64.92, 33.42],
            [2000, 4057, 50, 60],
            [2000, 4059, 113.78, 76.04],
            [2000, 4062, 70.39, 70],
            [2000, 4063, 50, 60],
            [2000, 4065, 70.03, 70],
            [2000, 4066, 70, 70],
            [2000, 4068, 120, 90],
            [2000, 4069, 58.37, 31.62],
            [2000, 4070, 70, 70],
            [2000, 4071, 70, 70],
            [2000, 4072, 120, 90],
            [2000, 4073, 30, 45],
            [2000, 4074, 70, 70],
            [2000, 4076, 120, 90],
            [2000, 4080, 120, 90],
            [2000, 4081, 120, 90],
            [2000, 4082, 120, 90],
            [2000, 4083, 120, 90],
            [2000, 4084, 14, 13.72],
            [2000, 4085, 70, 70],
            [2000, 4087, 120, 90],
            [2000, 4088, 120, 90],
            [2000, 4090, 120, 90],
            [2000, 4091, 70, 70],
            [2000, 4092, 98.89, 70],
            [2000, 4093, 120, 90],
            [2000, 4094, 50, 60],
            [2000, 4095, 30.82, 30.34],
            [2000, 4096, 85.87, 50.11],
            [2000, 4097, 120, 90],
            [2000, 4100, 50, 60],
            [2000, 4102, 70.01, 70],
            [2000, 4103, 70, 70],
            [2000, 4104, 70, 70],
            [2000, 4105, 120, 90],
            [2000, 4106, 35.03, 33.83],
            [2000, 4107, 120, 90],
            [2000, 4108, 47, 127],
            [2000, 4109, 11.09, 23.39],
            [2000, 4110, 70, 70],
            [2000, 4111, 46.81, 38.06],
            [2000, 4112, 40, 50],
            [2000, 4115, 120, 90],
            [2000, 4116, 31.55, 32.55],
            [2000, 4117, 53.51, 60],
            [2000, 4118, 27.75, 35.04],
            [2000, 4119, 120, 90],
            [2000, 4120, 34.02, 34.24],
            [2000, 4121, 70, 70],
            [2000, 4122, 103.31, 86.3],
            [2000, 4124, 53.38, 47.38],
            [2000, 4125, 12, 18],
            [2000, 4128, 28, 24.17],
            [2000, 4129, 14.06, 10.13],
            [2000, 4131, 16.41, 11.2],
            [2000, 4133, 70, 70],
            [2000, 4134, 89.38, 44.91],
            [2000, 4136, 50, 60],
            [2000, 4137, 120, 90],
            [2000, 4138, 11.77, 6.96],
            [2000, 4139, 30, 45],
            [2000, 4140, 49.79, 34.67],
            [2000, 4142, 70, 70],
            [2000, 4143, 50, 60],
            [2000, 4145, 120, 90],
            [2000, 4146, 6.49, 5.75],
            [2000, 4147, 120, 90],
            [2000, 4149, 50, 60],
            [2000, 4150, 70, 70],
            [2000, 4152, 101.39, 50.61],
            [2000, 4154, 120, 90],
            [2000, 4155, 70, 70],
            [2000, 4156, 78.4, 74.93],
            [2000, 4157, 30.51, 11.96],
            [2000, 4158, 120, 90],
            [2000, 4159, 6.8, 6.65],
            [2000, 4162, 120, 90],
            [2000, 4164, 16.17, 15.54],
            [2000, 4165, 120, 90],
            [2000, 4166, 30, 45],
            [2000, 4167, 70, 70],
            [2000, 4168, 37.5, 45],
            [2000, 4169, 35.25, 45.76],
            [2000, 4173, 12, 24.28],
            [2000, 4175, 51.01, 25.06],
            [2000, 4176, 10, 16],
            [2000, 4177, 58.73, 69.61],
            [2000, 4178, 120, 90],
            [2000, 4179, 23.41, 16.69],
            [2000, 4180, 14.1, 8.76],
            [2000, 4181, 120, 90],
            [2000, 4182, 76.84, 36.41],
            [2000, 4185, 14.91, 16.67],
            [2000, 4186, 50, 60],
            [2000, 4188, 120, 90],
            [2000, 4189, 24.6, 36],
            [2000, 4190, 120, 90],
            [2000, 4192, 50, 60],
            [2000, 4193, 120, 90],
            [2000, 4194, 120, 90],
            [2000, 4197, 50, 60],
            [2000, 4199, 76.31, 53.54],
            [2000, 4200, 12.14, 9.28],
            [2000, 4203, 62.98, 58.18],
            [2000, 4205, 120, 90],
            [2000, 4206, 12.5, 12],
            [2000, 4207, 60.24, 34.36],
            [2000, 4208, 120, 90],
            [2000, 4209, 22.23, 20.17],
            [2000, 4210, 56.87, 36.84],
            [2000, 4211, 120, 90],
            [2000, 4213, 40.9, 35.4],
            [2000, 4215, 120, 90],
            [2000, 4216, 120, 90],
            [2000, 4219, 30, 45],
            [2000, 4220, 70, 70],
            [2000, 4221, 70, 70],
            [2000, 4222, 120, 90],
            [2000, 4223, 5.37, 4.59],
            [2000, 4224, 42.19, 39.65],
            [2000, 4225, 120, 90],
            [2000, 4226, 73.7, 42.65],
            [2000, 4229, 36.01, 22.9],
            [2000, 4230, 70, 70],
            [2000, 4231, 70, 70],
            [2000, 4232, 40, 50],
            [2000, 4233, 30.06, 42.45],
            [2000, 4234, 70, 70],
            [2000, 4235, 6.53, 5.13],
            [2000, 4236, 70, 70],
            [2000, 4237, 120, 90],
            [2000, 4238, 120, 90],
            [2000, 4239, 120, 90],
            [2000, 4241, 120, 90],
            [2000, 4242, 22.45, 62.54],
            [2000, 4244, 11.58, 16.71],
            [2000, 4245, 50, 60],
            [2000, 4246, 23.77, 36.35],
            [2000, 4248, 70, 70],
            [2000, 4249, 120, 90],
            [2000, 4250, 120, 90],
            [2000, 4251, 120, 90],
            [2000, 4252, 7.87, 9.28],
            [2000, 4256, 50, 60],
            [2000, 4257, 40, 50],
            [2000, 4258, 17, 38.5],
            [2000, 4259, 12.25, 12.29],
            [2000, 4260, 120, 90],
            [2000, 4261, 50, 60],
            [2000, 4264, 8.46, 8.46],
            [2000, 4265, 70, 70],
            [2000, 4266, 120, 90],
            [2000, 4269, 120, 90],
            [2000, 4270, 120, 90],
            [2000, 4272, 72.31, 55.31],
            [2000, 4273, 120, 90],
            [2000, 4274, 120, 90],
            [2000, 4275, 70, 70],
            [2000, 4279, 25.11, 25.86],
            [2000, 4281, 70, 70],
            [2000, 4282, 50, 60],
            [2000, 4283, 19.15, 24.03],
            [2000, 4284, 120, 90],
            [2000, 4285, 36.64, 28.69],
            [2000, 4286, 120, 90],
            [2000, 4287, 14.84, 10.96],
            [2000, 4288, 120, 90],
            [2000, 4289, 43.54, 28.73],
            [2000, 4291, 50, 60],
            [2000, 4293, 7.15, 6.68],
            [2000, 4294, 79.07, 70],
            [2000, 4295, 70, 70],
            [2000, 4296, 42.82, 14.61],
            [2000, 4297, 70, 70],
            [2000, 4298, 120, 80],
            [2000, 4299, 70, 48.52],
            [2000, 4301, 60.86, 37.6],
            [2000, 4302, 26.64, 23.08],
            [2000, 4305, 70, 70],
            [2000, 4307, 120, 90],
            [2000, 4308, 120, 90],
            [2000, 4309, 11.7, 18],
            [2000, 4310, 50, 60],
            [2000, 4312, 70, 70],
            [2000, 4313, 120, 90],
            [2000, 4317, 50, 60],
            [2000, 4318, 39.31, 26.34],
            [2000, 4320, 46.9, 37],
            [2000, 4323, 24.53, 33.29],
            [2000, 4325, 29.6, 19.97],
            [2000, 4326, 11.3, 11.2],
            [2000, 4328, 70, 70],
            [2000, 4329, 22.52, 19.08],
            [2000, 4330, 70, 70],
            [2000, 4333, 17.64, 32.54],
            [2000, 4334, 120, 90],
            [2000, 4337, 30.93, 37.77],
            [2000, 4338, 26.42, 28.94],
            [2000, 4339, 21.74, 15.6],
            [2000, 4340, 13.6, 21.8],
            [2000, 4341, 120, 90],
            [2000, 4343, 120, 90],
            [2000, 4345, 48.44, 41.98],
            [2000, 4346, 50, 60],
            [2000, 4347, 120, 90],
            [2000, 4349, 21.62, 31.72],
            [2000, 4350, 26.85, 29.25],
            [2000, 4352, 41.47, 35.71],
            [2000, 4353, 40.7, 33.52],
            [2000, 4355, 120, 90],
            [2000, 4356, 12.68, 15.44],
            [2000, 4358, 23.24, 26.31],
            [2000, 4360, 84.9, 70],
            [2000, 4362, 57.64, 39.46],
            [2000, 4363, 70, 70],
            [2000, 4364, 59.2, 40.69],
            [2000, 4365, 120, 90],
            [2000, 4366, 70, 70],
            [2000, 4367, 120, 90],
            [2000, 4372, 70, 70],
            [2000, 4374, 30, 45],
            [2000, 4375, 70, 70],
            [2000, 4376, 120, 90],
            [2000, 4377, 70, 70],
            [2000, 4378, 70, 70],
            [2000, 4380, 66.47, 40.12],
            [2000, 4382, 70, 65],
            [2000, 4383, 70, 70],
            [2000, 4384, 45.16, 27.63],
            [2000, 4386, 16.95, 21.6],
            [2000, 4387, 120, 90],
            [2000, 4389, 70, 70],
            [2000, 4390, 120, 90],
            [2000, 4391, 19.92, 20.51],
            [2000, 4392, 70, 70],
            [2000, 4394, 70, 70],
            [2000, 4395, 70, 70],
            [2000, 4396, 70, 70],
            [2000, 4397, 7.76, 8.86],
            [2000, 4398, 70, 70],
            [2000, 4399, 50, 60],
            [2000, 4400, 120, 90],
            [2000, 4402, 40, 50],
            [2000, 4404, 120, 90],
            [2000, 4405, 6.29, 4.6],
            [2000, 4406, 63.31, 68.07],
            [2000, 4407, 70, 70],
            [2000, 4408, 18, 27],
            [2000, 4409, 120, 90],
            [2000, 4410, 70, 70],
            [2000, 4411, 120, 90],
            [2000, 4412, 120, 90],
            [2000, 4413, 26.66, 14.26],
            [2000, 4414, 18.02, 27],
            [2000, 4415, 126.64, 97.53],
            [2000, 4416, 70, 70],
            [2000, 4417, 50, 60],
            [2000, 4418, 131.53, 70.86],
            [2000, 4419, 70, 70],
            [2000, 4420, 5.73, 6.7],
            [2000, 4421, 73.94, 42.49],
            [2000, 4426, 12, 18],
            [2000, 4427, 40, 50],
            [2000, 4428, 70, 70],
            [2000, 4432, 70, 70],
            [2000, 4433, 120, 90],
            [2000, 4436, 40, 50],
            [2000, 4438, 50, 50],
            [2000, 4439, 40, 50],
            [2000, 4440, 70, 70],
            [2000, 4441, 16.95, 12.33],
            [2000, 4442, 18, 27],
            [2000, 4443, 41.1, 27.5],
            [2000, 4444, 70, 90],
            [2000, 4445, 70, 90],
            [2000, 4446, 37.11, 22.57],
            [2000, 4448, 70, 70],
            [2000, 4450, 120, 90],
            [2000, 4453, 50, 60],
            [2000, 4454, 25.13, 30.27],
            [2000, 4455, 70, 70],
            [2000, 4456, 15.9, 14.4],
            [2000, 4457, 40, 50],
            [2000, 4460, 70, 70],
            [2000, 4461, 25.09, 25.72],
            [2000, 4463, 38.22, 20.51],
            [2000, 4464, 44.69, 25.78],
            [2000, 4465, 70, 70],
            [2000, 4466, 70, 70],
            [2000, 4467, 120, 90],
            [2000, 4468, 70, 70],
            [2000, 4470, 50, 60],
            [2000, 4471, 48.21, 38.33],
            [2000, 4473, 70, 70],
            [2000, 4477, 37.5, 45],
            [2000, 4479, 120, 90],
            [2000, 4481, 120, 90],
            [2000, 4482, 120, 90],
            [2000, 4484, 120, 90],
            [2000, 4486, 120, 90],
            [2000, 4487, 44.33, 51.92],
            [2000, 4488, 70, 70],
            [2000, 4489, 11.71, 6.08],
            [2000, 4490, 120, 90],
            [2000, 4491, 70, 70],
            [2000, 4493, 47.38, 71.88],
            [2000, 4494, 19.4, 18.2],
            [2000, 4495, 74.53, 49.3],
            [2000, 4498, 70, 70],
            [2000, 4500, 18.74, 29.58],
            [2000, 4501, 120, 90],
            [2000, 4502, 50, 60],
            [2000, 4504, 69.49, 38],
            [2000, 4505, 70, 70],
            [2000, 4506, 29.14, 12.62],
            [2000, 4508, 43.63, 35.85],
            [2000, 4509, 120, 90],
            [2000, 4510, 33.56, 26.64],
            [2000, 4511, 70, 70],
            [2000, 4512, 12.38, 7.83],
            [2000, 4513, 40, 50],
            [2000, 4514, 120, 90],
            [2000, 4515, 40.56, 78.59],
            [2000, 4517, 29.39, 25.61],
            [2000, 4518, 72.62, 43.09],
            [2000, 4520, 22.49, 21.03],
            [2000, 4521, 115.81, 56],
            [2000, 4523, 50, 60],
            [2000, 4524, 36.64, 34.46],
            [2000, 4525, 50, 60],
            [2000, 4526, 7.23, 8.94],
            [2000, 4527, 120, 90],
            [2000, 4530, 13.96, 9.89],
            [2000, 4531, 120, 90],
            [2000, 4532, 66.87, 50.91],
            [2000, 4533, 70, 70],
            [2000, 4534, 70, 70],
            [2000, 4535, 70, 70],
            [2000, 4536, 7.2, 20.3],
            [2000, 4538, 18, 18],
            [2000, 4539, 78.64, 44.85],
            [2000, 4540, 10.59, 6.68],
            [2000, 4541, 120, 90],
            [2000, 4542, 65, 35],
            [2000, 4543, 37.5, 45],
            [2000, 4545, 70, 70],
            [2000, 4546, 16.6, 24.9],
            [2000, 4548, 20.54, 15.72],
            [2000, 4549, 23.8, 26.7],
            [2000, 4550, 65.66, 48.34],
            [2000, 4551, 70, 70],
            [2000, 4552, 55.6, 45.56],
            [2000, 4553, 120, 90],
            [2000, 4555, 11.6, 15.4],
            [2000, 4556, 120, 90],
            [2000, 4558, 90.79, 78.09],
            [2000, 4560, 120, 90],
            [2000, 4563, 53.86, 28.78],
            [2000, 4566, 83.86, 83.48],
            [2000, 4568, 50, 60],
            [2000, 4569, 70, 70],
            [2000, 4571, 70, 70],
            [2000, 4572, 105.72, 48.73],
            [2000, 4576, 28.7, 23.7],
            [2000, 4577, 13.21, 11.61],
            [2000, 4578, 90.9, 70],
            [2000, 4579, 8.36, 6.62],
            [2000, 4580, 50, 60],
            [2000, 4582, 70, 70],
            [2000, 4584, 40, 50],
            [2000, 4585, 92.75, 76.06],
            [2000, 4587, 120, 90],
            [2000, 4590, 70, 70],
            [2000, 4591, 38.76, 40.37],
            [2000, 4593, 6.78, 5.29],
            [2000, 4597, 120, 90],
            [2000, 4598, 120, 90],
            [2000, 4599, 120, 90],
            [2000, 4600, 50, 60],
            [2000, 4601, 33.72, 42.28],
            [2000, 4602, 29.41, 34.07],
            [2000, 4603, 120, 90],
            [2000, 4604, 120, 90],
            [2000, 4605, 9.5, 15.6],
            [2000, 4606, 28.45, 30.94],
            [2000, 4607, 120, 90],
            [2000, 4608, 38.4, 32.2],
            [2000, 4610, 70, 70],
            [2000, 4611, 62.95, 50.94],
            [2000, 4612, 70, 70],
            [2000, 4613, 120, 77.8],
            [2000, 4614, 70, 70],
            [2000, 4615, 120, 90],
            [2000, 4616, 27.98, 41.56],
            [2000, 4617, 95.75, 69.39],
            [2000, 4618, 70, 70],
            [2000, 4619, 70, 70],
            [2000, 4620, 70, 70],
            [2000, 4621, 40, 50],
            [2000, 4622, 120, 90],
            [2000, 4623, 18, 27],
            [2000, 4626, 40, 50],
            [2000, 4627, 70, 70],
            [2000, 4628, 120, 90],
            [2000, 4629, 70, 70],
            [2000, 4630, 120, 90],
            [2000, 4631, 20.43, 22.07],
            [2000, 4633, 23.94, 28.78],
            [2000, 4634, 34.71, 35.52],
            [2000, 4635, 16.11, 11.7],
            [2000, 4636, 120, 90],
            [2000, 4637, 70.44, 90],
            [2000, 4638, 54.7, 34.62],
            [2000, 4641, 15.53, 8.78],
            [2000, 4643, 120, 90],
            [2000, 4644, 15.8, 15.4],
            [2000, 4645, 50, 60],
            [2000, 4648, 50, 60],
            [2000, 4649, 50, 60],
            [2000, 4651, 70, 70],
            [2000, 4652, 50, 50],
            [2000, 4653, 120, 90],
            [2000, 4655, 120, 90],
            [2000, 4657, 120, 90],
            [2000, 4658, 70, 70],
            [2000, 4660, 70, 70],
            [2000, 4661, 70, 70],
            [2000, 4662, 70, 70],
            [2000, 4664, 10.86, 8.78],
            [2000, 4665, 120, 90],
            [2000, 4666, 120, 90],
            [2000, 4667, 70, 70],
            [2000, 4668, 62.61, 42.44],
            [2000, 4670, 70, 70],
            [2000, 4671, 120, 90],
            [2000, 4674, 15, 20],
            [2000, 4675, 19.2, 19.5],
            [2000, 4676, 13.79, 18.19],
            [2000, 4677, 70, 70],
            [2000, 4679, 120, 90],
            [2000, 4682, 120, 90],
            [2000, 4684, 39.81, 23.32],
            [2000, 4685, 60.96, 34.44],
            [2000, 4687, 14.2, 21.3],
            [2000, 4688, 17.49, 12.85],
            [2000, 4689, 50, 60],
            [2000, 4690, 70, 70],
            [2000, 4691, 27.06, 17.14],
            [2000, 4692, 3.57, 3.82],
            [2000, 4693, 119.12, 52.9],
            [2000, 4694, 58.78, 40.42],
            [2000, 4695, 70, 70],
            [2000, 4696, 120, 90],
            [2000, 4697, 120, 90],
            [2000, 4698, 70, 70],
            [2000, 4699, 120, 90],
            [2000, 4701, 70, 70],
            [2000, 4702, 120, 90],
            [2000, 4703, 23.69, 36.87],
            [2000, 4704, 120, 90],
            [2000, 4705, 120, 90],
            [2000, 4708, 70, 70],
            [2000, 4709, 120, 90],
            [2000, 4710, 8.73, 6.69],
            [2000, 4711, 34.53, 20.2],
            [2000, 4712, 39.53, 31.14],
            [2000, 4713, 50, 60],
            [2000, 4716, 120, 90],
            [2000, 4717, 16.28, 21.19],
            [2000, 4718, 120, 90],
            [2000, 4720, 49.72, 35.65],
            [2000, 4722, 120, 90],
            [2000, 4724, 47.15, 28.88],
            [2000, 4725, 8.6, 7.78],
            [2000, 4726, 120, 90],
            [2000, 4728, 25.36, 23.41],
            [2000, 4729, 68.67, 36.75],
            [2000, 4731, 4.74, 5.39],
            [2000, 4732, 50, 60],
            [2000, 4733, 86.8, 70],
            [2000, 4734, 20, 20],
            [2000, 4736, 70, 70],
            [2000, 4737, 120, 90],
            [2000, 4738, 50.45, 38.8],
            [2000, 4740, 70, 70],
            [2000, 4741, 50, 60],
            [2000, 4742, 120, 90],
            [2000, 4743, 70, 70],
            [2000, 4744, 40, 50],
            [2000, 4745, 40, 50],
            [2000, 4747, 55.87, 35.31],
            [2000, 4749, 70, 70],
            [2000, 4750, 9.46, 10.97],
            [2000, 4751, 19.36, 32.46],
            [2000, 4752, 70, 70],
            [2000, 4753, 88.11, 37.86],
            [2000, 4754, 120, 90],
            [2000, 4755, 13.77, 7.34],
            [2000, 4756, 129.21, 50],
            [2000, 4757, 120, 90],
            [2000, 4760, 120, 90],
            [2000, 4761, 15.75, 12.37],
            [2000, 4762, 52.5, 52.5],
            [2000, 4764, 46.9, 75],
            [2000, 4765, 50, 60],
            [2000, 4771, 70, 70],
            [2000, 4772, 70, 70],
            [2000, 4775, 70, 70],
            [2000, 4776, 37.5, 45],
            [2000, 4777, 24.04, 33.32],
            [2000, 4778, 50, 60],
            [2000, 4779, 50, 60],
            [2000, 4780, 110.99, 50.6],
            [2000, 4781, 30, 37.5],
            [2000, 4782, 87.14, 72.26],
            [2000, 4784, 120, 90],
            [2000, 4785, 120, 90],
            [2000, 4786, 120, 90],
            [2000, 4788, 6.3, 12.1],
            [2000, 4789, 70, 70],
            [2000, 4790, 70, 70],
            [2000, 4791, 39.76, 77.7],
            [2000, 4792, 92.77, 76.03],
            [2000, 4793, 120, 90],
            [2000, 4794, 41.99, 22.03],
            [2000, 4797, 20.25, 21.58],
            [2000, 4799, 70, 70],
            [2000, 4800, 22.3, 23.87],
            [2000, 4801, 21, 27],
            [2000, 4802, 128.4, 56.12],
            [2000, 4803, 79.74, 17.5],
            [2000, 4805, 16.75, 18],
            [2000, 4806, 70, 70],
            [2000, 4807, 50, 60],
            [2000, 4809, 120, 90],
            [2000, 4810, 120, 90],
            [2000, 4811, 50, 60],
            [2000, 4812, 120, 90],
            [2000, 4813, 60, 131],
            [2000, 4814, 120, 90],
            [2000, 4815, 55.01, 32.18],
            [2000, 4816, 70, 70],
            [2000, 4818, 120, 90],
            [2000, 4819, 57.44, 40.47],
            [2000, 4820, 70, 70],
            [2000, 4821, 120, 90],
            [2000, 4825, 120, 90],
            [2000, 4826, 28.39, 26.06],
            [2000, 4828, 47.32, 22.66],
            [2000, 4829, 45.03, 39.57],
            [2000, 4831, 7.24, 8.44],
            [2000, 4832, 12, 18],
            [2000, 4834, 120, 90],
            [2000, 4835, 51.6, 40.69],
            [2000, 4838, 39.63, 29.51],
            [2000, 4839, 37.82, 38.91],
            [2000, 4840, 70, 70],
            [2000, 4841, 120, 90],
            [2000, 4842, 120, 90],
            [2000, 4844, 59.83, 43.65],
            [2000, 4846, 12.98, 17.47],
            [2000, 4848, 120, 90],
            [2000, 4849, 14.83, 14.22],
            [2000, 4851, 120, 90],
            [2000, 4852, 70, 70],
            [2000, 4853, 10.34, 10.99],
            [2000, 4854, 120, 90],
            [2000, 4856, 12, 18],
            [2000, 4863, 70, 70],
            [2000, 4864, 8.85, 15.97],
            [2000, 4865, 40, 50],
            [2000, 4866, 12, 18],
            [2000, 4867, 38.67, 22.56],
            [2000, 4869, 120, 90],
            [2000, 4871, 21.01, 27.1],
            [2000, 4872, 36.26, 41.54],
            [2000, 4875, 11.1, 18.8],
            [2000, 4876, 40, 50],
            [2000, 4877, 18.65, 29.18],
            [2000, 4878, 50, 60],
            [2000, 4879, 120, 90],
            [2000, 4880, 23.1, 15.3],
            [2000, 4881, 35.37, 49.96],
            [2000, 4882, 120, 90],
            [2000, 4885, 18, 23.69],
            [2000, 4887, 120, 90],
            [2000, 4888, 70, 70],
            [2000, 4893, 53.46, 31.32],
            [2000, 4894, 50, 60],
            [2000, 4895, 120, 90],
            [2000, 4896, 18.2, 35.8],
            [2000, 4897, 22.65, 32.49],
            [2000, 4902, 70, 70],
            [2000, 4905, 40, 50],
            [2000, 4906, 40, 50],
            [2000, 4907, 70, 70],
            [2000, 4909, 17.42, 19.96],
            [2000, 4910, 20.48, 22.01],
            [2000, 4911, 11.82, 7.07],
            [2000, 4912, 12.39, 15.28],
            [2000, 4914, 120, 90],
            [2000, 4915, 12.81, 25.88],
            [2000, 4916, 21.19, 34.67],
            [2000, 4918, 29.8, 29.23],
            [2000, 4920, 40, 50],
            [2000, 4922, 68.28, 37.1],
            [2000, 4923, 120, 90],
            [2000, 4926, 55.14, 28.19],
            [2000, 4927, 28.01, 18.8],
            [2000, 4928, 70, 70],
            [2000, 4929, 70, 70],
            [2000, 4930, 70, 70],
            [2000, 4931, 33.7, 31.78],
            [2000, 4934, 51.99, 38.18],
            [2000, 4936, 120, 90],
            [2000, 4939, 28.05, 30.31],
            [2000, 4940, 95.48, 82.93],
            [2000, 4942, 50, 60],
            [2000, 4944, 18, 18],
            [2000, 4946, 120, 90],
            [2000, 4949, 50, 60],
            [2000, 4950, 70.53, 51.44],
            [2000, 4951, 66.71, 36.01],
            [2000, 4953, 120, 90],
            [2000, 4954, 70, 70],
            [2000, 4955, 29.76, 27.35],
            [2000, 4956, 70, 70],
            [2000, 4957, 64.8, 59.23],
            [2000, 4958, 120, 90],
            [2000, 4960, 106.07, 54.99],
            [2000, 4962, 70, 70],
            [2000, 4963, 31, 51],
            [2000, 4964, 7.37, 6.44],
            [2000, 4965, 42.65, 79.28],
            [2000, 4966, 70, 70],
            [2000, 4968, 120, 90],
            [2000, 4971, 70, 70],
            [2000, 4972, 120, 90],
            [2000, 4973, 34.33, 57.8],
            [2000, 4974, 50, 60],
            [2000, 4975, 52.81, 42.1],
            [2000, 4976, 12, 22.97],
            [2000, 4977, 120, 90],
            [2000, 4978, 120, 90],
            [2000, 4979, 56.77, 40.85],
            [2000, 4981, 50, 50],
            [2000, 4983, 29.76, 20.92],
            [2000, 4984, 20, 13.27],
            [2000, 4985, 6.45, 5.95],
            [2000, 4987, 39.69, 32.93],
            [2000, 4988, 70, 70],
            [2000, 4989, 120, 90],
            [2000, 4990, 106.41, 53.31],
            [2000, 4992, 45.11, 33.84],
            [2000, 4994, 120, 90],
            [2000, 4995, 28.23, 35.68],
            [2000, 4996, 16.69, 30.91],
            [2000, 4997, 26.79, 20.82],
            [2000, 4998, 49.03, 43.06],
            [2000, 5000, 13.36, 12.29],
            [2000, 5001, 70, 70],
            [2000, 5002, 120, 90],
            [2000, 5003, 120, 90],
            [2000, 5005, 17.46, 22.11],
            [2000, 5006, 112, 90],
            [2000, 5007, 120, 90],
            [2000, 5008, 126.38, 53.28],
            [2000, 5009, 18.59, 27.74],
            [2000, 5010, 8.39, 5.61],
            [2000, 5011, 21.98, 26],
            [2000, 5012, 35.55, 43.28],
            [2000, 5013, 46.69, 34.25],
            [2000, 5014, 61.9, 35.6],
            [2000, 5017, 13.52, 21.99],
            [2000, 5019, 70, 45.82],
            [2000, 5020, 32.11, 40.08],
            [2000, 5022, 137.19, 88.29],
            [2000, 5023, 70, 70],
            [2000, 5025, 120, 90],
            [2000, 5026, 120, 90],
            [2000, 5027, 24.1, 26.31],
            [2000, 5031, 10, 16],
            [2000, 5032, 26.02, 40.08],
            [2000, 5033, 40.97, 26.68],
            [2000, 5035, 47.55, 39.99],
            [2000, 5037, 91.49, 46.75],
            [2000, 5038, 18, 27],
            [2000, 5041, 120, 90],
            [2000, 5043, 50, 60],
            [2000, 5044, 70, 70],
            [2000, 5046, 59.27, 44.08],
            [2000, 5048, 17.82, 19.75],
            [2000, 5049, 120, 90],
            [2000, 5050, 20.33, 12.35],
            [2000, 5051, 12, 18],
            [2000, 5053, 77.54, 45.07],
            [2000, 5054, 45.4, 28.5],
            [2000, 5056, 120, 90],
            [2000, 5057, 120, 90],
            [2000, 5058, 48.62, 42.89],
            [2000, 5060, 120, 90],
            [2000, 5061, 120, 90],
            [2000, 5062, 67.65, 70],
            [2000, 5063, 20.35, 50],
            [2000, 5064, 20.75, 20.03],
            [2000, 5065, 100.18, 69.74],
            [2000, 5066, 120, 90],
            [2000, 5068, 164.36, 62.76],
            [2000, 5069, 149.63, 54.69],
            [2000, 5070, 13.6, 28.86],
            [2000, 5071, 34.13, 33.6],
            [2000, 5072, 120, 90],
            [2000, 5073, 50, 60],
            [2000, 5075, 21.04, 24.86],
            [2000, 5077, 40, 50],
            [2000, 5079, 30.65, 35.97],
            [2000, 5081, 120, 90],
            [2000, 5082, 9.69, 9.33],
            [2000, 5083, 5.36, 5.53],
            [2000, 5084, 50, 60],
            [2000, 5085, 41.13, 26.96],
            [2000, 5091, 40.5, 33.65],
            [2000, 5092, 10, 16],
            [2000, 5093, 50, 60],
            [2000, 5094, 36.74, 43],
            [2000, 5095, 13.3, 17.3],
            [2000, 5097, 120, 90],
            [2000, 5098, 47.81, 29.86],
            [2000, 5099, 58.83, 35.89],
            [2000, 5100, 120, 90],
            [2000, 5101, 5.93, 6.13],
            [2000, 5102, 35.03, 31.53],
            [2000, 5103, 89.21, 43],
            [2000, 5104, 120, 90],
            [2000, 5107, 70, 65],
            [2000, 5108, 25, 40],
            [2000, 5109, 55.7, 36.5],
            [2000, 5111, 120, 90],
            [2000, 5114, 4.87, 4],
            [2000, 5115, 12.26, 31.18],
            [2000, 5116, 26.44, 21.57],
            [2000, 5117, 40, 50],
            [2000, 5119, 120, 90],
            [2000, 5121, 36.95, 67.11],
            [2000, 5122, 21.51, 31.21],
            [2000, 5123, 11.8, 11.02],
            [2000, 5124, 56.09, 43.95],
            [2000, 5126, 26.81, 24.11],
            [2000, 5127, 18.25, 11.14],
            [2000, 5128, 70, 70],
            [2000, 5130, 50, 60],
            [2000, 5132, 120, 90],
            [2000, 5135, 68.8, 41.77],
            [2000, 5136, 10.18, 8.06],
            [2000, 5137, 120, 90],
            [2000, 5138, 15.14, 13.83],
            [2000, 5141, 24.58, 21.45],
            [2000, 5143, 70, 70],
            [2000, 5145, 120, 90],
            [2000, 5149, 120, 90],
            [2000, 5150, 52.83, 33.37],
            [2000, 5153, 179.52, 59.91],
            [2000, 5154, 70, 90],
            [2000, 5155, 70, 70],
            [2000, 5156, 40, 50],
            [2000, 5157, 50, 60],
            [2000, 5159, 52.86, 48.43],
            [2000, 5160, 120, 90],
            [2000, 5161, 17.42, 15.54],
            [2000, 5162, 65.6, 46.34],
            [2000, 5163, 120, 90],
            [2000, 5164, 120, 90],
            [2000, 5165, 3.38, 5.47],
            [2000, 5166, 33.73, 21.58],
            [2000, 5167, 120, 90],
            [2000, 5169, 56.5, 44.9],
            [2000, 5171, 249.75, 64.69],
            [2000, 5172, 70, 70],
            [2000, 5173, 46.38, 41.15],
            [2000, 5174, 143.07, 72.47],
            [2000, 5178, 120, 90],
            [2000, 5180, 86.39, 54.81],
            [2000, 5181, 120, 90],
            [2000, 5182, 16.01, 20.04],
            [2000, 5183, 30.55, 36.38],
            [2000, 5184, 25, 30.44],
            [2000, 5185, 22.64, 29.76],
            [2000, 5186, 12, 18],
            [2000, 5187, 12, 18],
            [2000, 5188, 12, 18],
            [2000, 5189, 32, 40],
            [2000, 5191, 50, 25],
            [2000, 5192, 15, 25],
            [2000, 5193, 15, 25],
            [2000, 5194, 15, 25],
            [2000, 5197, 15, 25],
            [2000, 5198, 15, 25],
            [2000, 5202, 15, 25],
            [2000, 5203, 15, 25],
            [2000, 5204, 40, 50],
            [2000, 5205, 15, 25],
            [2000, 5206, 15, 25],
            [2000, 5207, 15, 25],
            [2000, 5209, 15, 25],
            [2000, 5212, 15, 25],
            [2000, 5213, 15, 25],
            [2000, 5214, 15, 25],
            [2000, 5215, 15, 25],
            [2000, 5216, 15, 25],
            [2000, 5217, 70, 70],
            [2000, 5218, 50, 60],
            [2000, 5219, 20.7, 31.7],
            [2000, 5220, 12.6, 25.3],
            [2000, 5221, 14.8, 27.6],
            [2000, 5222, 23, 18.2],
            [2000, 5223, 10.5, 15.3],
            [2000, 5224, 16.8, 30.5],
            [2000, 5225, 21.5, 24.2],
            [2000, 5226, 8.5, 20.2],
            [2000, 5227, 55.9, 46.8],
            [2000, 5228, 18.7, 32.7],
            [2000, 5229, 7, 15.8],
            [2000, 5230, 15.5, 13.1],
            [2000, 5231, 15.2, 18.9],
            [2000, 5232, 26.7, 34.4],
            [2000, 5233, 22.9, 36.3],
            [2000, 5234, 10.9, 17.5],
            [2000, 5235, 43.7, 39.9],
            [2000, 5236, 15.6, 18.9],
            [2000, 5237, 27.3, 31.4],
            [2000, 5238, 23.1, 25.3],
            [2000, 5239, 23.3, 28.2],
            [2000, 5240, 17, 31.3],
            [2000, 5241, 26.1, 21.4],
            [2000, 5242, 25.2, 23.2],
            [2000, 5243, 28.2, 26.9],
            [2000, 5244, 20.5, 30],
            [2000, 5245, 21.3, 30],
            [2000, 5247, 80, 60],
            [2000, 5248, 80, 60],
            [2000, 5249, 19.35, 11.59],
            [2000, 5250, 20.93, 10.99],
            [2000, 5251, 10.39, 7.22],
            [2000, 5252, 30, 16.38],
            [2000, 5253, 11.8, 10.66],
            [2000, 5254, 25.42, 16.32],
            [2000, 5255, 23.04, 14.71],
            [2000, 5256, 24.56, 17.38],
            [2000, 5257, 15.4, 13.96],
            [2000, 5258, 23.85, 19.14],
            [2000, 5259, 10.2, 9.75],
            [2000, 5260, 14.55, 9.36],
            [2000, 5261, 24.59, 17.95],
            [2000, 5262, 13.46, 12.24],
            [2000, 5263, 19.45, 15.67],
            [2000, 5264, 70, 50.86],
            [2000, 5265, 7.91, 11.54],
            [2000, 5266, 24.83, 17.86],
            [2000, 5267, 21.83, 15.71],
            [2000, 5268, 15.77, 15],
            [2000, 5269, 14.5, 9.26],
            [2000, 5270, 13.36, 17.93],
            [2000, 5271, 70, 70],
            [2000, 5272, 49.88, 21.16],
            [2000, 5273, 27.17, 19.34],
            [2000, 5274, 21.56, 23.35],
            [2000, 5275, 21.89, 20.99],
            [2000, 5276, 33.57, 69.59],
            [2000, 5277, 33.53, 44.16],
            [2000, 5278, 17.61, 19.46],
            [2000, 5279, 22.19, 26.31],
            [2000, 5280, 54.9, 42.95],
            [2000, 5281, 23.97, 21.11],
            [2000, 5282, 18.86, 21.15],
            [2000, 5283, 14.72, 24.85],
            [2000, 5284, 19.82, 21.97],
            [2000, 5285, 12.98, 10.05],
            [2000, 5286, 21.47, 25.37],
            [2000, 5287, 12.95, 13.1],
            [2000, 5288, 15.79, 13.5],
            [2000, 5289, 14.72, 18.53],
            [2000, 5290, 23.09, 21.92],
            [2000, 5291, 13.74, 15.42],
            [2000, 5292, 27.71, 17.72],
            [2000, 5293, 31.42, 28.8],
            [2000, 5294, 27.26, 35.13],
            [2000, 5295, 17.19, 14.3],
            [2000, 5296, 37.77, 51.52],
            [2000, 5297, 36.44, 42.37],
            [2000, 5298, 13.26, 13.27],
            [2000, 5299, 18.16, 20.87],
            [2000, 5300, 19.04, 16.88],
            [2000, 5301, 42.73, 37.25],
            [2000, 5302, 9.07, 5.65],
            [2000, 5303, 36.15, 21.1],
            [2000, 5304, 19.35, 28.15],
            [2000, 5305, 28.21, 24.21],
            [2000, 5306, 30.08, 35.59],
            [2000, 5307, 28.82, 42.89],
            [2000, 5308, 30.68, 46.96],
            [2000, 5309, 22.98, 21.99],
            [2000, 5310, 18.38, 19.26],
            [2000, 5311, 14.95, 17.32],
            [2000, 5312, 24.78, 19.47],
            [2000, 5313, 14.05, 18.92],
            [2000, 5314, 22.31, 24.96],
            [2000, 5315, 19.95, 27.16],
            [2000, 5316, 34.5, 42.49],
            [2000, 5317, 47.68, 75.34],
            [2000, 5318, 30.3, 21.67],
            [2000, 5319, 13.84, 14.27],
            [2000, 5320, 53.44, 55.56],
            [2000, 5321, 21.43, 22.1],
            [2000, 5322, 21.86, 31.16],
            [2000, 5323, 13.54, 22.48],
            [2000, 5324, 28.56, 35.07],
            [2000, 5325, 16.07, 19.54],
            [2000, 5326, 34.56, 41.14],
            [2000, 5327, 16.58, 21.05],
            [2000, 5328, 21.03, 21.33],
            [2000, 5329, 17.44, 17.44],
            [2000, 5330, 28.89, 22.93],
            [2000, 5331, 20.27, 21.28],
            [2000, 5332, 24.04, 29.18],
            [2000, 5333, 13.04, 16.32],
            [2000, 5334, 14.81, 13.78],
            [2000, 5335, 19.89, 15.44],
            [2000, 5336, 16.38, 19.14],
            [2000, 5337, 17.09, 17.7],
            [2000, 5338, 33.77, 26.64],
            [2000, 5339, 21.48, 24.94],
            [2000, 5340, 31.28, 38.93],
            [2000, 5341, 21.6, 30.78],
            [2000, 5342, 67.33, 44.59],
            [2000, 5343, 16.6, 14.81],
            [2000, 5344, 47.23, 50.54],
            [2000, 5345, 17.36, 20.76],
            [2000, 5346, 12.53, 15.06],
            [2000, 5347, 20.45, 23.78],
            [2000, 5348, 18.99, 19.54],
            [2000, 5349, 23.6, 27.71],
            [2000, 5350, 17.87, 30.23],
            [2000, 5351, 25.6, 34.49],
            [2000, 5352, 12.65, 19.75],
            [2000, 5353, 20.64, 26.6],
            [2000, 5354, 15.47, 9.25],
            [2000, 5355, 24.3, 42.86],
            [2000, 5356, 15.64, 19.61],
            [2000, 5357, 30.99, 21.01],
            [2000, 5358, 18.44, 20.69],
            [2000, 5359, 17.32, 25.16],
            [2000, 5360, 14.69, 9.66],
            [2000, 5361, 25.44, 28.51],
            [2000, 5362, 22.78, 37.54],
            [2000, 5363, 17.15, 20.75],
            [2000, 5364, 27.13, 35.08],
            [2000, 5365, 14.15, 16.33],
            [2000, 5366, 31.71, 24.96],
            [2000, 5367, 18.39, 19.03],
            [2000, 5368, 25.49, 33.82],
            [2000, 5369, 17.87, 17.73],
            [2000, 5370, 26.37, 19.9],
            [2000, 5371, 34.48, 40.39],
            [2000, 5372, 23.31, 23.21],
            [2000, 5373, 39.81, 52.34],
            [2000, 5374, 38.4, 30.66],
            [2000, 5375, 20.13, 18.67],
            [2000, 5376, 39.93, 36.29],
            [2000, 5377, 17.78, 19.64],
            [2000, 5378, 44.16, 54.79],
            [2000, 5379, 17.59, 16],
            [2000, 5380, 19.5, 24.07],
            [2000, 5381, 24.54, 27.3],
            [2000, 5382, 27.26, 39.02],
            [2000, 5383, 24.98, 28.96],
            [2000, 5384, 32.06, 28.26],
            [2000, 5385, 35.75, 25.11],
            [2000, 5386, 12.39, 14.93],
            [2000, 5387, 16.52, 16.08],
            [2000, 5388, 28.27, 31.03],
            [2000, 5389, 21.28, 32.3],
            [2000, 5390, 27.81, 21.8],
            [2000, 5391, 15.92, 17.92],
            [2000, 5392, 18.92, 29.5],
            [2000, 5393, 21.42, 30.33],
            [2000, 5394, 25.56, 27.95],
            [2000, 5395, 15.36, 21.7],
            [2000, 5396, 24.37, 24.45],
            [2000, 5397, 37.72, 55.15],
            [2000, 5398, 22.54, 21.56],
            [2000, 5399, 30.96, 24.28],
            [2000, 5400, 13.97, 12.67],
            [2000, 5401, 27.87, 36.25],
            [2000, 5402, 25.63, 36.95],
            [2000, 5403, 24.28, 25.06],
            [2000, 5404, 24.46, 24.68],
            [2000, 5405, 17.96, 16.23],
            [2000, 5406, 26.71, 28.04],
            [2000, 5407, 20.69, 24.62],
            [2000, 5408, 18.11, 22.5],
            [2000, 5409, 31.73, 36.57],
            [2000, 5410, 58.51, 46.49],
            [2000, 5411, 27.68, 21.48],
            [2000, 5412, 23.04, 18.15],
            [2000, 5413, 23.32, 18.19],
            [2000, 5414, 9.91, 15.09],
            [2000, 5415, 51.57, 56.26],
            [2000, 5416, 12.77, 13.87],
            [2000, 5417, 23.61, 19.35],
            [2000, 5418, 28.79, 36.91],
            [2000, 5419, 27.19, 25.1],
            [2000, 5420, 16.27, 16.14],
            [2000, 5421, 18.76, 15.11],
            [2000, 5422, 25.14, 34.37],
            [2000, 5423, 35.81, 32.77],
            [2000, 5424, 17.07, 19.91],
            [2000, 5425, 16.63, 19.74],
            [2000, 5426, 22.35, 32.83],
            [2000, 5427, 30.13, 36.75],
            [2000, 5428, 18.88, 25.12],
            [2000, 5429, 14.33, 16.18],
            [2000, 5430, 35.21, 32.17],
            [2000, 5431, 21.98, 23.51],
            [2000, 5432, 22.49, 30.65],
            [2000, 5433, 22.03, 25.8],
            [2000, 5434, 15.65, 16.63],
            [2000, 5435, 28.65, 36.45],
            [2000, 5436, 22.2, 26.91],
            [2000, 5437, 28.46, 24.42],
            [2000, 5438, 26.15, 45.07],
            [2000, 5439, 23.1, 32.12],
            [2000, 5440, 42.61, 31.07],
            [2000, 5441, 31.6, 43.27],
            [2000, 5442, 27.28, 31.24],
            [2000, 5443, 27.08, 44.53],
            [2000, 5444, 21.92, 35.18],
            [2000, 5445, 16.8, 20.91],
            [2000, 5446, 28.06, 29.76],
            [2000, 5447, 20.25, 23.23],
            [2000, 5448, 18.61, 19.97],
            [2000, 5449, 26.78, 33.16],
            [2000, 5450, 28.76, 31.21],
            [2000, 5451, 36.55, 47.48],
            [2000, 5452, 22.51, 34.53],
            [2000, 5453, 28.94, 32.53],
            [2000, 5454, 12.32, 16.18],
            [2000, 5455, 28.32, 21.25],
            [2000, 5456, 21.35, 24.85],
            [2000, 5457, 16.87, 25.48],
            [2000, 5458, 18.67, 22.48],
            [2000, 5459, 25.03, 25.93],
            [2000, 5460, 15.43, 17.97],
            [2000, 5461, 18.92, 17.99],
            [2000, 5462, 22.52, 26.38],
            [2000, 5463, 14.28, 17.95],
            [2000, 5464, 18.6, 18.27],
            [2000, 5465, 23.82, 23.85],
            [2000, 5466, 18.5, 23.11],
            [2000, 5467, 21.73, 26.16],
            [2000, 5468, 48, 70],
            [2000, 5469, 28.95, 22.5],
            [2000, 5470, 18.2, 26.19],
            [2000, 5471, 21.88, 24.32],
            [2000, 5472, 24.34, 29.62],
            [2000, 5473, 18.21, 24.01],
            [2000, 5474, 15.15, 14.65],
            [2000, 5475, 19.39, 18.75],
            [2000, 5476, 15.52, 20.64],
            [2000, 5477, 11.66, 13.63],
            [2000, 5478, 18.69, 21.99],
            [2000, 5479, 20.66, 18.21],
            [2000, 5480, 38.45, 32.17],
            [2000, 5481, 15.98, 18.15],
            [2000, 5482, 17.06, 18.76],
            [2000, 5483, 25.35, 27.15],
            [2000, 5484, 22.09, 21.1],
            [2000, 5485, 22.02, 23.57],
            [2000, 5486, 22.14, 21.65],
            [2000, 5487, 17.97, 21.38],
            [2000, 5488, 24.02, 25.06],
            [2000, 5489, 34.19, 66.05],
            [2000, 5490, 28.94, 32.56],
            [2000, 5491, 15.88, 20.08],
            [2000, 5492, 22.58, 38.47],
            [2000, 5493, 27.68, 21.75],
            [2000, 5494, 25.82, 30.23],
            [2000, 5495, 33.94, 27.03],
            [2000, 5496, 70, 70],
            [2000, 5497, 18.35, 22.55],
            [2000, 5498, 27.02, 39.89],
            [2000, 5499, 33.57, 24.3],
            [2000, 5500, 22.47, 23.4],
            [2000, 5501, 27.13, 46.22],
            [2000, 5502, 29.4, 31.24],
            [2000, 5503, 25.48, 24.22],
            [2000, 5504, 29.82, 41.45],
            [2000, 5505, 19.44, 30.38],
            [2000, 5506, 19.55, 18.02],
            [2000, 5507, 8.92, 15.03],
            [2000, 5508, 25.07, 35.23],
            [2000, 5509, 25.6, 36.32],
            [2000, 5510, 23.88, 39.9],
            [2000, 5511, 27.52, 24.5],
            [2000, 5512, 11.13, 11.46],
            [2000, 5513, 20.91, 23.63],
            [2000, 5514, 17.98, 18.09],
            [2000, 5515, 38.99, 31.52],
            [2000, 5516, 24.35, 34.55],
            [2000, 5517, 22.32, 28.37],
            [2000, 5518, 19.91, 18.99],
            [2000, 5519, 31.61, 40.04],
            [2000, 5520, 22.33, 22.91],
            [2000, 5521, 33.45, 39.31],
            [2000, 5522, 20.71, 22.53],
            [2000, 5523, 26.18, 29.99],
            [2000, 5524, 21.48, 50.1],
            [2000, 5525, 22.24, 21.41],
            [2000, 5526, 32.51, 26.74],
            [2000, 5527, 30.84, 34.66],
            [2000, 5528, 20.96, 19.72],
            [2000, 5529, 59.13, 37.8],
            [2000, 5530, 19.55, 21.33],
            [2000, 5531, 24.12, 22.95],
            [2000, 5532, 25.42, 24.65],
            [2000, 5533, 14.52, 14.84],
            [2000, 5534, 17.4, 14.87],
            [2000, 5535, 15.5, 12.89],
            [2000, 5536, 2, 2],
            [2000, 5537, 12.2, 8.94],
            [2000, 5538, 37.26, 35.28],
            [2000, 5539, 14.86, 20],
            [2000, 5540, 23.95, 34.62],
            [2000, 5541, 26.12, 21.77],
            [2000, 5542, 12.8, 16.15],
            [2000, 5543, 12.26, 16.58],
            [2000, 5544, 22.77, 32.88],
            [2000, 5545, 16.25, 22.22],
            [2000, 5546, 34.03, 40.31],
            [2000, 5547, 26.1, 25.13],
            [2000, 5548, 38.2, 46.39],
            [2000, 5549, 16.23, 22.79],
            [2000, 5550, 16.66, 17.46],
            [2000, 5551, 47.85, 70],
            [2000, 5552, 28.07, 25.33],
            [2000, 5553, 31.7, 29.24],
            [2000, 5554, 26.98, 30.18],
            [2000, 5555, 32.21, 32.76],
            [2000, 5556, 17.16, 17.29],
            [2000, 5557, 15.34, 14.19],
            [2000, 5558, 14.56, 19.66],
            [2000, 5559, 30.04, 31.58],
            [2000, 5560, 74.52, 28.37],
            [2000, 5561, 38.69, 49.15],
            [2000, 5562, 40.29, 56.03],
            [2000, 5563, 33.52, 34.96],
            [2000, 5564, 70, 56.53],
            [2000, 5565, 19.45, 18.12],
            [2000, 5566, 24.67, 27.3],
            [2000, 5567, 28.59, 35.72],
            [2000, 5568, 26.89, 35.03],
            [2000, 5569, 51.02, 38.85],
            [2000, 5570, 37.26, 27.17],
            [2000, 5571, 28.9, 21.65],
            [2000, 5572, 20.43, 17.7],
            [2000, 5573, 42.96, 28.46],
            [2000, 5590, 70, 70],
            [2000, 5600, 70, 70],
            [2000, 5618, 60, 132],
            [2000, 5621, 59, 48],
            [2000, 5624, 79, 140],
            [2000, 5625, 46, 70],
            [2000, 5627, 45, 70],
            [2000, 5632, 50, 70],
            [2000, 5636, 50, 60],
            [2000, 5638, 40, 50],
            [2000, 5646, 120, 90],
            [2000, 5648, 58, 90],
            [2000, 5649, 50, 60],
            [2000, 5659, 5.35, 4.7],
            [2000, 5660, 7.67, 7.45],
            [2000, 5661, 70, 70],
            [2000, 5663, 120, 90],
            [2000, 5666, 120, 90],
            [2000, 5672, 70, 70],
            [2000, 5675, 40, 50],
            [2000, 5677, 120, 90],
            [2000, 5681, 70, 70],
            [2000, 5683, 120, 90],
            [2000, 5689, 120, 90],
            [2000, 5706, 120, 90],
            [2000, 5715, 70, 70],
            [2000, 5717, 120, 90],
            [2000, 5720, 70, 70],
            [2000, 5726, 120, 90],
            [2000, 5728, 120, 90],
            [2000, 5737, 120, 90],
            [2000, 5738, 120, 90],
            [2000, 5745, 70, 70],
            [2000, 5747, 120, 90],
            [2000, 5757, 40, 50],
            [2000, 5758, 70, 70],
            [2000, 5764, 50, 60],
            [2000, 5768, 70, 70],
            [2000, 5777, 120, 90],
            [2000, 5789, 40, 50],
            [2000, 5805, 120, 90],
            [2000, 5808, 70, 70],
            [2000, 5811, 120, 90],
            [2000, 5819, 120, 90],
            [2000, 5824, 70, 70],
            [2000, 5830, 70, 70],
            [2000, 5833, 120, 90],
            [2000, 5840, 120, 90],
            [2000, 5841, 120, 90],
            [2000, 5846, 120, 90],
            [2000, 5848, 120, 90],
            [2000, 5851, 120, 90],
            [2000, 5855, 50, 50],
            [2000, 5856, 40, 50],
            [2000, 5861, 120, 90],
            [2000, 5869, 120, 90],
            [2000, 5876, 120, 90],
            [2000, 5877, 120, 90],
            [2000, 5880, 50, 60],
            [2000, 5881, 70, 70],
            [2000, 5882, 70, 70],
            [2000, 5884, 120, 90],
            [2000, 5889, 70, 70],
            [2000, 5898, 120, 90],
            [2000, 5903, 70, 70],
            [2000, 5911, 120, 90],
            [2000, 5917, 120, 90],
            [2000, 5918, 120, 90],
            [2000, 5919, 70, 70],
            [2000, 5931, 70, 70],
            [2000, 5933, 40, 50],
            [2000, 5936, 70, 70],
            [2000, 5939, 120, 90],
            [2000, 5941, 120, 90],
            [2000, 5942, 120, 90],
            [2000, 5943, 120, 90],
            [2000, 5944, 40, 50],
            [2000, 5945, 40, 50],
            [2000, 5946, 40, 50],
            [2000, 5947, 120, 90],
            [2000, 5948, 120, 90],
            [2000, 5949, 120, 90],
            [2000, 5950, 120, 90],
            [2000, 5951, 120, 90],
            [2000, 5953, 120, 90],
            [2000, 5954, 120, 90],
            [2000, 5955, 120, 90],
            [2000, 5956, 120, 90],
            [2000, 5957, 120, 90],
            [2000, 5958, 40, 50],
            [2000, 5959, 40, 50],
            [2000, 5961, 40, 50],
            [2000, 5962, 50, 60],
            [2000, 5964, 120, 90],
            [2000, 5965, 28, 90],
            [2000, 5966, 68, 80],
            [2000, 5967, 41, 60],
            [2000, 5968, 120, 117],
            [2000, 5969, 56, 70],
            [2000, 5970, 70, 70],
            [2000, 5985, 15, 25],
            [2000, 5986, 50, 60],
            [2000, 5987, 15, 25],
            [2000, 5988, 21, 33],
            [2000, 5989, 50, 60],
            [2000, 5990, 50, 60],
            [2000, 5991, 50, 60],
            [2000, 5992, 50, 60],
            [2000, 5993, 50, 60],
            [2000, 5994, 60.08, 60],
            [2000, 5995, 70, 70],
            [2000, 5996, 70, 70],
            [2000, 5997, 70, 70],
            [2000, 5998, 120, 90],
            [2000, 5999, 50, 60],
            [2000, 6049, 70, 70],
            [2000, 6050, 70, 70],
            [2000, 6051, 70, 70],
            [2000, 6052, 120, 90],
            [2000, 6053, 120, 90],
            [2000, 6054, 120, 90],
            [2000, 6055, 52.5, 52.5],
            [2000, 6066, 37.5, 45],
            [2000, 6067, 15, 25],
            [2000, 6068, 120, 90],
            [2000, 6069, 70, 70],
            [2000, 6070, 70, 70],
            [2000, 6071, 49, 49],
            [2000, 6072, 40, 50],
            [2000, 6073, 49, 49],
            [2000, 6074, 49, 49],
            [2000, 6075, 70, 70],
            [2000, 6076, 50, 60],
            [2000, 6077, 49, 49],
            [2000, 6078, 50, 60],
            [2000, 6079, 49, 49],
            [2000, 6080, 70, 70],
            [2000, 6081, 38, 45],
            [2000, 6082, 49, 49],
            [2000, 6083, 49, 49],
            [2000, 6084, 84, 63],
            [2000, 6085, 84, 63],
            [2000, 6086, 35, 42],
            [2000, 6087, 49, 49],
            [2000, 6088, 49, 49],
            [2000, 6089, 49, 49],
            [2000, 6090, 84, 63],
            [2000, 6091, 49, 49],
            [2000, 6092, 49, 49],
            [2000, 6093, 49, 49],
            [2000, 6094, 49, 49],
            [2000, 6095, 35, 42],
            [2000, 6096, 49, 49],
            [2000, 6097, 49, 49],
            [2000, 6098, 49, 49],
            [2000, 6099, 84, 63],
            [2000, 6100, 49, 49],
            [2000, 6101, 49, 49],
            [2000, 6102, 35, 42],
            [2000, 6103, 49, 49],
            [2000, 6104, 84, 63],
            [2000, 6105, 84, 63],
            [2000, 6106, 49, 49],
            [2000, 6107, 49, 49],
            [2000, 6108, 49, 49],
            [2000, 6109, 35, 42],
            [2000, 6110, 49, 49],
            [2000, 6111, 24, 36],
            [2000, 6112, 49, 49],
            [2000, 6113, 42, 42],
            [2000, 6114, 35, 42],
            [2000, 6115, 35, 42],
            [2000, 6116, 49, 49],
            [2000, 6117, 49, 49],
            [2000, 6118, 49, 49],
            [2000, 6119, 49, 49],
            [2000, 6120, 28, 35],
            [2000, 6121, 49, 49],
            [2000, 6122, 49, 49],
            [2000, 6123, 49, 49],
            [2000, 6124, 49, 49],
            [2000, 6125, 49, 49],
            [2000, 6126, 49, 49],
            [2000, 6127, 49, 49],
            [2000, 6128, 49, 49],
            [2000, 6129, 28, 35],
            [2000, 6130, 49, 49],
            [2000, 6131, 49, 49],
            [2000, 6132, 49, 49],
            [2000, 6133, 49, 49],
            [2000, 6134, 49, 49],
            [2000, 6135, 49, 49],
            [2000, 6136, 70, 70],
            [2000, 6137, 28, 35],
            [2000, 6138, 35, 42],
            [2000, 6139, 49, 49],
            [2000, 6140, 28, 35],
            [2000, 6141, 49, 49],
            [2000, 6142, 35, 42],
            [2000, 6143, 49, 49],
            [2000, 6144, 42, 42],
            [2000, 6145, 49, 49],
            [2000, 6146, 24, 36],
            [2000, 6147, 40, 50],
            [2000, 6148, 32, 40],
            [2000, 6149, 49, 49],
            [2000, 6150, 28, 35],
            [2000, 6151, 49, 49],
            [2000, 6152, 28, 35],
            [2000, 6153, 28, 35],
            [2000, 6154, 49, 49],
            [2000, 6155, 30, 38],
            [2000, 6156, 35, 42],
            [2000, 6157, 49, 49],
            [2000, 6158, 35, 42],
            [2000, 6159, 49, 49],
            [2000, 6160, 35, 42],
            [2000, 6161, 28, 35],
            [2000, 6162, 35, 42],
            [2000, 6163, 50, 60],
            [2000, 6164, 49, 49],
            [2000, 6165, 35, 42],
            [2000, 6166, 70, 70],
            [2000, 6167, 70, 70],
            [2000, 6168, 24, 36],
            [2000, 6169, 24, 36],
            [2000, 6170, 24, 36],
            [2000, 6227, 120, 90],
            [2000, 6228, 15, 25],
            [2000, 6229, 15, 25],
            [2000, 6230, 50, 60],
            [2000, 6231, 50, 60],
            [2000, 6232, 50, 60],
            [2000, 6233, 70, 70],
            [2000, 6234, 50, 60],
            [2000, 6235, 50, 60],
            [2000, 6236, 50, 60],
            [2000, 6238, 70, 70],
            [2000, 6239, 50, 60],
            [2000, 6240, 50, 60],
            [2000, 6241, 50, 60],
            [2000, 6242, 50, 60],
            [2000, 6243, 70, 70],
            [2000, 6244, 70, 70],
            [2000, 6245, 50, 60],
            [2000, 6246, 70, 70],
            [2000, 6247, 50, 60],
            [2000, 6248, 30, 45],
            [2000, 6252, 50, 60],
            [2000, 6253, 120, 90],
            [2000, 6255, 70, 70],
            [2000, 6256, 50, 60],
            [2000, 6258, 50, 60],
            [2000, 6259, 120, 90],
            [2000, 6260, 120, 90],
            [2000, 6261, 70, 70],
            [2000, 6262, 70, 70],
            [2000, 6263, 120, 90],
            [2000, 6264, 70, 70],
            [2000, 6265, 70, 70],
            [2000, 6266, 50, 60],
            [2000, 6267, 50, 60],
            [2000, 6268, 70, 70],
            [2000, 6269, 50, 60],
            [2000, 6270, 50, 60],
            [2000, 6271, 70, 70],
            [2000, 6272, 40, 50],
            [2000, 6274, 70, 70],
            [2000, 6275, 70, 70],
            [2000, 6276, 50, 60],
            [2000, 6277, 120, 90],
            [2000, 6278, 70, 70],
            [2000, 6279, 70, 70],
            [2000, 6280, 70, 70],
            [2000, 6281, 70, 70],
            [2000, 6282, 50, 60],
            [2000, 6283, 70, 70],
            [2000, 6284, 50, 60],
            [2000, 6286, 70, 70],
            [2000, 6287, 50, 60],
            [2000, 6288, 70, 70],
            [2000, 6289, 50, 60],
            [2000, 6290, 120, 90],
            [2000, 6292, 70, 70],
            [2000, 6293, 70, 70],
            [2000, 6294, 120, 90],
            [2000, 6295, 120, 90],
            [2000, 6296, 70, 70],
            [2000, 6297, 120, 90],
            [2000, 6299, 70, 70],
            [2000, 6300, 70, 70],
            [2000, 6301, 70, 70],
            [2000, 6302, 70, 70],
            [2000, 6303, 70, 70],
            [2000, 6305, 120, 90],
            [2000, 6306, 70, 70],
            [2000, 6307, 120, 90],
            [2000, 6308, 120, 90],
            [2000, 6309, 70, 70],
            [2000, 6310, 50, 60],
            [2000, 6312, 120, 90],
            [2000, 6313, 70, 70],
            [2000, 6314, 120, 90],
            [2000, 6315, 70, 70],
            [2000, 6316, 70, 70],
            [2000, 6317, 70, 70],
            [2000, 6319, 50, 60],
            [2000, 6320, 70, 70],
            [2000, 6321, 70, 70],
            [2000, 6323, 50, 60],
            [2000, 6324, 50, 60],
            [2000, 6325, 120, 90],
            [2000, 6326, 70, 70],
            [2000, 6327, 50, 60],
            [2000, 6328, 120, 90],
            [2000, 6330, 120, 90],
            [2000, 6334, 17.01, 16],
            [2000, 6335, 22.88, 20.17],
            [2000, 6336, 34, 36.4],
            [2000, 6337, 22.28, 16.2],
            [2000, 6338, 35, 27.18],
            [2000, 6339, 20.53, 16.19],
            [2000, 6340, 34, 36.69],
            [2000, 6341, 28.74, 25],
            [2000, 6342, 22.3, 20],
            [2000, 6343, 28.6, 33.48],
            [2000, 6344, 22.3, 21.5],
            [2000, 6345, 31.99, 26.94],
            [2000, 6346, 30, 21.24],
            [2000, 6347, 22.82, 20],
            [2000, 6348, 40.24, 30],
            [2000, 6349, 20.84, 24.13],
            [2000, 6350, 22.32, 30],
            [2000, 6351, 29.17, 16.2],
            [2000, 6353, 40, 50],
            [2000, 6354, 40, 50],
            [2000, 6355, 30, 45],
            [2000, 6356, 50, 60],
            [2000, 6357, 70, 70],
            [2000, 6358, 40, 50],
            [2000, 6359, 28.08, 27.32],
            [2000, 6360, 120, 109.36],
            [2000, 6361, 120, 90],
            [2000, 6362, 115.35, 155.44],
            [2000, 6363, 63.74, 113.55],
            [2000, 6364, 120, 108.36],
            [2000, 6365, 120, 90],
            [2000, 6366, 152, 95.28],
            [2000, 6367, 70, 70],
            [2000, 6368, 120, 119.04],
            [2000, 6369, 68.6, 48.47],
            [2000, 6370, 120, 90],
            [2000, 6371, 120, 130.57],
            [2000, 6372, 120, 90],
            [2000, 6373, 120, 90],
            [2000, 6374, 120, 64.08],
            [2000, 6375, 120, 90],
            [2000, 6376, 70, 70],
            [2000, 6377, 120, 90],
            [2000, 6378, 70, 70],
            [2000, 6379, 120, 78.19],
            [2000, 6380, 70, 91.63],
            [2000, 6381, 70, 70],
            [2000, 6382, 120, 108.36],
            [2000, 6383, 70, 70],
            [2000, 6384, 120, 108.36],
            [2000, 6385, 120, 65.11],
            [2000, 6386, 120, 90],
            [2000, 6387, 120, 90],
            [2000, 6388, 120, 90],
            [2000, 6389, 120, 90],
            [2000, 6390, 120, 90],
            [2000, 6391, 78.33, 99.36],
            [2000, 6392, 120, 90],
            [2000, 6393, 120, 90],
            [2000, 6394, 120, 90],
            [2000, 6395, 120, 90],
            [2000, 6396, 120, 117.19],
            [2000, 6397, 120, 90],
            [2000, 6398, 120, 90],
            [2000, 6399, 120, 90],
            [2000, 6400, 120, 109.36],
            [2000, 6401, 70, 70],
            [2000, 6402, 120, 130.57],
            [2000, 6403, 120, 90],
            [2000, 6404, 120, 90],
            [2000, 6405, 120, 90],
            [2000, 6406, 120, 109.36],
            [2000, 6407, 120, 109.36],
            [2000, 6408, 120, 90],
            [2000, 6409, 120, 90],
            [2000, 6410, 120, 90],
            [2000, 6411, 120, 90],
            [2000, 6412, 120, 90],
            [2000, 6413, 120, 90],
            [2000, 6414, 120, 109.36],
            [2000, 6415, 120, 119.04],
            [2000, 6416, 120, 90],
            [2000, 6417, 120, 90],
            [2000, 6418, 120, 90],
            [2000, 6419, 120, 90],
            [2000, 6420, 120, 90],
            [2000, 6421, 120, 117.19],
            [2000, 6422, 120, 109.36],
            [2000, 6423, 42.81, 43.17],
            [2000, 6424, 115.49, 81.33],
            [2000, 6425, 70, 98.36],
            [2000, 6426, 120, 117.19],
            [2000, 6427, 120, 90],
            [2000, 6428, 120, 90],
            [2000, 6429, 120, 90],
            [2000, 6430, 70, 86.89],
            [2000, 6431, 120, 90],
            [2000, 6432, 120, 90],
            [2000, 6433, 63.74, 113.55],
            [2000, 6434, 120, 90],
            [2000, 6435, 78.33, 99.36],
            [2000, 6436, 120, 90],
            [2000, 6437, 120, 90],
            [2000, 6438, 120, 90],
            [2000, 6439, 120, 125.74],
            [2000, 6440, 120, 90],
            [2000, 6441, 120, 109.36],
            [2000, 6442, 70, 70],
            [2000, 6443, 120, 90],
            [2000, 6444, 120, 90],
            [2000, 6445, 120, 90],
            [2000, 6446, 120, 90],
            [2000, 6447, 48.53, 70],
            [2000, 6448, 120, 90],
            [2000, 6449, 120, 90],
            [2000, 6450, 120, 90],
            [2000, 6451, 120, 90],
            [2000, 6452, 120, 90],
            [2000, 6453, 120, 90],
            [2000, 6454, 120, 90],
            [2000, 6455, 120, 90],
            [2000, 6456, 120, 90],
            [2000, 6457, 56.58, 70],
            [2000, 6458, 40, 55.85],
            [2000, 6459, 120, 125.74],
            [2000, 6460, 163.78, 95.28],
            [2000, 6461, 120, 90],
            [2000, 6462, 152, 95.28],
            [2000, 6463, 120, 90],
            [2000, 6464, 120, 90],
            [2000, 6465, 120, 90],
            [2000, 6466, 120, 90],
            [2000, 6467, 120, 90],
            [2000, 6468, 120, 90],
            [2000, 6469, 120, 101.08],
            [2000, 6470, 120, 90],
            [2000, 6471, 120, 109.36],
            [2000, 6472, 120, 108.36],
            [2000, 6473, 120, 90],
            [2000, 6474, 120, 90],
            [2000, 6475, 120, 90],
            [2000, 6476, 120, 108.36],
            [2000, 6477, 120, 90],
            [2000, 6478, 120, 90],
            [2000, 6479, 120, 90],
            [2000, 6480, 120, 90],
            [2000, 6481, 120, 90],
            [2000, 6482, 152, 95.28],
            [2000, 6483, 120, 109.36],
            [2000, 6484, 70, 56.48],
            [2000, 6485, 120, 90],
            [2000, 6486, 120, 90],
            [2000, 6487, 120, 90],
            [2000, 6488, 120, 90],
            [2000, 6489, 120, 90],
            [2000, 6490, 120, 108.36],
            [2000, 6491, 120, 90],
            [2000, 6492, 60.88, 72.65],
            [2000, 6493, 120, 90],
            [2000, 6494, 60.88, 72.65],
            [2000, 6495, 120, 125.74],
            [2000, 6496, 120, 109.36],
            [2000, 6497, 120, 90],
            [2000, 6498, 120, 125.74],
            [2000, 6499, 120, 90],
            [2000, 6500, 80.71, 115.49],
            [2000, 6501, 120, 90],
            [2000, 6502, 120, 78.19],
            [2000, 6503, 120, 109.36],
            [2000, 6504, 120, 130.57],
            [2000, 6505, 120, 91.63],
            [2000, 6506, 120, 90],
            [2000, 6507, 120, 90],
            [2000, 6508, 120, 90],
            [2000, 6509, 120, 119.04],
            [2000, 6510, 120, 90],
            [2000, 6511, 120, 90],
            [2000, 6512, 120, 109.36],
            [2000, 6513, 31.53, 53.27],
            [2000, 6514, 120, 90],
            [2000, 6515, 120, 90],
            [2000, 6516, 73.07, 58.95],
            [2000, 6517, 68.95, 86.89],
            [2000, 6518, 120, 117.19],
            [2000, 6519, 120, 90],
            [2000, 6520, 120, 90],
            [2000, 6521, 56.58, 56.58],
            [2000, 6522, 120, 90],
            [2000, 6523, 120, 90],
            [2000, 6524, 120, 90],
            [2000, 6525, 120, 90],
            [2000, 6526, 120, 90],
            [2000, 6527, 120, 125.74],
            [2000, 6528, 120, 125.74],
            [2000, 6529, 120, 90],
            [2000, 6530, 120, 109.36],
            [2000, 6531, 120, 90],
            [2000, 6532, 120, 125.74],
            [2000, 6533, 120, 91.63],
            [2000, 6534, 120, 119.04],
            [2000, 6535, 120, 90],
            [2000, 6536, 70.23, 106.94],
            [2000, 6537, 120, 90],
            [2000, 6538, 120, 90],
            [2000, 6539, 120, 90],
            [2000, 6540, 120, 90],
            [2000, 6541, 120, 90],
            [2000, 6542, 120, 108.36],
            [2000, 6543, 120, 90],
            [2000, 6544, 120, 90],
            [2000, 6546, 120, 90],
            [2000, 6547, 120, 90],
            [2000, 6548, 120, 90],
            [2000, 6549, 120, 90],
            [2000, 6550, 120, 90],
            [2000, 6551, 120, 90],
            [2000, 6552, 120, 108.36],
            [2000, 6553, 120, 90],
            [2000, 6554, 120, 90],
            [2000, 6555, 120, 90],
            [2000, 6556, 120, 90],
            [2000, 6557, 120, 90],
            [2000, 6558, 120, 90],
            [2000, 6559, 120, 90],
            [2000, 6560, 120, 90],
            [2000, 6561, 120, 90],
            [2000, 6562, 120, 90],
            [2000, 6563, 120, 90],
            [2000, 6564, 120, 90],
            [2000, 6565, 120, 90],
            [2000, 6566, 120, 78.64],
            [2000, 6567, 120, 90],
            [2000, 6568, 120, 109.36],
            [2000, 6569, 120, 90],
            [2000, 6570, 120, 90],
            [2000, 6572, 120, 90],
            [2000, 6573, 120, 90],
            [2000, 6574, 120, 90],
            [2000, 6575, 120, 119.04],
            [2000, 6576, 120, 90],
            [2000, 6577, 120, 90],
            [2000, 6578, 120, 109.36],
            [2000, 6579, 120, 90],
            [2000, 6580, 120, 90],
            [2000, 6581, 120, 90],
            [2000, 6582, 120, 90],
            [2000, 6583, 120, 90],
            [2000, 6584, 120, 90],
            [2000, 6585, 120, 109.36],
            [2000, 6586, 120, 130.57],
            [2000, 6587, 120, 90],
            [2000, 6588, 120, 109.36],
            [2000, 6589, 120, 90],
            [2000, 6590, 120, 90],
            [2000, 6591, 120, 90],
            [2000, 6592, 120, 90],
            [2000, 6593, 120, 90],
            [2000, 6594, 120, 90],
            [2000, 6595, 120, 90],
            [2000, 6596, 120, 90],
            [2000, 6597, 120, 90],
            [2000, 6598, 120, 90],
            [2000, 6599, 120, 90],
            [2000, 6600, 120, 90],
            [2000, 6601, 120, 90],
            [2000, 6602, 120, 125.74],
            [2000, 6603, 70, 70],
            [2000, 6604, 120, 119.04],
            [2000, 6605, 120, 108.36],
            [2000, 6606, 120, 90],
            [2000, 6607, 120, 125.74],
            [2000, 6608, 120, 109.36],
            [2000, 6609, 120, 90],
            [2000, 6610, 120, 90],
            [2000, 6611, 70, 91.63],
            [2000, 6612, 120, 119.04],
            [2000, 6613, 120, 90],
            [2000, 6614, 50, 101.08],
            [2000, 6615, 120, 130.57],
            [2000, 6616, 120, 90],
            [2000, 6617, 39.9, 34.9],
            [2000, 6618, 120, 90],
            [2000, 6619, 120, 90],
            [2000, 6620, 120, 90],
            [2000, 6621, 120, 90],
            [2000, 6622, 120, 90],
            [2000, 6623, 152, 95.28],
            [2000, 6624, 120, 108.36],
            [2000, 6625, 120, 90],
            [2000, 6626, 120, 90],
            [2000, 6627, 120, 90],
            [2000, 6628, 120, 90],
            [2000, 6629, 70, 70],
            [2000, 6630, 70, 70],
            [2000, 6631, 50, 60],
            [2000, 6632, 28, 35],
            [2000, 6633, 50, 60],
            [2000, 6634, 49, 49],
            [2000, 6635, 70, 70],
            [2000, 6636, 70, 70],
            [2000, 6637, 84, 63],
            [2000, 6638, 70, 70],
            [2000, 6639, 84, 63],
            [2000, 6640, 50, 60],
            [2000, 6641, 70, 70],
            [2000, 6642, 40, 50],
            [2000, 6643, 30, 40],
            [2000, 6648, 120, 90],
            [2000, 6649, 84, 63],
            [2000, 6650, 84, 63],
            [2000, 6651, 84, 63],
            [2000, 6652, 84, 63],
            [2000, 6653, 70, 70],
            [2000, 6654, 49, 49],
            [2000, 6655, 49, 49],
            [2000, 6656, 49, 49],
            [2000, 6657, 70, 70],
            [2000, 6660, 49, 49],
            [2000, 6661, 49, 49],
            [2000, 6662, 49, 49],
            [2000, 6663, 49, 49],
            [2000, 6664, 49, 49],
            [2000, 6665, 49, 49],
            [2000, 6666, 49, 49],
            [2000, 6667, 49, 49],
            [2000, 6668, 49, 49],
            [2000, 6669, 49, 49],
            [2000, 6670, 49, 49],
            [2000, 6671, 49, 49],
            [2000, 6672, 49, 49],
            [2000, 6673, 49, 49],
            [2000, 6674, 49, 49],
            [2000, 6675, 49, 49],
            [2000, 6676, 49, 49],
            [2000, 6677, 49, 49],
            [2000, 6678, 49, 49],
            [2000, 6679, 70, 70],
            [2000, 6680, 49, 49],
            [2000, 6682, 49, 49],
            [2000, 6683, 70, 70],
            [2000, 6684, 49, 49],
            [2000, 6685, 35, 42],
            [2000, 6686, 35, 42],
            [2000, 6687, 35, 42],
            [2000, 6688, 35, 42],
            [2000, 6689, 35, 42],
            [2000, 6690, 35, 42],
            [2000, 6691, 10.46, 2.78],
            [2000, 6692, 12.66, 2.21],
            [2000, 6697, 40, 50],
            [2000, 6698, 70, 70],
            [2000, 6699, 70, 70],
            [2000, 6700, 120, 90],
            [2000, 6701, 70, 70],
            [2000, 6702, 70, 70],
            [2000, 6703, 30, 40],
            [2000, 6704, 70, 70],
            [2000, 6705, 70, 70],
            [2000, 6706, 70, 70],
            [2000, 6707, 120, 90],
            [2000, 6708, 70, 70],
            [2000, 6709, 30, 40],
            [2000, 6710, 50, 60],
            [2000, 6711, 70, 70],
            [2000, 6712, 50, 60],
            [2000, 6713, 70, 70],
            [2000, 6714, 50, 60],
            [2000, 6715, 120, 90],
            [2000, 6716, 70, 70],
            [2000, 6717, 70, 70],
            [2000, 6718, 70, 70],
            [2000, 6719, 70, 70],
            [2000, 6720, 70, 70],
            [2000, 6721, 50, 60],
            [2000, 6722, 30, 40],
            [2000, 6723, 70, 70],
            [2000, 6724, 70, 70],
            [2000, 6725, 70, 70],
            [2000, 6726, 70, 70],
            [2000, 6727, 70, 70],
            [2000, 6728, 70, 70],
            [2000, 6729, 70, 70],
            [2000, 6730, 120, 90],
            [2000, 6731, 70, 70],
            [2000, 6732, 70, 70],
            [2000, 6733, 70, 70],
            [2000, 6734, 70, 70],
            [2000, 6735, 70, 70],
            [2000, 6736, 50, 60],
            [2000, 6737, 70, 70],
            [2000, 6738, 70, 70],
            [2000, 6739, 50, 60],
            [2000, 6740, 18, 27],
            [2000, 6741, 18, 27],
            [2000, 6742, 18, 27],
            [2000, 6743, 18, 27],
            [2000, 6746, 50, 60],
            [2000, 6748, 70, 70],
            [2000, 6749, 70, 70],
            [2000, 6750, 70, 70],
            [2000, 6752, 35, 42],
            [2000, 6753, 120, 90],
            [2000, 6754, 70, 70],
            [2000, 6755, 70, 70],
            [2000, 6756, 70, 70],
            [2000, 6757, 70, 70],
            [2000, 6758, 70, 70],
            [2000, 6759, 50, 60],
            [2000, 6760, 70, 70],
            [2000, 6761, 70, 70],
            [2000, 6762, 70, 70],
            [2000, 6763, 35, 42],
            [2000, 6764, 70, 70],
            [2000, 6766, 120, 90],
            [2000, 6767, 49, 49],
            [2000, 6768, 49, 49],
            [2000, 6769, 120, 90],
            [2000, 6770, 70, 70],
            [2000, 6771, 70, 70],
            [2000, 6772, 50, 60],
            [2000, 6773, 120, 90],
            [2000, 6777, 70, 70],
            [2000, 6778, 70, 70],
            [2000, 6779, 50, 60],
            [2000, 6780, 70, 70],
            [2000, 6781, 70, 70],
            [2000, 6782, 120, 90],
            [2000, 6783, 70, 70],
            [2000, 6784, 70, 70],
            [2000, 6785, 70, 70],
            [2000, 6786, 70, 70],
            [2000, 6787, 70, 70],
            [2000, 6789, 70, 70],
            [2000, 6790, 70, 70],
            [2000, 6791, 30, 40],
            [2000, 6792, 70, 70],
            [2000, 6793, 30, 40],
            [2000, 6794, 70, 70],
            [2000, 6795, 70, 70],
            [2000, 6796, 70, 70],
            [2000, 6797, 70, 70],
            [2000, 6798, 30, 40],
            [2000, 6799, 30, 40],
            [2000, 6800, 70, 70],
            [2000, 6801, 70, 70],
            [2000, 6802, 70, 70],
            [2000, 6803, 70, 70],
            [2000, 6804, 70, 70],
            [2000, 6805, 70, 70],
            [2000, 6806, 70, 70],
            [2000, 6807, 70, 70],
            [2000, 6808, 120, 90],
            [2000, 6809, 70, 70],
            [2000, 6810, 70, 70],
            [2000, 6811, 30, 40],
            [2000, 6812, 30, 40],
            [2000, 6813, 70, 70],
            [2000, 6814, 30, 40],
            [2000, 6815, 70, 70],
            [2000, 6816, 120, 90],
            [2000, 6817, 50, 60],
            [2000, 6818, 21.25, 24.78],
            [2000, 6819, 40, 48],
            [2000, 6820, 40, 48],
            [2000, 6821, 56, 56],
            [2000, 6822, 56, 56],
            [2000, 6823, 56, 56],
            [2000, 6824, 120, 90],
            [2000, 6825, 120, 90],
            [2000, 6826, 50, 60],
            [2000, 6827, 50, 60],
            [2000, 6828, 50, 60],
            [2000, 6829, 70, 70],
            [2000, 6830, 70, 70],
            [2000, 6831, 120, 90],
            [2000, 6832, 70, 70],
            [2000, 6833, 30, 40],
            [2000, 6834, 30, 40],
            [2000, 6835, 30, 40],
            [2000, 6836, 70, 70],
            [2000, 6837, 120, 90],
            [2000, 6838, 30, 40],
            [2000, 6841, 49, 49],
            [2000, 6842, 70, 70],
            [2000, 6843, 70, 70],
            [2000, 6844, 50, 60],
            [2000, 6845, 120, 90],
            [2000, 6846, 120, 90],
            [2000, 6847, 70, 70],
            [2000, 6848, 50, 60],
            [2000, 6849, 70, 70],
            [2000, 6850, 50, 60],
            [2000, 6851, 50, 60],
            [2000, 6852, 50, 60],
            [2000, 6853, 50, 60],
            [2000, 6854, 120, 90],
            [2000, 6855, 50, 60],
            [2000, 6856, 70, 70],
            [2000, 6857, 70, 70],
            [2000, 6858, 50, 60],
            [2000, 6859, 30, 40],
            [2000, 6860, 70, 70],
            [2000, 6861, 50, 60],
            [2000, 6862, 50, 60],
            [2000, 6864, 40, 50],
            [2000, 6865, 30, 45],
            [2000, 6866, 19.37, 24.9],
            [2001, 2, 51, 44],
            [2001, 7, 33, 33],
            [2001, 25, 14, 10],
            [2001, 42, 21, 22],
            [2001, 48, 95, 70],
            [2001, 49, 38, 26],
            [2001, 51, 32, 33],
            [2001, 62, 22, 32],
            [2001, 65, 27, 23],
            [2001, 78, 21, 21],
            [2001, 82, 12, 21],
            [2001, 83, 43, 50],
            [2001, 87, 39, 33],
            [2001, 99, 33, 33],
            [2001, 101, 70, 57],
            [2001, 119, 45, 33],
            [2001, 122, 37, 22],
            [2001, 125, 35, 37],
            [2001, 135, 21, 21],
            [2001, 138, 35, 33],
            [2001, 163, 31, 28],
            [2001, 166, 43, 43],
            [2001, 169, 28, 22],
            [2001, 186, 17, 22],
            [2001, 190, 33, 32],
            [2001, 194, 27, 27],
            [2001, 200, 45, 34],
            [2001, 204, 12, 21],
            [2001, 211, 22, 54],
            [2001, 215, 31, 33],
            [2001, 216, 26, 22],
            [2001, 218, 69, 28],
            [2001, 220, 20, 21],
            [2001, 226, 18, 20],
            [2001, 230, 54, 50],
            [2001, 231, 60, 53],
            [2001, 233, 18, 19],
            [2001, 234, 12, 18],
            [2001, 239, 22, 22],
            [2001, 240, 21, 19],
            [2001, 242, 37, 21],
            [2001, 243, 32, 33],
            [2001, 246, 64, 38],
            [2001, 248, 22, 21],
            [2001, 270, 32, 32],
            [2001, 272, 62, 19],
            [2001, 282, 48, 24],
            [2001, 285, 21, 22],
            [2001, 286, 22, 13],
            [2001, 299, 21, 22],
            [2001, 305, 22, 22],
            [2001, 306, 33, 33],
            [2001, 308, 13, 53],
            [2001, 310, 23, 22],
            [2001, 312, 22, 22],
            [2001, 314, 20, 30],
            [2001, 317, 32, 33],
            [2001, 320, 26, 30],
            [2001, 324, 54, 45],
            [2001, 327, 51, 46],
            [2001, 329, 44, 36],
            [2001, 330, 32, 33],
            [2001, 332, 33, 33],
            [2001, 334, 39, 34],
            [2001, 337, 27, 19],
            [2001, 339, 25, 22],
            [2001, 344, 35, 21],
            [2001, 346, 47, 40],
            [2001, 355, 55, 37],
            [2001, 361, 33, 33],
            [2001, 365, 50, 36],
            [2001, 378, 22, 27],
            [2001, 379, 16, 14],
            [2001, 389, 18, 26],
            [2001, 392, 21, 22],
            [2001, 399, 85, 41],
            [2001, 402, 38, 32],
            [2001, 403, 33, 34],
            [2001, 418, 24, 22],
            [2001, 424, 22, 22],
            [2001, 425, 19, 30],
            [2001, 428, 31, 22],
            [2001, 430, 22, 29],
            [2001, 432, 40, 34],
            [2001, 436, 29, 24],
            [2001, 455, 30, 27],
            [2001, 471, 21, 22],
            [2001, 479, 39, 38],
            [2001, 480, 70, 29],
            [2001, 487, 36, 33],
            [2001, 493, 32, 33],
            [2001, 494, 17, 19],
            [2001, 497, 11, 16],
            [2001, 503, 72, 24],
            [2001, 504, 16, 14],
            [2001, 505, 31, 34],
            [2001, 519, 20, 30],
            [2001, 525, 20, 34],
            [2001, 536, 21, 21],
            [2001, 541, 87, 45],
            [2001, 545, 23, 28],
            [2001, 568, 22, 22],
            [2001, 569, 59, 33],
            [2001, 570, 28, 22],
            [2001, 573, 33, 34],
            [2001, 577, 32, 26],
            [2001, 579, 56, 50],
            [2001, 585, 70, 62],
            [2001, 590, 44, 49],
            [2001, 593, 49, 45],
            [2001, 595, 33, 33],
            [2001, 597, 26, 10],
            [2001, 599, 17, 25],
            [2001, 604, 60, 36],
            [2001, 608, 32, 22],
            [2001, 612, 53, 50],
            [2001, 618, 29, 23],
            [2001, 625, 26, 19],
            [2001, 627, 38, 35],
            [2001, 628, 33, 33],
            [2001, 631, 21, 22],
            [2001, 654, 15, 12],
            [2001, 660, 35, 36],
            [2001, 662, 82, 55],
            [2001, 663, 60, 37],
            [2001, 669, 38, 26],
            [2001, 678, 21, 29],
            [2001, 686, 17, 27],
            [2001, 691, 25, 22],
            [2001, 694, 45, 37],
            [2001, 695, 85, 63],
            [2001, 700, 65, 47],
            [2001, 703, 12, 19],
            [2001, 704, 29, 34],
            [2001, 709, 55, 38],
            [2001, 716, 70, 64],
            [2001, 717, 42, 33],
            [2001, 719, 34, 31],
            [2001, 720, 25, 22],
            [2001, 724, 32, 33],
            [2001, 727, 58, 57],
            [2001, 734, 22, 32],
            [2001, 737, 14, 12],
            [2001, 750, 22, 22],
            [2001, 751, 35, 19],
            [2001, 754, 32, 33],
            [2001, 766, 79, 34],
            [2001, 769, 41, 51],
            [2001, 773, 32, 34],
            [2001, 781, 30, 24],
            [2001, 783, 22, 28],
            [2001, 785, 66, 66],
            [2001, 790, 51, 35],
            [2001, 801, 21, 22],
            [2001, 803, 39, 37],
            [2001, 805, 44, 31],
            [2001, 811, 30, 26],
            [2001, 815, 16, 16],
            [2001, 820, 45, 52],
            [2001, 821, 21, 22],
            [2001, 822, 19, 23],
            [2001, 826, 21, 22],
            [2001, 827, 11, 15],
            [2001, 835, 32, 33],
            [2001, 843, 33, 33],
            [2001, 844, 32, 26],
            [2001, 845, 70, 34],
            [2001, 848, 27, 22],
            [2001, 865, 57, 36],
            [2001, 871, 47, 26],
            [2001, 878, 7, 6],
            [2001, 882, 50, 39],
            [2001, 890, 21, 22],
            [2001, 894, 30, 12],
            [2001, 909, 79, 46],
            [2001, 913, 21, 18],
            [2001, 915, 66, 43],
            [2001, 922, 59, 41],
            [2001, 926, 76, 24],
            [2001, 938, 12, 14],
            [2001, 940, 12, 15],
            [2001, 941, 44, 42],
            [2001, 944, 26, 22],
            [2001, 949, 78, 38],
            [2001, 950, 17, 22],
            [2001, 964, 13, 17],
            [2001, 969, 47, 44],
            [2001, 971, 23, 19],
            [2001, 972, 43, 28],
            [2001, 978, 57, 43],
            [2001, 979, 22, 22],
            [2001, 985, 92, 46],
            [2001, 990, 26, 22],
            [2001, 993, 70, 45],
            [2001, 998, 40, 23],
            [2001, 1003, 8, 6],
            [2001, 1006, 13, 20],
            [2001, 1008, 24, 26],
            [2001, 1016, 11, 16],
            [2001, 1030, 9, 15],
            [2001, 1033, 21, 22],
            [2001, 1042, 120, 55],
            [2001, 1048, 46, 45],
            [2001, 1051, 29, 22],
            [2001, 1056, 23, 46],
            [2001, 1059, 51, 55],
            [2001, 1071, 109, 33],
            [2001, 1073, 58, 38],
            [2001, 1082, 61, 52],
            [2001, 1084, 91, 39],
            [2001, 1094, 21, 22],
            [2001, 1095, 22, 22],
            [2001, 1097, 37, 20],
            [2001, 1100, 24, 25],
            [2001, 1102, 16, 18],
            [2001, 1106, 108, 38],
            [2001, 1109, 30, 33],
            [2001, 1111, 43, 58],
            [2001, 1124, 71, 42],
            [2001, 1131, 35, 33],
            [2001, 1132, 12, 15],
            [2001, 1136, 51, 57],
            [2001, 1140, 33, 28],
            [2001, 1141, 33, 33],
            [2001, 1142, 29, 29],
            [2001, 1144, 35, 25],
            [2001, 1145, 32, 25],
            [2001, 1150, 40, 30],
            [2001, 1155, 33, 33],
            [2001, 1156, 30, 20],
            [2001, 1157, 41, 28],
            [2001, 1159, 57, 49],
            [2001, 1167, 21, 21],
            [2001, 1169, 22, 22],
            [2001, 1174, 32, 48],
            [2001, 1175, 23, 22],
            [2001, 1177, 43, 34],
            [2001, 1186, 15, 22],
            [2001, 1194, 120, 52],
            [2001, 1200, 21, 22],
            [2001, 1203, 11, 19],
            [2001, 1205, 22, 22],
            [2001, 1213, 23, 23],
            [2001, 1217, 33, 34],
            [2001, 1219, 22, 22],
            [2001, 1221, 23, 22],
            [2001, 1224, 33, 33],
            [2001, 1226, 24, 16],
            [2001, 1228, 20, 21],
            [2001, 1234, 12, 16],
            [2001, 1235, 28, 25],
            [2001, 1238, 14, 29],
            [2001, 1247, 65, 38],
            [2001, 1254, 60, 31],
            [2001, 1262, 33, 33],
            [2001, 1268, 51, 36],
            [2001, 1275, 25, 15],
            [2001, 1281, 17, 24],
            [2001, 1295, 50, 60],
            [2001, 1302, 60, 73],
            [2001, 1303, 95, 46],
            [2001, 1305, 19, 22],
            [2001, 1319, 59, 28],
            [2001, 1320, 48, 46],
            [2001, 1323, 25, 22],
            [2001, 1334, 21, 21],
            [2001, 1358, 60, 32],
            [2001, 1359, 32, 33],
            [2001, 1361, 33, 33],
            [2001, 1363, 35, 34],
            [2001, 1367, 43, 49],
            [2001, 1370, 15, 25],
            [2001, 1375, 21, 22],
            [2001, 1376, 30, 27],
            [2001, 1396, 11, 20],
            [2001, 1420, 59, 54],
            [2001, 1445, 75, 19],
            [2001, 1454, 26, 33],
            [2001, 1456, 33, 33],
            [2001, 1465, 18, 21],
            [2001, 1466, 40, 27],
            [2001, 1471, 34, 33],
            [2001, 1473, 17, 25],
            [2001, 1475, 35, 33],
            [2001, 1476, 33, 34],
            [2001, 1477, 22, 22],
            [2001, 1481, 50, 33],
            [2001, 1482, 13, 17],
            [2001, 1484, 34, 34],
            [2001, 1486, 14, 14],
            [2001, 1490, 24, 22],
            [2001, 1491, 12, 9],
            [2001, 1493, 30, 22],
            [2001, 1507, 40, 27],
            [2001, 1508, 32, 33],
            [2001, 1510, 17, 22],
            [2001, 1511, 32, 33],
            [2001, 1515, 25, 20],
            [2001, 1522, 15, 22],
            [2001, 1525, 53, 51],
            [2001, 1527, 31, 33],
            [2001, 1530, 63, 59],
            [2001, 1536, 19, 20],
            [2001, 1537, 34, 31],
            [2001, 1548, 31, 34],
            [2001, 1553, 32, 33],
            [2001, 1555, 60, 50],
            [2001, 1556, 33, 33],
            [2001, 1557, 37, 34],
            [2001, 1561, 21, 22],
            [2001, 1562, 32, 33],
            [2001, 1568, 34, 33],
            [2001, 1575, 103, 69],
            [2001, 1577, 30, 23],
            [2001, 1580, 50, 41],
            [2001, 1582, 30, 30],
            [2001, 1587, 17, 21],
            [2001, 1589, 49, 22],
            [2001, 1593, 13, 14],
            [2001, 1598, 16, 9],
            [2001, 1610, 33, 34],
            [2001, 1628, 40, 24],
            [2001, 1635, 19, 18],
            [2001, 1638, 34, 54],
            [2001, 1644, 38, 33],
            [2001, 1645, 50, 33],
            [2001, 1659, 28, 25],
            [2001, 1660, 32, 34],
            [2001, 1662, 15, 12],
            [2001, 1663, 33, 34],
            [2001, 1664, 18, 16],
            [2001, 1672, 21, 22],
            [2001, 1673, 72, 48],
            [2001, 1680, 31, 33],
            [2001, 1685, 50, 45],
            [2001, 1704, 19, 23],
            [2001, 1717, 65, 32],
            [2001, 1724, 22, 22],
            [2001, 1730, 17, 13],
            [2001, 1744, 33, 33],
            [2001, 1748, 32, 33],
            [2001, 1756, 33, 33],
            [2001, 1760, 13, 17],
            [2001, 1763, 26, 26],
            [2001, 1769, 63, 54],
            [2001, 1771, 21, 22],
            [2001, 1772, 11, 16],
            [2001, 1774, 31, 33],
            [2001, 1776, 32, 20],
            [2001, 1780, 20, 22],
            [2001, 1781, 22, 21],
            [2001, 1786, 20, 27],
            [2001, 1790, 21, 21],
            [2001, 1792, 34, 34],
            [2001, 1794, 38, 41],
            [2001, 1795, 14, 10],
            [2001, 1797, 70, 50],
            [2001, 1798, 45, 60],
            [2001, 1804, 21, 22],
            [2001, 1812, 15, 19],
            [2001, 1816, 114, 27],
            [2001, 1818, 22, 22],
            [2001, 1824, 43, 50],
            [2001, 1825, 22, 32],
            [2001, 1829, 20, 30],
            [2001, 1841, 53, 53],
            [2001, 1845, 33, 33],
            [2001, 1848, 33, 33],
            [2001, 1853, 71, 29],
            [2001, 1864, 81, 75],
            [2001, 1866, 70, 39],
            [2001, 1869, 40, 47],
            [2001, 1876, 32, 33],
            [2001, 1879, 26, 22],
            [2001, 1882, 19, 22],
            [2001, 1891, 33, 50],
            [2001, 1894, 40, 16],
            [2001, 1901, 21, 22],
            [2001, 1903, 108, 40],
            [2001, 1915, 52, 42],
            [2001, 1916, 21, 19],
            [2001, 1917, 32, 33],
            [2001, 1921, 24, 22],
            [2001, 1925, 33, 33],
            [2001, 1930, 11, 9],
            [2001, 1933, 12, 16],
            [2001, 1945, 31, 33],
            [2001, 1948, 27, 36],
            [2001, 1950, 22, 40],
            [2001, 1952, 120, 79],
            [2001, 1962, 14, 18],
            [2001, 1965, 68, 53],
            [2001, 1995, 33, 33],
            [2001, 2000, 34, 33],
            [2001, 2001, 40, 30],
            [2001, 2006, 26, 24],
            [2001, 2011, 12, 18],
            [2001, 2017, 49, 50],
            [2001, 2021, 33, 33],
            [2001, 2023, 12, 12],
            [2001, 2025, 33, 34],
            [2001, 2026, 53, 36],
            [2001, 2028, 51, 27],
            [2001, 2029, 31, 33],
            [2001, 2032, 17, 20],
            [2001, 2035, 70, 39],
            [2001, 2042, 21, 22],
            [2001, 2048, 14, 32],
            [2001, 2056, 42, 49],
            [2001, 2057, 117, 48],
            [2001, 2064, 60, 39],
            [2001, 2081, 21, 22],
            [2001, 2084, 65, 35],
            [2001, 2098, 16, 19],
            [2001, 2099, 27, 22],
            [2001, 2101, 10, 14],
            [2001, 2104, 35, 33],
            [2001, 2121, 19, 18],
            [2001, 2127, 20, 13],
            [2001, 2128, 33, 33],
            [2001, 2131, 31, 42],
            [2001, 2138, 30, 29],
            [2001, 2142, 10, 11],
            [2001, 2144, 24, 76],
            [2001, 2162, 21, 43],
            [2001, 2163, 42, 20],
            [2001, 2170, 29, 22],
            [2001, 2171, 32, 30],
            [2001, 2174, 30, 23],
            [2001, 2178, 13, 21],
            [2001, 2180, 33, 34],
            [2001, 2181, 34, 33],
            [2001, 2182, 32, 34],
            [2001, 2190, 30, 25],
            [2001, 2198, 26, 19],
            [2001, 2201, 33, 33],
            [2001, 2208, 55, 39],
            [2001, 2213, 50, 41],
            [2001, 2216, 26, 34],
            [2001, 2220, 21, 22],
            [2001, 2224, 32, 36],
            [2001, 2227, 20, 21],
            [2001, 2232, 33, 33],
            [2001, 2236, 20, 22],
            [2001, 2238, 33, 33],
            [2001, 2239, 24, 22],
            [2001, 2244, 27, 29],
            [2001, 2250, 50, 34],
            [2001, 2255, 32, 32],
            [2001, 2258, 33, 34],
            [2001, 2277, 35, 30],
            [2001, 2280, 9, 7],
            [2001, 2282, 22, 65],
            [2001, 2293, 33, 33],
            [2001, 2297, 111, 40],
            [2001, 2300, 51, 60],
            [2001, 2303, 21, 22],
            [2001, 2311, 42, 41],
            [2001, 2312, 21, 22],
            [2001, 2316, 63, 39],
            [2001, 2332, 16, 17],
            [2001, 2335, 33, 33],
            [2001, 2343, 29, 19],
            [2001, 2352, 49, 41],
            [2001, 2356, 120, 57],
            [2001, 2366, 17, 18],
            [2001, 2367, 36, 33],
            [2001, 2371, 64, 36],
            [2001, 2383, 37, 22],
            [2001, 2384, 30, 43],
            [2001, 2404, 32, 33],
            [2001, 2405, 31, 35],
            [2001, 2428, 38, 22],
            [2001, 2429, 12, 12],
            [2001, 2433, 63, 25],
            [2001, 2435, 20, 17],
            [2001, 2443, 65, 39],
            [2001, 2447, 20, 21],
            [2001, 2458, 17, 15],
            [2001, 2459, 14, 19],
            [2001, 2467, 12, 17],
            [2001, 2472, 36, 24],
            [2001, 2483, 73, 52],
            [2001, 2485, 14, 14],
            [2001, 2488, 27, 28],
            [2001, 2493, 26, 22],
            [2001, 2494, 31, 33],
            [2001, 2497, 21, 22],
            [2001, 2500, 31, 21],
            [2001, 2501, 69, 30],
            [2001, 2505, 50, 35],
            [2001, 2509, 16, 19],
            [2001, 2514, 36, 33],
            [2001, 2516, 33, 33],
            [2001, 2518, 32, 33],
            [2001, 2524, 11, 12],
            [2001, 2527, 27, 21],
            [2001, 2533, 11, 19],
            [2001, 2539, 62, 29],
            [2001, 2540, 23, 25],
            [2001, 2543, 24, 24],
            [2001, 2547, 17, 16],
            [2001, 2551, 43, 33],
            [2001, 2554, 12, 12],
            [2001, 2555, 40, 25],
            [2001, 2562, 38, 34],
            [2001, 2564, 20, 22],
            [2001, 2574, 31, 33],
            [2001, 2576, 63, 32],
            [2001, 2585, 62, 51],
            [2001, 2587, 32, 33],
            [2001, 2593, 30, 33],
            [2001, 2595, 45, 42],
            [2001, 2603, 98, 45],
            [2001, 2604, 33, 33],
            [2001, 2606, 22, 16],
            [2001, 2607, 11, 10],
            [2001, 2612, 31, 32],
            [2001, 2615, 37, 33],
            [2001, 2617, 50, 27],
            [2001, 2619, 12, 13],
            [2001, 2622, 31, 22],
            [2001, 2627, 70, 40],
            [2001, 2628, 22, 22],
            [2001, 2632, 32, 20],
            [2001, 2633, 32, 33],
            [2001, 2635, 13, 22],
            [2001, 2644, 29, 22],
            [2001, 2647, 36, 31],
            [2001, 2650, 25, 22],
            [2001, 2656, 22, 21],
            [2001, 2658, 32, 33],
            [2001, 2667, 32, 34],
            [2001, 2668, 32, 33],
            [2001, 2669, 58, 51],
            [2001, 2670, 50, 34],
            [2001, 2671, 52, 60],
            [2001, 2684, 36, 19],
            [2001, 2687, 28, 19],
            [2001, 2692, 65, 29],
            [2001, 2695, 12, 13],
            [2001, 2720, 38, 42],
            [2001, 2723, 45, 70],
            [2001, 2743, 33, 33],
            [2001, 2747, 32, 32],
            [2001, 2748, 33, 33],
            [2001, 2758, 37, 33],
            [2001, 2762, 97, 52],
            [2001, 2775, 65, 39],
            [2001, 2785, 14, 16],
            [2001, 2787, 37, 28],
            [2001, 2788, 33, 33],
            [2001, 2791, 44, 28],
            [2001, 2797, 15, 16],
            [2001, 2798, 12, 21],
            [2001, 2813, 31, 33],
            [2001, 2822, 30, 25],
            [2001, 2823, 22, 22],
            [2001, 2827, 14, 20],
            [2001, 2832, 16, 16],
            [2001, 2833, 57, 37],
            [2001, 2835, 38, 35],
            [2001, 2836, 35, 18],
            [2001, 2838, 50, 41],
            [2001, 2846, 28, 29],
            [2001, 2851, 22, 18],
            [2001, 2854, 38, 40],
            [2001, 2856, 38, 33],
            [2001, 2867, 22, 22],
            [2001, 2872, 19, 22],
            [2001, 2876, 32, 34],
            [2001, 2879, 25, 26],
            [2001, 2880, 39, 31],
            [2001, 2883, 36, 34],
            [2001, 2884, 26, 45],
            [2001, 2897, 120, 63],
            [2001, 2901, 80, 66],
            [2001, 2904, 53, 36],
            [2001, 2910, 21, 22],
            [2001, 2914, 50, 34],
            [2001, 2918, 58, 41],
            [2001, 2922, 17, 17],
            [2001, 2923, 33, 33],
            [2001, 2929, 34, 33],
            [2001, 2932, 36, 36],
            [2001, 2934, 24, 22],
            [2001, 2935, 80, 36],
            [2001, 2936, 25, 22],
            [2001, 2946, 34, 22],
            [2001, 2950, 33, 33],
            [2001, 2969, 23, 19],
            [2001, 2973, 41, 54],
            [2001, 2974, 48, 24],
            [2001, 2978, 32, 33],
            [2001, 2979, 28, 17],
            [2001, 2991, 45, 48],
            [2001, 2995, 22, 22],
            [2001, 3009, 42, 47],
            [2001, 3011, 33, 33],
            [2001, 3016, 34, 34],
            [2001, 3019, 48, 24],
            [2001, 3027, 20, 22],
            [2001, 3033, 95, 54],
            [2001, 3035, 21, 21],
            [2001, 3041, 36, 27],
            [2001, 3046, 32, 14],
            [2001, 3048, 49, 25],
            [2001, 3050, 36, 23],
            [2001, 3053, 80, 70],
            [2001, 3061, 33, 34],
            [2001, 3066, 63, 33],
            [2001, 3070, 35, 38],
            [2001, 3077, 40, 22],
            [2001, 3086, 81, 27],
            [2001, 3091, 10, 16],
            [2001, 3092, 50, 27],
            [2001, 3098, 21, 21],
            [2001, 3106, 20, 22],
            [2001, 3112, 62, 33],
            [2001, 3114, 33, 31],
            [2001, 3119, 12, 28],
            [2001, 3121, 21, 22],
            [2001, 3122, 33, 33],
            [2001, 3123, 120, 43],
            [2001, 3126, 50, 23],
            [2001, 3129, 39, 49],
            [2001, 3133, 29, 22],
            [2001, 3134, 54, 45],
            [2001, 3137, 33, 33],
            [2001, 3142, 41, 50],
            [2001, 3148, 37, 34],
            [2001, 3154, 35, 33],
            [2001, 3155, 29, 23],
            [2001, 3158, 16, 19],
            [2001, 3160, 21, 22],
            [2001, 3161, 22, 22],
            [2001, 3164, 60, 40],
            [2001, 3167, 23, 33],
            [2001, 3171, 40, 22],
            [2001, 3175, 41, 29],
            [2001, 3182, 22, 26],
            [2001, 3188, 44, 42],
            [2001, 3189, 40, 33],
            [2001, 3195, 21, 22],
            [2001, 3206, 33, 33],
            [2001, 3217, 32, 33],
            [2001, 3221, 50, 24],
            [2001, 3228, 32, 33],
            [2001, 3231, 22, 22],
            [2001, 3234, 62, 28],
            [2001, 3246, 64, 37],
            [2001, 3248, 21, 24],
            [2001, 3251, 40, 49],
            [2001, 3252, 44, 29],
            [2001, 3254, 26, 19],
            [2001, 3256, 23, 25],
            [2001, 3264, 34, 34],
            [2001, 3268, 33, 33],
            [2001, 3272, 27, 24],
            [2001, 3273, 90, 20],
            [2001, 3274, 34, 28],
            [2001, 3277, 36, 25],
            [2001, 3280, 32, 33],
            [2001, 3283, 27, 22],
            [2001, 3284, 21, 22],
            [2001, 3289, 71, 59],
            [2001, 3301, 46, 45],
            [2001, 3306, 24, 30],
            [2001, 3308, 70, 41],
            [2001, 3309, 50, 45],
            [2001, 3320, 62, 68],
            [2001, 3321, 50, 28],
            [2001, 3326, 21, 22],
            [2001, 3327, 57, 60],
            [2001, 3331, 21, 21],
            [2001, 3336, 27, 22],
            [2001, 3344, 21, 21],
            [2001, 3346, 21, 37],
            [2001, 3348, 65, 34],
            [2001, 3357, 12, 19],
            [2001, 3358, 16, 19],
            [2001, 3363, 82, 34],
            [2001, 3364, 11, 19],
            [2001, 3372, 60, 36],
            [2001, 3382, 44, 27],
            [2001, 3404, 43, 34],
            [2001, 3407, 21, 22],
            [2001, 3418, 88, 42],
            [2001, 3422, 26, 20],
            [2001, 3429, 32, 33],
            [2001, 3434, 7, 6],
            [2001, 3438, 60, 33],
            [2001, 3439, 22, 22],
            [2001, 3441, 31, 32],
            [2001, 3442, 21, 22],
            [2001, 3451, 53, 57],
            [2001, 3453, 21, 22],
            [2001, 3454, 13, 10],
            [2001, 3457, 33, 34],
            [2001, 3459, 28, 24],
            [2001, 3462, 56, 25],
            [2001, 3468, 23, 22],
            [2001, 3469, 34, 20],
            [2001, 3476, 34, 44],
            [2001, 3494, 12, 15],
            [2001, 3498, 22, 30],
            [2001, 3503, 97, 62],
            [2001, 3511, 20, 36],
            [2001, 3515, 17, 77],
            [2001, 3517, 63, 24],
            [2001, 3531, 31, 22],
            [2001, 3541, 24, 30],
            [2001, 3557, 10, 16],
            [2001, 3559, 50, 44],
            [2001, 3566, 14, 12],
            [2001, 3569, 76, 77],
            [2001, 3572, 32, 32],
            [2001, 3579, 22, 33],
            [2001, 3590, 35, 38],
            [2001, 3593, 57, 23],
            [2001, 3598, 18, 14],
            [2001, 3602, 22, 22],
            [2001, 3608, 30, 32],
            [2001, 3632, 33, 33],
            [2001, 3639, 22, 22],
            [2001, 3642, 36, 31],
            [2001, 3644, 33, 33],
            [2001, 3650, 44, 32],
            [2001, 3653, 22, 22],
            [2001, 3656, 32, 33],
            [2001, 3659, 21, 17],
            [2001, 3661, 34, 34],
            [2001, 3667, 21, 22],
            [2001, 3669, 11, 22],
            [2001, 3670, 44, 33],
            [2001, 3679, 21, 22],
            [2001, 3700, 27, 32],
            [2001, 3703, 34, 35],
            [2001, 3718, 60, 31],
            [2001, 3726, 12, 13],
            [2001, 3729, 120, 32],
            [2001, 3731, 30, 25],
            [2001, 3747, 31, 25],
            [2001, 3751, 26, 22],
            [2001, 3755, 33, 34],
            [2001, 3761, 23, 24],
            [2001, 3765, 29, 19],
            [2001, 3777, 33, 24],
            [2001, 3782, 82, 35],
            [2001, 3786, 14, 12],
            [2001, 3795, 31, 33],
            [2001, 3796, 33, 34],
            [2001, 3802, 56, 60],
            [2001, 3807, 21, 21],
            [2001, 3827, 33, 33],
            [2001, 3828, 22, 25],
            [2001, 3832, 33, 33],
            [2001, 3833, 27, 14],
            [2001, 3834, 33, 40],
            [2001, 3841, 30, 33],
            [2001, 3845, 34, 34],
            [2001, 3854, 21, 22],
            [2001, 3855, 21, 21],
            [2001, 3859, 12, 16],
            [2001, 3870, 36, 34],
            [2001, 3871, 23, 26],
            [2001, 3874, 32, 33],
            [2001, 3883, 21, 22],
            [2001, 3884, 65, 39],
            [2001, 3889, 90, 33],
            [2001, 3897, 30, 33],
            [2001, 3900, 29, 28],
            [2001, 3905, 34, 34],
            [2001, 3915, 32, 33],
            [2001, 3921, 33, 34],
            [2001, 3925, 76, 56],
            [2001, 3932, 28, 36],
            [2001, 3942, 20, 34],
            [2001, 3943, 18, 30],
            [2001, 3947, 59, 46],
            [2001, 3953, 33, 33],
            [2001, 3956, 48, 57],
            [2001, 3959, 21, 21],
            [2001, 3960, 43, 33],
            [2001, 3963, 30, 16],
            [2001, 3969, 105, 53],
            [2001, 3970, 33, 33],
            [2001, 3972, 99, 73],
            [2001, 3976, 17, 16],
            [2001, 3985, 34, 26],
            [2001, 3988, 25, 34],
            [2001, 3992, 33, 34],
            [2001, 3993, 11, 14],
            [2001, 3999, 31, 33],
            [2001, 4015, 65, 35],
            [2001, 4022, 50, 33],
            [2001, 4023, 32, 33],
            [2001, 4026, 42, 21],
            [2001, 4027, 100, 43],
            [2001, 4028, 38, 49],
            [2001, 4031, 18, 15],
            [2001, 4034, 106, 56],
            [2001, 4035, 22, 22],
            [2001, 4038, 120, 47],
            [2001, 4040, 33, 34],
            [2001, 4043, 19, 19],
            [2001, 4047, 34, 40],
            [2001, 4074, 25, 38],
            [2001, 4082, 102, 45],
            [2001, 4084, 12, 19],
            [2001, 4091, 44, 17],
            [2001, 4095, 33, 33],
            [2001, 4096, 31, 33],
            [2001, 4106, 31, 33],
            [2001, 4107, 80, 34],
            [2001, 4109, 19, 20],
            [2001, 4111, 21, 14],
            [2001, 4116, 32, 33],
            [2001, 4118, 33, 34],
            [2001, 4120, 32, 33],
            [2001, 4122, 73, 68],
            [2001, 4124, 31, 32],
            [2001, 4125, 13, 18],
            [2001, 4134, 39, 33],
            [2001, 4152, 134, 59],
            [2001, 4156, 22, 23],
            [2001, 4164, 22, 22],
            [2001, 4165, 47, 46],
            [2001, 4169, 30, 23],
            [2001, 4173, 12, 19],
            [2001, 4176, 11, 16],
            [2001, 4177, 58, 40],
            [2001, 4182, 32, 33],
            [2001, 4185, 21, 22],
            [2001, 4188, 113, 29],
            [2001, 4189, 22, 34],
            [2001, 4199, 50, 33],
            [2001, 4203, 33, 34],
            [2001, 4206, 17, 19],
            [2001, 4209, 22, 20],
            [2001, 4229, 29, 23],
            [2001, 4242, 21, 21],
            [2001, 4246, 12, 16],
            [2001, 4250, 79, 27],
            [2001, 4272, 33, 34],
            [2001, 4279, 28, 34],
            [2001, 4283, 20, 20],
            [2001, 4285, 38, 34],
            [2001, 4298, 50, 62],
            [2001, 4299, 23, 41],
            [2001, 4301, 67, 34],
            [2001, 4302, 18, 19],
            [2001, 4310, 36, 29],
            [2001, 4312, 63, 36],
            [2001, 4318, 21, 22],
            [2001, 4320, 34, 33],
            [2001, 4325, 66, 34],
            [2001, 4326, 11, 14],
            [2001, 4329, 23, 34],
            [2001, 4333, 18, 23],
            [2001, 4338, 34, 33],
            [2001, 4345, 20, 23],
            [2001, 4349, 32, 33],
            [2001, 4350, 20, 22],
            [2001, 4352, 22, 22],
            [2001, 4353, 30, 28],
            [2001, 4358, 13, 17],
            [2001, 4362, 54, 34],
            [2001, 4364, 21, 22],
            [2001, 4380, 19, 14],
            [2001, 4382, 63, 53],
            [2001, 4384, 37, 22],
            [2001, 4386, 15, 19],
            [2001, 4391, 21, 21],
            [2001, 4406, 51, 35],
            [2001, 4413, 13, 13],
            [2001, 4414, 15, 26],
            [2001, 4415, 105, 31],
            [2001, 4421, 33, 33],
            [2001, 4426, 11, 15],
            [2001, 4438, 63, 30],
            [2001, 4440, 50, 38],
            [2001, 4441, 17, 13],
            [2001, 4442, 15, 22],
            [2001, 4446, 33, 34],
            [2001, 4454, 25, 23],
            [2001, 4461, 41, 30],
            [2001, 4464, 64, 31],
            [2001, 4470, 35, 40],
            [2001, 4471, 22, 22],
            [2001, 4477, 34, 39],
            [2001, 4487, 37, 50],
            [2001, 4491, 55, 40],
            [2001, 4494, 20, 20],
            [2001, 4495, 30, 23],
            [2001, 4500, 30, 22],
            [2001, 4504, 68, 43],
            [2001, 4506, 21, 22],
            [2001, 4508, 37, 32],
            [2001, 4510, 30, 25],
            [2001, 4515, 33, 33],
            [2001, 4518, 44, 33],
            [2001, 4521, 31, 33],
            [2001, 4524, 32, 33],
            [2001, 4532, 24, 22],
            [2001, 4536, 23, 21],
            [2001, 4542, 50, 31],
            [2001, 4545, 56, 43],
            [2001, 4550, 32, 33],
            [2001, 4552, 16, 19],
            [2001, 4558, 30, 29],
            [2001, 4563, 32, 34],
            [2001, 4572, 33, 21],
            [2001, 4587, 36, 28],
            [2001, 4591, 24, 22],
            [2001, 4601, 61, 33],
            [2001, 4602, 26, 33],
            [2001, 4606, 21, 22],
            [2001, 4608, 23, 25],
            [2001, 4610, 64, 31],
            [2001, 4611, 21, 22],
            [2001, 4613, 52, 43],
            [2001, 4616, 24, 19],
            [2001, 4617, 100, 43],
            [2001, 4618, 29, 28],
            [2001, 4623, 15, 20],
            [2001, 4626, 38, 25],
            [2001, 4631, 16, 16],
            [2001, 4633, 21, 22],
            [2001, 4634, 33, 32],
            [2001, 4635, 90, 15],
            [2001, 4638, 80, 46],
            [2001, 4643, 24, 19],
            [2001, 4644, 14, 19],
            [2001, 4648, 32, 11],
            [2001, 4660, 70, 33],
            [2001, 4668, 33, 33],
            [2001, 4670, 70, 26],
            [2001, 4676, 14, 23],
            [2001, 4684, 25, 22],
            [2001, 4689, 50, 36],
            [2001, 4693, 34, 32],
            [2001, 4694, 24, 24],
            [2001, 4703, 11, 16],
            [2001, 4710, 9, 7],
            [2001, 4711, 17, 16],
            [2001, 4712, 27, 20],
            [2001, 4717, 22, 22],
            [2001, 4724, 38, 23],
            [2001, 4728, 27, 24],
            [2001, 4729, 42, 33],
            [2001, 4732, 96, 113],
            [2001, 4734, 19, 19],
            [2001, 4738, 46, 57],
            [2001, 4745, 20, 25],
            [2001, 4747, 74, 39],
            [2001, 4749, 50, 38],
            [2001, 4753, 28, 23],
            [2001, 4762, 69, 66],
            [2001, 4764, 58, 51],
            [2001, 4777, 23, 24],
            [2001, 4780, 21, 21],
            [2001, 4781, 30, 35],
            [2001, 4789, 45, 28],
            [2001, 4791, 21, 22],
            [2001, 4794, 29, 21],
            [2001, 4800, 32, 33],
            [2001, 4801, 11, 23],
            [2001, 4802, 32, 22],
            [2001, 4805, 15, 22],
            [2001, 4815, 32, 33],
            [2001, 4819, 20, 22],
            [2001, 4820, 60, 55],
            [2001, 4826, 22, 22],
            [2001, 4828, 44, 22],
            [2001, 4829, 22, 30],
            [2001, 4832, 12, 17],
            [2001, 4835, 30, 28],
            [2001, 4839, 44, 24],
            [2001, 4840, 65, 45],
            [2001, 4844, 23, 22],
            [2001, 4849, 23, 21],
            [2001, 4863, 50, 31],
            [2001, 4864, 21, 24],
            [2001, 4865, 35, 25],
            [2001, 4871, 18, 24],
            [2001, 4872, 32, 33],
            [2001, 4877, 27, 21],
            [2001, 4880, 17, 21],
            [2001, 4881, 32, 33],
            [2001, 4888, 62, 60],
            [2001, 4897, 18, 27],
            [2001, 4910, 32, 34],
            [2001, 4912, 11, 23],
            [2001, 4914, 37, 20],
            [2001, 4915, 23, 19],
            [2001, 4918, 25, 35],
            [2001, 4922, 44, 22],
            [2001, 4926, 28, 24],
            [2001, 4927, 21, 21],
            [2001, 4931, 21, 22],
            [2001, 4939, 26, 25],
            [2001, 4940, 50, 23],
            [2001, 4944, 15, 19],
            [2001, 4950, 32, 33],
            [2001, 4951, 55, 33],
            [2001, 4955, 33, 33],
            [2001, 4957, 21, 23],
            [2001, 4960, 129, 57],
            [2001, 4973, 35, 40],
            [2001, 4975, 34, 34],
            [2001, 4976, 12, 19],
            [2001, 4978, 83, 64],
            [2001, 4979, 108, 40],
            [2001, 4983, 25, 22],
            [2001, 4987, 20, 21],
            [2001, 4990, 22, 22],
            [2001, 4992, 27, 26],
            [2001, 4995, 32, 35],
            [2001, 4996, 32, 33],
            [2001, 4997, 31, 22],
            [2001, 4998, 32, 33],
            [2001, 5005, 19, 33],
            [2001, 5006, 55, 29],
            [2001, 5008, 32, 33],
            [2001, 5009, 19, 21],
            [2001, 5011, 33, 33],
            [2001, 5012, 27, 30],
            [2001, 5013, 12, 19],
            [2001, 5017, 34, 34],
            [2001, 5019, 58, 36],
            [2001, 5022, 99, 55],
            [2001, 5027, 34, 34],
            [2001, 5031, 11, 16],
            [2001, 5032, 24, 35],
            [2001, 5033, 21, 22],
            [2001, 5035, 32, 33],
            [2001, 5037, 34, 21],
            [2001, 5038, 12, 21],
            [2001, 5046, 32, 33],
            [2001, 5048, 24, 21],
            [2001, 5050, 13, 15],
            [2001, 5051, 12, 13],
            [2001, 5053, 32, 24],
            [2001, 5058, 32, 33],
            [2001, 5062, 39, 56],
            [2001, 5063, 27, 38],
            [2001, 5064, 32, 34],
            [2001, 5065, 31, 33],
            [2001, 5068, 35, 26],
            [2001, 5069, 33, 33],
            [2001, 5070, 22, 22],
            [2001, 5071, 33, 34],
            [2001, 5073, 68, 49],
            [2001, 5075, 22, 33],
            [2001, 5079, 21, 22],
            [2001, 5081, 41, 19],
            [2001, 5091, 60, 52],
            [2001, 5092, 12, 19],
            [2001, 5095, 14, 17],
            [2001, 5098, 21, 22],
            [2001, 5102, 20, 12],
            [2001, 5103, 33, 33],
            [2001, 5104, 67, 45],
            [2001, 5107, 61, 52],
            [2001, 5108, 24, 37],
            [2001, 5109, 24, 22],
            [2001, 5116, 29, 34],
            [2001, 5121, 21, 21],
            [2001, 5122, 33, 24],
            [2001, 5126, 21, 22],
            [2001, 5127, 22, 22],
            [2001, 5130, 62, 73],
            [2001, 5138, 16, 15],
            [2001, 5149, 26, 24],
            [2001, 5150, 76, 47],
            [2001, 5153, 40, 33],
            [2001, 5159, 47, 28],
            [2001, 5162, 24, 24],
            [2001, 5173, 51, 28],
            [2001, 5180, 23, 37],
            [2001, 5181, 20, 22],
            [2001, 5182, 23, 26],
            [2001, 5183, 33, 33],
            [2001, 5184, 40, 24],
            [2001, 5185, 36, 20],
            [2001, 5186, 13, 19],
            [2001, 5187, 12, 13],
            [2001, 5188, 12, 15],
            [2001, 5189, 20, 11],
            [2001, 5217, 65, 44],
            [2001, 5219, 17, 60],
            [2001, 5220, 14, 62],
            [2001, 5221, 13, 48],
            [2001, 5222, 16, 24],
            [2001, 5223, 11, 31],
            [2001, 5224, 16, 45],
            [2001, 5225, 17, 62],
            [2001, 5226, 12, 60],
            [2001, 5227, 31, 69],
            [2001, 5228, 20, 62],
            [2001, 5229, 11, 44],
            [2001, 5230, 16, 38],
            [2001, 5231, 15, 37],
            [2001, 5232, 20, 69],
            [2001, 5233, 24, 82],
            [2001, 5234, 11, 28],
            [2001, 5235, 43, 43],
            [2001, 5236, 16, 44],
            [2001, 5237, 33, 67],
            [2001, 5238, 20, 52],
            [2001, 5239, 25, 69],
            [2001, 5240, 19, 69],
            [2001, 5241, 29, 63],
            [2001, 5242, 23, 50],
            [2001, 5243, 28, 69],
            [2001, 5244, 20, 87],
            [2001, 5245, 26, 69],
            [2001, 5247, 40, 15],
            [2001, 5248, 41, 21],
            [2001, 5273, 27, 18],
            [2001, 5276, 34, 67],
            [2001, 5279, 23, 27],
            [2001, 5287, 13, 14],
            [2001, 5290, 24, 22],
            [2001, 5298, 14, 14],
            [2001, 5299, 19, 21],
            [2001, 5303, 35, 22],
            [2001, 5305, 29, 25],
            [2001, 5314, 23, 25],
            [2001, 5315, 20, 28],
            [2001, 5317, 48, 72],
            [2001, 5321, 22, 23],
            [2001, 5323, 14, 23],
            [2001, 5328, 22, 22],
            [2001, 5332, 25, 30],
            [2001, 5333, 14, 17],
            [2001, 5336, 17, 20],
            [2001, 5337, 18, 18],
            [2001, 5338, 34, 27],
            [2001, 5339, 22, 25],
            [2001, 5340, 32, 37],
            [2001, 5343, 17, 15],
            [2001, 5344, 45, 49],
            [2001, 5347, 21, 24],
            [2001, 5349, 24, 28],
            [2001, 5350, 22, 31],
            [2001, 5353, 21, 27],
            [2001, 5355, 25, 41],
            [2001, 5357, 30, 22],
            [2001, 5359, 18, 26],
            [2001, 5366, 32, 25],
            [2001, 5371, 35, 39],
            [2001, 5372, 24, 25],
            [2001, 5375, 21, 19],
            [2001, 5377, 18, 20],
            [2001, 5383, 30, 29],
            [2001, 5385, 34, 26],
            [2001, 5387, 17, 17],
            [2001, 5400, 14, 13],
            [2001, 5403, 25, 26],
            [2001, 5404, 25, 25],
            [2001, 5407, 21, 25],
            [2001, 5408, 19, 23],
            [2001, 5411, 27, 22],
            [2001, 5412, 24, 19],
            [2001, 5414, 13, 16],
            [2001, 5415, 49, 54],
            [2001, 5418, 29, 37],
            [2001, 5420, 17, 17],
            [2001, 5421, 19, 16],
            [2001, 5422, 26, 35],
            [2001, 5425, 17, 20],
            [2001, 5426, 23, 32],
            [2001, 5428, 19, 26],
            [2001, 5431, 22, 24],
            [2001, 5432, 23, 31],
            [2001, 5434, 16, 17],
            [2001, 5436, 23, 26],
            [2001, 5437, 29, 25],
            [2001, 5440, 41, 32],
            [2001, 5441, 32, 42],
            [2001, 5444, 22, 36],
            [2001, 5447, 21, 24],
            [2001, 5449, 27, 34],
            [2001, 5450, 29, 32],
            [2001, 5452, 23, 35],
            [2001, 5453, 35, 33],
            [2001, 5454, 15, 17],
            [2001, 5455, 29, 22],
            [2001, 5457, 17, 26],
            [2001, 5459, 26, 26],
            [2001, 5462, 23, 27],
            [2001, 5463, 15, 18],
            [2001, 5464, 19, 19],
            [2001, 5465, 24, 24],
            [2001, 5472, 25, 30],
            [2001, 5473, 19, 25],
            [2001, 5476, 16, 21],
            [2001, 5479, 21, 19],
            [2001, 5480, 37, 33],
            [2001, 5482, 18, 19],
            [2001, 5486, 23, 22],
            [2001, 5489, 35, 63],
            [2001, 5492, 23, 39],
            [2001, 5494, 26, 31],
            [2001, 5495, 33, 28],
            [2001, 5498, 37, 39],
            [2001, 5499, 34, 25],
            [2001, 5501, 28, 44],
            [2001, 5505, 20, 31],
            [2001, 5508, 26, 36],
            [2001, 5528, 21, 20],
            [2001, 5532, 26, 25],
            [2001, 5534, 18, 15],
            [2001, 5539, 17, 20],
            [2001, 5541, 27, 22],
            [2001, 5544, 23, 33],
            [2001, 5545, 17, 23],
            [2001, 5547, 27, 26],
            [2001, 5550, 17, 18],
            [2001, 5571, 28, 22],
            [2001, 5659, 9, 7],
            [2001, 5944, 7, 8],
            [2001, 5945, 11, 9],
            [2001, 5946, 6, 5],
            [2001, 5962, 77, 101],
            [2001, 5986, 65, 42],
            [2001, 5989, 50, 60],
            [2001, 5990, 50, 60],
            [2001, 5991, 50, 60],
            [2001, 5992, 50, 60],
            [2001, 5993, 50, 60],
            [2001, 5996, 63, 36],
            [2001, 6055, 70, 41],
            [2001, 6066, 38, 36],
            [2001, 6068, 66, 57],
            [2001, 6069, 71, 71],
            [2001, 6070, 71, 71],
            [2001, 6071, 36, 36],
            [2001, 6072, 26, 51],
            [2001, 6073, 41, 46],
            [2001, 6074, 46, 46],
            [2001, 6075, 71, 71],
            [2001, 6076, 51, 49],
            [2001, 6077, 41, 41],
            [2001, 6078, 51, 61],
            [2001, 6079, 50, 49],
            [2001, 6080, 51, 57],
            [2001, 6081, 31, 37],
            [2001, 6082, 46, 46],
            [2001, 6083, 41, 41],
            [2001, 6084, 61, 46],
            [2001, 6085, 51, 51],
            [2001, 6086, 31, 28],
            [2001, 6087, 121, 41],
            [2001, 6088, 50, 50],
            [2001, 6089, 41, 40],
            [2001, 6090, 71, 54],
            [2001, 6091, 36, 41],
            [2001, 6092, 41, 49],
            [2001, 6093, 46, 46],
            [2001, 6094, 46, 46],
            [2001, 6095, 31, 31],
            [2001, 6096, 41, 36],
            [2001, 6097, 50, 42],
            [2001, 6098, 41, 41],
            [2001, 6099, 61, 46],
            [2001, 6100, 46, 46],
            [2001, 6101, 46, 36],
            [2001, 6102, 31, 33],
            [2001, 6103, 41, 41],
            [2001, 6104, 51, 38],
            [2001, 6105, 61, 46],
            [2001, 6106, 36, 36],
            [2001, 6107, 36, 36],
            [2001, 6108, 46, 43],
            [2001, 6109, 26, 35],
            [2001, 6110, 41, 46],
            [2001, 6111, 20, 31],
            [2001, 6112, 41, 41],
            [2001, 6113, 31, 31],
            [2001, 6114, 31, 31],
            [2001, 6115, 31, 37],
            [2001, 6116, 46, 41],
            [2001, 6117, 36, 36],
            [2001, 6118, 46, 45],
            [2001, 6119, 41, 41],
            [2001, 6120, 26, 30],
            [2001, 6121, 41, 41],
            [2001, 6122, 41, 36],
            [2001, 6123, 30, 31],
            [2001, 6124, 46, 36],
            [2001, 6125, 36, 36],
            [2001, 6126, 41, 41],
            [2001, 6127, 41, 41],
            [2001, 6128, 35, 47],
            [2001, 6129, 21, 31],
            [2001, 6130, 41, 41],
            [2001, 6131, 41, 41],
            [2001, 6132, 46, 46],
            [2001, 6133, 41, 41],
            [2001, 6134, 41, 41],
            [2001, 6135, 121, 121],
            [2001, 6136, 101, 101],
            [2001, 6137, 21, 26],
            [2001, 6138, 36, 43],
            [2001, 6139, 41, 43],
            [2001, 6140, 26, 36],
            [2001, 6141, 41, 50],
            [2001, 6142, 35, 43],
            [2001, 6143, 36, 36],
            [2001, 6144, 31, 31],
            [2001, 6145, 46, 46],
            [2001, 6146, 20, 31],
            [2001, 6147, 31, 47],
            [2001, 6148, 31, 39],
            [2001, 6149, 41, 41],
            [2001, 6150, 21, 31],
            [2001, 6151, 31, 31],
            [2001, 6152, 26, 32],
            [2001, 6153, 29, 36],
            [2001, 6154, 41, 41],
            [2001, 6155, 26, 33],
            [2001, 6156, 31, 37],
            [2001, 6157, 50, 46],
            [2001, 6158, 31, 35],
            [2001, 6159, 46, 46],
            [2001, 6160, 26, 31],
            [2001, 6161, 19, 27],
            [2001, 6162, 25, 31],
            [2001, 6163, 71, 60],
            [2001, 6164, 41, 46],
            [2001, 6165, 36, 35],
            [2001, 6166, 61, 43],
            [2001, 6167, 71, 58],
            [2001, 6244, 67, 50],
            [2001, 6353, 25, 16],
            [2001, 6357, 35, 29],
            [2001, 6358, 27, 36],
            [2001, 6359, 26, 26],
            [2001, 6360, 107, 80],
            [2001, 6361, 107, 90],
            [2001, 6362, 65, 64],
            [2001, 6363, 65, 70],
            [2001, 6364, 107, 80],
            [2001, 6365, 111, 83],
            [2001, 6366, 111, 83],
            [2001, 6367, 63, 64],
            [2001, 6368, 107, 80],
            [2001, 6369, 70, 70],
            [2001, 6370, 106, 80],
            [2001, 6371, 107, 90],
            [2001, 6372, 111, 83],
            [2001, 6373, 111, 90],
            [2001, 6374, 107, 80],
            [2001, 6375, 120, 80],
            [2001, 6376, 71, 64],
            [2001, 6377, 120, 89],
            [2001, 6378, 65, 64],
            [2001, 6379, 71, 70],
            [2001, 6380, 70, 63],
            [2001, 6381, 71, 64],
            [2001, 6382, 107, 80],
            [2001, 6383, 71, 64],
            [2001, 6384, 107, 80],
            [2001, 6385, 107, 66],
            [2001, 6386, 107, 80],
            [2001, 6387, 106, 89],
            [2001, 6388, 107, 79],
            [2001, 6389, 111, 83],
            [2001, 6390, 107, 80],
            [2001, 6391, 64, 63],
            [2001, 6392, 107, 80],
            [2001, 6393, 120, 90],
            [2001, 6394, 111, 83],
            [2001, 6395, 107, 80],
            [2001, 6396, 111, 83],
            [2001, 6397, 107, 80],
            [2001, 6398, 120, 90],
            [2001, 6399, 111, 83],
            [2001, 6400, 105, 79],
            [2001, 6401, 70, 70],
            [2001, 6402, 111, 83],
            [2001, 6403, 120, 90],
            [2001, 6404, 111, 83],
            [2001, 6405, 111, 83],
            [2001, 6406, 107, 80],
            [2001, 6407, 107, 80],
            [2001, 6408, 107, 80],
            [2001, 6409, 107, 80],
            [2001, 6410, 107, 80],
            [2001, 6411, 104, 78],
            [2001, 6412, 107, 80],
            [2001, 6413, 120, 90],
            [2001, 6414, 120, 80],
            [2001, 6415, 107, 80],
            [2001, 6416, 111, 83],
            [2001, 6417, 111, 83],
            [2001, 6418, 120, 90],
            [2001, 6419, 111, 90],
            [2001, 6420, 120, 90],
            [2001, 6421, 107, 80],
            [2001, 6422, 107, 80],
            [2001, 6423, 33, 32],
            [2001, 6424, 71, 70],
            [2001, 6425, 71, 64],
            [2001, 6426, 107, 90],
            [2001, 6427, 120, 90],
            [2001, 6428, 120, 90],
            [2001, 6429, 120, 89],
            [2001, 6430, 65, 70],
            [2001, 6431, 107, 80],
            [2001, 6432, 107, 90],
            [2001, 6433, 58, 63],
            [2001, 6434, 107, 80],
            [2001, 6435, 70, 62],
            [2001, 6436, 120, 80],
            [2001, 6437, 111, 83],
            [2001, 6438, 107, 80],
            [2001, 6439, 107, 80],
            [2001, 6440, 120, 90],
            [2001, 6441, 105, 78],
            [2001, 6442, 64, 63],
            [2001, 6443, 107, 80],
            [2001, 6444, 82, 90],
            [2001, 6445, 107, 80],
            [2001, 6446, 111, 83],
            [2001, 6447, 64, 48],
            [2001, 6448, 107, 80],
            [2001, 6449, 111, 90],
            [2001, 6450, 120, 90],
            [2001, 6451, 111, 90],
            [2001, 6452, 120, 80],
            [2001, 6453, 107, 80],
            [2001, 6454, 107, 80],
            [2001, 6455, 107, 80],
            [2001, 6456, 107, 80],
            [2001, 6457, 36, 41],
            [2001, 6458, 28, 32],
            [2001, 6459, 120, 83],
            [2001, 6460, 120, 90],
            [2001, 6461, 107, 80],
            [2001, 6462, 106, 90],
            [2001, 6463, 107, 90],
            [2001, 6464, 120, 90],
            [2001, 6465, 111, 90],
            [2001, 6466, 106, 80],
            [2001, 6467, 120, 90],
            [2001, 6468, 111, 83],
            [2001, 6469, 107, 80],
            [2001, 6470, 107, 80],
            [2001, 6471, 107, 80],
            [2001, 6472, 111, 83],
            [2001, 6473, 111, 83],
            [2001, 6474, 107, 80],
            [2001, 6475, 107, 80],
            [2001, 6476, 107, 80],
            [2001, 6477, 115, 87],
            [2001, 6478, 107, 80],
            [2001, 6479, 107, 80],
            [2001, 6480, 107, 80],
            [2001, 6481, 111, 83],
            [2001, 6482, 111, 90],
            [2001, 6483, 107, 80],
            [2001, 6484, 71, 52],
            [2001, 6485, 105, 80],
            [2001, 6486, 111, 83],
            [2001, 6487, 107, 80],
            [2001, 6488, 107, 80],
            [2001, 6489, 107, 80],
            [2001, 6490, 107, 80],
            [2001, 6491, 107, 80],
            [2001, 6492, 29, 32],
            [2001, 6493, 107, 80],
            [2001, 6494, 29, 32],
            [2001, 6495, 105, 79],
            [2001, 6496, 107, 80],
            [2001, 6497, 120, 90],
            [2001, 6498, 120, 90],
            [2001, 6499, 120, 90],
            [2001, 6500, 71, 64],
            [2001, 6501, 107, 80],
            [2001, 6502, 63, 64],
            [2001, 6503, 107, 80],
            [2001, 6504, 107, 90],
            [2001, 6505, 107, 80],
            [2001, 6506, 107, 90],
            [2001, 6507, 111, 83],
            [2001, 6508, 111, 83],
            [2001, 6509, 107, 80],
            [2001, 6510, 120, 90],
            [2001, 6511, 107, 80],
            [2001, 6512, 107, 80],
            [2001, 6513, 26, 24],
            [2001, 6514, 106, 79],
            [2001, 6515, 107, 90],
            [2001, 6516, 71, 59],
            [2001, 6517, 34, 32],
            [2001, 6518, 107, 90],
            [2001, 6519, 120, 90],
            [2001, 6520, 120, 90],
            [2001, 6521, 53, 52],
            [2001, 6522, 107, 80],
            [2001, 6523, 120, 90],
            [2001, 6524, 120, 91],
            [2001, 6525, 107, 80],
            [2001, 6526, 111, 83],
            [2001, 6527, 107, 80],
            [2001, 6528, 107, 80],
            [2001, 6529, 120, 90],
            [2001, 6530, 105, 79],
            [2001, 6531, 111, 90],
            [2001, 6532, 107, 80],
            [2001, 6533, 107, 80],
            [2001, 6534, 107, 90],
            [2001, 6535, 111, 83],
            [2001, 6536, 34, 37],
            [2001, 6537, 111, 83],
            [2001, 6538, 111, 90],
            [2001, 6539, 107, 80],
            [2001, 6540, 111, 90],
            [2001, 6541, 111, 83],
            [2001, 6542, 111, 83],
            [2001, 6543, 111, 83],
            [2001, 6544, 111, 83],
            [2001, 6546, 111, 83],
            [2001, 6547, 120, 90],
            [2001, 6548, 111, 83],
            [2001, 6549, 111, 90],
            [2001, 6550, 111, 83],
            [2001, 6551, 111, 83],
            [2001, 6552, 111, 90],
            [2001, 6553, 111, 83],
            [2001, 6554, 111, 83],
            [2001, 6555, 111, 83],
            [2001, 6556, 111, 83],
            [2001, 6557, 111, 83],
            [2001, 6558, 107, 80],
            [2001, 6559, 111, 83],
            [2001, 6560, 107, 80],
            [2001, 6561, 111, 90],
            [2001, 6562, 111, 83],
            [2001, 6563, 111, 83],
            [2001, 6564, 111, 83],
            [2001, 6565, 120, 90],
            [2001, 6566, 107, 70],
            [2001, 6567, 111, 83],
            [2001, 6568, 107, 80],
            [2001, 6569, 107, 80],
            [2001, 6570, 111, 83],
            [2001, 6572, 111, 83],
            [2001, 6573, 107, 80],
            [2001, 6574, 107, 80],
            [2001, 6575, 106, 79],
            [2001, 6576, 107, 80],
            [2001, 6577, 107, 80],
            [2001, 6578, 107, 80],
            [2001, 6579, 111, 83],
            [2001, 6580, 107, 80],
            [2001, 6581, 120, 90],
            [2001, 6582, 107, 80],
            [2001, 6583, 120, 90],
            [2001, 6584, 115, 87],
            [2001, 6585, 107, 80],
            [2001, 6586, 107, 80],
            [2001, 6587, 107, 80],
            [2001, 6588, 107, 80],
            [2001, 6589, 107, 80],
            [2001, 6590, 115, 87],
            [2001, 6591, 111, 83],
            [2001, 6592, 111, 83],
            [2001, 6593, 111, 83],
            [2001, 6594, 111, 83],
            [2001, 6595, 107, 80],
            [2001, 6596, 107, 80],
            [2001, 6597, 111, 83],
            [2001, 6598, 111, 83],
            [2001, 6599, 120, 90],
            [2001, 6600, 107, 80],
            [2001, 6601, 111, 83],
            [2001, 6602, 107, 80],
            [2001, 6603, 65, 64],
            [2001, 6604, 111, 90],
            [2001, 6605, 107, 80],
            [2001, 6606, 107, 80],
            [2001, 6607, 120, 80],
            [2001, 6608, 107, 80],
            [2001, 6609, 107, 80],
            [2001, 6610, 107, 80],
            [2001, 6611, 65, 64],
            [2001, 6612, 107, 90],
            [2001, 6613, 107, 80],
            [2001, 6614, 34, 37],
            [2001, 6615, 107, 80],
            [2001, 6616, 107, 80],
            [2001, 6617, 38, 33],
            [2001, 6618, 107, 80],
            [2001, 6619, 111, 83],
            [2001, 6620, 111, 83],
            [2001, 6621, 107, 80],
            [2001, 6622, 107, 80],
            [2001, 6623, 120, 90],
            [2001, 6624, 120, 83],
            [2001, 6625, 111, 83],
            [2001, 6626, 120, 90],
            [2001, 6627, 107, 80],
            [2001, 6628, 111, 90],
            [2001, 6629, 65, 70],
            [2001, 6630, 70, 70],
            [2001, 6631, 61, 73],
            [2001, 6632, 26, 31],
            [2001, 6633, 36, 43],
            [2001, 6634, 46, 46],
            [2001, 6635, 51, 51],
            [2001, 6636, 81, 81],
            [2001, 6637, 61, 46],
            [2001, 6638, 71, 58],
            [2001, 6639, 51, 64],
            [2001, 6640, 72, 80],
            [2001, 6643, 51, 48],
            [2001, 6649, 61, 48],
            [2001, 6650, 61, 46],
            [2001, 6651, 41, 31],
            [2001, 6652, 61, 46],
            [2001, 6653, 56, 56],
            [2001, 6654, 41, 41],
            [2001, 6655, 36, 36],
            [2001, 6656, 46, 41],
            [2001, 6657, 51, 51],
            [2001, 6660, 46, 33],
            [2001, 6661, 36, 36],
            [2001, 6662, 53, 46],
            [2001, 6663, 41, 41],
            [2001, 6664, 50, 50],
            [2001, 6665, 41, 41],
            [2001, 6666, 41, 36],
            [2001, 6667, 41, 41],
            [2001, 6668, 41, 30],
            [2001, 6669, 50, 50],
            [2001, 6670, 41, 41],
            [2001, 6671, 61, 41],
            [2001, 6672, 46, 36],
            [2001, 6673, 46, 41],
            [2001, 6674, 46, 46],
            [2001, 6675, 41, 41],
            [2001, 6676, 61, 61],
            [2001, 6677, 41, 41],
            [2001, 6678, 41, 41],
            [2001, 6679, 101, 101],
            [2001, 6680, 36, 36],
            [2001, 6682, 36, 36],
            [2001, 6683, 41, 41],
            [2001, 6684, 36, 50],
            [2001, 6685, 30, 35],
            [2001, 6686, 31, 37],
            [2001, 6687, 31, 37],
            [2001, 6688, 31, 37],
            [2001, 6689, 30, 37],
            [2001, 6690, 31, 37],
            [2001, 6697, 40, 31],
            [2001, 6699, 73, 61],
            [2001, 6700, 88, 80],
            [2001, 6701, 73, 93],
            [2001, 6702, 74, 49],
            [2001, 6704, 59, 50],
            [2001, 6706, 49, 47],
            [2001, 6708, 69, 69],
            [2001, 6715, 72, 60],
            [2001, 6716, 92, 60],
            [2001, 6718, 101, 76],
            [2001, 6722, 78, 62],
            [2001, 6723, 70, 53],
            [2001, 6725, 53, 54],
            [2001, 6726, 103, 69],
            [2001, 6728, 63, 62],
            [2001, 6730, 53, 54],
            [2001, 6734, 69, 52],
            [2001, 6737, 74, 62],
            [2001, 6738, 60, 60],
            [2001, 6741, 17, 20],
            [2001, 6748, 36, 36],
            [2001, 6749, 41, 41],
            [2001, 6750, 61, 61],
            [2001, 6752, 31, 37],
            [2001, 6753, 51, 46],
            [2001, 6754, 46, 46],
            [2001, 6755, 61, 61],
            [2001, 6756, 51, 51],
            [2001, 6757, 46, 46],
            [2001, 6758, 51, 65],
            [2001, 6759, 31, 37],
            [2001, 6760, 61, 61],
            [2001, 6761, 61, 61],
            [2001, 6762, 51, 51],
            [2001, 6763, 31, 31],
            [2001, 6764, 46, 51],
            [2001, 6766, 71, 74],
            [2001, 6767, 41, 45],
            [2001, 6768, 46, 46],
            [2001, 6769, 61, 78],
            [2001, 6770, 51, 61],
            [2001, 6771, 51, 56],
            [2001, 6772, 41, 52],
            [2001, 6773, 71, 65],
            [2001, 6777, 71, 70],
            [2001, 6778, 41, 41],
            [2001, 6779, 51, 61],
            [2001, 6780, 51, 57],
            [2001, 6781, 61, 61],
            [2001, 6782, 101, 91],
            [2001, 6783, 71, 71],
            [2001, 6784, 51, 51],
            [2001, 6785, 51, 51],
            [2001, 6786, 51, 61],
            [2001, 6787, 46, 58],
            [2001, 6789, 61, 61],
            [2001, 6790, 103, 78],
            [2001, 6791, 96, 65],
            [2001, 6794, 102, 77],
            [2001, 6795, 75, 66],
            [2001, 6798, 98, 67],
            [2001, 6803, 80, 69],
            [2001, 6804, 80, 69],
            [2001, 6805, 105, 79],
            [2001, 6806, 75, 69],
            [2001, 6807, 101, 69],
            [2001, 6808, 104, 79],
            [2001, 6812, 117, 103],
            [2001, 6813, 101, 76],
            [2001, 6814, 96, 89],
            [2001, 6816, 98, 82],
            [2001, 6818, 21, 24],
            [2001, 6819, 39, 47],
            [2001, 6820, 38, 44],
            [2001, 6821, 51, 52],
            [2001, 6822, 54, 53],
            [2001, 6823, 50, 52],
            [2001, 6833, 93, 72],
            [2001, 6834, 104, 87],
            [2001, 6835, 113, 87],
            [2001, 6836, 103, 80],
            [2001, 6837, 104, 78],
            [2001, 6838, 116, 89],
            [2001, 6841, 41, 30],
            [2001, 6845, 103, 78],
            [2001, 6846, 115, 99],
            [2001, 6847, 102, 77],
            [2001, 6848, 105, 79],
            [2001, 6849, 68, 67],
            [2001, 6850, 103, 78],
            [2001, 6851, 102, 77],
            [2001, 6852, 106, 80],
            [2001, 6853, 106, 80],
            [2001, 6854, 101, 84],
            [2001, 6855, 104, 79],
            [2001, 6856, 103, 78],
            [2001, 6857, 104, 87],
            [2001, 6858, 109, 82],
            [2001, 6859, 93, 71],
            [2001, 6860, 103, 78],
            [2001, 6861, 106, 88],
            [2001, 6862, 106, 80],
            [2001, 6867, 12, 20],
            [2001, 6868, 12, 17],
            [2001, 6869, 15, 18],
            [2001, 6870, 15, 21],
            [2001, 6871, 16, 19],
            [2001, 6872, 12, 18],
            [2001, 6873, 21, 21],
            [2001, 6874, 17, 21],
            [2001, 6875, 16, 20],
            [2001, 6876, 15, 22],
            [2001, 6877, 18, 21],
            [2001, 6878, 15, 19],
            [2001, 6879, 15, 22],
            [2001, 6880, 21, 27],
            [2001, 6881, 15, 15],
            [2001, 6882, 16, 21],
            [2001, 6883, 15, 23],
            [2001, 6884, 7, 8],
            [2001, 6885, 26, 16],
            [2001, 6886, 12, 17],
            [2001, 6887, 120, 40],
            [2001, 6888, 11, 12],
            [2001, 6889, 22, 14],
            [2001, 6890, 8, 10],
            [2001, 6891, 18, 17],
            [2001, 6892, 9, 10],
            [2001, 6893, 23, 15],
            [2001, 6894, 7, 9],
            [2001, 6895, 29, 16],
            [2001, 6896, 9, 12],
            [2001, 6897, 16, 16],
            [2001, 6898, 6, 8],
            [2001, 6899, 30, 14],
            [2001, 6900, 6, 7],
            [2001, 6901, 25, 16],
            [2001, 6902, 11, 16],
            [2001, 6903, 36, 25],
            [2001, 6904, 12, 12],
            [2001, 6905, 45, 26],
            [2001, 6906, 8, 10],
            [2001, 6907, 26, 17],
            [2001, 6908, 8, 8],
            [2001, 6909, 25, 19],
            [2001, 6910, 36, 31],
            [2001, 6911, 65, 44],
            [2001, 6912, 40, 25],
            [2001, 6913, 71, 43],
            [2001, 6914, 13, 12],
            [2001, 6915, 42, 41],
            [2001, 6916, 11, 12],
            [2001, 6917, 31, 37],
            [2001, 6918, 31, 25],
            [2001, 6919, 31, 31],
            [2001, 6920, 31, 25],
            [2001, 6921, 54, 40],
            [2001, 6922, 15, 13],
            [2001, 6923, 59, 43],
            [2001, 6924, 11, 12],
            [2001, 6925, 45, 45],
            [2001, 6926, 75, 31],
            [2001, 6927, 75, 41],
            [2001, 6928, 21, 20],
            [2001, 6929, 60, 45],
            [2001, 6930, 22, 15],
            [2001, 6931, 42, 45],
            [2001, 6932, 21, 14],
            [2001, 6933, 31, 29],
            [2001, 6934, 21, 15],
            [2001, 6935, 50, 55],
            [2001, 6936, 25, 23],
            [2001, 6937, 53, 45],
            [2001, 6938, 23, 15],
            [2001, 6939, 55, 42],
            [2001, 6940, 13, 11],
            [2001, 6941, 33, 26],
            [2001, 6942, 35, 30],
            [2001, 6943, 65, 44],
            [2001, 6944, 12, 12],
            [2001, 6945, 84, 65],
            [2001, 6946, 71, 37],
            [2001, 6947, 75, 55],
            [2001, 6948, 15, 13],
            [2001, 6949, 54, 41],
            [2001, 6950, 18, 15],
            [2001, 6951, 60, 45],
            [2001, 6952, 69, 28],
            [2001, 6953, 72, 41],
            [2001, 6954, 31, 18],
            [2001, 6955, 54, 41],
            [2001, 6956, 20, 16],
            [2001, 6957, 84, 73],
            [2001, 6958, 16, 12],
            [2001, 6959, 55, 45],
            [2001, 6960, 12, 11],
            [2001, 6961, 31, 28],
            [2001, 6962, 14, 12],
            [2001, 6963, 12, 11],
            [2001, 6964, 28, 18],
            [2001, 6965, 9, 10],
            [2001, 6966, 34, 77],
            [2001, 6967, 25, 74],
            [2001, 6968, 44, 97],
            [2001, 6969, 26, 66],
            [2001, 6970, 36, 80],
            [2001, 6971, 38, 29],
            [2001, 6972, 77, 35],
            [2001, 6973, 24, 12],
            [2001, 6974, 6, 7],
            [2001, 6975, 9, 10],
            [2001, 6976, 22, 18],
            [2001, 6977, 7, 9],
            [2001, 6978, 53, 21],
            [2001, 6979, 7, 9],
            [2001, 6980, 20, 15],
            [2001, 6981, 9, 9],
            [2001, 6982, 29, 17],
            [2001, 6983, 12, 14],
            [2001, 6984, 34, 26],
            [2001, 6985, 60, 34],
            [2001, 6986, 120, 49],
            [2001, 6987, 9, 9],
            [2001, 6988, 27, 12],
            [2001, 6989, 15, 16],
            [2001, 6990, 32, 23],
            [2001, 6991, 7, 5],
            [2001, 6992, 24, 13],
            [2001, 6993, 8, 8],
            [2001, 6994, 61, 26],
            [2001, 6995, 11, 11],
            [2001, 6996, 22, 16],
            [2001, 6997, 7, 6],
            [2001, 6998, 15, 8],
            [2001, 6999, 7, 7],
            [2001, 7000, 21, 15],
            [2001, 7001, 7, 7],
            [2001, 7002, 18, 14],
            [2001, 7003, 8, 8],
            [2001, 7004, 18, 14],
            [2001, 7005, 15, 15],
            [2001, 7006, 31, 25],
            [2001, 7007, 43, 33],
            [2001, 7008, 43, 33],
            [2001, 7009, 21, 15],
            [2001, 7010, 21, 15],
            [2001, 7011, 10, 10],
            [2001, 7012, 24, 23],
            [2001, 7013, 32, 21],
            [2001, 7014, 13, 11],
            [2001, 7015, 12, 9],
            [2001, 7019, 11, 10],
            [2001, 7020, 43, 45],
            [2001, 7021, 13, 12],
            [2001, 7022, 23, 23],
            [2001, 7023, 19, 19],
            [2001, 7024, 31, 31],
            [2001, 7025, 15, 13],
            [2001, 7026, 31, 25],
            [2001, 7027, 22, 21],
            [2001, 7028, 43, 45],
            [2001, 7029, 45, 31],
            [2001, 7030, 62, 45],
            [2001, 7031, 15, 13],
            [2001, 7032, 31, 25],
            [2001, 7033, 25, 25],
            [2001, 7034, 40, 33],
            [2001, 7035, 11, 12],
            [2001, 7036, 31, 31],
            [2001, 7037, 31, 33],
            [2001, 7038, 41, 45],
            [2001, 7039, 25, 14],
            [2001, 7040, 33, 31],
            [2001, 7041, 15, 13],
            [2001, 7042, 62, 58],
            [2001, 7043, 21, 31],
            [2001, 7044, 31, 31],
            [2001, 7045, 40, 25],
            [2001, 7046, 58, 41],
            [2001, 7047, 20, 15],
            [2001, 7048, 31, 25],
            [2001, 7049, 55, 41],
            [2001, 7050, 23, 17],
            [2001, 7051, 61, 45],
            [2001, 7052, 17, 15],
            [2001, 7053, 55, 45],
            [2001, 7054, 18, 15],
            [2001, 7055, 45, 32],
            [2001, 7056, 15, 15],
            [2001, 7057, 66, 45],
            [2001, 7058, 31, 19],
            [2001, 7059, 61, 45],
            [2001, 7060, 32, 21],
            [2001, 7061, 55, 45],
            [2001, 7062, 20, 14],
            [2001, 7063, 55, 25],
            [2001, 7064, 32, 15],
            [2001, 7065, 45, 45],
            [2001, 7066, 13, 13],
            [2001, 7067, 56, 46],
            [2001, 7068, 45, 35],
            [2001, 7069, 75, 65],
            [2001, 7070, 31, 21],
            [2001, 7071, 61, 45],
            [2001, 7072, 11, 12],
            [2001, 7073, 31, 31],
            [2001, 7074, 26, 21],
            [2001, 7075, 56, 60],
            [2001, 7076, 31, 25],
            [2001, 7077, 44, 31],
            [2001, 7078, 11, 12],
            [2001, 7079, 31, 25],
            [2001, 7080, 47, 41],
            [2001, 7081, 82, 64],
            [2001, 7082, 31, 25],
            [2001, 7083, 45, 45],
            [2001, 7084, 70, 24],
            [2001, 7085, 71, 45],
            [2001, 7086, 13, 12],
            [2001, 7087, 46, 41],
            [2001, 7088, 31, 28],
            [2001, 7089, 61, 45],
            [2001, 7090, 22, 12],
            [2001, 7091, 60, 45],
            [2001, 7092, 63, 27],
            [2001, 7093, 82, 70],
            [2001, 7094, 42, 31],
            [2001, 7095, 64, 45],
            [2001, 7096, 31, 25],
            [2001, 7097, 45, 31],
            [2001, 7098, 31, 31],
            [2001, 7099, 58, 46],
            [2001, 7100, 15, 13],
            [2001, 7101, 21, 20],
            [2001, 7102, 15, 11],
            [2001, 7103, 37, 18],
            [2001, 7104, 10, 7],
            [2001, 7105, 22, 13],
            [2001, 7106, 5, 7],
            [2001, 7107, 22, 12],
            [2001, 7108, 12, 10],
            [2001, 7109, 30, 16],
            [2001, 7110, 9, 11],
            [2001, 7111, 28, 14],
            [2001, 7112, 5, 5],
            [2001, 7113, 34, 14],
            [2001, 7114, 29, 21],
            [2001, 7115, 49, 27],
            [2001, 7116, 11, 12],
            [2001, 7117, 34, 22],
            [2001, 7118, 8, 16],
            [2001, 7119, 17, 16],
            [2001, 7120, 12, 14],
            [2001, 7121, 43, 38],
            [2001, 7122, 10, 8],
            [2001, 7123, 30, 17],
            [2001, 7124, 7, 10],
            [2001, 7125, 16, 16],
            [2001, 7126, 8, 7],
            [2001, 7127, 21, 16],
            [2001, 7128, 9, 8],
            [2001, 7129, 21, 14],
            [2001, 7130, 8, 9],
            [2001, 7131, 24, 14],
            [2001, 7132, 9, 8],
            [2001, 7133, 35, 21],
            [2001, 7134, 18, 11],
            [2001, 7135, 26, 11],
            [2001, 7136, 19, 14],
            [2001, 7137, 35, 20],
            [2001, 7138, 10, 9],
            [2001, 7139, 26, 19],
            [2001, 7140, 6, 7],
            [2001, 7141, 14, 12],
            [2001, 7142, 9, 11],
            [2001, 7143, 26, 15],
            [2001, 7144, 9, 9],
            [2001, 7145, 18, 14],
            [2001, 7146, 11, 12],
            [2001, 7147, 29, 22],
            [2001, 7148, 9, 11],
            [2001, 7149, 37, 21],
            [2001, 7150, 5, 9],
            [2001, 7151, 18, 14],
            [2001, 7152, 8, 8],
            [2001, 7153, 29, 21],
            [2001, 7154, 18, 21],
            [2001, 7155, 26, 24],
            [2001, 7156, 20, 19],
            [2001, 7157, 10, 8],
            [2001, 7158, 46, 23],
            [2001, 7159, 21, 15],
            [2001, 7160, 49, 32],
            [2001, 7161, 9, 11],
            [2001, 7162, 27, 22],
            [2001, 7163, 8, 7],
            [2001, 7164, 22, 13],
            [2001, 7165, 13, 11],
            [2001, 7166, 58, 32],
            [2001, 7167, 7, 8],
            [2001, 7168, 28, 18],
            [2001, 7169, 5, 5],
            [2001, 7170, 38, 23],
            [2001, 7171, 6, 7],
            [2001, 7172, 44, 27],
            [2001, 7173, 14, 14],
            [2001, 7174, 70, 42],
            [2001, 7175, 6, 5],
            [2001, 7176, 17, 13],
            [2001, 7177, 16, 10],
            [2001, 7178, 23, 13],
            [2001, 7179, 16, 14],
            [2001, 7180, 50, 31],
            [2001, 7181, 10, 10],
            [2001, 7182, 43, 20],
            [2001, 7183, 20, 12],
            [2001, 7184, 92, 62],
            [2001, 7185, 19, 15],
            [2001, 7186, 53, 28],
            [2001, 7187, 14, 11],
            [2001, 7188, 49, 27],
            [2001, 7189, 18, 16],
            [2001, 7190, 46, 27],
            [2001, 7191, 18, 13],
            [2001, 7192, 27, 16],
            [2001, 7193, 14, 13],
            [2001, 7194, 21, 12],
            [2001, 7195, 15, 13],
            [2001, 7196, 42, 24],
            [2001, 7197, 8, 6],
            [2001, 7198, 22, 11],
            [2001, 7199, 16, 11],
            [2001, 7200, 35, 18],
            [2001, 7201, 6, 5],
            [2001, 7202, 14, 9],
            [2001, 7203, 10, 7],
            [2001, 7204, 18, 16],
            [2001, 7205, 20, 17],
            [2001, 7206, 56, 31],
            [2001, 7207, 15, 15],
            [2001, 7208, 42, 27],
            [2001, 7209, 17, 10],
            [2001, 7210, 50, 41],
            [2001, 7211, 10, 10],
            [2001, 7212, 28, 16],
            [2001, 7213, 8, 9],
            [2001, 7214, 70, 35],
            [2001, 7215, 8, 6],
            [2001, 7216, 56, 28],
            [2001, 7217, 13, 10],
            [2001, 7218, 32, 21],
            [2001, 7219, 18, 18],
            [2001, 7220, 38, 25],
            [2001, 7221, 15, 12],
            [2001, 7222, 34, 24],
            [2001, 7223, 12, 11],
            [2001, 7224, 43, 22],
            [2001, 7225, 7, 8],
            [2001, 7226, 29, 17],
            [2001, 7227, 11, 11],
            [2001, 7228, 32, 23],
            [2001, 7229, 14, 9],
            [2001, 7230, 62, 30],
            [2001, 7231, 11, 9],
            [2001, 7232, 32, 20],
            [2001, 7233, 8, 6],
            [2001, 7234, 27, 16],
            [2001, 7235, 12, 10],
            [2001, 7236, 21, 16],
            [2001, 7237, 7, 7],
            [2001, 7238, 21, 14],
            [2001, 7239, 8, 8],
            [2001, 7240, 19, 13],
            [2001, 7241, 21, 22],
            [2001, 7242, 28, 15],
            [2001, 7243, 5, 6],
            [2001, 7244, 18, 12],
            [2001, 7245, 5, 7],
            [2001, 7246, 27, 15],
            [2001, 7247, 7, 9],
            [2001, 7248, 26, 18],
            [2001, 7249, 7, 8],
            [2001, 7250, 25, 16],
            [2001, 7251, 18, 20],
            [2001, 7252, 30, 24],
            [2001, 7253, 16, 10],
            [2001, 7254, 59, 18],
            [2001, 7255, 48, 25],
            [2001, 7256, 26, 17],
            [2001, 7257, 120, 90],
            [2001, 7258, 120, 90],
            [2001, 7259, 103, 65],
            [2001, 7260, 124, 95],
            [2001, 7261, 103, 91],
            [2001, 7262, 118, 138],
            [2001, 7263, 107, 95],
            [2001, 7264, 124, 145],
            [2001, 7265, 104, 92],
            [2001, 7266, 126, 96],
            [2001, 7267, 103, 91],
            [2001, 7268, 125, 96],
            [2001, 7269, 125, 96],
            [2001, 7270, 102, 65],
            [2001, 7271, 69, 68],
            [2001, 7272, 124, 95],
            [2001, 7273, 124, 145],
            [2001, 7274, 124, 94],
            [2001, 7275, 105, 94],
            [2001, 7276, 67, 64],
            [2001, 7277, 104, 92],
            [2001, 7278, 118, 139],
            [2001, 7279, 120, 90],
            [2001, 7280, 126, 96],
            [2001, 7281, 103, 91],
            [2001, 7282, 117, 137],
            [2001, 7283, 15, 25],
            [2001, 7284, 11, 10],
            [2001, 7285, 12, 11],
            [2001, 7286, 20, 31],
            [2001, 7287, 17, 35],
            [2001, 7288, 37, 40],
            [2001, 7289, 43, 31],
            [2001, 7290, 69, 45],
            [2001, 7291, 52, 43],
            [2001, 7292, 49, 52],
            [2001, 7293, 33, 31],
            [2001, 7294, 32, 31],
            [2001, 7295, 15, 14],
            [2001, 7296, 27, 23],
            [2001, 7297, 29, 25],
            [2001, 7298, 16, 20],
            [2001, 7299, 17, 22],
            [2001, 7300, 21, 34],
            [2001, 7301, 13, 30],
            [2001, 7302, 55, 64],
            [2001, 7303, 84, 81],
            [2001, 7304, 43, 48],
            [2001, 7305, 58, 60],
            [2001, 7306, 39, 47],
            [2001, 7307, 57, 64],
            [2001, 7308, 46, 53],
            [2001, 7309, 43, 51],
            [2001, 7310, 89, 77],
            [2001, 7311, 72, 71],
            [2001, 7312, 56, 61],
            [2001, 7313, 115, 85],
            [2001, 7314, 109, 82],
            [2001, 7315, 107, 81],
            [2001, 7316, 109, 82],
            [2001, 7317, 110, 82],
            [2001, 7318, 109, 82],
            [2001, 7319, 116, 86],
            [2001, 7320, 108, 81],
            [2001, 7321, 140, 105],
            [2001, 7322, 109, 82],
            [2001, 7323, 138, 103],
            [2001, 7324, 115, 85],
            [2001, 7325, 110, 82],
            [2001, 7326, 109, 82],
            [2001, 7327, 138, 104],
            [2001, 7328, 42, 50],
            [2001, 7329, 77, 75],
            [2001, 7330, 57, 56],
            [2001, 7331, 57, 56],
            [2001, 7332, 42, 49],
            [2001, 7333, 78, 99],
            [2001, 7337, 16, 16],
            [2001, 7342, 14, 9],
            [2001, 7343, 14, 9],
            [2001, 7344, 12, 9],
            [2001, 7348, 12, 8],
            [2001, 7352, 11, 9],
            [2001, 7354, 14, 14],
            [2001, 7356, 11, 8],
            [2001, 7357, 22, 11],
            [2001, 7358, 16, 11],
            [2001, 7359, 27, 12],
            [2001, 7360, 13, 10],
            [2001, 7362, 11, 9],
            [2001, 7363, 13, 12],
            [2001, 7364, 12, 12],
            [2001, 7367, 13, 8],
            [2001, 7370, 12, 11],
            [2001, 7371, 17, 12],
            [2001, 7372, 19, 10],
            [2001, 7373, 15, 11],
            [2001, 7374, 11, 8],
            [2001, 7375, 12, 8],
            [2001, 7376, 9, 8],
            [2001, 7377, 11, 8],
            [2001, 7378, 21, 20],
            [2001, 7379, 37, 28],
            [2001, 7396, 56, 56],
            [2001, 7397, 94, 72],
            [2001, 7398, 56, 56],
            [2001, 7399, 41, 49],
            [2001, 7400, 63, 62],
            [2001, 7401, 41, 49],
            [2001, 7402, 79, 101],
            [2001, 7403, 34, 41],
            [2001, 7404, 100, 75],
            [2001, 7405, 55, 56],
            [2001, 7406, 75, 94],
            [2001, 7407, 56, 56],
            [2001, 7408, 63, 78],
            [2001, 7409, 25, 31],
            [2001, 7410, 26, 32],
            [2001, 7411, 26, 32],
            [2001, 7412, 60, 65],
            [2001, 7413, 24, 31],
            [2001, 7414, 25, 31],
            [2001, 7415, 23, 36],
            [2001, 7416, 33, 42],
            [2001, 7417, 26, 33],
            [2001, 7418, 29, 32],
            [2001, 7419, 65, 72],
            [2001, 7420, 24, 32],
            [2001, 7421, 49, 57],
            [2001, 7422, 25, 31],
            [2001, 7423, 40, 43],
            [2001, 7424, 65, 60],
            [2001, 7425, 48, 41],
            [2001, 7426, 81, 70],
            [2001, 7427, 60, 57],
            [2001, 7428, 60, 60],
            [2001, 7429, 36, 40],
            [2001, 7430, 56, 43],
            [2001, 7431, 40, 43],
            [2001, 7432, 97, 74],
            [2001, 7433, 60, 56],
            [2001, 7434, 101, 64],
            [2001, 7435, 66, 61],
            [2001, 7436, 78, 70],
            [2001, 7437, 34, 45],
            [2001, 7438, 61, 60],
            [2001, 7439, 55, 50],
            [2001, 7440, 84, 75],
            [2001, 7441, 50, 46],
            [2001, 7442, 75, 65],
            [2001, 7443, 75, 67],
            [2001, 7444, 92, 75],
            [2001, 7445, 75, 63],
            [2001, 7446, 105, 80],
            [2001, 7447, 46, 47],
            [2001, 7448, 78, 77],
            [2001, 7449, 28, 27],
            [2001, 7450, 28, 32],
            [2001, 7451, 17, 20],
            [2001, 7452, 32, 21],
            [2001, 7453, 81, 39],
            [2001, 7454, 24, 25],
            [2001, 7455, 33, 30],
            [2001, 7456, 101, 76],
            [2001, 7457, 71, 71],
            [2001, 7458, 51, 51],
            [2001, 7459, 71, 71],
            [2001, 7460, 71, 81],
            [2001, 7461, 51, 50],
            [2001, 7462, 61, 61],
            [2001, 7463, 71, 71],
            [2001, 7464, 81, 61],
            [2001, 7465, 81, 61],
            [2001, 7466, 71, 53],
            [2001, 7467, 71, 71],
            [2001, 7468, 61, 61],
            [2001, 7469, 86, 65],
            [2001, 7470, 91, 68],
            [2001, 7471, 116, 87],
            [2001, 7472, 41, 91],
            [2001, 7473, 51, 61],
            [2001, 7474, 71, 71],
            [2001, 7475, 71, 71],
            [2001, 7476, 66, 66],
            [2001, 7477, 56, 56],
            [2001, 7478, 61, 61],
            [2001, 7479, 61, 61],
            [2001, 7480, 71, 60],
            [2001, 7481, 51, 61],
            [2001, 7482, 71, 53],
            [2001, 7483, 71, 71],
            [2001, 7484, 51, 61],
            [2001, 7485, 121, 91],
            [2001, 7486, 101, 76],
            [2001, 7487, 66, 66],
            [2001, 7488, 81, 61],
            [2001, 7489, 86, 55],
            [2001, 7490, 61, 61],
            [2001, 7491, 81, 61],
            [2001, 7492, 101, 76],
            [2001, 7493, 71, 71],
            [2001, 7494, 71, 71],
            [2001, 7495, 71, 71],
            [2001, 7496, 121, 91],
            [2001, 7497, 81, 61],
            [2001, 7498, 51, 61],
            [2001, 7499, 60, 51],
            [2001, 7500, 61, 61],
            [2001, 7501, 81, 61],
            [2001, 7502, 80, 61],
            [2001, 7503, 91, 68],
            [2001, 7504, 86, 64],
            [2001, 7505, 71, 71],
            [2001, 7506, 81, 61],
            [2001, 7507, 66, 66],
            [2001, 7508, 81, 61],
            [2001, 7509, 71, 71],
            [2001, 7510, 71, 71],
            [2001, 7511, 81, 61],
            [2001, 7512, 71, 71],
            [2001, 7513, 80, 61],
            [2001, 7514, 120, 91],
            [2001, 7515, 91, 68],
            [2001, 7516, 71, 71],
            [2001, 7517, 121, 91],
            [2001, 7518, 81, 61],
            [2001, 7519, 71, 71],
            [2001, 7520, 71, 71],
            [2001, 7521, 51, 61],
            [2001, 7522, 91, 68],
            [2001, 7523, 71, 71],
            [2001, 7524, 121, 121],
            [2001, 7525, 71, 71],
            [2001, 7526, 86, 64],
            [2001, 7527, 51, 61],
            [2001, 7528, 101, 76],
            [2001, 7529, 121, 121],
            [2001, 7530, 91, 68],
            [2001, 7531, 51, 61],
            [2001, 7532, 71, 71],
            [2001, 7533, 101, 76],
            [2001, 7534, 121, 121],
            [2001, 7535, 71, 71],
            [2001, 7536, 91, 68],
            [2001, 7537, 96, 72],
            [2001, 7538, 101, 76],
            [2001, 7539, 71, 71],
            [2001, 7540, 101, 76],
            [2001, 7541, 91, 68],
            [2001, 7542, 101, 76],
            [2001, 7543, 91, 68],
            [2001, 7544, 96, 72],
            [2001, 7545, 66, 66],
            [2001, 7546, 81, 61],
            [2001, 7547, 80, 61],
            [2001, 7548, 61, 61],
            [2001, 7549, 71, 71],
            [2001, 7550, 61, 61],
            [2001, 7551, 61, 61],
            [2001, 7552, 61, 61],
            [2001, 7553, 71, 71],
            [2001, 7554, 111, 101],
            [2001, 7555, 101, 81],
            [2001, 7556, 71, 71],
            [2001, 7557, 121, 91],
            [2001, 7558, 51, 51],
            [2001, 7559, 80, 61],
            [2001, 7560, 61, 61],
            [2001, 7561, 121, 91],
            [2001, 7562, 121, 91],
            [2001, 7563, 91, 68],
            [2001, 7564, 91, 68],
            [2001, 7565, 71, 71],
            [2001, 7566, 71, 71],
            [2001, 7567, 71, 71],
            [2001, 7568, 71, 71],
            [2001, 7569, 71, 71],
            [2001, 7570, 71, 71],
            [2001, 7571, 71, 71],
            [2001, 7572, 121, 91],
            [2001, 7573, 71, 61],
            [2001, 7574, 71, 71],
            [2001, 7575, 81, 61],
            [2001, 7576, 81, 61],
            [2001, 7577, 91, 68],
            [2001, 7578, 71, 71],
            [2001, 7579, 91, 68],
            [2001, 7580, 91, 68],
            [2001, 7581, 91, 68],
            [2001, 7582, 91, 80],
            [2001, 7583, 71, 71],
            [2001, 7584, 66, 66],
            [2001, 7585, 66, 65],
            [2001, 7586, 121, 91],
            [2001, 7587, 61, 61],
            [2001, 7588, 71, 71],
            [2001, 7589, 121, 91],
            [2001, 7590, 71, 71],
            [2001, 7591, 81, 61],
            [2001, 7592, 91, 68],
            [2001, 7593, 96, 72],
            [2001, 7594, 71, 71],
            [2001, 7595, 71, 71],
            [2001, 7596, 61, 61],
            [2001, 7597, 71, 71],
            [2001, 7598, 81, 61],
            [2001, 7599, 71, 71],
            [2001, 7600, 71, 71],
            [2001, 7601, 61, 61],
            [2001, 7602, 56, 56],
            [2001, 7603, 71, 71],
            [2001, 7604, 71, 71],
            [2001, 7605, 71, 71],
            [2001, 7606, 71, 61],
            [2001, 7607, 91, 68],
            [2001, 7608, 61, 61],
            [2001, 7609, 71, 71],
            [2001, 7610, 61, 61],
            [2001, 7611, 46, 71],
            [2001, 7612, 71, 68],
            [2001, 7613, 71, 71],
            [2001, 7614, 81, 71],
            [2001, 7615, 91, 68],
            [2001, 7616, 91, 68],
            [2001, 7617, 81, 61],
            [2001, 7618, 91, 68],
            [2001, 7619, 71, 71],
            [2001, 7620, 61, 61],
            [2001, 7621, 71, 71],
            [2001, 7622, 91, 68],
            [2001, 7623, 71, 71],
            [2001, 7624, 101, 76],
            [2001, 7625, 61, 61],
            [2001, 7626, 91, 68],
            [2001, 7627, 66, 66],
            [2001, 7628, 91, 68],
            [2001, 7629, 61, 61],
            [2001, 7630, 66, 66],
            [2001, 7631, 66, 66],
            [2001, 7632, 91, 68],
            [2001, 7633, 61, 61],
            [2001, 7634, 19, 34],
            [2001, 7635, 19, 28],
            [2001, 7636, 21, 31],
            [2001, 7637, 43, 42],
            [2001, 7638, 27, 23],
            [2001, 7639, 13, 17],
            [2001, 7640, 12, 14],
            [2001, 7641, 15, 19],
            [2001, 7642, 37, 46],
            [2001, 7643, 19, 20],
            [2001, 7644, 36, 52],
            [2001, 7645, 18, 25],
            [2001, 7646, 36, 34],
            [2001, 7647, 50, 31],
            [2001, 7648, 13, 14],
            [2001, 7649, 13, 14],
            [2001, 7650, 20, 22],
            [2001, 7651, 17, 14],
            [2001, 7652, 19, 15],
            [2001, 7653, 53, 41],
            [2001, 7654, 15, 17],
            [2001, 7655, 19, 18],
            [2001, 7656, 16, 15],
            [2001, 7657, 34, 35],
            [2001, 7658, 23, 33],
            [2001, 7659, 14, 21],
            [2001, 7661, 10, 10],
            [2001, 7662, 15, 13],
            [2001, 7663, 18, 20],
            [2001, 7664, 29, 44],
            [2001, 7665, 46, 67],
            [2001, 7666, 18, 23],
            [2001, 7667, 18, 21],
            [2001, 7668, 18, 14],
            [2001, 7669, 12, 8],
            [2001, 7670, 33, 26],
            [2001, 7671, 45, 39],
            [2001, 7672, 10, 9],
            [2001, 7673, 8, 7],
            [2001, 7674, 22, 19],
            [2001, 7675, 9, 10],
            [2001, 7676, 6, 7],
            [2001, 7677, 6, 6],
            [2001, 7678, 10, 8],
            [2001, 7679, 14, 11],
            [2001, 7680, 20, 22],
            [2001, 7681, 5, 3],
            [2001, 7682, 16, 13],
            [2001, 7683, 5, 3],
            [2001, 7684, 16, 15],
            [2001, 7685, 12, 11],
            [2001, 7686, 22, 20],
            [2001, 7687, 5, 3],
            [2001, 7688, 18, 17],
            [2001, 7689, 12, 13],
            [2001, 7690, 7, 8],
            [2001, 7691, 21, 26],
            [2001, 7692, 11, 10],
            [2001, 7693, 9, 9],
            [2001, 7694, 10, 9],
            [2001, 7695, 31, 21],
            [2001, 7696, 5, 3],
            [2001, 7697, 16, 12],
            [2001, 7698, 10, 8],
            [2001, 7699, 14, 16],
            [2001, 7700, 11, 10],
            [2001, 7701, 9, 8],
            [2001, 7702, 17, 13],
            [2001, 7703, 15, 15],
            [2001, 7704, 18, 19],
            [2001, 7705, 22, 14],
            [2001, 7706, 11, 10],
            [2001, 7707, 10, 10],
            [2001, 7708, 9, 7],
            [2001, 7709, 12, 15],
            [2001, 7710, 6, 6],
            [2001, 7711, 16, 12],
            [2001, 7712, 13, 10],
            [2001, 7713, 21, 12],
            [2001, 7714, 11, 9],
            [2001, 7715, 44, 52],
            [2001, 7716, 55, 56],
            [2001, 7717, 78, 99],
            [2001, 7718, 57, 56],
            [2001, 7719, 42, 49],
            [2001, 7720, 80, 102],
            [2001, 7721, 57, 57],
            [2001, 7722, 71, 57],
            [2001, 7723, 41, 48],
            [2001, 7724, 76, 96],
            [2001, 7725, 24, 33],
            [2001, 7726, 43, 51],
            [2001, 7727, 58, 58],
            [2001, 7728, 71, 69],
            [2001, 7729, 57, 57],
            [2001, 7730, 41, 48],
            [2001, 7731, 77, 98],
            [2001, 7732, 43, 51],
            [2001, 7733, 63, 78],
            [2001, 7734, 92, 71],
            [2001, 7735, 102, 100],
            [2001, 7736, 41, 49],
            [2001, 7737, 62, 61],
            [2001, 7738, 41, 49],
            [2001, 7739, 46, 61],
            [2001, 7740, 42, 49],
            [2001, 7741, 62, 76],
            [2001, 7742, 69, 75],
            [2001, 7743, 56, 56],
            [2001, 7744, 77, 97],
            [2001, 7745, 78, 61],
            [2001, 7746, 57, 57],
            [2001, 7747, 72, 92],
            [2001, 7748, 64, 63],
            [2001, 7749, 57, 58],
            [2001, 7750, 70, 89],
            [2001, 7751, 92, 71],
            [2001, 7752, 101, 99],
            [2001, 7753, 63, 62],
            [2001, 7754, 57, 58],
            [2001, 7755, 42, 49],
            [2001, 7756, 95, 62],
            [2001, 7757, 73, 61],
            [2001, 7758, 106, 80],
            [2001, 7759, 36, 42],
            [2001, 7760, 72, 74],
            [2001, 7761, 43, 55],
            [2001, 7762, 93, 85],
            [2001, 7763, 19, 28],
            [2001, 7764, 19, 27],
            [2001, 7765, 20, 31],
            [2001, 7766, 11, 21],
            [2001, 7767, 29, 36],
            [2001, 7768, 12, 23],
            [2001, 7769, 42, 39],
            [2001, 7770, 62, 45],
            [2001, 7771, 17, 18],
            [2001, 7772, 16, 20],
            [2001, 7773, 26, 28],
            [2001, 7774, 15, 26],
            [2001, 7775, 45, 42],
            [2001, 7776, 18, 37],
            [2001, 7777, 24, 39],
            [2001, 7778, 9, 13],
            [2001, 7779, 15, 20],
            [2001, 7780, 23, 23],
            [2001, 7781, 30, 33],
            [2001, 7782, 36, 29],
            [2001, 7783, 37, 28],
            [2001, 7784, 15, 36],
            [2001, 7785, 26, 46],
            [2001, 7786, 16, 18],
            [2001, 7787, 26, 33],
            [2001, 7788, 23, 27],
            [2001, 7789, 24, 30],
            [2001, 7790, 24, 31],
            [2001, 7791, 47, 43],
            [2001, 7792, 20, 26],
            [2001, 7793, 38, 38],
            [2001, 7795, 61, 58],
            [2001, 7796, 96, 74],
            [2001, 7797, 61, 59],
            [2001, 7798, 61, 58],
            [2001, 7799, 61, 59],
            [2001, 7800, 60, 60],
            [2001, 7801, 63, 59],
            [2001, 7802, 61, 57],
            [2001, 7803, 63, 62],
            [2001, 7804, 98, 74],
            [2001, 7805, 62, 59],
            [2001, 7806, 63, 59],
            [2001, 7807, 61, 57],
            [2001, 7808, 100, 75],
            [2001, 7809, 100, 74],
            [2001, 7810, 60, 56],
            [2001, 7811, 61, 58],
            [2001, 7812, 61, 57],
            [2001, 7813, 62, 58],
            [2001, 7815, 62, 59],
            [2001, 7816, 61, 57],
            [2001, 7817, 99, 74],
            [2001, 7818, 62, 59],
            [2001, 7819, 62, 58],
            [2001, 7820, 63, 75],
            [2001, 7821, 61, 58],
            [2001, 7822, 99, 76],
            [2001, 7823, 95, 73],
            [2001, 7824, 103, 77],
            [2001, 7825, 62, 58],
            [2001, 7826, 99, 74],
            [2001, 7827, 45, 50],
            [2001, 7828, 61, 58],
            [2001, 7829, 60, 60],
            [2001, 7830, 62, 58],
            [2001, 7831, 62, 60],
            [2001, 7832, 62, 58],
            [2001, 7833, 61, 57],
            [2001, 7834, 45, 50],
            [2001, 7835, 62, 58],
            [2001, 7836, 102, 76],
            [2001, 7837, 62, 58],
            [2001, 7838, 99, 74],
            [2001, 7839, 62, 58],
            [2001, 7840, 99, 74],
            [2001, 7841, 61, 57],
            [2001, 7842, 61, 59],
            [2001, 7843, 61, 58],
            [2001, 7844, 61, 56],
            [2001, 7845, 23, 14],
            [2001, 7846, 62, 58],
            [2001, 7847, 100, 75],
            [2001, 7848, 100, 75],
            [2001, 7849, 104, 78],
            [2001, 7850, 45, 50],
            [2001, 7851, 61, 57],
            [2001, 7852, 38, 44],
            [2001, 7853, 46, 51],
            [2001, 7854, 45, 49],
            [2001, 7855, 45, 50],
            [2001, 7856, 43, 50],
            [2001, 7857, 61, 57],
            [2001, 7858, 61, 58],
            [2001, 7859, 60, 59],
            [2001, 7860, 62, 57],
            [2001, 7861, 59, 55],
            [2001, 7862, 106, 79],
            [2001, 7863, 107, 80],
            [2001, 7864, 61, 59],
            [2001, 7865, 63, 60],
            [2001, 7866, 99, 74],
            [2001, 7867, 62, 58],
            [2001, 7868, 62, 58],
            [2001, 7869, 98, 73],
            [2001, 7870, 62, 58],
            [2001, 7871, 61, 59],
            [2001, 7872, 99, 74],
            [2001, 7873, 61, 57],
            [2001, 7874, 62, 58],
            [2001, 7875, 45, 50],
            [2001, 7876, 61, 57],
            [2001, 7877, 101, 75],
            [2001, 7878, 63, 61],
            [2001, 7879, 61, 59],
            [2001, 7880, 61, 59],
            [2001, 7881, 61, 59],
            [2001, 7882, 45, 39],
            [2001, 7883, 45, 50],
            [2001, 7884, 61, 58],
            [2001, 7885, 61, 59],
            [2001, 7886, 61, 59],
            [2001, 7887, 62, 58],
            [2001, 7888, 62, 58],
            [2001, 7889, 99, 74],
            [2001, 7890, 61, 59],
            [2001, 7891, 45, 50],
            [2001, 7892, 62, 58],
            [2001, 7893, 62, 57],
            [2001, 7894, 63, 59],
            [2001, 7895, 62, 60],
            [2001, 7896, 99, 74],
            [2001, 7897, 101, 75],
            [2001, 7898, 62, 57],
            [2001, 7899, 62, 60],
            [2001, 7900, 99, 74],
            [2001, 7901, 61, 56],
            [2001, 7902, 61, 60],
            [2001, 7903, 99, 74],
            [2001, 7904, 62, 57],
            [2001, 7905, 61, 57],
            [2001, 7906, 62, 58],
            [2001, 7907, 100, 74],
            [2001, 7908, 95, 74],
            [2001, 7909, 62, 59],
            [2001, 7910, 62, 58],
            [2001, 7911, 61, 56],
            [2001, 7912, 62, 58],
            [2001, 7913, 61, 59],
            [2001, 7914, 61, 59],
            [2001, 7915, 99, 74],
            [2001, 7916, 97, 74],
            [2001, 7917, 101, 75],
            [2001, 7918, 61, 57],
            [2001, 7919, 62, 58],
            [2001, 7920, 100, 75],
            [2001, 7921, 62, 57],
            [2001, 7922, 63, 59],
            [2001, 7923, 61, 57],
            [2001, 7924, 62, 57],
            [2001, 7925, 62, 57],
            [2001, 7926, 97, 75],
            [2001, 7927, 62, 58],
            [2001, 7928, 43, 50],
            [2001, 7929, 101, 75],
            [2001, 7930, 61, 57],
            [2001, 7931, 62, 58],
            [2001, 7932, 62, 58],
            [2001, 7933, 45, 51],
            [2001, 7934, 43, 51],
            [2001, 7935, 63, 59],
            [2001, 7936, 62, 58],
            [2001, 7937, 62, 57],
            [2001, 7938, 61, 58],
            [2001, 7939, 99, 76],
            [2001, 7940, 98, 73],
            [2001, 7941, 99, 74],
            [2001, 7942, 61, 59],
            [2001, 7943, 62, 58],
            [2001, 7944, 43, 50],
            [2001, 7945, 99, 74],
            [2001, 7946, 62, 58],
            [2001, 7947, 99, 74],
            [2001, 7948, 45, 51],
            [2001, 7949, 100, 74],
            [2001, 7950, 104, 77],
            [2001, 7951, 61, 57],
            [2001, 7952, 51, 44],
            [2001, 7953, 45, 51],
            [2001, 7954, 62, 58],
            [2001, 7955, 62, 58],
            [2001, 7956, 63, 59],
            [2001, 7957, 96, 74],
            [2001, 7958, 101, 75],
            [2001, 7959, 62, 58],
            [2001, 7960, 58, 58],
            [2001, 7961, 62, 59],
            [2001, 7962, 63, 59],
            [2001, 7963, 45, 50],
            [2001, 7964, 100, 74],
            [2001, 7965, 62, 61],
            [2001, 7966, 60, 58],
            [2001, 7967, 61, 57],
            [2001, 7968, 107, 80],
            [2001, 7969, 99, 74],
            [2001, 7970, 62, 58],
            [2001, 7971, 45, 50],
            [2001, 7972, 61, 57],
            [2001, 7974, 45, 51],
            [2001, 7975, 62, 58],
            [2001, 7976, 100, 75],
            [2001, 7977, 61, 58],
            [2001, 7978, 99, 74],
            [2001, 7979, 100, 75],
            [2001, 7980, 61, 57],
            [2001, 7981, 100, 74],
            [2001, 7982, 62, 58],
            [2001, 7983, 61, 57],
            [2001, 7984, 100, 75],
            [2001, 7985, 61, 59],
            [2001, 7986, 61, 57],
            [2001, 7987, 61, 59],
            [2001, 7988, 98, 73],
            [2001, 7989, 47, 54],
            [2001, 7990, 62, 50],
            [2001, 7992, 63, 59],
            [2001, 7993, 99, 76],
            [2001, 7994, 60, 57],
            [2001, 7995, 61, 58],
            [2001, 7996, 61, 59],
            [2001, 7997, 62, 58],
            [2001, 7998, 62, 58],
            [2001, 7999, 61, 58],
            [2001, 8000, 45, 50],
            [2001, 8001, 61, 59],
            [2001, 8002, 45, 50],
            [2001, 8003, 43, 50],
            [2001, 8004, 45, 50],
            [2001, 8005, 27, 34],
            [2001, 8006, 17, 24],
            [2001, 8007, 28, 37],
            [2001, 8008, 23, 31],
            [2001, 8009, 20, 21],
            [2001, 8010, 16, 20],
            [2001, 8011, 19, 22],
            [2001, 8012, 14, 18],
            [2001, 8013, 8, 8],
            [2001, 8014, 9, 10],
            [2001, 8015, 12, 13],
            [2001, 8016, 6, 6],
            [2001, 8017, 14, 14],
            [2001, 8018, 8, 9],
            [2001, 8019, 18, 20],
            [2001, 8020, 15, 17],
            [2001, 8021, 7, 8],
            [2001, 8022, 32, 42],
            [2001, 8023, 18, 20],
            [2001, 8024, 24, 22],
            [2001, 8025, 18, 25],
            [2001, 8026, 20, 22],
            [2001, 8027, 13, 11],
            [2001, 8028, 16, 16],
            [2001, 8029, 32, 29],
            [2001, 8030, 20, 17],
            [2001, 8031, 12, 11],
            [2001, 8032, 20, 29],
            [2001, 8033, 31, 34],
            [2001, 8034, 29, 41],
            [2001, 8035, 23, 22],
            [2001, 8036, 19, 25],
            [2001, 8037, 28, 34],
            [2001, 8038, 56, 56],
            [2001, 8039, 39, 70],
            [2001, 8040, 23, 70],
            [2001, 8041, 8, 18],
            [2001, 8042, 7, 10],
            [2001, 8043, 12, 18],
            [2001, 8044, 12, 17],
            [2001, 8045, 5, 3],
            [2001, 8046, 5, 3],
            [2001, 8047, 5, 6],
            [2001, 8048, 17, 23],
            [2001, 8049, 13, 17],
            [2001, 8050, 10, 11],
            [2001, 8051, 23, 27],
            [2001, 8052, 42, 49],
            [2001, 8053, 28, 39],
            [2001, 8054, 24, 34],
            [2001, 8055, 35, 50],
            [2001, 8056, 46, 54],
            [2001, 8057, 29, 36],
            [2001, 8058, 24, 29],
            [2001, 8059, 27, 34],
            [2001, 8060, 32, 37],
            [2001, 8061, 60, 67],
            [2001, 8062, 62, 80],
            [2001, 8063, 13, 10],
            [2001, 8064, 14, 17],
            [2001, 8065, 20, 15],
            [2001, 8066, 91, 56],
            [2001, 8067, 45, 34],
            [2001, 8068, 14, 12],
            [2001, 8069, 13, 30],
            [2001, 8070, 19, 20],
            [2001, 8071, 57, 24],
            [2001, 8072, 48, 27],
            [2001, 8073, 70, 34],
            [2001, 8074, 15, 18],
            [2001, 8075, 16, 19],
            [2001, 8076, 70, 50],
            [2001, 8077, 102, 43],
            [2001, 8078, 31, 45],
            [2001, 8079, 76, 61],
            [2001, 8080, 97, 27],
            [2001, 8081, 117, 60],
            [2001, 8082, 79, 46],
            [2001, 8083, 127, 51],
            [2001, 8084, 74, 64],
            [2001, 8085, 55, 38],
            [2001, 8086, 18, 52],
            [2001, 8087, 15, 36],
            [2001, 8088, 20, 42],
            [2001, 8089, 24, 56],
            [2001, 8090, 26, 40],
            [2001, 8091, 26, 70],
            [2001, 8092, 25, 54],
            [2001, 8093, 28, 70],
            [2001, 8094, 14, 70],
            [2001, 8095, 23, 29],
            [2001, 8096, 27, 43],
            [2001, 8097, 21, 37],
            [2001, 8098, 9, 30],
            [2001, 8099, 56, 56],
            [2001, 8100, 56, 56],
            [2001, 8101, 57, 56],
            [2001, 8102, 42, 49],
            [2001, 8103, 57, 56],
            [2001, 8104, 56, 56],
            [2001, 8105, 93, 72],
            [2001, 8106, 58, 58],
            [2001, 8107, 42, 49],
            [2001, 8108, 62, 61],
            [2001, 8109, 57, 57],
            [2001, 8110, 41, 49],
            [2001, 8111, 61, 60],
            [2001, 8112, 56, 56],
            [2001, 8113, 93, 72],
            [2001, 8114, 42, 49],
            [2001, 8115, 80, 102],
            [2001, 8116, 58, 58],
            [2001, 8117, 62, 99],
            [2001, 8118, 42, 50],
            [2001, 8119, 57, 57],
            [2001, 8120, 61, 60],
            [2001, 8121, 42, 49],
            [2001, 8122, 56, 56],
            [2001, 8123, 94, 72],
            [2001, 8124, 57, 57],
            [2001, 8125, 94, 72],
            [2001, 8126, 54, 54],
            [2001, 8127, 57, 58],
            [2001, 8128, 104, 102],
            [2001, 8129, 56, 56],
            [2001, 8130, 94, 72],
            [2001, 8131, 41, 49],
            [2001, 8132, 62, 61],
            [2001, 8133, 42, 50],
            [2001, 8134, 63, 61],
            [2001, 8135, 94, 72],
            [2001, 8136, 33, 41],
            [2001, 8137, 56, 57],
            [2001, 8138, 58, 58],
            [2001, 8139, 72, 86],
            [2001, 8140, 70, 90],
            [2001, 8141, 56, 56],
            [2001, 8142, 56, 56],
            [2001, 8143, 79, 101],
            [2001, 8144, 36, 43],
            [2001, 8145, 41, 48],
            [2001, 8146, 61, 75],
            [2001, 8147, 56, 56],
            [2001, 8148, 57, 57],
            [2001, 8149, 42, 50],
            [2001, 8150, 81, 104],
            [2001, 8151, 41, 49],
            [2001, 8152, 70, 89],
            [2001, 8153, 56, 57],
            [2001, 8154, 56, 56],
            [2001, 8155, 90, 69],
            [2001, 8156, 89, 119],
            [2001, 8157, 58, 58],
            [2001, 8158, 57, 56],
            [2001, 8159, 54, 55],
            [2001, 8160, 56, 56],
            [2001, 8161, 94, 72],
            [2001, 8162, 95, 73],
            [2001, 8163, 63, 59],
            [2001, 8164, 56, 56],
            [2001, 8165, 57, 57],
            [2001, 8166, 102, 77],
            [2001, 8167, 94, 72],
            [2001, 8168, 56, 57],
            [2001, 8169, 62, 59],
            [2001, 8170, 57, 57],
            [2001, 8171, 57, 57],
            [2001, 8172, 102, 76],
            [2001, 8173, 56, 56],
            [2001, 8174, 57, 57],
            [2001, 8175, 42, 49],
            [2001, 8176, 42, 49],
            [2001, 8177, 42, 50],
            [2001, 8178, 58, 58],
            [2001, 8179, 61, 60],
            [2001, 8180, 56, 56],
            [2001, 8181, 101, 76],
            [2001, 8182, 94, 72],
            [2001, 8183, 58, 58],
            [2001, 8184, 56, 56],
            [2001, 8185, 56, 56],
            [2001, 8186, 57, 57],
            [2001, 8187, 42, 50],
            [2001, 8188, 33, 41],
            [2001, 8189, 62, 60],
            [2001, 8190, 41, 48],
            [2001, 8191, 93, 92],
            [2001, 8192, 58, 57],
            [2001, 8193, 101, 75],
            [2001, 8194, 56, 55],
            [2001, 8195, 57, 56],
            [2001, 8196, 42, 50],
            [2001, 8197, 58, 58],
            [2001, 8198, 42, 50],
            [2001, 8199, 77, 98],
            [2001, 8200, 42, 49],
            [2001, 8201, 102, 77],
            [2001, 8202, 73, 72],
            [2001, 8203, 99, 72],
            [2001, 8204, 93, 72],
            [2001, 8205, 40, 47],
            [2001, 8206, 64, 63],
            [2001, 8207, 56, 56],
            [2001, 8208, 41, 49],
            [2001, 8209, 102, 77],
            [2001, 8210, 57, 57],
            [2001, 8211, 79, 101],
            [2001, 8212, 42, 49],
            [2001, 8213, 57, 57],
            [2001, 8214, 78, 99],
            [2001, 8215, 57, 57],
            [2001, 8216, 57, 56],
            [2001, 8217, 58, 57],
            [2001, 8218, 23, 35],
            [2001, 8219, 64, 63],
            [2001, 8220, 41, 49],
            [2001, 8221, 62, 60],
            [2001, 8222, 34, 42],
            [2001, 8223, 41, 49],
            [2001, 8224, 61, 74],
            [2001, 8225, 45, 53],
            [2001, 8226, 79, 101],
            [2001, 8227, 57, 56],
            [2001, 8228, 40, 47],
            [2001, 8229, 56, 55],
            [2001, 8230, 57, 57],
            [2001, 8231, 33, 41],
            [2001, 8232, 70, 71],
            [2001, 8233, 56, 56],
            [2001, 8234, 40, 48],
            [2001, 8235, 78, 99],
            [2001, 8236, 42, 49],
            [2001, 8237, 70, 69],
            [2001, 8238, 56, 56],
            [2001, 8239, 118, 90],
            [2001, 8240, 57, 56],
            [2001, 8241, 42, 50],
            [2001, 8242, 63, 62],
            [2001, 8245, 57, 57],
            [2001, 8246, 58, 58],
            [2001, 8247, 93, 72],
            [2001, 8248, 34, 41],
            [2001, 8249, 62, 61],
            [2001, 8250, 56, 56],
            [2001, 8251, 57, 56],
            [2001, 8252, 61, 60],
            [2001, 8253, 92, 71],
            [2001, 8254, 42, 53],
            [2001, 8255, 56, 56],
            [2001, 8256, 42, 49],
            [2001, 8257, 78, 99],
            [2001, 8258, 56, 56],
            [2001, 8259, 56, 56],
            [2001, 8260, 57, 58],
            [2001, 8261, 77, 98],
            [2001, 8262, 63, 64],
            [2001, 8263, 98, 74],
            [2001, 8264, 43, 51],
            [2001, 8265, 63, 102],
            [2001, 8267, 93, 71],
            [2001, 8268, 57, 57],
            [2001, 8269, 57, 56],
            [2001, 8270, 32, 41],
            [2001, 8271, 42, 50],
            [2001, 8272, 61, 60],
            [2001, 8273, 57, 56],
            [2001, 8274, 56, 56],
            [2001, 8275, 43, 50],
            [2001, 8276, 56, 56],
            [2001, 8277, 50, 35],
            [2001, 8278, 94, 72],
            [2001, 8279, 56, 56],
            [2001, 8280, 58, 58],
            [2001, 8281, 56, 56],
            [2001, 8282, 58, 58],
            [2001, 8283, 57, 57],
            [2001, 8284, 57, 56],
            [2001, 8285, 58, 58],
            [2001, 8286, 58, 58],
            [2001, 8287, 57, 57],
            [2001, 8288, 42, 50],
            [2001, 8289, 62, 61],
            [2001, 8290, 58, 58],
            [2001, 8291, 58, 58],
            [2001, 8292, 57, 57],
            [2001, 8293, 56, 56],
            [2001, 8294, 56, 56],
            [2001, 8295, 93, 72],
            [2001, 8296, 93, 57],
            [2001, 8297, 57, 57],
            [2001, 8298, 29, 57],
            [2001, 8299, 34, 41],
            [2001, 8300, 102, 77],
            [2001, 8301, 58, 57],
            [2001, 8302, 56, 56],
            [2001, 8303, 94, 72],
            [2001, 8304, 56, 56],
            [2001, 8305, 92, 71],
            [2001, 8306, 42, 50],
            [2001, 8307, 33, 41],
            [2001, 8308, 56, 56],
            [2001, 8309, 22, 30],
            [2001, 8310, 62, 60],
            [2001, 8311, 22, 28],
            [2001, 8312, 20, 24],
            [2001, 8313, 20, 24],
            [2001, 8314, 23, 30],
            [2001, 8315, 20, 24],
            [2001, 8316, 20, 24],
            [2001, 8317, 59, 59],
            [2001, 8318, 97, 73],
            [2001, 8319, 33, 39],
            [2001, 8320, 94, 72],
            [2001, 8321, 58, 43],
            [2001, 8322, 57, 57],
            [2001, 8323, 42, 50],
            [2001, 8324, 99, 74],
            [2001, 8325, 96, 74],
            [2001, 8326, 93, 72],
            [2001, 8327, 92, 71],
            [2001, 8328, 95, 73],
            [2001, 8329, 56, 56],
            [2001, 8330, 95, 73],
            [2001, 8331, 92, 71],
            [2001, 8332, 93, 72],
            [2001, 8333, 25, 34],
            [2001, 8334, 22, 32],
            [2001, 8335, 18, 29],
            [2001, 8336, 25, 20],
            [2001, 8337, 15, 19],
            [2001, 8338, 14, 15],
            [2001, 8339, 51, 53],
            [2001, 8340, 17, 20],
            [2001, 8341, 35, 42],
            [2001, 8342, 18, 18],
            [2001, 8343, 21, 22],
            [2001, 8344, 15, 14],
            [2001, 8345, 20, 16],
            [2001, 8346, 22, 31],
            [2001, 8347, 18, 21],
            [2001, 8348, 26, 35],
            [2001, 8349, 16, 20],
            [2001, 8350, 19, 21],
            [2001, 8351, 15, 11],
            [2001, 8352, 23, 36],
            [2001, 8353, 17, 21],
            [2001, 8354, 28, 36],
            [2001, 8355, 19, 20],
            [2001, 8356, 26, 34],
            [2001, 8357, 18, 18],
            [2001, 8358, 27, 20],
            [2001, 8359, 38, 50],
            [2001, 8360, 42, 53],
            [2001, 8361, 18, 16],
            [2001, 8362, 20, 30],
            [2001, 8363, 28, 40],
            [2001, 8364, 33, 29],
            [2001, 8365, 13, 15],
            [2001, 8366, 28, 25],
            [2001, 8367, 16, 18],
            [2001, 8368, 19, 30],
            [2001, 8369, 22, 31],
            [2001, 8370, 24, 25],
            [2001, 8371, 23, 22],
            [2001, 8372, 30, 25],
            [2001, 8373, 28, 37],
            [2001, 8374, 26, 37],
            [2001, 8375, 18, 17],
            [2001, 8376, 32, 35],
            [2001, 8377, 24, 19],
            [2001, 8378, 24, 20],
            [2001, 8379, 28, 26],
            [2001, 8380, 35, 33],
            [2001, 8381, 31, 41],
            [2001, 8382, 23, 26],
            [2001, 8383, 29, 35],
            [2001, 8384, 27, 43],
            [2001, 8385, 24, 33],
            [2001, 8386, 17, 21],
            [2001, 8387, 29, 30],
            [2001, 8388, 19, 20],
            [2001, 8389, 19, 23],
            [2001, 8390, 16, 18],
            [2001, 8391, 19, 24],
            [2001, 8392, 22, 27],
            [2001, 8393, 46, 67],
            [2001, 8394, 29, 23],
            [2001, 8395, 22, 25],
            [2001, 8396, 62, 60],
            [2001, 8397, 99, 74],
            [2001, 8398, 67, 53],
            [2001, 8399, 92, 58],
            [2001, 8400, 82, 74],
            [2001, 8401, 96, 58],
            [2001, 8402, 72, 60],
            [2001, 8403, 84, 57],
            [2001, 8404, 61, 59],
            [2001, 8405, 85, 57],
            [2001, 8406, 71, 59],
            [2001, 8407, 62, 60],
            [2001, 8408, 60, 73],
            [2001, 8409, 42, 37],
            [2001, 8410, 84, 63],
            [2001, 8411, 93, 65],
            [2001, 8412, 62, 61],
            [2001, 8413, 80, 64],
            [2001, 8414, 119, 57],
            [2001, 8415, 132, 84],
            [2001, 8416, 41, 44],
            [2001, 8417, 88, 59],
            [2001, 8418, 29, 35],
            [2001, 8419, 70, 52],
            [2001, 8420, 93, 71],
            [2001, 8421, 98, 74],
            [2001, 8422, 38, 42],
            [2001, 8423, 65, 63],
            [2001, 8424, 92, 103],
            [2001, 8425, 47, 63],
            [2001, 8426, 59, 57],
            [2001, 8427, 61, 52],
            [2001, 8428, 71, 58],
            [2001, 8429, 38, 38],
            [2001, 8430, 65, 63],
            [2001, 8431, 97, 73],
            [2001, 8432, 66, 63],
            [2001, 8433, 64, 62],
            [2001, 8434, 91, 60],
            [2001, 8435, 152, 71],
            [2001, 8436, 99, 74],
            [2001, 8438, 43, 38],
            [2001, 8439, 49, 46],
            [2001, 8440, 120, 70],
            [2001, 8441, 96, 60],
            [2001, 8442, 60, 59],
            [2001, 8443, 80, 73],
            [2001, 8444, 65, 63],
            [2001, 8445, 37, 35],
            [2001, 8446, 49, 44],
            [2001, 8447, 78, 64],
            [2001, 8448, 62, 58],
            [2001, 8449, 140, 56],
            [2001, 8450, 103, 69],
            [2001, 8451, 22, 33],
            [2001, 8452, 31, 47],
            [2001, 8453, 20, 29],
            [2001, 8454, 35, 46],
            [2001, 8455, 25, 33],
            [2001, 8456, 24, 33],
            [2001, 8457, 65, 63],
            [2001, 8458, 54, 44],
            [2001, 8459, 81, 58],
            [2001, 8460, 61, 59],
            [2001, 8461, 106, 58],
            [2001, 8462, 88, 59],
            [2001, 8463, 87, 70],
            [2001, 8464, 99, 74],
            [2001, 8465, 42, 33],
            [2001, 8466, 48, 60],
            [2001, 8467, 54, 51],
            [2001, 8468, 76, 64],
            [2001, 8469, 64, 58],
            [2001, 8470, 99, 75],
            [2001, 8471, 41, 50],
            [2001, 8472, 115, 57],
            [2001, 8473, 80, 74],
            [2001, 8474, 60, 59],
            [2001, 8475, 96, 72],
            [2001, 8476, 96, 73],
            [2001, 8477, 96, 73],
            [2001, 8478, 35, 39],
            [2001, 8479, 61, 59],
            [2001, 8480, 99, 75],
            [2001, 8481, 62, 52],
            [2001, 8482, 65, 55],
            [2001, 8483, 67, 58],
            [2001, 8484, 82, 64],
            [2001, 8485, 90, 74],
            [2001, 8486, 40, 35],
            [2001, 8487, 78, 58],
            [2001, 8488, 60, 57],
            [2001, 8489, 38, 66],
            [2001, 8490, 82, 64],
            [2001, 8491, 70, 72],
            [2001, 8492, 72, 57],
            [2001, 8493, 95, 58],
            [2001, 8494, 38, 33],
            [2001, 8495, 106, 109],
            [2001, 8496, 43, 58],
            [2001, 8497, 70, 75],
            [2001, 8498, 47, 58],
            [2001, 8499, 61, 58],
            [2001, 8500, 97, 59],
            [2001, 8501, 65, 80],
            [2001, 8502, 100, 59],
            [2001, 8503, 97, 73],
            [2001, 8504, 61, 60],
            [2001, 8505, 98, 74],
            [2001, 8506, 99, 74],
            [2001, 8507, 99, 75],
            [2001, 8508, 48, 52],
            [2001, 8509, 60, 58],
            [2001, 8510, 105, 73],
            [2001, 8511, 95, 72],
            [2001, 8512, 65, 63],
            [2001, 8513, 72, 70],
            [2001, 8514, 74, 72],
            [2001, 8515, 61, 60],
            [2001, 8516, 170, 92],
            [2001, 8517, 80, 32],
            [2001, 8518, 99, 95],
            [2001, 8519, 44, 43],
            [2001, 8520, 68, 58],
            [2001, 8521, 60, 58],
            [2001, 8522, 63, 59],
            [2001, 8523, 61, 58],
            [2001, 8524, 60, 57],
            [2001, 8525, 80, 58],
            [2001, 8526, 96, 73],
            [2001, 8527, 84, 86],
            [2001, 8528, 101, 83],
            [2001, 8529, 105, 82],
            [2001, 8530, 42, 41],
            [2001, 8531, 96, 93],
            [2001, 8532, 81, 86],
            [2001, 8533, 98, 93],
            [2001, 8534, 67, 68],
            [2001, 8535, 93, 96],
            [2001, 8536, 25, 55],
            [2001, 8537, 65, 42],
            [2001, 8538, 65, 42],
            [2001, 8539, 55, 47],
            [2001, 8540, 45, 80],
            [2001, 8541, 56, 88],
            [2001, 8542, 52, 85],
            [2001, 8543, 30, 81],
            [2001, 8544, 35, 88],
            [2001, 8546, 42, 80],
            [2001, 8547, 42, 86],
            [2001, 8548, 16, 22],
            [2001, 8549, 26, 35],
            [2001, 8550, 21, 33],
            [2001, 8551, 40, 33],
            [2001, 8552, 35, 44],
            [2001, 8553, 53, 74],
            [2001, 8554, 24, 21],
            [2001, 8555, 43, 41],
            [2001, 8556, 49, 72],
            [2001, 8557, 71, 70],
            [2001, 8558, 33, 37],
            [2001, 8559, 44, 44],
            [2001, 8560, 34, 41],
            [2001, 8561, 25, 33],
            [2001, 8562, 41, 42],
            [2001, 8563, 53, 59],
            [2001, 8564, 108, 86],
            [2001, 8565, 10, 13],
            [2001, 8566, 16, 15],
            [2001, 8567, 24, 23],
            [2001, 8568, 18, 17],
            [2001, 8569, 18, 16],
            [2001, 8570, 10, 10],
            [2001, 8571, 14, 11],
            [2001, 8572, 15, 11],
            [2001, 8573, 13, 11],
            [2001, 8574, 15, 13],
            [2001, 8575, 10, 10],
            [2001, 8576, 23, 17],
            [2001, 8577, 19, 17],
            [2001, 8578, 25, 25],
            [2001, 8579, 20, 22],
            [2001, 8580, 18, 18],
            [2001, 8581, 12, 10],
            [2001, 8582, 19, 18],
            [2001, 8583, 20, 19],
            [2001, 8584, 15, 15],
            [2001, 8585, 13, 13],
            [2001, 8586, 25, 20],
            [2001, 8587, 11, 9],
            [2001, 8588, 25, 15],
            [2001, 8589, 14, 13],
            [2001, 8590, 25, 16],
            [2001, 8591, 21, 17],
            [2001, 8592, 35, 36],
            [2001, 8593, 29, 29],
            [2001, 8594, 30, 29],
            [2001, 8595, 14, 13],
            [2001, 8596, 15, 16],
            [2001, 8597, 22, 13],
            [2001, 8598, 18, 12],
            [2001, 8599, 15, 13],
            [2001, 8600, 25, 16],
            [2001, 8601, 34, 25],
            [2001, 8602, 34, 23],
            [2001, 8603, 20, 17],
            [2001, 8604, 23, 20],
            [2001, 8605, 20, 19],
            [2001, 8606, 26, 18],
            [2001, 8607, 20, 18],
            [2001, 8608, 25, 22],
            [2001, 8609, 30, 22],
            [2001, 8610, 27, 20],
            [2001, 8611, 21, 15],
            [2001, 8612, 25, 17],
            [2001, 8613, 15, 12],
            [2001, 8614, 20, 15],
            [2001, 8615, 13, 13],
            [2001, 8616, 25, 18],
            [2001, 8617, 36, 16],
            [2001, 8618, 21, 13],
            [2001, 8619, 26, 15],
            [2001, 8622, 50, 35],
            [2001, 8623, 54, 36],
            [2001, 8624, 19, 14],
            [2001, 8625, 39, 34],
            [2001, 8626, 28, 19],
            [2001, 8627, 30, 24],
            [2001, 8628, 39, 31],
            [2001, 8629, 40, 31],
            [2001, 8630, 27, 19],
            [2001, 8631, 34, 23],
            [2001, 8632, 25, 18],
            [2001, 8633, 28, 21],
            [2001, 8634, 15, 11],
            [2001, 8635, 18, 12],
            [2001, 8636, 12, 10],
            [2001, 8637, 18, 15],
            [2001, 8638, 18, 13],
            [2001, 8639, 21, 13],
            [2001, 8640, 28, 21],
            [2001, 8641, 49, 22],
            [2001, 8642, 31, 27],
            [2001, 8643, 35, 34],
            [2001, 8644, 36, 29],
            [2001, 8645, 26, 23],
            [2001, 8646, 33, 24],
            [2001, 8647, 21, 16],
            [2001, 8648, 20, 15],
            [2001, 8649, 28, 24],
            [2001, 8650, 41, 19],
            [2001, 8651, 39, 27],
            [2001, 8652, 54, 36],
            [2001, 8653, 34, 31],
            [2001, 8654, 45, 37],
            [2001, 8655, 25, 26],
            [2001, 8656, 25, 21],
            [2001, 8657, 10, 8],
            [2001, 8658, 16, 13],
            [2001, 8659, 37, 19],
            [2001, 8660, 16, 13],
            [2001, 8661, 19, 13],
            [2001, 8662, 23, 14],
            [2001, 8663, 25, 15],
            [2001, 8664, 32, 23],
            [2001, 8665, 53, 37],
            [2001, 8666, 23, 23],
            [2001, 8667, 26, 23],
            [2001, 8668, 24, 32],
            [2001, 8669, 48, 45],
            [2001, 8670, 21, 24],
            [2001, 8671, 30, 33],
            [2001, 8672, 16, 21],
            [2001, 8673, 29, 28],
            [2001, 8674, 29, 21],
            [2001, 8675, 39, 23],
            [2001, 8676, 51, 35],
            [2001, 8677, 59, 35],
            [2001, 8678, 48, 25],
            [2001, 8679, 55, 23],
            [2001, 8680, 28, 22],
            [2001, 8681, 44, 28],
            [2001, 8682, 49, 25],
            [2001, 8683, 48, 15],
            [2001, 8684, 33, 25],
            [2001, 8685, 24, 21],
            [2001, 8686, 24, 21],
            [2001, 8687, 35, 22],
            [2001, 8688, 47, 29],
            [2001, 8689, 40, 27],
            [2001, 8690, 54, 27],
            [2001, 8691, 27, 30],
            [2001, 8692, 57, 32],
            [2001, 8693, 45, 15],
            [2001, 8694, 52, 27],
            [2001, 8695, 16, 17],
            [2001, 8696, 21, 22],
            [2001, 8697, 21, 17],
            [2001, 8698, 23, 19],
            [2001, 8699, 29, 19],
            [2001, 8700, 30, 18],
            [2001, 8701, 35, 18],
            [2001, 8702, 34, 21],
            [2001, 8703, 29, 26],
            [2001, 8704, 39, 30],
            [2001, 8705, 33, 21],
            [2001, 8706, 42, 22],
            [2001, 8707, 25, 26],
            [2001, 8708, 38, 29],
            [2001, 8709, 45, 23],
            [2001, 8710, 43, 23],
            [2001, 8711, 14, 13],
            [2001, 8712, 26, 24],
            [2001, 8713, 40, 24],
            [2001, 8714, 8, 8],
            [2001, 8715, 10, 8],
            [2001, 8716, 12, 9],
            [2001, 8717, 14, 13],
            [2001, 8718, 14, 11],
            [2001, 8719, 23, 25],
            [2001, 8720, 30, 33],
            [2001, 8721, 30, 33],
            [2001, 8722, 28, 26],
            [2001, 8723, 30, 29],
            [2001, 8724, 29, 28],
            [2001, 8725, 25, 22],
            [2001, 8726, 28, 24],
            [2001, 8727, 25, 25],
            [2001, 8728, 22, 23],
            [2001, 8729, 27, 23],
            [2001, 8730, 21, 18],
            [2001, 8731, 22, 21],
            [2001, 8732, 28, 22],
            [2001, 8733, 29, 22],
            [2001, 8734, 25, 20],
            [2001, 8735, 22, 19],
            [2001, 8736, 22, 22],
            [2001, 8737, 22, 19],
            [2001, 8738, 24, 20],
            [2001, 8739, 24, 21],
            [2001, 8740, 24, 20],
            [2001, 8741, 28, 22],
            [2001, 8742, 25, 23],
            [2001, 8743, 25, 21],
            [2001, 8744, 25, 22],
            [2001, 8745, 29, 21],
            [2001, 8746, 31, 24],
            [2001, 8747, 32, 25],
            [2001, 8748, 33, 26],
            [2001, 8749, 27, 22],
            [2001, 8750, 25, 27],
            [2001, 8751, 25, 28],
            [2001, 8752, 20, 18],
            [2001, 8753, 21, 19],
            [2001, 8754, 21, 23],
            [2001, 8755, 22, 21],
            [2001, 8756, 34, 25],
            [2001, 8757, 21, 19],
            [2001, 8758, 21, 21],
            [2001, 8759, 25, 24],
            [2001, 8760, 34, 36],
            [2001, 8761, 26, 21],
            [2001, 8762, 33, 22],
            [2001, 8763, 19, 18],
            [2001, 8764, 35, 28],
            [2001, 8765, 29, 21],
            [2001, 8766, 29, 23],
            [2001, 8767, 35, 27],
            [2001, 8768, 34, 26],
            [2001, 8769, 22, 22],
            [2001, 8770, 35, 27],
            [2001, 8771, 37, 29],
            [2001, 8772, 35, 28],
            [2001, 8773, 20, 18],
            [2001, 8774, 21, 21],
            [2001, 8775, 22, 19],
            [2001, 8776, 21, 21],
            [2001, 8777, 26, 21],
            [2001, 8778, 37, 28],
            [2001, 8779, 10, 15],
            [2001, 8780, 14, 11],
            [2001, 8781, 16, 11],
            [2001, 8782, 17, 12],
            [2001, 8783, 11, 8],
            [2001, 8784, 14, 10],
            [2001, 8785, 8, 7],
            [2001, 8786, 10, 11],
            [2001, 8787, 12, 12],
            [2001, 8788, 14, 11],
            [2001, 8790, 8, 7],
            [2001, 8791, 7, 6],
            [2001, 8792, 13, 12],
            [2001, 8793, 8, 8],
            [2001, 8794, 8, 7],
            [2001, 8795, 9, 8],
            [2001, 8796, 15, 11],
            [2001, 8797, 17, 11],
            [2001, 8798, 9, 9],
            [2001, 8799, 12, 10],
            [2001, 8800, 11, 8],
            [2001, 8801, 13, 11],
            [2001, 8802, 8, 7],
            [2001, 8803, 9, 9],
            [2001, 8804, 7, 11],
            [2001, 8805, 10, 9],
            [2001, 8806, 10, 11],
            [2001, 8807, 15, 15],
            [2001, 8808, 8, 8],
            [2001, 8809, 6, 7],
            [2001, 8810, 12, 12],
            [2001, 8811, 8, 9],
            [2001, 8812, 13, 11],
            [2001, 8814, 7, 7],
            [2001, 8815, 9, 9],
            [2001, 8816, 13, 8],
            [2001, 8817, 19, 11],
            [2001, 8818, 56, 46],
            [2001, 8819, 41, 25],
            [2001, 8820, 63, 53],
            [2001, 8821, 53, 35],
            [2001, 8822, 64, 54],
            [2001, 8823, 34, 29],
            [2001, 8824, 24, 20],
            [2001, 8825, 38, 33],
            [2001, 8826, 24, 24],
            [2001, 8827, 43, 33],
            [2001, 8828, 46, 37],
            [2001, 8829, 47, 37],
            [2001, 8830, 31, 35],
            [2001, 8831, 38, 33],
            [2001, 8832, 20, 11],
            [2001, 8833, 37, 32],
            [2001, 8834, 42, 36],
            [2001, 8835, 37, 21],
            [2001, 8836, 55, 45],
            [2001, 8837, 36, 21],
            [2001, 8838, 47, 41],
            [2001, 8839, 29, 14],
            [2001, 8840, 42, 28],
            [2001, 8841, 29, 14],
            [2001, 8842, 17, 23],
            [2001, 8843, 21, 12],
            [2001, 8844, 29, 24],
            [2001, 8845, 15, 19],
            [2001, 8846, 38, 33],
            [2001, 8847, 20, 23],
            [2001, 8848, 55, 45],
            [2001, 8849, 34, 27],
            [2001, 8850, 42, 37],
            [2001, 8851, 26, 28],
            [2001, 8852, 38, 29],
            [2001, 8853, 14, 19],
            [2001, 8854, 38, 33],
            [2001, 8855, 21, 11],
            [2001, 8856, 34, 28],
            [2001, 8857, 26, 13],
            [2001, 8858, 34, 15],
            [2001, 8859, 51, 46],
            [2001, 8860, 36, 12],
            [2001, 8861, 38, 33],
            [2001, 8862, 28, 24],
            [2001, 8863, 43, 37],
            [2001, 8864, 22, 23],
            [2001, 8865, 34, 29],
            [2001, 8866, 22, 23],
            [2001, 8867, 60, 54],
            [2001, 8868, 42, 37],
            [2001, 8869, 56, 51],
            [2001, 8870, 51, 42],
            [2001, 8871, 41, 36],
            [2001, 8872, 30, 27],
            [2001, 8873, 45, 40],
            [2001, 8874, 38, 32],
            [2001, 8875, 38, 33],
            [2001, 8876, 21, 18],
            [2001, 8877, 47, 42],
            [2001, 8878, 19, 11],
            [2001, 8879, 33, 28],
            [2001, 8880, 34, 28],
            [2001, 8881, 62, 52],
            [2001, 8882, 36, 31],
            [2001, 8883, 56, 50],
            [2001, 8884, 20, 18],
            [2001, 8885, 69, 44],
            [2001, 8886, 38, 33],
            [2001, 8887, 22, 12],
            [2001, 8888, 35, 25],
            [2001, 8889, 51, 42],
            [2001, 8890, 14, 19],
            [2001, 8891, 38, 33],
            [2001, 8892, 14, 11],
            [2001, 8893, 38, 33],
            [2001, 8894, 20, 19],
            [2001, 8895, 15, 11],
            [2001, 8896, 29, 24],
            [2001, 8897, 15, 11],
            [2001, 8898, 22, 21],
            [2001, 8899, 58, 52],
            [2001, 8900, 43, 37],
            [2001, 8901, 55, 34],
            [2001, 8902, 38, 33],
            [2001, 8903, 28, 17],
            [2001, 8904, 38, 33],
            [2001, 8905, 27, 17],
            [2001, 8906, 33, 28],
            [2001, 8907, 24, 22],
            [2001, 8908, 34, 29],
            [2001, 8909, 25, 22],
            [2001, 8910, 26, 13],
            [2001, 8911, 26, 13],
            [2001, 8912, 47, 42],
            [2001, 8913, 31, 27],
            [2001, 8914, 46, 41],
            [2001, 8915, 31, 27],
            [2001, 8916, 55, 45],
            [2001, 8917, 43, 27],
            [2001, 8918, 51, 46],
            [2001, 8919, 39, 37],
            [2001, 8920, 40, 38],
            [2001, 8921, 40, 38],
            [2001, 8922, 33, 28],
            [2001, 8923, 26, 21],
            [2001, 8924, 16, 16],
            [2001, 8925, 12, 12],
            [2001, 8926, 16, 14],
            [2001, 8927, 19, 17],
            [2001, 8928, 15, 14],
            [2001, 8929, 11, 10],
            [2001, 8930, 9, 11],
            [2001, 8931, 15, 17],
            [2001, 8932, 21, 22],
            [2001, 8933, 30, 28],
            [2001, 8934, 30, 30],
            [2001, 8935, 55, 46],
            [2001, 8936, 29, 21],
            [2001, 8937, 38, 33],
            [2001, 8938, 29, 21],
            [2001, 8939, 34, 29],
            [2001, 8940, 20, 18],
            [2001, 8941, 33, 28],
            [2001, 8942, 20, 18],
            [2001, 8943, 31, 22],
            [2001, 8944, 34, 29],
            [2001, 8945, 25, 14],
            [2001, 8946, 34, 29],
            [2001, 8947, 25, 14],
            [2001, 8948, 34, 29],
            [2001, 8949, 25, 14],
            [2001, 8950, 25, 21],
            [2001, 8951, 34, 29],
            [2001, 8952, 25, 21],
            [2001, 8953, 56, 50],
            [2001, 8954, 31, 21],
            [2001, 8955, 47, 42],
            [2001, 8956, 33, 28],
            [2001, 8957, 31, 21],
            [2001, 8958, 56, 47],
            [2001, 8959, 32, 22],
            [2001, 8960, 56, 46],
            [2001, 8961, 31, 22],
            [2001, 8962, 51, 46],
            [2001, 8963, 34, 33],
            [2001, 8964, 21, 12],
            [2001, 8965, 51, 45],
            [2001, 8966, 43, 34],
            [2001, 8967, 47, 37],
            [2001, 8968, 33, 28],
            [2001, 8969, 22, 14],
            [2001, 8970, 47, 41],
            [2001, 8971, 47, 37],
            [2001, 8972, 21, 14],
            [2001, 8973, 47, 38],
            [2001, 8974, 14, 20],
            [2001, 8975, 55, 45],
            [2001, 8976, 59, 54],
            [2001, 8977, 29, 24],
            [2001, 8978, 14, 11],
            [2001, 8979, 43, 37],
            [2001, 8980, 34, 28],
            [2001, 8981, 33, 28],
            [2001, 8983, 38, 33],
            [2001, 8984, 27, 22],
            [2001, 8985, 38, 33],
            [2001, 8986, 27, 22],
            [2001, 8987, 29, 29],
            [2001, 8988, 19, 13],
            [2001, 8989, 38, 33],
            [2001, 8990, 20, 13],
            [2001, 8991, 38, 32],
            [2001, 8992, 19, 13],
            [2001, 8993, 42, 31],
            [2001, 8994, 45, 31],
            [2001, 8995, 44, 32],
            [2001, 8996, 55, 46],
            [2001, 8997, 25, 14],
            [2001, 8998, 29, 24],
            [2001, 8999, 21, 11],
            [2001, 9000, 63, 53],
            [2001, 9001, 54, 34],
            [2001, 9002, 46, 37],
            [2001, 9003, 26, 24],
            [2001, 9004, 56, 46],
            [2001, 9005, 25, 21],
            [2001, 9006, 38, 33],
            [2001, 9007, 31, 22],
            [2001, 9008, 45, 28],
            [2001, 9009, 37, 28],
            [2001, 9010, 29, 24],
            [2001, 9011, 21, 11],
            [2001, 9012, 29, 28],
            [2001, 9013, 14, 14],
            [2001, 9014, 46, 37],
            [2001, 9015, 23, 16],
            [2001, 9016, 22, 16],
            [2001, 9017, 47, 37],
            [2001, 9018, 31, 34],
            [2001, 9019, 37, 36],
            [2001, 9020, 20, 25],
            [2001, 9021, 38, 33],
            [2001, 9022, 26, 28],
            [2001, 9023, 39, 31],
            [2001, 9024, 46, 37],
            [2001, 9025, 34, 29],
            [2001, 9026, 38, 20],
            [2001, 9027, 34, 19],
            [2001, 9028, 46, 37],
            [2001, 9030, 50, 37],
            [2001, 9031, 42, 31],
            [2001, 9032, 50, 37],
            [2001, 9033, 34, 33],
            [2001, 9034, 55, 45],
            [2001, 9035, 46, 41],
            [2001, 9036, 42, 37],
            [2001, 9037, 19, 15],
            [2001, 9038, 29, 29],
            [2001, 9039, 15, 22],
            [2001, 9040, 42, 37],
            [2001, 9041, 28, 23],
            [2001, 9042, 46, 37],
            [2001, 9043, 38, 33],
            [2001, 9044, 29, 14],
            [2001, 9045, 38, 28],
            [2001, 9046, 32, 23],
            [2001, 9047, 42, 32],
            [2001, 9048, 36, 25],
            [2001, 9049, 68, 42],
            [2001, 9050, 34, 23],
            [2001, 9051, 47, 38],
            [2001, 9052, 22, 20],
            [2001, 9053, 31, 22],
            [2001, 9054, 34, 24],
            [2001, 9055, 26, 14],
            [2001, 9056, 38, 25],
            [2001, 9057, 51, 33],
            [2001, 9058, 31, 22],
            [2001, 9059, 56, 37],
            [2001, 9060, 50, 34],
            [2001, 9061, 25, 20],
            [2001, 9062, 14, 15],
            [2001, 9063, 38, 29],
            [2001, 9064, 14, 20],
            [2001, 9065, 25, 24],
            [2001, 9066, 18, 20],
            [2001, 9067, 34, 24],
            [2001, 9068, 31, 20],
            [2001, 9069, 38, 45],
            [2001, 9070, 14, 14],
            [2001, 9071, 29, 37],
            [2001, 9072, 14, 18],
            [2001, 9073, 14, 18],
            [2001, 9074, 33, 32],
            [2001, 9075, 25, 29],
            [2001, 9076, 25, 28],
            [2001, 9077, 38, 24],
            [2001, 9078, 31, 18],
            [2001, 9079, 51, 42],
            [2001, 9080, 23, 20],
            [2001, 9081, 35, 27],
            [2001, 9082, 56, 37],
            [2001, 9083, 26, 22],
            [2001, 9084, 33, 24],
            [2001, 9085, 21, 23],
            [2001, 9086, 42, 33],
            [2001, 9087, 47, 33],
            [2001, 9088, 35, 19],
            [2001, 9089, 18, 15],
            [2001, 9090, 25, 20],
            [2001, 9091, 26, 17],
            [2001, 9092, 51, 33],
            [2001, 9093, 24, 22],
            [2001, 9094, 55, 53],
            [2001, 9095, 14, 12],
            [2001, 9096, 29, 36],
            [2001, 9097, 38, 25],
            [2001, 9098, 42, 27],
            [2001, 9099, 21, 11],
            [2001, 9100, 45, 28],
            [2001, 9101, 14, 14],
            [2001, 9102, 45, 36],
            [2001, 9103, 33, 33],
            [2001, 9104, 42, 33],
            [2001, 9105, 19, 13],
            [2001, 9106, 25, 13],
            [2001, 9107, 38, 28],
            [2001, 9108, 38, 29],
            [2001, 9109, 43, 31],
            [2001, 9110, 51, 33],
            [2001, 9111, 29, 14],
            [2001, 9112, 56, 46],
            [2001, 9113, 27, 22],
            [2001, 9114, 34, 29],
            [2001, 9115, 14, 11],
            [2001, 9116, 20, 15],
            [2001, 9117, 35, 13],
            [2001, 9118, 54, 36],
            [2001, 9119, 19, 13],
            [2001, 9120, 29, 24],
            [2001, 9121, 37, 32],
            [2001, 9122, 46, 41],
            [2001, 9123, 34, 21],
            [2001, 9124, 43, 33],
            [2001, 9125, 19, 28],
            [2001, 9126, 50, 44],
            [2001, 9127, 33, 24],
            [2001, 9128, 38, 29],
            [2001, 9129, 53, 41],
            [2001, 9130, 60, 47],
            [2001, 9131, 31, 32],
            [2001, 9132, 55, 50],
            [2001, 9133, 31, 21],
            [2001, 9134, 38, 29],
            [2001, 9135, 57, 40],
            [2001, 9136, 50, 35],
            [2001, 9137, 20, 15],
            [2001, 9138, 17, 11],
            [2001, 9139, 36, 32],
            [2001, 9140, 47, 42],
            [2001, 9141, 31, 27],
            [2001, 9142, 56, 47],
            [2001, 9143, 21, 23],
            [2001, 9144, 25, 29],
            [2001, 9145, 42, 36],
            [2001, 9146, 50, 40],
            [2001, 9149, 21, 18],
            [2001, 9150, 25, 28],
            [2001, 9151, 20, 19],
            [2001, 9152, 31, 32],
            [2001, 9153, 15, 20],
            [2001, 9154, 18, 18],
            [2001, 9155, 27, 31],
            [2001, 9156, 32, 30],
            [2001, 9157, 35, 39],
            [2001, 9158, 13, 17],
            [2001, 9159, 24, 35],
            [2001, 9160, 15, 15],
            [2001, 9161, 20, 22],
            [2001, 9162, 31, 35],
            [2001, 9163, 33, 27],
            [2001, 9164, 23, 22],
            [2001, 9165, 22, 48],
            [2001, 9166, 27, 30],
            [2001, 9167, 20, 23],
            [2001, 9168, 34, 38],
            [2001, 9169, 23, 23],
            [2001, 9170, 32, 41],
            [2001, 9171, 20, 19],
            [2001, 9172, 23, 29],
            [2001, 9173, 25, 35],
            [2001, 9174, 18, 19],
            [2001, 9175, 21, 24],
            [2001, 9176, 12, 12],
            [2001, 9177, 28, 25],
            [2001, 9178, 24, 40],
            [2001, 9179, 26, 37],
            [2001, 9180, 12, 16],
            [2001, 9181, 20, 19],
            [2001, 9182, 30, 40],
            [2001, 9183, 26, 25],
            [2001, 9184, 30, 32],
            [2001, 9185, 23, 24],
            [2001, 9186, 19, 23],
            [2001, 9187, 27, 26],
            [2001, 9188, 29, 33],
            [2001, 9189, 25, 26],
            [2001, 9190, 18, 22],
            [2001, 9191, 23, 22],
            [2001, 9192, 25, 28],
            [2001, 9193, 20, 19],
            [2001, 9194, 34, 21],
            [2001, 9195, 40, 49],
            [2001, 9196, 31, 32],
            [2001, 9197, 43, 28],
            [2001, 9198, 39, 29],
            [2001, 9199, 70, 45],
            [2001, 9200, 49, 58],
            [2001, 9201, 65, 38],
            [2001, 9202, 50, 48],
            [2001, 9203, 13, 22],
            [2001, 9204, 12, 16],
            [2001, 9205, 32, 31],
            [2001, 9206, 20, 25],
            [2001, 9207, 34, 38],
            [2001, 9208, 49, 49],
            [2001, 9209, 34, 30],
            [2001, 9210, 60, 50],
            [2001, 9211, 30, 37],
            [2001, 9212, 53, 52],
            [2001, 9213, 80, 70],
            [2001, 9214, 51, 47],
            [2001, 9215, 20, 28],
            [2001, 9216, 75, 76],
            [2001, 9217, 67, 50],
            [2001, 9218, 29, 27],
            [2001, 9219, 53, 60],
            [2001, 9220, 39, 36],
            [2001, 9221, 32, 37],
            [2001, 9222, 50, 59],
            [2001, 9223, 46, 59],
            [2001, 9224, 63, 48],
            [2001, 9225, 50, 41],
            [2001, 9226, 74, 48],
            [2001, 9227, 76, 60],
            [2001, 9228, 79, 81],
            [2001, 9229, 57, 60],
            [2001, 9230, 43, 42],
            [2001, 9231, 83, 67],
            [2001, 9232, 54, 46],
            [2001, 9233, 46, 44],
            [2001, 9234, 30, 38],
            [2001, 9235, 45, 50],
            [2001, 9236, 26, 21],
            [2001, 9237, 44, 25],
            [2001, 9238, 45, 60],
            [2001, 9239, 66, 79],
            [2001, 9240, 45, 51],
            [2001, 9241, 34, 49],
            [2001, 9242, 51, 43],
            [2001, 9243, 64, 60],
            [2001, 9244, 50, 47],
            [2001, 9245, 25, 32],
            [2001, 9246, 37, 30],
            [2001, 9247, 57, 44],
            [2001, 9248, 47, 35],
            [2001, 9249, 31, 23],
            [2001, 9250, 35, 23],
            [2001, 9251, 38, 33],
            [2001, 9252, 21, 29],
            [2001, 9253, 96, 70],
            [2001, 9254, 110, 127],
            [2001, 9255, 55, 38],
            [2001, 9257, 93, 86],
            [2001, 9258, 49, 73],
            [2001, 9259, 77, 77],
            [2001, 9260, 62, 46],
            [2001, 9261, 102, 132],
            [2001, 9263, 66, 74],
            [2001, 9264, 64, 70],
            [2001, 9265, 67, 74],
            [2001, 9266, 105, 132],
            [2001, 9267, 77, 80],
            [2001, 9268, 69, 77],
            [2001, 9269, 107, 121],
            [2001, 9270, 105, 132],
            [2001, 9271, 106, 134],
            [2001, 9272, 108, 137],
            [2001, 9273, 114, 145],
            [2001, 9274, 94, 92],
            [2001, 9275, 80, 76],
            [2001, 9276, 97, 92],
            [2001, 9277, 103, 85],
            [2001, 9278, 92, 93],
            [2001, 9279, 92, 89],
            [2001, 9280, 78, 77],
            [2001, 9281, 93, 88],
            [2001, 9282, 110, 100],
            [2001, 9283, 106, 122],
            [2001, 9284, 115, 144],
            [2001, 9285, 92, 119],
            [2001, 9286, 112, 142],
            [2001, 9287, 113, 141],
            [2001, 9288, 63, 48],
            [2001, 9289, 117, 140],
            [2001, 9290, 99, 119],
            [2001, 9291, 110, 135],
            [2001, 9292, 109, 135],
            [2001, 9293, 72, 52],
            [2001, 9294, 78, 78],
            [2001, 9295, 91, 89],
            [2001, 9296, 70, 51],
            [2001, 9297, 82, 58],
            [2001, 9298, 91, 120],
            [2001, 9299, 102, 134],
            [2001, 9300, 111, 138],
            [2001, 9301, 97, 124],
            [2001, 9302, 114, 141],
            [2001, 9303, 113, 145],
            [2001, 9304, 60, 86],
            [2001, 9305, 99, 127],
            [2001, 9306, 114, 146],
            [2001, 9307, 52, 76],
            [2001, 9308, 59, 86],
            [2001, 9309, 63, 80],
            [2001, 9310, 72, 88],
            [2001, 9311, 66, 82],
            [2001, 9312, 72, 88],
            [2001, 9313, 66, 81],
            [2001, 9314, 76, 94],
            [2001, 9315, 47, 47],
            [2001, 9316, 30, 30],
            [2001, 9317, 13, 15],
            [2001, 9318, 15, 19],
            [2001, 9319, 45, 52],
            [2001, 9320, 70, 70],
            [2001, 9327, 14, 19],
            [2001, 9328, 29, 35],
            [2001, 9329, 40, 50],
            [2001, 9330, 54, 62],
            [2001, 9331, 38, 38],
            [2001, 9332, 34, 40],
            [2001, 9333, 14, 17],
            [2001, 9334, 12, 15],
            [2001, 9335, 39, 39],
            [2001, 9336, 32, 39],
            [2001, 9337, 22, 27],
            [2001, 9338, 14, 16],
            [2001, 9339, 19, 24],
            [2001, 9340, 55, 64],
            [2001, 9341, 29, 34],
            [2001, 9342, 38, 38],
            [2001, 9343, 9, 11],
            [2001, 9344, 22, 26],
            [2001, 9345, 22, 27],
            [2001, 9346, 16, 19],
            [2001, 9347, 12, 16],
            [2001, 9348, 23, 26],
            [2001, 9349, 19, 23],
            [2001, 9350, 56, 66],
            [2001, 9351, 40, 39],
            [2001, 9352, 44, 44],
            [2001, 9353, 22, 26],
            [2001, 9354, 31, 31],
            [2001, 9355, 20, 20],
            [2001, 9356, 38, 45],
            [2001, 9357, 22, 25],
            [2001, 9358, 29, 28],
            [2001, 9359, 23, 23],
            [2001, 9360, 34, 41],
            [2001, 9361, 31, 37],
            [2001, 9362, 40, 39],
            [2001, 9363, 35, 41],
            [2001, 9364, 46, 35],
            [2001, 9365, 21, 26],
            [2001, 9366, 36, 42],
            [2001, 9367, 23, 22],
            [2001, 9368, 35, 35],
            [2001, 9369, 37, 37],
            [2001, 9370, 19, 22],
            [2001, 9371, 35, 35],
            [2001, 9372, 30, 29],
            [2001, 9373, 25, 25],
            [2001, 9374, 45, 45],
            [2001, 9375, 26, 31],
            [2001, 9376, 50, 50],
            [2001, 9377, 15, 21],
            [2001, 9378, 21, 25],
            [2001, 9379, 38, 47],
            [2001, 9380, 35, 42],
            [2001, 9381, 70, 84],
            [2001, 9382, 41, 48],
            [2001, 9383, 44, 44],
            [2001, 9384, 22, 26],
            [2001, 9385, 27, 32],
            [2001, 9386, 25, 29],
            [2001, 9387, 20, 23],
            [2001, 9388, 20, 27],
            [2001, 9389, 22, 26],
            [2001, 9390, 23, 28],
            [2001, 9391, 26, 31],
            [2001, 9392, 25, 29],
            [2001, 9393, 27, 27],
            [2001, 9394, 20, 24],
            [2001, 9395, 28, 33],
            [2001, 9396, 29, 36],
            [2001, 9397, 56, 66],
            [2001, 9398, 51, 61],
            [2001, 9399, 75, 87],
            [2001, 9400, 32, 39],
            [2001, 9401, 48, 47],
            [2001, 9402, 49, 38],
            [2001, 9403, 116, 87],
            [2001, 9404, 116, 86],
            [2001, 9405, 117, 87],
            [2001, 9406, 111, 87],
            [2001, 9407, 70, 68],
            [2001, 9408, 117, 87],
            [2001, 9409, 115, 86],
            [2001, 9410, 117, 87],
            [2001, 9411, 115, 85],
            [2001, 9412, 115, 86],
            [2001, 9413, 117, 87],
            [2001, 9414, 116, 86],
            [2001, 9415, 117, 87],
            [2001, 9416, 111, 84],
            [2001, 9417, 117, 87],
            [2001, 9418, 114, 83],
            [2001, 9419, 115, 87],
            [2001, 9420, 116, 86],
            [2001, 9421, 114, 83],
            [2001, 9422, 115, 87],
            [2001, 9423, 111, 83],
            [2001, 9424, 116, 86],
            [2001, 9425, 117, 87],
            [2001, 9426, 115, 87],
            [2001, 9427, 117, 87],
            [2001, 9428, 115, 85],
            [2001, 9429, 115, 86],
            [2001, 9430, 117, 87],
            [2001, 9431, 115, 86],
            [2001, 9432, 67, 65],
            [2001, 9433, 111, 83],
            [2001, 9434, 115, 86],
            [2001, 9435, 117, 87],
            [2001, 9436, 115, 86],
            [2001, 9437, 116, 86],
            [2001, 9438, 117, 87],
            [2001, 9439, 115, 85],
            [2001, 9440, 117, 87],
            [2001, 9441, 115, 87],
            [2001, 9442, 117, 87],
            [2001, 9443, 116, 86],
            [2001, 9444, 115, 85],
            [2001, 9445, 115, 86],
            [2001, 9446, 117, 87],
            [2001, 9447, 115, 86],
            [2001, 9448, 117, 87],
            [2001, 9449, 93, 72],
            [2001, 9450, 111, 83],
            [2001, 9451, 111, 87],
            [2001, 9452, 115, 86],
            [2001, 9453, 115, 86],
            [2001, 9454, 115, 86],
            [2001, 9455, 117, 87],
            [2001, 9456, 116, 86],
            [2001, 9457, 111, 87],
            [2001, 9458, 116, 86],
            [2001, 9459, 115, 86],
            [2001, 9460, 117, 87],
            [2001, 9461, 115, 86],
            [2001, 9462, 117, 87],
            [2001, 9463, 85, 83],
            [2001, 9464, 85, 83],
            [2001, 9465, 67, 65],
            [2001, 9466, 115, 86],
            [2001, 9467, 116, 86],
            [2001, 9468, 116, 68],
            [2001, 9469, 117, 87],
            [2001, 9470, 115, 85],
            [2001, 9471, 159, 95],
            [2001, 9472, 190, 180],
            [2001, 9473, 52, 91],
            [2001, 9474, 85, 139],
            [2001, 9475, 120, 106],
            [2001, 9476, 120, 200],
            [2001, 9477, 38, 54],
            [2001, 9478, 60, 83],
            [2001, 9479, 84, 93],
            [2001, 9480, 125, 139],
            [2001, 9481, 27, 79],
            [2001, 9482, 42, 123],
            [2001, 9483, 120, 90],
            [2001, 9484, 168, 83],
            [2001, 9485, 76, 50],
            [2001, 9486, 100, 80],
            [2001, 9487, 27, 55],
            [2001, 9488, 47, 82],
            [2001, 9489, 111, 83],
            [2001, 9490, 110, 107],
            [2001, 9491, 47, 80],
            [2001, 9492, 77, 91],
            [2001, 9493, 120, 100],
            [2001, 9494, 127, 138],
            [2001, 9495, 47, 46],
            [2001, 9496, 85, 57],
            [2001, 9497, 44, 31],
            [2001, 9498, 74, 50],
            [2001, 9499, 67, 83],
            [2001, 9500, 111, 123],
            [2001, 9501, 70, 119],
            [2001, 9502, 120, 200],
            [2001, 9503, 67, 57],
            [2001, 9504, 84, 68],
            [2001, 9505, 67, 108],
            [2001, 9506, 111, 174],
            [2001, 9507, 78, 83],
            [2001, 9508, 110, 158],
            [2001, 9509, 111, 77],
            [2001, 9510, 111, 113],
            [2001, 9511, 67, 66],
            [2001, 9512, 67, 110],
            [2001, 9513, 80, 84],
            [2001, 9514, 111, 126],
            [2001, 9515, 70, 70],
            [2001, 9516, 120, 104],
            [2001, 9517, 111, 91],
            [2001, 9518, 145, 142],
            [2001, 9519, 34, 39],
            [2001, 9520, 56, 64],
            [2001, 9521, 67, 170],
            [2001, 9522, 104, 200],
            [2001, 9523, 111, 91],
            [2001, 9524, 138, 149],
            [2001, 9525, 32, 42],
            [2001, 9526, 49, 63],
            [2001, 9527, 85, 86],
            [2001, 9528, 110, 117],
            [2001, 9529, 46, 55],
            [2001, 9530, 73, 83],
            [2001, 9531, 46, 63],
            [2001, 9532, 55, 99],
            [2001, 9533, 111, 116],
            [2001, 9534, 161, 157],
            [2001, 9535, 38, 94],
            [2001, 9536, 65, 164],
            [2001, 9537, 130, 90],
            [2001, 9538, 180, 145],
            [2001, 9539, 64, 63],
            [2001, 9540, 85, 98],
            [2001, 9541, 46, 45],
            [2001, 9542, 71, 69],
            [2001, 9543, 38, 49],
            [2001, 9544, 60, 76],
            [2001, 9545, 67, 65],
            [2001, 9546, 76, 91],
            [2001, 9547, 41, 52],
            [2001, 9548, 68, 85],
            [2001, 9549, 35, 36],
            [2001, 9550, 54, 65],
            [2001, 9551, 38, 59],
            [2001, 9552, 58, 97],
            [2001, 9553, 47, 55],
            [2001, 9554, 67, 83],
            [2001, 9555, 64, 144],
            [2001, 9556, 101, 173],
            [2001, 9557, 38, 63],
            [2001, 9558, 67, 99],
            [2001, 9559, 44, 46],
            [2001, 9560, 59, 70],
            [2001, 9561, 46, 72],
            [2001, 9562, 72, 112],
            [2001, 9563, 63, 141],
            [2001, 9564, 103, 174],
            [2001, 9565, 67, 65],
            [2001, 9566, 74, 106],
            [2001, 9567, 61, 80],
            [2001, 9568, 79, 129],
            [2001, 9569, 111, 108],
            [2001, 9570, 143, 149],
            [2001, 9571, 95, 180],
            [2001, 9572, 145, 200],
            [2001, 9573, 85, 83],
            [2001, 9574, 111, 135],
            [2001, 9575, 74, 82],
            [2001, 9576, 124, 137],
            [2001, 9577, 120, 81],
            [2001, 9578, 155, 140],
            [2001, 9579, 45, 108],
            [2001, 9580, 66, 141],
            [2001, 9581, 49, 65],
            [2001, 9582, 59, 86],
            [2001, 9583, 111, 146],
            [2001, 9584, 170, 174],
            [2001, 9585, 111, 74],
            [2001, 9586, 119, 87],
            [2001, 9587, 64, 63],
            [2001, 9588, 66, 84],
            [2001, 9589, 35, 80],
            [2001, 9590, 54, 123],
            [2001, 9591, 67, 57],
            [2001, 9592, 73, 65],
            [2001, 9593, 38, 58],
            [2001, 9594, 60, 103],
            [2001, 9595, 43, 59],
            [2001, 9596, 72, 90],
            [2001, 9597, 29, 29],
            [2001, 9598, 39, 56],
            [2001, 9599, 111, 74],
            [2001, 9600, 111, 83],
            [2001, 9601, 49, 83],
            [2001, 9602, 99, 155],
            [2001, 9603, 64, 83],
            [2001, 9604, 97, 108],
            [2001, 9605, 64, 46],
            [2001, 9606, 67, 55],
            [2001, 9607, 57, 71],
            [2001, 9608, 90, 83],
            [2001, 9609, 42, 47],
            [2001, 9610, 54, 65],
            [2001, 9611, 47, 55],
            [2001, 9612, 67, 74],
            [2001, 9613, 70, 142],
            [2001, 9614, 107, 174],
            [2001, 9615, 55, 48],
            [2001, 9616, 89, 78],
            [2001, 9617, 23, 31],
            [2001, 9618, 67, 65],
            [2001, 9619, 36, 48],
            [2001, 9620, 36, 48],
            [2001, 9621, 40, 74],
            [2001, 9622, 54, 82],
            [2001, 9623, 67, 57],
            [2001, 9624, 67, 65],
            [2001, 9625, 111, 83],
            [2001, 9626, 110, 114],
            [2001, 9627, 67, 48],
            [2001, 9628, 85, 65],
            [2001, 9629, 47, 57],
            [2001, 9630, 85, 78],
            [2001, 9631, 47, 48],
            [2001, 9632, 60, 77],
            [2001, 9633, 63, 79],
            [2001, 9634, 107, 150],
            [2001, 9635, 152, 141],
            [2001, 9636, 178, 174],
            [2001, 9637, 79, 85],
            [2001, 9638, 118, 127],
            [2001, 9639, 23, 32],
            [2001, 9640, 38, 65],
            [2001, 9641, 64, 50],
            [2001, 9642, 76, 82],
            [2001, 9643, 29, 54],
            [2001, 9644, 46, 86],
            [2001, 9645, 67, 130],
            [2001, 9646, 77, 174],
            [2001, 9647, 111, 83],
            [2001, 9648, 127, 157],
            [2001, 9651, 71, 70],
            [2001, 9652, 93, 92],
            [2001, 9653, 60, 55],
            [2001, 9654, 99, 76],
            [2001, 9655, 49, 49],
            [2001, 9656, 82, 81],
            [2001, 9657, 62, 61],
            [2001, 9658, 76, 67],
            [2001, 9659, 53, 45],
            [2001, 9660, 78, 77],
            [2001, 9661, 43, 43],
            [2001, 9662, 76, 74],
            [2001, 9663, 47, 43],
            [2001, 9664, 78, 72],
            [2001, 9665, 67, 66],
            [2001, 9666, 82, 81],
            [2001, 9667, 56, 50],
            [2001, 9668, 82, 71],
            [2001, 9669, 50, 50],
            [2001, 9670, 70, 70],
            [2001, 9671, 49, 50],
            [2001, 9672, 93, 81],
            [2001, 9673, 53, 53],
            [2001, 9674, 70, 70],
            [2001, 9675, 60, 61],
            [2001, 9676, 110, 83],
            [2001, 9677, 52, 50],
            [2001, 9678, 77, 73],
            [2001, 9679, 50, 52],
            [2001, 9680, 77, 76],
            [2001, 9681, 67, 55],
            [2001, 9682, 88, 81],
            [2001, 9683, 64, 59],
            [2001, 9684, 84, 81],
            [2001, 9685, 61, 60],
            [2001, 9686, 85, 82],
            [2001, 9687, 57, 50],
            [2001, 9688, 85, 82],
            [2001, 9689, 88, 89],
            [2001, 9690, 86, 83],
            [2001, 9691, 55, 49],
            [2001, 9692, 82, 73],
            [2001, 9693, 70, 54],
            [2001, 9694, 110, 73],
            [2001, 9695, 43, 43],
            [2001, 9696, 77, 73],
            [2001, 9697, 48, 44],
            [2001, 9698, 100, 67],
            [2001, 9699, 43, 49],
            [2001, 9700, 80, 81],
            [2001, 9701, 46, 46],
            [2001, 9702, 61, 59],
            [2001, 9703, 40, 41],
            [2001, 9704, 82, 79],
            [2001, 9705, 41, 41],
            [2001, 9706, 89, 85],
            [2001, 9707, 60, 49],
            [2001, 9708, 76, 59],
            [2001, 9709, 50, 50],
            [2001, 9710, 60, 58],
            [2001, 9711, 108, 81],
            [2001, 9712, 107, 84],
            [2001, 9713, 108, 81],
            [2001, 9714, 105, 79],
            [2001, 9715, 103, 78],
            [2001, 9716, 55, 45],
            [2001, 9717, 70, 60],
            [2001, 9718, 49, 46],
            [2001, 9719, 76, 73],
            [2001, 9720, 101, 75],
            [2001, 9721, 94, 83],
            [2001, 9722, 43, 43],
            [2001, 9723, 90, 87],
            [2001, 9724, 75, 72],
            [2001, 9725, 95, 87],
            [2001, 9726, 29, 37],
            [2001, 9727, 69, 67],
            [2001, 9728, 60, 58],
            [2001, 9729, 69, 66],
            [2001, 9730, 35, 35],
            [2001, 9731, 100, 75],
            [2001, 9735, 71, 61],
            [2001, 9736, 58, 58],
            [2001, 9737, 58, 52],
            [2001, 9738, 121, 84],
            [2001, 9739, 74, 72],
            [2001, 9740, 80, 78],
            [2001, 9741, 81, 73],
            [2001, 9742, 78, 70],
            [2001, 9743, 59, 50],
            [2001, 9744, 110, 80],
            [2001, 9745, 68, 67],
            [2001, 9746, 71, 71],
            [2001, 9747, 68, 66],
            [2001, 9748, 56, 59],
            [2001, 9751, 49, 43],
            [2001, 9752, 60, 55],
            [2001, 9753, 46, 46],
            [2001, 9754, 78, 78],
            [2001, 9755, 49, 49],
            [2001, 9756, 87, 84],
            [2001, 9757, 48, 48],
            [2001, 9758, 70, 68],
            [2001, 9759, 25, 15],
            [2001, 9760, 55, 33],
            [2001, 9761, 57, 35],
            [2001, 9762, 51, 22],
            [2001, 9763, 27, 18],
            [2001, 9764, 34, 15],
            [2001, 9765, 59, 35],
            [2001, 9766, 52, 26],
            [2001, 9767, 51, 60],
            [2001, 9768, 46, 30],
            [2001, 9769, 29, 21],
            [2001, 9770, 58, 51],
            [2001, 9771, 69, 27],
            [2001, 9772, 38, 17],
            [2001, 9773, 55, 41],
            [2001, 9774, 29, 23],
            [2001, 9775, 29, 21],
            [2001, 9776, 38, 16],
            [2001, 9777, 59, 35],
            [2001, 9778, 57, 38],
            [2001, 9779, 51, 36],
            [2001, 9780, 54, 42],
            [2001, 9781, 38, 19],
            [2001, 9782, 57, 39],
            [2001, 9783, 46, 26],
            [2001, 9784, 46, 38],
            [2001, 9785, 35, 29],
            [2001, 9786, 28, 20],
            [2001, 9787, 54, 35],
            [2001, 9788, 27, 21],
            [2001, 9789, 59, 26],
            [2001, 9790, 54, 32],
            [2001, 9791, 69, 41],
            [2001, 9792, 57, 50],
            [2001, 9793, 21, 15],
            [2001, 9794, 17, 16],
            [2001, 9795, 17, 15],
            [2001, 9796, 26, 20],
            [2001, 9797, 21, 15],
            [2001, 9798, 17, 16],
            [2001, 9799, 66, 54],
            [2001, 9800, 32, 27],
            [2001, 9801, 26, 20],
            [2001, 9802, 26, 20],
            [2001, 9803, 12, 10],
            [2001, 9804, 24, 18],
            [2001, 9805, 50, 35],
            [2001, 9806, 32, 23],
            [2001, 9807, 41, 24],
            [2001, 9808, 120, 70],
            [2001, 9809, 60, 20],
            [2001, 9811, 64, 33],
            [2001, 9812, 120, 65],
            [2001, 9813, 90, 35],
            [2001, 9814, 32, 17],
            [2001, 9815, 65, 33],
            [2001, 9816, 47, 18],
            [2001, 9817, 40, 16],
            [2001, 9818, 90, 24],
            [2001, 9819, 81, 54],
            [2001, 9820, 99, 57],
            [2001, 9821, 70, 37],
            [2001, 9822, 29, 24],
            [2001, 9823, 40, 25],
            [2001, 9824, 42, 33],
            [2001, 9825, 29, 22],
            [2001, 9826, 81, 53],
            [2001, 9827, 73, 38],
            [2001, 9828, 81, 52],
            [2001, 9829, 63, 37],
            [2001, 9830, 48, 35],
            [2001, 9831, 61, 34],
            [2001, 9832, 47, 29],
            [2001, 9833, 50, 33],
            [2001, 9834, 88, 54],
            [2001, 9835, 48, 42],
            [2001, 9836, 73, 50],
            [2001, 9837, 44, 27],
            [2001, 9838, 81, 59],
            [2001, 9839, 22, 19],
            [2001, 9840, 66, 47],
            [2001, 9841, 130, 71],
            [2001, 9842, 45, 25],
            [2001, 9843, 40, 28],
            [2001, 9844, 53, 32],
            [2001, 9845, 43, 36],
            [2001, 9846, 40, 23],
            [2001, 9847, 19, 16],
            [2001, 9848, 35, 22],
            [2001, 9849, 35, 20],
            [2001, 9850, 35, 15],
            [2001, 9851, 31, 15],
            [2001, 9852, 29, 15],
            [2001, 9853, 32, 21],
            [2001, 9854, 18, 15],
            [2001, 9855, 43, 35],
            [2001, 9856, 21, 22],
            [2001, 9857, 21, 16],
            [2001, 9858, 65, 39],
            [2001, 9859, 82, 48],
            [2001, 9860, 69, 50],
            [2001, 9861, 81, 70],
            [2001, 9862, 41, 45],
            [2001, 9863, 66, 45],
            [2001, 9864, 81, 30],
            [2001, 9865, 52, 30],
            [2001, 9866, 81, 30],
            [2001, 9867, 31, 21],
            [2001, 9868, 69, 42],
            [2001, 9869, 63, 35],
            [2001, 9870, 53, 65],
            [2001, 9871, 69, 39],
            [2001, 9872, 35, 30],
            [2001, 9873, 50, 47],
            [2001, 9874, 64, 28],
            [2001, 9875, 49, 32],
            [2001, 9876, 35, 30],
            [2001, 9877, 51, 39],
            [2001, 9878, 62, 35],
            [2001, 9879, 54, 30],
            [2001, 9880, 59, 45],
            [2001, 9881, 80, 41],
            [2001, 9882, 59, 45],
            [2001, 9883, 52, 28],
            [2001, 9884, 50, 25],
            [2001, 9885, 65, 30],
            [2001, 9886, 62, 29],
            [2001, 9887, 53, 35],
            [2001, 9888, 69, 50],
            [2001, 9889, 69, 40],
            [2001, 9890, 61, 40],
            [2001, 9891, 51, 31],
            [2001, 9892, 42, 31],
            [2001, 9893, 32, 23],
            [2001, 9894, 68, 44],
            [2001, 9895, 30, 18],
            [2001, 9896, 13, 16],
            [2001, 9897, 51, 31],
            [2001, 9898, 53, 40],
            [2001, 9899, 36, 27],
            [2001, 9900, 90, 79],
            [2001, 9901, 82, 50],
            [2001, 9902, 131, 95],
            [2001, 9903, 110, 65],
            [2001, 9904, 96, 67],
            [2001, 9905, 61, 45],
            [2001, 9906, 62, 34],
            [2001, 9907, 43, 39],
            [2001, 9908, 95, 60],
            [2001, 9909, 21, 18],
            [2001, 9910, 88, 72],
            [2001, 9911, 129, 67],
            [2001, 9912, 79, 45],
            [2001, 9913, 32, 26],
            [2001, 9914, 45, 33],
            [2001, 9915, 45, 37],
            [2001, 9916, 45, 40],
            [2001, 9917, 42, 37],
            [2001, 9918, 124, 40],
            [2001, 9919, 111, 91],
            [2001, 9920, 133, 92],
            [2001, 9921, 35, 27],
            [2001, 9922, 40, 21],
            [2001, 9923, 44, 27],
            [2001, 9924, 70, 34],
            [2001, 9925, 80, 76],
            [2001, 9926, 60, 76],
            [2001, 9927, 45, 29],
            [2001, 9928, 86, 42],
            [2001, 9929, 70, 60],
            [2001, 9930, 60, 37],
            [2001, 9931, 81, 46],
            [2001, 9932, 80, 37],
            [2001, 9933, 75, 57],
            [2001, 9934, 76, 40],
            [2001, 9935, 59, 30],
            [2001, 9936, 64, 40],
            [2001, 9937, 40, 37],
            [2001, 9938, 23, 20],
            [2001, 9939, 66, 30],
            [2001, 9940, 52, 45],
            [2001, 9941, 55, 28],
            [2001, 9942, 29, 22],
            [2001, 9943, 173, 93],
            [2001, 9944, 76, 36],
            [2001, 9945, 108, 43],
            [2001, 9946, 51, 24],
            [2001, 9947, 76, 36],
            [2001, 9948, 142, 65],
            [2001, 9949, 128, 73],
            [2001, 9950, 101, 70],
            [2001, 9951, 47, 29],
            [2001, 9952, 76, 35],
            [2001, 9953, 39, 29],
            [2001, 9954, 100, 65],
            [2001, 9955, 37, 30],
            [2001, 9956, 87, 35],
            [2001, 9957, 137, 62],
            [2001, 9958, 41, 31],
            [2001, 9959, 119, 57],
            [2001, 9960, 82, 36],
            [2001, 9961, 38, 37],
            [2001, 9962, 49, 31],
            [2001, 9963, 90, 54],
            [2001, 9964, 46, 43],
            [2001, 9965, 43, 20],
            [2001, 9966, 88, 42],
            [2001, 9967, 105, 47],
            [2001, 9968, 59, 52],
            [2001, 9969, 57, 31],
            [2001, 9970, 76, 35],
            [2001, 9971, 51, 36],
            [2001, 9972, 155, 61],
            [2001, 9973, 65, 50],
            [2001, 9974, 42, 18],
            [2001, 9975, 121, 48],
            [2001, 9976, 155, 61],
            [2001, 9977, 55, 25],
            [2001, 9978, 60, 26],
            [2001, 9979, 137, 57],
            [2001, 9980, 69, 29],
            [2001, 9981, 41, 23],
            [2001, 9982, 23, 16],
            [2001, 9983, 120, 45],
            [2001, 9984, 62, 34],
            [2001, 9985, 62, 33],
            [2001, 9986, 67, 36],
            [2001, 9987, 69, 57],
            [2001, 9988, 63, 37],
            [2001, 9989, 51, 39],
            [2001, 9990, 38, 22],
            [2001, 9991, 64, 44],
            [2001, 9992, 63, 47],
            [2001, 9993, 45, 51],
            [2001, 9994, 42, 36],
            [2001, 9995, 59, 47],
            [2001, 9996, 50, 42],
            [2001, 9997, 22, 30],
            [2001, 9998, 25, 20],
            [2001, 9999, 40, 45],
            [2001, 10000, 32, 20],
            [2001, 10001, 26, 19],
            [2001, 10002, 23, 18],
            [2001, 10003, 68, 36],
            [2001, 10004, 25, 21],
            [2001, 10005, 25, 20],
            [2001, 10006, 19, 15],
            [2001, 10007, 47, 54],
            [2001, 10008, 63, 63],
            [2001, 10009, 65, 46],
            [2001, 10010, 77, 42],
            [2001, 10011, 58, 40],
            [2001, 10012, 84, 36],
            [2001, 10013, 41, 39],
            [2001, 10014, 53, 61],
            [2001, 10015, 41, 39],
            [2001, 10016, 45, 52],
            [2001, 10017, 53, 46],
            [2001, 10018, 57, 52],
            [2001, 10019, 56, 49],
            [2001, 10020, 71, 60],
            [2001, 10021, 92, 60],
            [2001, 10022, 73, 60],
            [2001, 10023, 84, 61],
            [2001, 10024, 106, 74],
            [2001, 10025, 89, 74],
            [2001, 10026, 87, 63],
            [2001, 10027, 84, 67],
            [2001, 10030, 77, 63],
            [2001, 10031, 92, 82],
            [2001, 10032, 102, 77],
            [2001, 10033, 58, 44],
            [2001, 10034, 64, 43],
            [2001, 10035, 116, 60],
            [2001, 10036, 106, 48],
            [2001, 10037, 126, 63],
            [2001, 10038, 37, 24],
            [2001, 10039, 21, 25],
            [2001, 10040, 37, 25],
            [2001, 10041, 34, 21],
            [2001, 10042, 58, 39],
            [2001, 10043, 62, 30],
            [2001, 10044, 71, 30],
            [2001, 10045, 46, 26],
            [2001, 10046, 70, 45],
            [2001, 10047, 66, 36],
            [2001, 10048, 62, 36],
            [2001, 10049, 42, 33],
            [2001, 10050, 58, 40],
            [2001, 10051, 65, 44],
            [2001, 10052, 84, 74],
            [2001, 10053, 95, 79],
            [2001, 10054, 82, 79],
            [2001, 10055, 91, 81],
            [2001, 10056, 76, 77],
            [2001, 10057, 86, 81],
            [2001, 10058, 46, 52],
            [2001, 10059, 99, 57],
            [2001, 10060, 70, 51],
            [2001, 10061, 85, 82],
            [2001, 10063, 24, 28],
            [2001, 10064, 46, 38],
            [2001, 10065, 41, 53],
            [2001, 10066, 56, 51],
            [2001, 10067, 83, 66],
            [2001, 10068, 88, 68],
            [2001, 10069, 84, 67],
            [2001, 10070, 51, 29],
            [2001, 10071, 83, 60],
            [2001, 10072, 80, 29],
            [2001, 10073, 84, 35],
            [2001, 10074, 83, 36],
            [2001, 10075, 98, 51],
            [2001, 10076, 83, 51],
            [2001, 10077, 84, 51],
            [2001, 10078, 102, 63],
            [2001, 10079, 64, 47],
            [2001, 10080, 53, 47],
            [2001, 10081, 100, 63],
            [2001, 10082, 68, 74],
            [2001, 10083, 52, 51],
            [2001, 10084, 58, 40],
            [2001, 10085, 55, 26],
            [2001, 10086, 61, 36],
            [2001, 10087, 55, 25],
            [2001, 10088, 85, 54],
            [2001, 10089, 85, 56],
            [2001, 10090, 67, 54],
            [2001, 10091, 81, 39],
            [2001, 10092, 95, 40],
            [2001, 10093, 63, 54],
            [2001, 10094, 106, 65],
            [2001, 10095, 97, 64],
            [2001, 10096, 83, 50],
            [2001, 10097, 65, 50],
            [2001, 10098, 75, 56],
            [2001, 10099, 88, 62],
            [2001, 10101, 97, 79],
            [2001, 10102, 84, 72],
            [2001, 10103, 85, 82],
            [2001, 10104, 20, 21],
            [2001, 10105, 37, 25],
            [2001, 10106, 37, 36],
            [2001, 10107, 78, 75],
            [2001, 10108, 96, 89],
            [2001, 10109, 143, 90],
            [2001, 10110, 76, 68],
            [2001, 10111, 109, 83],
            [2001, 10112, 115, 93],
            [2001, 10113, 123, 103],
            [2001, 10114, 98, 60],
            [2001, 10115, 56, 41],
            [2001, 10116, 65, 55],
            [2001, 10117, 61, 67],
            [2001, 10118, 66, 75],
            [2001, 10119, 28, 19],
            [2001, 10120, 37, 24],
            [2001, 10121, 93, 83],
            [2001, 10122, 93, 82],
            [2001, 10123, 103, 88],
            [2001, 10124, 89, 87],
            [2001, 10125, 100, 62],
            [2001, 10126, 85, 50],
            [2001, 10127, 84, 54],
            [2001, 10128, 85, 60],
            [2001, 10129, 101, 65],
            [2001, 10130, 93, 63],
            [2001, 10131, 63, 51],
            [2001, 10132, 63, 51],
            [2001, 10133, 85, 50],
            [2001, 10134, 105, 73],
            [2001, 10135, 101, 82],
            [2001, 10136, 69, 34],
            [2001, 10137, 80, 54],
            [2001, 10138, 76, 40],
            [2001, 10139, 73, 47],
            [2001, 10141, 66, 40],
            [2001, 10142, 72, 43],
            [2001, 10144, 94, 47],
            [2001, 10145, 54, 57],
            [2001, 10146, 66, 64],
            [2001, 10148, 69, 36],
            [2001, 10149, 71, 78],
            [2001, 10150, 32, 44],
            [2001, 10151, 55, 53],
            [2001, 10152, 79, 62],
            [2001, 10153, 87, 69],
            [2001, 10154, 35, 35],
            [2001, 10155, 65, 67],
            [2001, 10156, 45, 47],
            [2001, 10157, 86, 64],
            [2001, 10158, 45, 49],
            [2001, 10159, 65, 52],
            [2001, 10160, 69, 44],
            [2001, 10161, 101, 57],
            [2001, 10162, 74, 38],
            [2001, 10163, 98, 46],
            [2001, 10164, 77, 39],
            [2001, 10165, 82, 41],
            [2001, 10166, 61, 36],
            [2001, 10167, 76, 59],
            [2001, 10168, 75, 59],
            [2001, 10169, 85, 61],
            [2001, 10170, 36, 47],
            [2001, 10171, 66, 56],
            [2001, 10172, 50, 45],
            [2001, 10173, 65, 56],
            [2001, 10174, 62, 43],
            [2001, 10175, 84, 57],
            [2001, 10176, 24, 26],
            [2001, 10177, 21, 24],
            [2001, 10178, 28, 27],
            [2001, 10179, 22, 24],
            [2001, 10180, 46, 37],
            [2001, 10181, 28, 20],
            [2001, 10182, 46, 52],
            [2001, 10183, 61, 34],
            [2001, 10184, 61, 21],
            [2001, 10185, 19, 15],
            [2001, 10186, 16, 14],
            [2001, 10187, 25, 19],
            [2001, 10188, 26, 18],
            [2001, 10189, 84, 43],
            [2001, 10190, 27, 17],
            [2001, 10191, 64, 33],
            [2001, 10192, 44, 26],
            [2001, 10193, 25, 23],
            [2001, 10194, 18, 13],
            [2001, 10195, 18, 15],
            [2001, 10196, 48, 34],
            [2001, 10197, 45, 32],
            [2001, 10198, 32, 36],
            [2001, 10199, 31, 36],
            [2001, 10200, 30, 36],
            [2001, 10201, 29, 33],
            [2001, 10202, 73, 64],
            [2001, 10203, 60, 42],
            [2001, 10204, 61, 42],
            [2001, 10205, 52, 38],
            [2001, 10206, 48, 33],
            [2001, 10207, 44, 31],
            [2001, 10208, 48, 35],
            [2001, 10209, 45, 32],
            [2001, 10210, 53, 43],
            [2001, 10211, 51, 40],
            [2001, 10212, 58, 36],
            [2001, 10213, 55, 34],
            [2001, 10214, 48, 43],
            [2001, 10215, 45, 40],
            [2001, 10216, 50, 35],
            [2001, 10217, 53, 38],
            [2001, 10218, 51, 42],
            [2001, 10219, 49, 42],
            [2001, 10220, 47, 39],
            [2001, 10221, 51, 35],
            [2001, 10222, 48, 37],
            [2001, 10223, 62, 51],
            [2001, 10224, 68, 57],
            [2001, 10225, 65, 62],
            [2001, 10226, 34, 34],
            [2001, 10227, 36, 34],
            [2001, 10228, 33, 31],
            [2001, 10234, 66, 52],
            [2001, 10235, 46, 41],
            [2001, 10236, 46, 44],
            [2001, 10237, 43, 42],
            [2001, 10238, 51, 51],
            [2001, 10239, 68, 54],
            [2001, 10240, 44, 46],
            [2001, 10241, 37, 50],
            [2001, 10242, 50, 39],
            [2001, 10243, 51, 43],
            [2001, 10244, 46, 52],
            [2001, 10245, 23, 35],
            [2001, 10246, 40, 37],
            [2001, 10247, 30, 35],
            [2001, 10248, 46, 39],
            [2001, 10249, 30, 39],
            [2001, 10250, 46, 44],
            [2001, 10251, 51, 43],
            [2001, 10252, 46, 44],
            [2001, 10253, 46, 48],
            [2001, 10255, 51, 47],
            [2001, 10256, 54, 52],
            [2001, 10257, 50, 43],
            [2001, 10258, 52, 51],
            [2001, 10259, 23, 38],
            [2001, 10260, 46, 44],
            [2001, 10261, 52, 43],
            [2001, 10263, 30, 38],
            [2001, 10264, 46, 44],
            [2001, 10267, 37, 35],
            [2001, 10268, 52, 39],
            [2001, 10269, 37, 38],
            [2001, 10270, 39, 44],
            [2001, 10271, 46, 36],
            [2001, 10272, 38, 39],
            [2001, 10276, 44, 43],
            [2001, 10277, 53, 48],
            [2001, 10278, 31, 39],
            [2001, 10279, 51, 50],
            [2001, 10280, 30, 46],
            [2001, 10281, 46, 52],
            [2001, 10283, 30, 35],
            [2001, 10284, 44, 43],
            [2001, 10285, 33, 34],
            [2001, 10286, 38, 36],
            [2001, 10287, 38, 35],
            [2001, 10288, 50, 35],
            [2001, 10289, 51, 40],
            [2001, 10290, 50, 39],
            [2001, 10291, 50, 43],
            [2001, 10292, 36, 42],
            [2001, 10293, 50, 50],
            [2001, 10294, 23, 35],
            [2001, 10295, 30, 39],
            [2001, 10296, 45, 44],
            [2001, 10297, 31, 35],
            [2001, 10298, 39, 40],
            [2001, 10299, 30, 35],
            [2001, 10300, 39, 40],
            [2001, 10301, 39, 44],
            [2001, 10302, 30, 39],
            [2001, 10303, 46, 45],
            [2001, 10304, 31, 39],
            [2001, 10305, 39, 44],
            [2001, 10306, 37, 47],
            [2001, 10307, 43, 49],
            [2001, 10309, 44, 39],
            [2001, 10310, 31, 39],
            [2001, 10311, 40, 44],
            [2001, 10312, 43, 42],
            [2001, 10313, 53, 46],
            [2001, 10314, 47, 40],
            [2001, 10315, 45, 35],
            [2001, 10317, 37, 38],
            [2001, 10318, 54, 44],
            [2001, 10319, 37, 46],
            [2001, 10320, 84, 51],
            [2001, 10321, 37, 35],
            [2001, 10322, 51, 52],
            [2001, 10323, 36, 49],
            [2001, 10326, 66, 52],
            [2001, 10327, 37, 42],
            [2001, 10329, 38, 35],
            [2001, 10330, 43, 50],
            [2001, 10332, 30, 35],
            [2001, 10333, 50, 50],
            [2001, 10334, 56, 50],
            [2001, 10335, 45, 51],
            [2001, 10337, 36, 38],
            [2001, 10338, 52, 44],
            [2001, 10339, 37, 39],
            [2001, 10340, 53, 44],
            [2001, 10341, 30, 34],
            [2001, 10342, 39, 36],
            [2001, 10343, 43, 39],
            [2001, 10344, 38, 43],
            [2001, 10347, 30, 46],
            [2001, 10354, 30, 38],
            [2001, 10355, 51, 44],
            [2001, 10356, 37, 42],
            [2001, 10357, 51, 51],
            [2001, 10358, 45, 43],
            [2001, 10360, 30, 35],
            [2001, 10361, 46, 40],
            [2001, 10362, 50, 50],
            [2001, 10363, 82, 51],
            [2001, 10364, 86, 48],
            [2001, 10366, 52, 51],
            [2001, 10367, 81, 50],
            [2001, 10368, 85, 52],
            [2001, 10369, 81, 50],
            [2001, 10370, 86, 53],
            [2001, 10371, 39, 52],
            [2001, 10372, 30, 38],
            [2001, 10374, 30, 39],
            [2001, 10376, 30, 34],
            [2001, 10377, 32, 36],
            [2001, 10378, 49, 49],
            [2001, 10380, 43, 45],
            [2001, 10381, 66, 52],
            [2001, 10382, 43, 46],
            [2001, 10383, 85, 51],
            [2001, 10384, 50, 50],
            [2001, 10385, 86, 52],
            [2001, 10388, 23, 39],
            [2001, 10390, 31, 36],
            [2001, 10391, 44, 35],
            [2001, 10392, 44, 43],
            [2001, 10394, 30, 34],
            [2001, 10395, 39, 40],
            [2001, 10396, 31, 35],
            [2001, 10398, 31, 39],
            [2001, 10399, 45, 44],
            [2001, 10400, 31, 36],
            [2001, 10402, 30, 46],
            [2001, 10403, 47, 52],
            [2001, 10404, 32, 40],
            [2001, 10408, 30, 46],
            [2001, 10409, 45, 52],
            [2001, 10410, 34, 46],
            [2001, 10411, 52, 51],
            [2001, 10412, 62, 34],
            [2001, 10413, 88, 50],
            [2001, 10417, 46, 52],
            [2001, 10418, 30, 35],
            [2001, 10419, 50, 50],
            [2001, 10420, 51, 52],
            [2001, 10422, 44, 50],
            [2001, 10424, 47, 47],
            [2001, 10425, 30, 42],
            [2001, 10426, 45, 51],
            [2001, 10427, 38, 35],
            [2001, 10428, 38, 44],
            [2001, 10431, 31, 39],
            [2001, 10432, 46, 44],
            [2001, 10433, 30, 38],
            [2001, 10434, 46, 44],
            [2001, 10435, 51, 40],
            [2001, 10436, 37, 35],
            [2001, 10437, 50, 35],
            [2001, 10438, 31, 35],
            [2001, 10439, 45, 51],
            [2001, 10440, 30, 42],
            [2001, 10441, 50, 43],
            [2001, 10442, 38, 39],
            [2001, 10443, 30, 34],
            [2001, 10444, 51, 36],
            [2001, 10445, 53, 44],
            [2001, 10447, 30, 34],
            [2001, 10448, 40, 37],
            [2001, 10450, 30, 38],
            [2001, 10453, 83, 43],
            [2001, 10454, 80, 42],
            [2001, 10455, 83, 50],
            [2001, 10456, 30, 38],
            [2001, 10458, 30, 35],
            [2001, 10459, 38, 35],
            [2001, 10461, 30, 39],
            [2001, 10463, 23, 31],
            [2001, 10464, 32, 36],
            [2001, 10467, 30, 43],
            [2001, 10469, 37, 38],
            [2001, 10471, 36, 34],
            [2001, 10474, 21, 21],
            [2001, 10475, 21, 21],
            [2001, 10476, 22, 23],
            [2001, 10477, 23, 23],
            [2001, 10478, 31, 50],
            [2001, 10479, 46, 35],
            [2001, 10480, 30, 34],
            [2001, 10482, 30, 39],
            [2001, 10483, 35, 44],
            [2001, 10484, 30, 38],
            [2001, 10485, 35, 44],
            [2001, 10486, 30, 38],
            [2001, 10487, 35, 44],
            [2001, 10490, 17, 30],
            [2001, 10491, 10, 23],
            [2001, 10492, 8, 14],
            [2001, 10493, 36, 41],
            [2001, 10494, 11, 40],
            [2001, 10495, 13, 33],
            [2001, 10496, 10, 22],
            [2001, 10497, 29, 61],
            [2001, 10498, 10, 29],
            [2001, 10499, 10, 57],
            [2001, 10500, 13, 59],
            [2001, 10501, 13, 59],
            [2001, 10502, 34, 89],
            [2001, 10503, 13, 60],
            [2001, 10504, 15, 81],
            [2001, 10505, 35, 70],
            [2001, 10506, 17, 47],
            [2001, 10507, 10, 26],
            [2001, 10508, 27, 68],
            [2001, 10509, 29, 46],
            [2001, 10510, 16, 42],
            [2001, 10511, 8, 22],
            [2001, 10512, 30, 34],
            [2001, 10513, 39, 40],
            [2001, 10514, 19, 29],
            [2001, 10515, 21, 37],
            [2001, 10516, 19, 31],
            [2001, 10517, 30, 42],
            [2001, 10518, 24, 29],
            [2001, 10519, 28, 33],
            [2001, 10520, 13, 18],
            [2001, 10521, 23, 30],
            [2001, 10522, 22, 29],
            [2001, 10523, 22, 29],
            [2001, 10524, 22, 29],
            [2001, 10525, 22, 29],
            [2001, 10526, 22, 29],
            [2001, 10527, 21, 27],
            [2001, 10528, 30, 30],
            [2001, 10529, 22, 29],
            [2001, 10530, 22, 29],
            [2001, 10531, 22, 29],
            [2001, 10532, 24, 24],
            [2001, 10533, 38, 32],
            [2001, 10534, 17, 15],
            [2001, 10535, 34, 29],
            [2001, 10536, 18, 24],
            [2001, 10537, 26, 23],
            [2001, 10538, 33, 28],
            [2001, 10539, 19, 20],
            [2001, 10540, 37, 30],
            [2001, 10541, 46, 40],
            [2001, 10542, 56, 36],
            [2001, 10543, 7, 7],
            [2001, 10544, 13, 11],
            [2001, 10545, 7, 7],
            [2001, 10546, 8, 8],
            [2001, 10547, 8, 9],
            [2001, 10548, 13, 13],
            [2001, 10549, 9, 9],
            [2001, 10550, 16, 11],
            [2001, 10551, 9, 10],
            [2001, 10552, 8, 8],
            [2001, 10553, 22, 16],
            [2001, 10554, 23, 15],
            [2001, 10555, 14, 10],
            [2001, 10556, 24, 16],
            [2001, 10557, 19, 12],
            [2001, 10558, 36, 20],
            [2001, 10559, 22, 14],
            [2001, 10560, 22, 15],
            [2001, 10561, 12, 11],
            [2001, 10562, 9, 8],
            [2001, 10563, 7, 8],
            [2001, 10564, 5, 5],
            [2001, 10565, 9, 10],
            [2001, 10566, 16, 13],
            [2001, 10567, 16, 13],
            [2001, 10568, 11, 11],
            [2001, 10569, 16, 14],
            [2001, 10570, 23, 17],
            [2001, 10571, 30, 19],
            [2001, 10572, 13, 11],
            [2001, 10573, 12, 8],
            [2001, 10574, 17, 13],
            [2001, 10575, 16, 15],
            [2001, 10576, 15, 12],
            [2001, 10577, 21, 13],
            [2001, 10578, 51, 61],
            [2001, 10579, 73, 62],
            [2001, 10580, 92, 75],
            [2001, 10581, 120, 102],
            [2001, 10582, 88, 75],
            [2001, 10583, 78, 72],
            [2001, 10584, 105, 85],
            [2001, 10585, 77, 81],
            [2001, 10586, 114, 99],
            [2001, 10587, 100, 80],
            [2001, 10588, 52, 52],
            [2001, 10589, 94, 85],
            [2001, 10590, 116, 90],
            [2001, 10591, 103, 98],
            [2001, 10592, 92, 51],
            [2001, 10593, 67, 57],
            [2001, 10594, 96, 94],
            [2001, 10595, 47, 55],
            [2001, 10596, 61, 60],
            [2001, 10597, 78, 64],
            [2001, 10598, 76, 61],
            [2001, 10600, 18, 22],
            [2001, 10601, 18, 18],
            [2001, 10602, 36, 44],
            [2001, 10603, 50, 51],
            [2001, 10604, 62, 39],
            [2001, 10605, 22, 11],
            [2001, 10606, 18, 11],
            [2001, 10607, 28, 15],
            [2001, 10608, 15, 11],
            [2001, 10609, 15, 11],
            [2001, 10610, 25, 11],
            [2001, 10611, 25, 16],
            [2001, 10612, 23, 17],
            [2001, 10613, 63, 18],
            [2001, 10614, 50, 32],
            [2001, 10615, 59, 32],
            [2001, 10616, 50, 43],
            [2001, 10617, 69, 38],
            [2001, 10618, 70, 38],
            [2001, 10619, 50, 29],
            [2001, 10620, 35, 24],
            [2001, 10621, 50, 20],
            [2001, 10622, 45, 23],
            [2001, 10623, 50, 23],
            [2001, 10624, 50, 23],
            [2001, 10625, 41, 28],
            [2001, 10626, 70, 38],
            [2001, 10627, 60, 28],
            [2001, 10628, 66, 45],
            [2001, 10629, 66, 45],
            [2001, 10630, 38, 23],
            [2001, 10631, 60, 23],
            [2001, 10632, 45, 23],
            [2001, 10633, 67, 33],
            [2001, 10634, 67, 23],
            [2001, 10635, 67, 23],
            [2001, 10636, 50, 33],
            [2001, 10637, 50, 29],
            [2001, 10638, 28, 20],
            [2001, 10639, 70, 39],
            [2001, 10640, 63, 39],
            [2001, 10641, 63, 39],
            [2001, 10642, 63, 39],
            [2001, 10643, 50, 35],
            [2001, 10644, 63, 39],
            [2001, 10645, 45, 37],
            [2001, 10646, 63, 37],
            [2001, 10647, 63, 37],
            [2001, 10648, 50, 46],
            [2001, 10649, 55, 33],
            [2001, 10650, 63, 30],
            [2001, 10651, 63, 32],
            [2001, 10652, 50, 31],
            [2001, 10653, 69, 31],
            [2001, 10654, 47, 37],
            [2001, 10655, 65, 37],
            [2001, 10656, 63, 37],
            [2001, 10657, 50, 28],
            [2001, 10658, 60, 26],
            [2001, 10659, 25, 20],
            [2001, 10660, 70, 32],
            [2001, 10661, 108, 39],
            [2001, 10662, 65, 42],
            [2001, 10663, 55, 22],
            [2001, 10664, 70, 32],
            [2001, 10665, 65, 32],
            [2001, 10666, 70, 28],
            [2001, 10667, 65, 28],
            [2001, 10668, 60, 29],
            [2001, 10669, 25, 20],
            [2001, 10670, 63, 28],
            [2001, 10671, 62, 40],
            [2001, 10672, 70, 39],
            [2001, 10673, 45, 19],
            [2001, 10674, 50, 25],
            [2001, 10675, 50, 48],
            [2001, 10676, 50, 48],
            [2001, 10677, 45, 24],
            [2001, 10678, 55, 37],
            [2001, 10679, 85, 37],
            [2001, 10680, 30, 26],
            [2001, 10681, 60, 32],
            [2001, 10682, 50, 32],
            [2001, 10683, 49, 32],
            [2001, 10684, 33, 35],
            [2001, 10685, 120, 50],
            [2001, 10686, 60, 50],
            [2001, 10687, 50, 53],
            [2001, 10688, 85, 53],
            [2001, 10689, 85, 53],
            [2001, 10690, 85, 53],
            [2001, 10691, 85, 53],
            [2001, 10692, 95, 36],
            [2001, 10693, 120, 36],
            [2001, 10694, 90, 36],
            [2001, 10695, 70, 36],
            [2001, 10696, 70, 35],
            [2001, 10697, 45, 35],
            [2001, 10698, 50, 45],
            [2001, 10699, 60, 45],
            [2001, 10700, 25, 27],
            [2001, 10701, 108, 34],
            [2001, 10702, 108, 34],
            [2001, 10703, 108, 34],
            [2001, 10704, 68, 34],
            [2001, 10705, 80, 32],
            [2001, 10706, 70, 32],
            [2001, 10707, 55, 59],
            [2001, 10708, 63, 59],
            [2001, 10709, 63, 59],
            [2001, 10710, 108, 26],
            [2001, 10711, 65, 26],
            [2001, 10712, 70, 49],
            [2001, 10713, 70, 49],
            [2001, 10714, 60, 41],
            [2001, 10715, 108, 31],
            [2001, 10716, 68, 59],
            [2001, 10717, 70, 59],
            [2001, 10718, 60, 59],
            [2001, 10719, 85, 54],
            [2001, 10720, 95, 54],
            [2001, 10721, 35, 30],
            [2001, 10722, 90, 52],
            [2001, 10723, 70, 52],
            [2001, 10724, 70, 52],
            [2001, 10725, 60, 52],
            [2001, 10726, 48, 38],
            [2001, 10727, 65, 38],
            [2001, 10728, 65, 39],
            [2001, 10729, 65, 39],
            [2001, 10730, 70, 39],
            [2001, 10731, 50, 32],
            [2001, 10732, 70, 32],
            [2001, 10733, 70, 32],
            [2001, 10734, 70, 32],
            [2001, 10735, 70, 25],
            [2001, 10736, 70, 25],
            [2001, 10737, 120, 25],
            [2001, 10738, 70, 40],
            [2001, 10739, 35, 20],
            [2001, 10740, 63, 28],
            [2001, 10741, 50, 28],
            [2001, 10742, 62, 47],
            [2001, 10743, 55, 44],
            [2001, 10744, 50, 33],
            [2001, 10745, 63, 36],
            [2001, 10746, 63, 34],
            [2001, 10747, 36, 26],
            [2001, 10748, 60, 23],
            [2001, 10749, 63, 33],
            [2001, 10750, 63, 12],
            [2001, 10751, 63, 29],
            [2001, 10752, 63, 29],
            [2001, 10753, 70, 38],
            [2001, 10754, 60, 28],
            [2001, 10755, 23, 16],
            [2001, 10756, 120, 90],
            [2001, 10757, 24, 15],
            [2001, 10758, 35, 13],
            [2001, 10759, 80, 34],
            [2001, 10760, 80, 44],
            [2001, 10761, 63, 45],
            [2001, 10762, 63, 34],
            [2001, 10763, 50, 34],
            [2001, 10764, 35, 34],
            [2001, 10765, 45, 33],
            [2001, 10766, 65, 33],
            [2001, 10767, 70, 24],
            [2001, 10768, 60, 24],
            [2001, 10769, 63, 24],
            [2001, 10770, 70, 50],
            [2001, 10771, 70, 50],
            [2001, 10772, 45, 60],
            [2001, 10773, 63, 70],
            [2001, 10774, 50, 33],
            [2001, 10775, 63, 33],
            [2001, 10776, 50, 23],
            [2001, 10777, 40, 26],
            [2001, 10778, 120, 26],
            [2001, 10779, 50, 39],
            [2001, 10780, 60, 26],
            [2001, 10781, 55, 26],
            [2001, 10782, 50, 23],
            [2001, 10783, 75, 45],
            [2001, 10784, 70, 33],
            [2001, 10785, 70, 33],
            [2001, 10786, 49, 26],
            [2001, 10787, 60, 26],
            [2001, 10788, 67, 59],
            [2001, 10789, 55, 34],
            [2001, 10790, 70, 34],
            [2001, 10791, 70, 34],
            [2001, 10792, 35, 23],
            [2001, 10793, 64, 23],
            [2001, 10794, 69, 24],
            [2001, 10795, 69, 24],
            [2001, 10796, 70, 24],
            [2001, 10797, 63, 24],
            [2001, 10798, 40, 24],
            [2001, 10799, 28, 21],
            [2001, 10800, 63, 46],
            [2001, 10801, 63, 33],
            [2001, 10802, 50, 33],
            [2001, 10803, 45, 26],
            [2001, 10804, 86, 28],
            [2001, 10805, 85, 30],
            [2001, 10806, 50, 29],
            [2001, 10807, 63, 29],
            [2001, 10808, 40, 20],
            [2001, 10809, 36, 25],
            [2001, 10810, 50, 25],
            [2001, 10811, 50, 22],
            [2001, 10812, 100, 74],
            [2001, 10813, 62, 59],
            [2001, 10814, 50, 29],
            [2001, 10815, 63, 29],
            [2001, 10816, 70, 28],
            [2001, 10817, 63, 28],
            [2001, 10818, 70, 46],
            [2001, 10819, 70, 46],
            [2001, 10820, 70, 36],
            [2001, 10821, 63, 23],
            [2001, 10822, 63, 23],
            [2001, 10823, 55, 23],
            [2001, 10824, 50, 33],
            [2001, 10825, 50, 33],
            [2001, 10826, 56, 34],
            [2001, 10827, 50, 34],
            [2001, 10828, 40, 25],
            [2001, 10829, 65, 39],
            [2001, 10830, 63, 39],
            [2001, 10831, 67, 38],
            [2001, 10832, 64, 38],
            [2001, 10833, 63, 38],
            [2001, 10834, 63, 38],
            [2001, 10835, 64, 38],
            [2001, 10836, 60, 38],
            [2001, 10837, 70, 38],
            [2001, 10838, 63, 38],
            [2001, 10839, 50, 38],
            [2001, 10840, 35, 30],
            [2001, 10841, 110, 24],
            [2001, 10842, 45, 23],
            [2001, 10843, 63, 33],
            [2001, 10844, 45, 40],
            [2001, 10845, 40, 36],
            [2001, 10846, 50, 36],
            [2001, 10847, 45, 24],
            [2001, 10848, 63, 24],
            [2001, 10849, 63, 24],
            [2001, 10850, 55, 38],
            [2001, 10851, 45, 33],
            [2001, 10852, 50, 33],
            [2001, 10853, 70, 47],
            [2001, 10854, 65, 34],
            [2001, 10855, 70, 34],
            [2001, 10856, 70, 41],
            [2001, 10857, 70, 41],
            [2001, 10858, 60, 39],
            [2001, 10859, 70, 39],
            [2001, 10860, 95, 40],
            [2001, 10861, 85, 40],
            [2001, 10862, 60, 40],
            [2001, 10863, 33, 30],
            [2001, 10864, 90, 40],
            [2001, 10865, 63, 25],
            [2001, 10866, 45, 29],
            [2001, 10867, 65, 39],
            [2001, 10868, 65, 39],
            [2001, 10869, 70, 24],
            [2001, 10870, 70, 33],
            [2001, 10871, 70, 34],
            [2001, 10872, 70, 24],
            [2001, 10873, 84, 24],
            [2001, 10874, 70, 24],
            [2001, 10875, 70, 32],
            [2001, 10876, 84, 32],
            [2001, 10877, 100, 42],
            [2001, 10878, 70, 32],
            [2001, 10879, 70, 32],
            [2001, 10880, 70, 32],
            [2001, 10881, 50, 22],
            [2001, 10882, 90, 33],
            [2001, 10883, 108, 33],
            [2001, 10884, 120, 33],
            [2001, 10885, 50, 46],
            [2001, 10886, 70, 34],
            [2001, 10887, 50, 33],
            [2001, 10888, 95, 43],
            [2001, 10889, 65, 36],
            [2001, 10890, 50, 26],
            [2001, 10891, 35, 26],
            [2001, 10892, 45, 32],
            [2001, 10893, 70, 56],
            [2001, 10894, 70, 56],
            [2001, 10895, 108, 48],
            [2001, 10896, 70, 48],
            [2001, 10897, 70, 48],
            [2001, 10898, 70, 48],
            [2001, 10899, 60, 31],
            [2001, 10900, 50, 25],
            [2001, 10901, 60, 22],
            [2001, 10902, 60, 23],
            [2001, 10903, 63, 31],
            [2001, 10904, 63, 31],
            [2001, 10905, 50, 31],
            [2001, 10906, 69, 45],
            [2001, 10907, 69, 45],
            [2001, 10908, 63, 27],
            [2001, 10909, 108, 27],
            [2001, 10910, 63, 27],
            [2001, 10911, 90, 70],
            [2001, 10912, 90, 70],
            [2001, 10913, 55, 49],
            [2001, 10914, 120, 49],
            [2001, 10915, 70, 54],
            [2001, 10916, 85, 54],
            [2001, 10917, 90, 54],
            [2001, 10918, 45, 45],
            [2001, 10978, 63, 23],
            [2001, 10979, 63, 43],
            [2001, 10980, 60, 33],
            [2001, 11091, 10, 6],
            [2001, 11092, 15, 11],
            [2001, 11093, 13, 8],
            [2001, 11094, 22, 11],
            [2001, 11095, 10, 7],
            [2001, 11096, 25, 19],
            [2001, 11097, 13, 8],
            [2001, 11098, 11, 7],
            [2001, 11099, 50, 40],
            [2001, 11100, 10, 7],
            [2001, 11101, 14, 9],
            [2001, 11102, 13, 8],
            [2001, 11103, 20, 11],
            [2001, 11104, 70, 40],
            [2001, 11105, 40, 39],
            [2001, 11106, 34, 20],
            [2001, 11107, 25, 14],
            [2001, 11108, 11, 6],
            [2001, 11109, 25, 20],
            [2001, 11110, 25, 12],
            [2001, 11111, 8, 8],
            [2001, 11112, 37, 21],
            [2001, 11113, 32, 18],
            [2001, 11114, 50, 33],
            [2001, 11115, 9, 6],
            [2001, 11116, 10, 5],
            [2001, 11117, 11, 8],
            [2001, 11118, 21, 14],
            [2001, 11119, 50, 27],
            [2001, 11120, 37, 25],
            [2001, 11121, 12, 10],
            [2001, 11122, 14, 8],
            [2001, 11123, 19, 10],
            [2001, 11124, 11, 9],
            [2001, 11125, 37, 17],
            [2001, 11126, 18, 11],
            [2001, 11127, 8, 8],
            [2001, 11128, 16, 8],
            [2001, 11129, 8, 6],
            [2001, 11130, 17, 10],
            [2001, 11131, 9, 6],
            [2001, 11132, 22, 13],
            [2001, 11133, 14, 9],
            [2001, 11134, 8, 4],
            [2001, 11135, 70, 34],
            [2001, 11136, 13, 9],
            [2001, 11137, 8, 6],
            [2001, 11138, 22, 15],
            [2001, 11139, 15, 10],
            [2001, 11140, 14, 12],
            [2001, 11141, 12, 8],
            [2001, 11142, 12, 8],
            [2001, 11143, 10, 6],
            [2001, 11144, 11, 9],
            [2001, 11145, 30, 24],
            [2001, 11146, 8, 7],
            [2001, 11147, 5, 3],
            [2001, 11148, 40, 35],
            [2001, 11149, 15, 11],
            [2001, 11150, 26, 18],
            [2001, 11151, 16, 13],
            [2001, 11152, 15, 12],
            [2001, 11153, 15, 10],
            [2001, 11154, 30, 18],
            [2001, 11155, 18, 10],
            [2001, 11156, 12, 11],
            [2001, 11157, 12, 10],
            [2001, 11158, 14, 11],
            [2001, 11159, 13, 12],
            [2001, 11160, 14, 10],
            [2001, 11161, 14, 11],
            [2001, 11162, 13, 12],
            [2001, 11163, 14, 14],
            [2001, 11164, 19, 18],
            [2001, 11165, 14, 10],
            [2001, 11166, 60, 39],
            [2001, 11167, 104, 55],
            [2001, 11168, 26, 19],
            [2001, 11169, 12, 11],
            [2001, 11170, 16, 13],
            [2001, 11171, 16, 13],
            [2001, 11172, 11, 11],
            [2001, 11173, 16, 14],
            [2001, 11174, 9, 8],
            [2001, 11175, 7, 8],
            [2001, 11176, 5, 5],
            [2001, 11177, 23, 17],
            [2001, 11178, 9, 10],
            [2001, 11179, 13, 11],
            [2001, 11180, 12, 8],
            [2001, 11181, 17, 13],
            [2001, 11182, 16, 15],
            [2001, 11183, 15, 12],
            [2002, 2, 46, 39],
            [2002, 7, 30, 30],
            [2002, 25, 13, 10],
            [2002, 42, 20, 21],
            [2002, 48, 79, 61],
            [2002, 49, 35, 24],
            [2002, 51, 30, 30],
            [2002, 62, 21, 30],
            [2002, 65, 24, 21],
            [2002, 78, 20, 20],
            [2002, 82, 12, 20],
            [2002, 83, 38, 43],
            [2002, 87, 35, 30],
            [2002, 99, 30, 29],
            [2002, 101, 61, 51],
            [2002, 119, 40, 29],
            [2002, 122, 32, 20],
            [2002, 125, 31, 32],
            [2002, 135, 20, 20],
            [2002, 138, 31, 30],
            [2002, 163, 27, 25],
            [2002, 166, 36, 35],
            [2002, 169, 25, 20],
            [2002, 186, 16, 20],
            [2002, 190, 30, 29],
            [2002, 194, 23, 24],
            [2002, 200, 40, 30],
            [2002, 204, 12, 21],
            [2002, 211, 21, 48],
            [2002, 215, 29, 30],
            [2002, 216, 23, 20],
            [2002, 218, 57, 25],
            [2002, 220, 18, 19],
            [2002, 226, 16, 17],
            [2002, 230, 45, 42],
            [2002, 231, 54, 48],
            [2002, 233, 18, 19],
            [2002, 234, 12, 16],
            [2002, 239, 20, 20],
            [2002, 240, 20, 18],
            [2002, 242, 32, 19],
            [2002, 243, 30, 30],
            [2002, 246, 51, 32],
            [2002, 248, 21, 20],
            [2002, 270, 30, 29],
            [2002, 272, 49, 17],
            [2002, 282, 43, 22],
            [2002, 285, 20, 20],
            [2002, 286, 20, 12],
            [2002, 299, 19, 20],
            [2002, 305, 20, 20],
            [2002, 306, 30, 30],
            [2002, 308, 12, 43],
            [2002, 310, 20, 20],
            [2002, 312, 20, 20],
            [2002, 314, 18, 27],
            [2002, 317, 30, 30],
            [2002, 320, 23, 27],
            [2002, 324, 46, 39],
            [2002, 327, 45, 40],
            [2002, 329, 39, 31],
            [2002, 330, 30, 30],
            [2002, 332, 30, 30],
            [2002, 334, 34, 30],
            [2002, 337, 25, 18],
            [2002, 339, 22, 20],
            [2002, 344, 30, 20],
            [2002, 346, 43, 36],
            [2002, 355, 49, 32],
            [2002, 361, 30, 30],
            [2002, 365, 44, 32],
            [2002, 378, 20, 24],
            [2002, 379, 15, 13],
            [2002, 389, 18, 24],
            [2002, 392, 19, 20],
            [2002, 399, 75, 38],
            [2002, 402, 34, 30],
            [2002, 403, 29, 30],
            [2002, 418, 22, 20],
            [2002, 424, 20, 20],
            [2002, 425, 16, 25],
            [2002, 428, 28, 20],
            [2002, 430, 21, 27],
            [2002, 432, 35, 30],
            [2002, 436, 27, 22],
            [2002, 455, 26, 24],
            [2002, 471, 19, 20],
            [2002, 479, 33, 33],
            [2002, 480, 61, 26],
            [2002, 487, 32, 29],
            [2002, 493, 30, 30],
            [2002, 494, 16, 18],
            [2002, 497, 10, 15],
            [2002, 503, 64, 23],
            [2002, 504, 14, 12],
            [2002, 505, 28, 30],
            [2002, 519, 18, 27],
            [2002, 525, 20, 31],
            [2002, 536, 20, 20],
            [2002, 541, 76, 41],
            [2002, 545, 21, 25],
            [2002, 568, 20, 20],
            [2002, 569, 52, 30],
            [2002, 570, 26, 21],
            [2002, 573, 30, 30],
            [2002, 577, 29, 24],
            [2002, 579, 47, 43],
            [2002, 585, 59, 55],
            [2002, 590, 35, 39],
            [2002, 593, 43, 39],
            [2002, 595, 31, 30],
            [2002, 597, 23, 10],
            [2002, 599, 16, 22],
            [2002, 604, 53, 32],
            [2002, 608, 28, 20],
            [2002, 612, 43, 42],
            [2002, 618, 26, 21],
            [2002, 625, 24, 18],
            [2002, 627, 33, 31],
            [2002, 628, 30, 30],
            [2002, 631, 20, 20],
            [2002, 654, 15, 12],
            [2002, 660, 32, 32],
            [2002, 662, 69, 47],
            [2002, 663, 51, 34],
            [2002, 669, 31, 23],
            [2002, 678, 20, 26],
            [2002, 686, 15, 23],
            [2002, 691, 23, 20],
            [2002, 694, 40, 33],
            [2002, 695, 72, 53],
            [2002, 700, 58, 43],
            [2002, 703, 12, 17],
            [2002, 704, 26, 30],
            [2002, 716, 61, 58],
            [2002, 717, 37, 30],
            [2002, 719, 31, 28],
            [2002, 720, 24, 20],
            [2002, 724, 29, 29],
            [2002, 727, 48, 48],
            [2002, 734, 21, 32],
            [2002, 737, 14, 12],
            [2002, 750, 20, 20],
            [2002, 751, 32, 18],
            [2002, 754, 30, 30],
            [2002, 766, 66, 30],
            [2002, 769, 37, 44],
            [2002, 773, 29, 30],
            [2002, 781, 27, 22],
            [2002, 783, 21, 26],
            [2002, 785, 55, 54],
            [2002, 790, 43, 30],
            [2002, 801, 20, 20],
            [2002, 803, 36, 33],
            [2002, 805, 37, 27],
            [2002, 811, 27, 23],
            [2002, 815, 16, 16],
            [2002, 820, 40, 44],
            [2002, 821, 20, 20],
            [2002, 822, 17, 21],
            [2002, 826, 20, 20],
            [2002, 827, 10, 14],
            [2002, 835, 30, 30],
            [2002, 843, 30, 30],
            [2002, 844, 28, 23],
            [2002, 845, 58, 30],
            [2002, 848, 25, 20],
            [2002, 865, 50, 33],
            [2002, 871, 41, 23],
            [2002, 878, 7, 6],
            [2002, 882, 45, 34],
            [2002, 890, 20, 20],
            [2002, 894, 28, 12],
            [2002, 909, 64, 40],
            [2002, 913, 20, 18],
            [2002, 915, 56, 37],
            [2002, 922, 47, 34],
            [2002, 926, 62, 22],
            [2002, 938, 12, 13],
            [2002, 940, 12, 14],
            [2002, 941, 39, 35],
            [2002, 944, 23, 20],
            [2002, 949, 67, 34],
            [2002, 950, 16, 20],
            [2002, 964, 12, 16],
            [2002, 969, 41, 38],
            [2002, 971, 21, 17],
            [2002, 972, 38, 25],
            [2002, 978, 49, 38],
            [2002, 979, 20, 20],
            [2002, 985, 77, 41],
            [2002, 990, 23, 20],
            [2002, 993, 60, 39],
            [2002, 998, 37, 21],
            [2002, 1003, 8, 6],
            [2002, 1008, 23, 24],
            [2002, 1016, 11, 15],
            [2002, 1030, 9, 14],
            [2002, 1033, 20, 20],
            [2002, 1042, 96, 47],
            [2002, 1048, 40, 38],
            [2002, 1051, 25, 20],
            [2002, 1056, 21, 43],
            [2002, 1059, 45, 47],
            [2002, 1073, 50, 33],
            [2002, 1082, 53, 45],
            [2002, 1094, 20, 20],
            [2002, 1095, 20, 20],
            [2002, 1097, 33, 19],
            [2002, 1100, 22, 22],
            [2002, 1102, 15, 17],
            [2002, 1106, 90, 33],
            [2002, 1109, 28, 30],
            [2002, 1111, 38, 48],
            [2002, 1131, 33, 30],
            [2002, 1132, 12, 15],
            [2002, 1136, 44, 47],
            [2002, 1140, 29, 25],
            [2002, 1141, 29, 30],
            [2002, 1142, 25, 25],
            [2002, 1144, 30, 22],
            [2002, 1145, 30, 24],
            [2002, 1150, 36, 27],
            [2002, 1155, 30, 30],
            [2002, 1156, 28, 19],
            [2002, 1157, 37, 25],
            [2002, 1159, 50, 43],
            [2002, 1167, 20, 20],
            [2002, 1169, 20, 20],
            [2002, 1174, 30, 44],
            [2002, 1175, 20, 20],
            [2002, 1177, 36, 30],
            [2002, 1186, 15, 20],
            [2002, 1194, 98, 45],
            [2002, 1200, 20, 20],
            [2002, 1203, 11, 18],
            [2002, 1205, 20, 20],
            [2002, 1213, 23, 21],
            [2002, 1217, 30, 30],
            [2002, 1219, 20, 20],
            [2002, 1221, 21, 19],
            [2002, 1224, 30, 30],
            [2002, 1226, 21, 15],
            [2002, 1228, 19, 20],
            [2002, 1234, 12, 15],
            [2002, 1235, 27, 23],
            [2002, 1238, 14, 27],
            [2002, 1247, 57, 33],
            [2002, 1254, 54, 28],
            [2002, 1262, 29, 30],
            [2002, 1268, 43, 31],
            [2002, 1275, 22, 14],
            [2002, 1281, 15, 21],
            [2002, 1295, 45, 53],
            [2002, 1302, 54, 63],
            [2002, 1303, 83, 41],
            [2002, 1305, 18, 20],
            [2002, 1319, 51, 26],
            [2002, 1320, 43, 40],
            [2002, 1323, 22, 20],
            [2002, 1334, 20, 20],
            [2002, 1358, 51, 28],
            [2002, 1359, 29, 30],
            [2002, 1361, 30, 30],
            [2002, 1363, 31, 30],
            [2002, 1367, 37, 41],
            [2002, 1370, 14, 22],
            [2002, 1375, 20, 20],
            [2002, 1376, 26, 24],
            [2002, 1396, 11, 20],
            [2002, 1420, 52, 48],
            [2002, 1445, 65, 18],
            [2002, 1454, 24, 29],
            [2002, 1456, 29, 29],
            [2002, 1465, 17, 20],
            [2002, 1466, 36, 24],
            [2002, 1471, 30, 30],
            [2002, 1473, 15, 22],
            [2002, 1475, 32, 30],
            [2002, 1476, 29, 30],
            [2002, 1477, 20, 20],
            [2002, 1481, 45, 29],
            [2002, 1482, 13, 17],
            [2002, 1484, 30, 30],
            [2002, 1486, 14, 13],
            [2002, 1490, 22, 20],
            [2002, 1491, 11, 9],
            [2002, 1493, 28, 21],
            [2002, 1507, 37, 25],
            [2002, 1508, 30, 30],
            [2002, 1510, 16, 20],
            [2002, 1511, 30, 30],
            [2002, 1515, 24, 19],
            [2002, 1522, 14, 20],
            [2002, 1525, 44, 43],
            [2002, 1527, 28, 30],
            [2002, 1530, 57, 52],
            [2002, 1536, 17, 18],
            [2002, 1537, 31, 28],
            [2002, 1548, 29, 31],
            [2002, 1553, 29, 30],
            [2002, 1555, 49, 41],
            [2002, 1556, 30, 30],
            [2002, 1557, 34, 30],
            [2002, 1561, 19, 20],
            [2002, 1562, 29, 30],
            [2002, 1568, 32, 30],
            [2002, 1575, 87, 60],
            [2002, 1577, 28, 21],
            [2002, 1580, 45, 38],
            [2002, 1582, 26, 26],
            [2002, 1587, 17, 19],
            [2002, 1589, 44, 20],
            [2002, 1598, 15, 9],
            [2002, 1610, 30, 30],
            [2002, 1628, 36, 22],
            [2002, 1635, 18, 17],
            [2002, 1638, 29, 44],
            [2002, 1644, 36, 30],
            [2002, 1645, 45, 29],
            [2002, 1659, 26, 23],
            [2002, 1660, 29, 30],
            [2002, 1662, 15, 12],
            [2002, 1663, 29, 30],
            [2002, 1664, 17, 16],
            [2002, 1672, 20, 20],
            [2002, 1673, 62, 42],
            [2002, 1680, 30, 30],
            [2002, 1685, 44, 40],
            [2002, 1704, 17, 21],
            [2002, 1717, 57, 28],
            [2002, 1724, 20, 20],
            [2002, 1730, 17, 12],
            [2002, 1744, 30, 29],
            [2002, 1748, 29, 30],
            [2002, 1756, 29, 30],
            [2002, 1760, 13, 16],
            [2002, 1763, 24, 23],
            [2002, 1769, 57, 48],
            [2002, 1771, 20, 20],
            [2002, 1772, 11, 15],
            [2002, 1774, 26, 28],
            [2002, 1780, 19, 20],
            [2002, 1781, 20, 20],
            [2002, 1786, 20, 26],
            [2002, 1790, 20, 20],
            [2002, 1792, 30, 30],
            [2002, 1794, 34, 37],
            [2002, 1795, 13, 10],
            [2002, 1797, 61, 42],
            [2002, 1798, 41, 53],
            [2002, 1804, 19, 20],
            [2002, 1812, 14, 18],
            [2002, 1816, 97, 26],
            [2002, 1818, 20, 20],
            [2002, 1824, 36, 42],
            [2002, 1825, 20, 28],
            [2002, 1829, 19, 27],
            [2002, 1841, 45, 44],
            [2002, 1845, 30, 30],
            [2002, 1848, 30, 30],
            [2002, 1853, 60, 26],
            [2002, 1864, 69, 63],
            [2002, 1866, 62, 34],
            [2002, 1869, 34, 40],
            [2002, 1876, 29, 30],
            [2002, 1879, 23, 20],
            [2002, 1882, 18, 20],
            [2002, 1891, 28, 41],
            [2002, 1894, 36, 16],
            [2002, 1901, 20, 20],
            [2002, 1903, 89, 35],
            [2002, 1915, 46, 37],
            [2002, 1916, 20, 18],
            [2002, 1917, 29, 30],
            [2002, 1921, 20, 18],
            [2002, 1925, 30, 30],
            [2002, 1930, 11, 9],
            [2002, 1933, 11, 15],
            [2002, 1945, 28, 29],
            [2002, 1948, 24, 33],
            [2002, 1950, 21, 35],
            [2002, 1952, 106, 70],
            [2002, 1962, 13, 17],
            [2002, 1965, 60, 47],
            [2002, 1995, 30, 30],
            [2002, 2000, 30, 30],
            [2002, 2001, 37, 27],
            [2002, 2006, 23, 21],
            [2002, 2011, 12, 17],
            [2002, 2017, 41, 41],
            [2002, 2021, 30, 29],
            [2002, 2023, 12, 12],
            [2002, 2025, 30, 30],
            [2002, 2026, 43, 31],
            [2002, 2028, 42, 24],
            [2002, 2029, 29, 30],
            [2002, 2032, 17, 19],
            [2002, 2035, 62, 34],
            [2002, 2042, 19, 20],
            [2002, 2048, 14, 31],
            [2002, 2056, 34, 40],
            [2002, 2057, 89, 40],
            [2002, 2064, 53, 35],
            [2002, 2081, 19, 20],
            [2002, 2084, 56, 31],
            [2002, 2098, 14, 17],
            [2002, 2099, 24, 20],
            [2002, 2101, 10, 13],
            [2002, 2104, 31, 30],
            [2002, 2121, 18, 17],
            [2002, 2127, 17, 12],
            [2002, 2128, 30, 30],
            [2002, 2131, 28, 39],
            [2002, 2138, 27, 26],
            [2002, 2142, 10, 11],
            [2002, 2144, 22, 65],
            [2002, 2162, 20, 37],
            [2002, 2163, 36, 18],
            [2002, 2170, 25, 20],
            [2002, 2171, 28, 26],
            [2002, 2174, 28, 21],
            [2002, 2178, 13, 19],
            [2002, 2180, 29, 30],
            [2002, 2181, 30, 29],
            [2002, 2182, 29, 30],
            [2002, 2190, 28, 23],
            [2002, 2198, 24, 18],
            [2002, 2201, 30, 30],
            [2002, 2208, 48, 34],
            [2002, 2213, 45, 38],
            [2002, 2216, 24, 30],
            [2002, 2220, 19, 20],
            [2002, 2224, 30, 32],
            [2002, 2227, 18, 18],
            [2002, 2232, 30, 30],
            [2002, 2236, 19, 20],
            [2002, 2238, 30, 30],
            [2002, 2239, 22, 20],
            [2002, 2244, 25, 27],
            [2002, 2250, 45, 30],
            [2002, 2255, 29, 29],
            [2002, 2258, 29, 30],
            [2002, 2277, 29, 26],
            [2002, 2280, 9, 7],
            [2002, 2282, 20, 60],
            [2002, 2293, 30, 30],
            [2002, 2300, 43, 49],
            [2002, 2303, 20, 20],
            [2002, 2311, 39, 38],
            [2002, 2312, 20, 20],
            [2002, 2316, 55, 33],
            [2002, 2332, 15, 16],
            [2002, 2335, 30, 30],
            [2002, 2343, 27, 18],
            [2002, 2352, 44, 38],
            [2002, 2366, 16, 17],
            [2002, 2367, 33, 30],
            [2002, 2371, 57, 32],
            [2002, 2383, 33, 20],
            [2002, 2384, 27, 37],
            [2002, 2404, 29, 29],
            [2002, 2405, 30, 32],
            [2002, 2428, 33, 20],
            [2002, 2429, 12, 12],
            [2002, 2433, 55, 23],
            [2002, 2435, 18, 14],
            [2002, 2443, 57, 34],
            [2002, 2447, 19, 20],
            [2002, 2458, 16, 14],
            [2002, 2459, 13, 17],
            [2002, 2467, 12, 16],
            [2002, 2472, 32, 22],
            [2002, 2483, 61, 44],
            [2002, 2485, 14, 13],
            [2002, 2488, 25, 25],
            [2002, 2493, 23, 20],
            [2002, 2494, 28, 30],
            [2002, 2497, 20, 20],
            [2002, 2500, 26, 18],
            [2002, 2501, 62, 27],
            [2002, 2505, 45, 30],
            [2002, 2509, 15, 18],
            [2002, 2514, 30, 30],
            [2002, 2516, 30, 30],
            [2002, 2518, 30, 30],
            [2002, 2524, 11, 11],
            [2002, 2527, 24, 20],
            [2002, 2533, 11, 18],
            [2002, 2539, 55, 27],
            [2002, 2540, 20, 22],
            [2002, 2543, 21, 21],
            [2002, 2547, 16, 15],
            [2002, 2551, 38, 30],
            [2002, 2554, 12, 12],
            [2002, 2555, 35, 23],
            [2002, 2562, 34, 30],
            [2002, 2564, 20, 20],
            [2002, 2574, 29, 30],
            [2002, 2576, 56, 29],
            [2002, 2585, 54, 44],
            [2002, 2587, 29, 29],
            [2002, 2593, 28, 30],
            [2002, 2595, 42, 36],
            [2002, 2603, 77, 39],
            [2002, 2604, 30, 30],
            [2002, 2606, 20, 15],
            [2002, 2607, 11, 10],
            [2002, 2612, 30, 30],
            [2002, 2615, 33, 30],
            [2002, 2617, 41, 24],
            [2002, 2619, 12, 13],
            [2002, 2622, 27, 20],
            [2002, 2627, 60, 34],
            [2002, 2628, 20, 20],
            [2002, 2632, 30, 18],
            [2002, 2633, 30, 30],
            [2002, 2635, 13, 20],
            [2002, 2644, 26, 20],
            [2002, 2647, 32, 27],
            [2002, 2650, 22, 20],
            [2002, 2656, 20, 20],
            [2002, 2658, 29, 30],
            [2002, 2667, 29, 30],
            [2002, 2668, 30, 30],
            [2002, 2669, 48, 43],
            [2002, 2670, 45, 30],
            [2002, 2671, 48, 54],
            [2002, 2687, 24, 17],
            [2002, 2692, 58, 26],
            [2002, 2695, 12, 13],
            [2002, 2720, 35, 38],
            [2002, 2723, 41, 63],
            [2002, 2743, 30, 30],
            [2002, 2747, 29, 30],
            [2002, 2748, 30, 30],
            [2002, 2758, 33, 29],
            [2002, 2762, 76, 44],
            [2002, 2775, 57, 34],
            [2002, 2785, 13, 15],
            [2002, 2788, 30, 30],
            [2002, 2791, 39, 26],
            [2002, 2797, 14, 15],
            [2002, 2798, 12, 20],
            [2002, 2813, 29, 30],
            [2002, 2822, 28, 23],
            [2002, 2823, 20, 20],
            [2002, 2827, 13, 18],
            [2002, 2832, 16, 16],
            [2002, 2833, 49, 32],
            [2002, 2835, 33, 31],
            [2002, 2836, 30, 17],
            [2002, 2838, 41, 34],
            [2002, 2846, 25, 26],
            [2002, 2851, 20, 17],
            [2002, 2854, 34, 34],
            [2002, 2856, 34, 30],
            [2002, 2867, 20, 20],
            [2002, 2872, 18, 20],
            [2002, 2876, 30, 30],
            [2002, 2879, 24, 24],
            [2002, 2880, 35, 28],
            [2002, 2883, 32, 30],
            [2002, 2884, 23, 38],
            [2002, 2897, 90, 51],
            [2002, 2901, 66, 54],
            [2002, 2904, 47, 32],
            [2002, 2910, 20, 20],
            [2002, 2914, 45, 30],
            [2002, 2918, 50, 36],
            [2002, 2922, 15, 16],
            [2002, 2923, 29, 29],
            [2002, 2929, 30, 30],
            [2002, 2932, 32, 32],
            [2002, 2934, 21, 20],
            [2002, 2935, 66, 31],
            [2002, 2936, 23, 20],
            [2002, 2946, 29, 20],
            [2002, 2950, 30, 30],
            [2002, 2969, 21, 18],
            [2002, 2973, 38, 48],
            [2002, 2974, 40, 22],
            [2002, 2978, 29, 30],
            [2002, 2979, 24, 16],
            [2002, 2991, 40, 43],
            [2002, 2995, 20, 20],
            [2002, 3009, 37, 41],
            [2002, 3011, 30, 30],
            [2002, 3016, 30, 30],
            [2002, 3019, 42, 22],
            [2002, 3027, 19, 20],
            [2002, 3033, 75, 45],
            [2002, 3035, 20, 20],
            [2002, 3041, 34, 26],
            [2002, 3046, 30, 14],
            [2002, 3048, 44, 23],
            [2002, 3050, 31, 21],
            [2002, 3053, 68, 61],
            [2002, 3061, 30, 30],
            [2002, 3066, 57, 30],
            [2002, 3070, 33, 35],
            [2002, 3077, 34, 20],
            [2002, 3086, 67, 25],
            [2002, 3091, 10, 15],
            [2002, 3092, 45, 24],
            [2002, 3098, 20, 20],
            [2002, 3106, 19, 21],
            [2002, 3112, 56, 30],
            [2002, 3114, 33, 30],
            [2002, 3119, 11, 27],
            [2002, 3121, 20, 20],
            [2002, 3122, 30, 30],
            [2002, 3126, 45, 21],
            [2002, 3129, 35, 43],
            [2002, 3133, 25, 20],
            [2002, 3134, 46, 39],
            [2002, 3137, 30, 30],
            [2002, 3142, 34, 41],
            [2002, 3148, 33, 29],
            [2002, 3154, 31, 30],
            [2002, 3155, 26, 21],
            [2002, 3158, 16, 18],
            [2002, 3160, 19, 20],
            [2002, 3161, 20, 20],
            [2002, 3164, 54, 35],
            [2002, 3167, 21, 29],
            [2002, 3171, 37, 20],
            [2002, 3175, 35, 26],
            [2002, 3182, 19, 22],
            [2002, 3188, 39, 36],
            [2002, 3189, 35, 30],
            [2002, 3195, 20, 20],
            [2002, 3206, 30, 30],
            [2002, 3217, 30, 30],
            [2002, 3221, 45, 22],
            [2002, 3228, 29, 30],
            [2002, 3231, 20, 20],
            [2002, 3234, 53, 25],
            [2002, 3246, 57, 33],
            [2002, 3248, 19, 22],
            [2002, 3251, 36, 43],
            [2002, 3252, 40, 26],
            [2002, 3254, 25, 18],
            [2002, 3256, 21, 22],
            [2002, 3264, 29, 30],
            [2002, 3268, 30, 30],
            [2002, 3272, 24, 21],
            [2002, 3273, 77, 19],
            [2002, 3274, 28, 24],
            [2002, 3277, 31, 22],
            [2002, 3280, 29, 30],
            [2002, 3283, 25, 21],
            [2002, 3284, 20, 20],
            [2002, 3289, 61, 50],
            [2002, 3301, 42, 40],
            [2002, 3306, 22, 26],
            [2002, 3308, 62, 38],
            [2002, 3309, 42, 38],
            [2002, 3320, 54, 58],
            [2002, 3321, 45, 25],
            [2002, 3326, 20, 20],
            [2002, 3327, 50, 51],
            [2002, 3331, 20, 20],
            [2002, 3336, 24, 20],
            [2002, 3344, 20, 19],
            [2002, 3346, 20, 32],
            [2002, 3348, 57, 30],
            [2002, 3357, 12, 18],
            [2002, 3358, 15, 18],
            [2002, 3363, 65, 30],
            [2002, 3364, 11, 17],
            [2002, 3372, 53, 31],
            [2002, 3382, 37, 24],
            [2002, 3404, 38, 30],
            [2002, 3407, 19, 20],
            [2002, 3418, 74, 37],
            [2002, 3422, 24, 18],
            [2002, 3429, 29, 29],
            [2002, 3434, 7, 6],
            [2002, 3438, 54, 29],
            [2002, 3439, 20, 20],
            [2002, 3441, 29, 30],
            [2002, 3442, 20, 20],
            [2002, 3451, 47, 49],
            [2002, 3453, 20, 20],
            [2002, 3454, 12, 10],
            [2002, 3457, 30, 30],
            [2002, 3459, 26, 22],
            [2002, 3462, 53, 24],
            [2002, 3468, 21, 20],
            [2002, 3469, 30, 18],
            [2002, 3476, 30, 38],
            [2002, 3494, 12, 15],
            [2002, 3498, 20, 26],
            [2002, 3503, 78, 51],
            [2002, 3511, 19, 32],
            [2002, 3515, 15, 58],
            [2002, 3517, 55, 22],
            [2002, 3531, 27, 20],
            [2002, 3541, 22, 27],
            [2002, 3557, 10, 15],
            [2002, 3559, 45, 40],
            [2002, 3566, 14, 12],
            [2002, 3569, 65, 65],
            [2002, 3572, 28, 28],
            [2002, 3579, 20, 31],
            [2002, 3590, 29, 32],
            [2002, 3593, 46, 20],
            [2002, 3598, 17, 13],
            [2002, 3602, 20, 20],
            [2002, 3608, 27, 29],
            [2002, 3632, 30, 30],
            [2002, 3639, 20, 20],
            [2002, 3642, 33, 29],
            [2002, 3644, 29, 29],
            [2002, 3650, 39, 30],
            [2002, 3653, 20, 20],
            [2002, 3656, 29, 30],
            [2002, 3659, 20, 16],
            [2002, 3661, 30, 30],
            [2002, 3667, 19, 20],
            [2002, 3669, 11, 20],
            [2002, 3670, 39, 30],
            [2002, 3679, 19, 20],
            [2002, 3700, 23, 26],
            [2002, 3703, 28, 30],
            [2002, 3718, 53, 28],
            [2002, 3726, 11, 13],
            [2002, 3729, 100, 30],
            [2002, 3731, 28, 23],
            [2002, 3747, 28, 23],
            [2002, 3751, 23, 20],
            [2002, 3755, 29, 30],
            [2002, 3761, 21, 21],
            [2002, 3765, 25, 18],
            [2002, 3777, 29, 22],
            [2002, 3782, 69, 31],
            [2002, 3786, 13, 12],
            [2002, 3795, 29, 30],
            [2002, 3796, 30, 30],
            [2002, 3802, 47, 50],
            [2002, 3807, 20, 20],
            [2002, 3827, 30, 30],
            [2002, 3828, 20, 22],
            [2002, 3832, 28, 28],
            [2002, 3833, 25, 13],
            [2002, 3834, 29, 35],
            [2002, 3841, 27, 30],
            [2002, 3845, 30, 30],
            [2002, 3854, 19, 20],
            [2002, 3855, 20, 20],
            [2002, 3859, 12, 16],
            [2002, 3870, 32, 30],
            [2002, 3874, 29, 30],
            [2002, 3883, 20, 20],
            [2002, 3884, 58, 34],
            [2002, 3889, 79, 30],
            [2002, 3897, 28, 29],
            [2002, 3905, 29, 29],
            [2002, 3915, 29, 30],
            [2002, 3921, 30, 30],
            [2002, 3925, 65, 48],
            [2002, 3932, 25, 31],
            [2002, 3942, 19, 30],
            [2002, 3943, 17, 27],
            [2002, 3947, 48, 39],
            [2002, 3953, 30, 30],
            [2002, 3956, 44, 53],
            [2002, 3959, 20, 20],
            [2002, 3960, 39, 30],
            [2002, 3963, 25, 15],
            [2002, 3969, 85, 45],
            [2002, 3970, 30, 30],
            [2002, 3972, 82, 62],
            [2002, 3976, 17, 15],
            [2002, 3985, 30, 24],
            [2002, 3988, 24, 30],
            [2002, 3992, 30, 30],
            [2002, 3993, 11, 13],
            [2002, 3999, 29, 30],
            [2002, 4015, 58, 31],
            [2002, 4022, 44, 28],
            [2002, 4023, 29, 30],
            [2002, 4026, 36, 19],
            [2002, 4027, 83, 38],
            [2002, 4028, 32, 40],
            [2002, 4031, 17, 15],
            [2002, 4034, 83, 47],
            [2002, 4035, 20, 20],
            [2002, 4038, 95, 40],
            [2002, 4040, 29, 30],
            [2002, 4043, 18, 18],
            [2002, 4047, 29, 34],
            [2002, 4074, 22, 32],
            [2002, 4082, 83, 39],
            [2002, 4084, 12, 18],
            [2002, 4091, 39, 16],
            [2002, 4095, 30, 30],
            [2002, 4096, 30, 30],
            [2002, 4106, 28, 30],
            [2002, 4107, 72, 31],
            [2002, 4109, 18, 19],
            [2002, 4111, 20, 14],
            [2002, 4116, 28, 30],
            [2002, 4118, 30, 30],
            [2002, 4120, 30, 30],
            [2002, 4122, 63, 57],
            [2002, 4124, 30, 30],
            [2002, 4125, 13, 17],
            [2002, 4134, 34, 30],
            [2002, 4152, 108, 50],
            [2002, 4156, 20, 21],
            [2002, 4164, 20, 20],
            [2002, 4165, 40, 39],
            [2002, 4169, 28, 22],
            [2002, 4173, 12, 18],
            [2002, 4176, 11, 15],
            [2002, 4177, 51, 35],
            [2002, 4182, 28, 30],
            [2002, 4185, 19, 20],
            [2002, 4188, 91, 26],
            [2002, 4189, 19, 30],
            [2002, 4199, 46, 30],
            [2002, 4203, 29, 30],
            [2002, 4206, 15, 19],
            [2002, 4209, 21, 19],
            [2002, 4229, 27, 21],
            [2002, 4242, 20, 20],
            [2002, 4246, 11, 14],
            [2002, 4250, 71, 26],
            [2002, 4272, 30, 30],
            [2002, 4279, 25, 30],
            [2002, 4283, 19, 18],
            [2002, 4285, 32, 29],
            [2002, 4298, 44, 52],
            [2002, 4299, 20, 35],
            [2002, 4301, 59, 32],
            [2002, 4310, 33, 26],
            [2002, 4312, 54, 32],
            [2002, 4318, 19, 20],
            [2002, 4320, 31, 31],
            [2002, 4325, 54, 30],
            [2002, 4326, 10, 14],
            [2002, 4329, 21, 30],
            [2002, 4333, 17, 21],
            [2002, 4338, 30, 30],
            [2002, 4345, 19, 21],
            [2002, 4349, 30, 29],
            [2002, 4350, 20, 20],
            [2002, 4352, 20, 20],
            [2002, 4353, 27, 26],
            [2002, 4358, 12, 16],
            [2002, 4362, 48, 31],
            [2002, 4364, 20, 20],
            [2002, 4380, 17, 13],
            [2002, 4382, 55, 47],
            [2002, 4384, 32, 20],
            [2002, 4386, 15, 17],
            [2002, 4391, 20, 20],
            [2002, 4406, 42, 30],
            [2002, 4413, 12, 12],
            [2002, 4414, 15, 24],
            [2002, 4415, 88, 28],
            [2002, 4421, 30, 30],
            [2002, 4426, 11, 15],
            [2002, 4438, 55, 27],
            [2002, 4440, 45, 33],
            [2002, 4441, 17, 13],
            [2002, 4442, 15, 20],
            [2002, 4446, 29, 30],
            [2002, 4454, 22, 20],
            [2002, 4461, 38, 28],
            [2002, 4464, 56, 28],
            [2002, 4470, 31, 34],
            [2002, 4471, 20, 20],
            [2002, 4477, 31, 35],
            [2002, 4487, 30, 39],
            [2002, 4491, 49, 34],
            [2002, 4494, 19, 20],
            [2002, 4495, 27, 21],
            [2002, 4500, 27, 20],
            [2002, 4504, 61, 38],
            [2002, 4506, 19, 20],
            [2002, 4508, 33, 28],
            [2002, 4510, 26, 22],
            [2002, 4515, 30, 29],
            [2002, 4518, 36, 28],
            [2002, 4521, 29, 30],
            [2002, 4524, 30, 30],
            [2002, 4532, 23, 20],
            [2002, 4536, 22, 20],
            [2002, 4542, 41, 26],
            [2002, 4545, 50, 37],
            [2002, 4550, 29, 30],
            [2002, 4552, 15, 18],
            [2002, 4558, 29, 27],
            [2002, 4563, 29, 30],
            [2002, 4572, 29, 20],
            [2002, 4587, 32, 25],
            [2002, 4591, 21, 20],
            [2002, 4602, 23, 29],
            [2002, 4606, 19, 20],
            [2002, 4608, 21, 23],
            [2002, 4610, 57, 28],
            [2002, 4611, 20, 20],
            [2002, 4613, 45, 38],
            [2002, 4616, 22, 18],
            [2002, 4617, 86, 39],
            [2002, 4618, 26, 25],
            [2002, 4623, 15, 19],
            [2002, 4626, 35, 23],
            [2002, 4633, 20, 20],
            [2002, 4634, 31, 30],
            [2002, 4635, 72, 13],
            [2002, 4638, 67, 39],
            [2002, 4643, 22, 18],
            [2002, 4644, 14, 18],
            [2002, 4648, 31, 11],
            [2002, 4660, 61, 29],
            [2002, 4668, 29, 29],
            [2002, 4670, 61, 25],
            [2002, 4676, 13, 20],
            [2002, 4684, 22, 20],
            [2002, 4689, 45, 32],
            [2002, 4693, 31, 30],
            [2002, 4694, 22, 22],
            [2002, 4703, 10, 15],
            [2002, 4710, 9, 7],
            [2002, 4711, 17, 15],
            [2002, 4712, 24, 18],
            [2002, 4717, 20, 20],
            [2002, 4724, 31, 20],
            [2002, 4728, 25, 22],
            [2002, 4729, 37, 30],
            [2002, 4732, 77, 88],
            [2002, 4734, 18, 18],
            [2002, 4738, 42, 51],
            [2002, 4745, 19, 22],
            [2002, 4747, 60, 33],
            [2002, 4749, 45, 33],
            [2002, 4753, 25, 21],
            [2002, 4762, 57, 55],
            [2002, 4764, 49, 43],
            [2002, 4777, 21, 22],
            [2002, 4780, 20, 20],
            [2002, 4781, 27, 31],
            [2002, 4789, 41, 25],
            [2002, 4791, 19, 20],
            [2002, 4794, 26, 20],
            [2002, 4800, 30, 30],
            [2002, 4801, 11, 20],
            [2002, 4802, 28, 20],
            [2002, 4805, 15, 21],
            [2002, 4815, 29, 30],
            [2002, 4819, 19, 20],
            [2002, 4820, 53, 49],
            [2002, 4826, 20, 20],
            [2002, 4828, 40, 21],
            [2002, 4829, 20, 27],
            [2002, 4832, 12, 16],
            [2002, 4835, 26, 24],
            [2002, 4839, 37, 22],
            [2002, 4840, 56, 38],
            [2002, 4844, 21, 20],
            [2002, 4849, 20, 19],
            [2002, 4863, 45, 28],
            [2002, 4864, 19, 22],
            [2002, 4865, 32, 23],
            [2002, 4871, 16, 21],
            [2002, 4872, 30, 30],
            [2002, 4877, 25, 20],
            [2002, 4880, 17, 21],
            [2002, 4881, 30, 30],
            [2002, 4888, 54, 52],
            [2002, 4897, 17, 24],
            [2002, 4910, 29, 30],
            [2002, 4912, 11, 20],
            [2002, 4914, 32, 18],
            [2002, 4915, 21, 18],
            [2002, 4918, 22, 30],
            [2002, 4922, 37, 20],
            [2002, 4926, 26, 22],
            [2002, 4927, 20, 20],
            [2002, 4931, 19, 20],
            [2002, 4939, 24, 23],
            [2002, 4940, 44, 22],
            [2002, 4944, 14, 17],
            [2002, 4950, 30, 30],
            [2002, 4951, 45, 29],
            [2002, 4955, 30, 30],
            [2002, 4957, 20, 20],
            [2002, 4960, 107, 50],
            [2002, 4973, 31, 34],
            [2002, 4975, 30, 30],
            [2002, 4976, 12, 18],
            [2002, 4978, 68, 53],
            [2002, 4979, 89, 36],
            [2002, 4983, 22, 19],
            [2002, 4987, 20, 20],
            [2002, 4990, 20, 20],
            [2002, 4992, 25, 23],
            [2002, 4995, 28, 30],
            [2002, 4996, 30, 30],
            [2002, 4997, 28, 20],
            [2002, 4998, 30, 30],
            [2002, 5005, 18, 30],
            [2002, 5006, 48, 26],
            [2002, 5008, 29, 30],
            [2002, 5009, 19, 20],
            [2002, 5011, 30, 30],
            [2002, 5012, 27, 29],
            [2002, 5013, 11, 18],
            [2002, 5017, 29, 30],
            [2002, 5019, 52, 33],
            [2002, 5022, 81, 47],
            [2002, 5027, 29, 30],
            [2002, 5031, 10, 15],
            [2002, 5032, 22, 30],
            [2002, 5033, 20, 20],
            [2002, 5035, 30, 30],
            [2002, 5037, 30, 20],
            [2002, 5038, 12, 19],
            [2002, 5046, 30, 30],
            [2002, 5048, 21, 19],
            [2002, 5050, 12, 14],
            [2002, 5051, 12, 13],
            [2002, 5053, 30, 22],
            [2002, 5058, 30, 30],
            [2002, 5062, 34, 47],
            [2002, 5063, 24, 33],
            [2002, 5064, 28, 30],
            [2002, 5065, 28, 30],
            [2002, 5068, 30, 23],
            [2002, 5069, 29, 30],
            [2002, 5070, 20, 20],
            [2002, 5071, 29, 30],
            [2002, 5073, 61, 44],
            [2002, 5075, 21, 30],
            [2002, 5079, 20, 20],
            [2002, 5081, 36, 17],
            [2002, 5091, 52, 45],
            [2002, 5092, 12, 17],
            [2002, 5095, 14, 17],
            [2002, 5098, 20, 20],
            [2002, 5102, 20, 12],
            [2002, 5103, 30, 30],
            [2002, 5104, 57, 39],
            [2002, 5107, 53, 45],
            [2002, 5108, 23, 33],
            [2002, 5109, 22, 20],
            [2002, 5116, 27, 31],
            [2002, 5121, 20, 20],
            [2002, 5122, 30, 22],
            [2002, 5126, 19, 20],
            [2002, 5127, 20, 20],
            [2002, 5130, 51, 59],
            [2002, 5138, 15, 15],
            [2002, 5149, 24, 21],
            [2002, 5150, 64, 40],
            [2002, 5153, 35, 30],
            [2002, 5159, 40, 25],
            [2002, 5162, 23, 22],
            [2002, 5173, 43, 25],
            [2002, 5180, 21, 32],
            [2002, 5181, 19, 20],
            [2002, 5182, 21, 23],
            [2002, 5183, 30, 30],
            [2002, 5184, 37, 22],
            [2002, 5185, 32, 18],
            [2002, 5186, 13, 18],
            [2002, 5187, 12, 13],
            [2002, 5188, 12, 15],
            [2002, 5189, 18, 11],
            [2002, 5217, 57, 39],
            [2002, 5219, 17, 54],
            [2002, 5220, 14, 57],
            [2002, 5221, 12, 43],
            [2002, 5222, 16, 23],
            [2002, 5223, 11, 30],
            [2002, 5224, 15, 43],
            [2002, 5225, 16, 56],
            [2002, 5226, 12, 56],
            [2002, 5227, 30, 65],
            [2002, 5228, 20, 60],
            [2002, 5229, 11, 43],
            [2002, 5230, 16, 37],
            [2002, 5231, 14, 34],
            [2002, 5232, 19, 62],
            [2002, 5233, 24, 78],
            [2002, 5234, 11, 26],
            [2002, 5235, 40, 41],
            [2002, 5236, 15, 42],
            [2002, 5237, 29, 59],
            [2002, 5238, 18, 46],
            [2002, 5239, 24, 65],
            [2002, 5240, 19, 66],
            [2002, 5241, 28, 62],
            [2002, 5242, 21, 46],
            [2002, 5243, 27, 67],
            [2002, 5244, 20, 79],
            [2002, 5245, 25, 67],
            [2002, 5247, 36, 14],
            [2002, 5248, 37, 20],
            [2002, 5273, 26, 17],
            [2002, 5276, 31, 54],
            [2002, 5279, 21, 24],
            [2002, 5287, 13, 13],
            [2002, 5290, 22, 21],
            [2002, 5298, 13, 13],
            [2002, 5299, 18, 20],
            [2002, 5303, 32, 21],
            [2002, 5305, 26, 23],
            [2002, 5314, 21, 23],
            [2002, 5315, 19, 25],
            [2002, 5317, 41, 59],
            [2002, 5321, 21, 21],
            [2002, 5323, 14, 21],
            [2002, 5328, 19, 20],
            [2002, 5332, 22, 26],
            [2002, 5333, 13, 15],
            [2002, 5336, 15, 18],
            [2002, 5337, 17, 17],
            [2002, 5338, 30, 24],
            [2002, 5339, 21, 23],
            [2002, 5340, 28, 32],
            [2002, 5343, 16, 14],
            [2002, 5344, 41, 42],
            [2002, 5347, 20, 22],
            [2002, 5349, 22, 25],
            [2002, 5350, 20, 27],
            [2002, 5353, 19, 24],
            [2002, 5355, 22, 35],
            [2002, 5357, 26, 20],
            [2002, 5359, 17, 23],
            [2002, 5366, 29, 23],
            [2002, 5371, 32, 34],
            [2002, 5372, 22, 23],
            [2002, 5375, 19, 18],
            [2002, 5377, 17, 18],
            [2002, 5383, 26, 26],
            [2002, 5385, 31, 23],
            [2002, 5387, 16, 15],
            [2002, 5400, 14, 13],
            [2002, 5403, 23, 23],
            [2002, 5404, 23, 23],
            [2002, 5407, 20, 23],
            [2002, 5408, 18, 21],
            [2002, 5411, 24, 20],
            [2002, 5412, 21, 17],
            [2002, 5414, 12, 15],
            [2002, 5415, 42, 45],
            [2002, 5418, 27, 33],
            [2002, 5420, 16, 16],
            [2002, 5421, 17, 14],
            [2002, 5422, 24, 31],
            [2002, 5425, 17, 19],
            [2002, 5426, 20, 27],
            [2002, 5428, 18, 23],
            [2002, 5431, 22, 23],
            [2002, 5432, 22, 28],
            [2002, 5434, 15, 16],
            [2002, 5436, 20, 23],
            [2002, 5437, 27, 23],
            [2002, 5440, 35, 28],
            [2002, 5441, 28, 35],
            [2002, 5444, 22, 32],
            [2002, 5447, 19, 22],
            [2002, 5449, 25, 29],
            [2002, 5450, 26, 28],
            [2002, 5452, 22, 30],
            [2002, 5453, 30, 29],
            [2002, 5454, 14, 15],
            [2002, 5455, 25, 20],
            [2002, 5457, 16, 23],
            [2002, 5459, 23, 24],
            [2002, 5462, 21, 24],
            [2002, 5463, 14, 17],
            [2002, 5464, 18, 18],
            [2002, 5465, 22, 22],
            [2002, 5472, 22, 26],
            [2002, 5473, 17, 22],
            [2002, 5476, 15, 20],
            [2002, 5479, 20, 18],
            [2002, 5480, 33, 29],
            [2002, 5482, 17, 18],
            [2002, 5486, 21, 21],
            [2002, 5489, 30, 51],
            [2002, 5492, 22, 35],
            [2002, 5494, 24, 27],
            [2002, 5495, 28, 24],
            [2002, 5498, 34, 35],
            [2002, 5499, 30, 23],
            [2002, 5501, 25, 38],
            [2002, 5505, 18, 27],
            [2002, 5508, 23, 31],
            [2002, 5528, 20, 18],
            [2002, 5532, 23, 23],
            [2002, 5534, 16, 14],
            [2002, 5539, 16, 19],
            [2002, 5541, 25, 21],
            [2002, 5544, 21, 29],
            [2002, 5545, 16, 21],
            [2002, 5547, 26, 24],
            [2002, 5550, 17, 17],
            [2002, 5571, 25, 20],
            [2002, 5659, 9, 7],
            [2002, 5944, 7, 8],
            [2002, 5945, 11, 9],
            [2002, 5946, 6, 5],
            [2002, 5962, 74, 91],
            [2002, 5986, 55, 37],
            [2002, 5996, 55, 31],
            [2002, 6055, 61, 37],
            [2002, 6066, 34, 33],
            [2002, 6068, 58, 48],
            [2002, 6069, 62, 58],
            [2002, 6070, 62, 58],
            [2002, 6071, 33, 31],
            [2002, 6072, 23, 43],
            [2002, 6073, 37, 39],
            [2002, 6074, 42, 39],
            [2002, 6075, 62, 58],
            [2002, 6076, 45, 42],
            [2002, 6077, 37, 36],
            [2002, 6078, 45, 51],
            [2002, 6079, 45, 42],
            [2002, 6080, 45, 48],
            [2002, 6081, 29, 32],
            [2002, 6082, 42, 39],
            [2002, 6083, 38, 35],
            [2002, 6084, 54, 39],
            [2002, 6085, 46, 43],
            [2002, 6086, 29, 25],
            [2002, 6087, 107, 36],
            [2002, 6088, 44, 42],
            [2002, 6089, 37, 35],
            [2002, 6090, 62, 45],
            [2002, 6091, 33, 35],
            [2002, 6092, 38, 42],
            [2002, 6093, 42, 39],
            [2002, 6094, 42, 39],
            [2002, 6095, 29, 27],
            [2002, 6096, 38, 31],
            [2002, 6097, 45, 36],
            [2002, 6098, 38, 35],
            [2002, 6099, 54, 39],
            [2002, 6100, 42, 39],
            [2002, 6101, 42, 31],
            [2002, 6102, 29, 29],
            [2002, 6103, 38, 35],
            [2002, 6104, 46, 33],
            [2002, 6105, 54, 39],
            [2002, 6106, 33, 31],
            [2002, 6107, 33, 31],
            [2002, 6108, 42, 37],
            [2002, 6109, 24, 31],
            [2002, 6110, 38, 39],
            [2002, 6111, 19, 27],
            [2002, 6112, 36, 36],
            [2002, 6113, 28, 28],
            [2002, 6114, 28, 28],
            [2002, 6115, 28, 33],
            [2002, 6116, 40, 36],
            [2002, 6117, 32, 32],
            [2002, 6118, 40, 39],
            [2002, 6119, 36, 36],
            [2002, 6120, 24, 27],
            [2002, 6121, 36, 36],
            [2002, 6122, 36, 32],
            [2002, 6123, 28, 28],
            [2002, 6124, 40, 32],
            [2002, 6125, 32, 32],
            [2002, 6126, 36, 36],
            [2002, 6127, 36, 36],
            [2002, 6128, 31, 40],
            [2002, 6129, 20, 27],
            [2002, 6130, 36, 36],
            [2002, 6131, 38, 35],
            [2002, 6132, 42, 39],
            [2002, 6133, 38, 35],
            [2002, 6134, 38, 35],
            [2002, 6135, 101, 94],
            [2002, 6136, 85, 80],
            [2002, 6137, 20, 24],
            [2002, 6138, 32, 37],
            [2002, 6139, 37, 37],
            [2002, 6140, 25, 32],
            [2002, 6141, 37, 42],
            [2002, 6142, 31, 37],
            [2002, 6143, 32, 32],
            [2002, 6144, 27, 28],
            [2002, 6145, 40, 40],
            [2002, 6146, 19, 27],
            [2002, 6147, 27, 40],
            [2002, 6148, 27, 34],
            [2002, 6149, 36, 36],
            [2002, 6150, 19, 27],
            [2002, 6151, 27, 28],
            [2002, 6152, 23, 28],
            [2002, 6153, 25, 31],
            [2002, 6154, 36, 36],
            [2002, 6155, 25, 30],
            [2002, 6156, 28, 32],
            [2002, 6157, 43, 40],
            [2002, 6158, 29, 31],
            [2002, 6159, 41, 39],
            [2002, 6160, 24, 28],
            [2002, 6161, 18, 25],
            [2002, 6162, 23, 27],
            [2002, 6163, 60, 51],
            [2002, 6164, 37, 39],
            [2002, 6165, 32, 31],
            [2002, 6166, 53, 37],
            [2002, 6167, 60, 49],
            [2002, 6244, 58, 43],
            [2002, 6353, 23, 15],
            [2002, 6357, 33, 26],
            [2002, 6358, 24, 31],
            [2002, 6359, 24, 24],
            [2002, 6360, 94, 70],
            [2002, 6361, 94, 80],
            [2002, 6362, 59, 57],
            [2002, 6363, 59, 62],
            [2002, 6364, 94, 71],
            [2002, 6365, 102, 75],
            [2002, 6366, 102, 75],
            [2002, 6367, 57, 57],
            [2002, 6368, 94, 71],
            [2002, 6369, 63, 62],
            [2002, 6370, 94, 70],
            [2002, 6371, 95, 79],
            [2002, 6372, 102, 75],
            [2002, 6373, 102, 82],
            [2002, 6374, 95, 70],
            [2002, 6375, 105, 70],
            [2002, 6376, 64, 57],
            [2002, 6377, 105, 78],
            [2002, 6378, 59, 57],
            [2002, 6379, 64, 62],
            [2002, 6380, 64, 57],
            [2002, 6381, 64, 57],
            [2002, 6382, 95, 70],
            [2002, 6383, 64, 57],
            [2002, 6384, 94, 71],
            [2002, 6385, 95, 59],
            [2002, 6386, 95, 70],
            [2002, 6387, 94, 78],
            [2002, 6388, 95, 70],
            [2002, 6389, 102, 75],
            [2002, 6390, 94, 71],
            [2002, 6391, 58, 55],
            [2002, 6392, 95, 70],
            [2002, 6393, 105, 78],
            [2002, 6394, 102, 75],
            [2002, 6395, 94, 71],
            [2002, 6396, 102, 75],
            [2002, 6397, 95, 70],
            [2002, 6398, 110, 82],
            [2002, 6399, 102, 75],
            [2002, 6400, 92, 68],
            [2002, 6401, 63, 63],
            [2002, 6402, 102, 75],
            [2002, 6403, 110, 82],
            [2002, 6404, 102, 75],
            [2002, 6405, 102, 75],
            [2002, 6406, 95, 70],
            [2002, 6407, 94, 71],
            [2002, 6408, 94, 71],
            [2002, 6409, 95, 70],
            [2002, 6410, 94, 71],
            [2002, 6411, 91, 68],
            [2002, 6412, 95, 70],
            [2002, 6413, 110, 82],
            [2002, 6414, 105, 70],
            [2002, 6415, 94, 70],
            [2002, 6416, 102, 75],
            [2002, 6417, 102, 75],
            [2002, 6418, 110, 82],
            [2002, 6419, 102, 82],
            [2002, 6420, 110, 82],
            [2002, 6421, 95, 70],
            [2002, 6422, 94, 71],
            [2002, 6423, 31, 30],
            [2002, 6424, 64, 63],
            [2002, 6425, 64, 57],
            [2002, 6426, 95, 79],
            [2002, 6427, 110, 82],
            [2002, 6428, 105, 79],
            [2002, 6429, 110, 81],
            [2002, 6430, 59, 63],
            [2002, 6431, 94, 71],
            [2002, 6432, 95, 79],
            [2002, 6433, 53, 56],
            [2002, 6434, 94, 70],
            [2002, 6435, 63, 55],
            [2002, 6436, 105, 70],
            [2002, 6437, 102, 75],
            [2002, 6438, 95, 70],
            [2002, 6439, 95, 70],
            [2002, 6440, 105, 79],
            [2002, 6441, 91, 68],
            [2002, 6442, 58, 56],
            [2002, 6443, 95, 70],
            [2002, 6444, 73, 80],
            [2002, 6445, 95, 70],
            [2002, 6446, 102, 75],
            [2002, 6447, 58, 43],
            [2002, 6448, 95, 70],
            [2002, 6449, 102, 82],
            [2002, 6450, 105, 79],
            [2002, 6451, 102, 82],
            [2002, 6452, 105, 70],
            [2002, 6453, 95, 70],
            [2002, 6454, 95, 70],
            [2002, 6455, 95, 70],
            [2002, 6456, 95, 70],
            [2002, 6457, 34, 37],
            [2002, 6458, 26, 30],
            [2002, 6459, 110, 75],
            [2002, 6460, 105, 79],
            [2002, 6461, 95, 70],
            [2002, 6462, 94, 78],
            [2002, 6463, 94, 78],
            [2002, 6464, 110, 82],
            [2002, 6465, 102, 82],
            [2002, 6466, 94, 70],
            [2002, 6467, 105, 79],
            [2002, 6468, 102, 75],
            [2002, 6469, 95, 70],
            [2002, 6470, 94, 71],
            [2002, 6471, 95, 70],
            [2002, 6472, 102, 75],
            [2002, 6473, 102, 75],
            [2002, 6474, 95, 70],
            [2002, 6475, 95, 70],
            [2002, 6476, 95, 70],
            [2002, 6477, 111, 83],
            [2002, 6478, 95, 70],
            [2002, 6479, 95, 70],
            [2002, 6480, 95, 70],
            [2002, 6481, 102, 75],
            [2002, 6482, 102, 82],
            [2002, 6483, 95, 70],
            [2002, 6484, 64, 47],
            [2002, 6485, 91, 71],
            [2002, 6486, 102, 75],
            [2002, 6487, 94, 71],
            [2002, 6488, 94, 71],
            [2002, 6489, 94, 70],
            [2002, 6490, 95, 70],
            [2002, 6491, 95, 70],
            [2002, 6492, 28, 30],
            [2002, 6493, 94, 71],
            [2002, 6494, 28, 29],
            [2002, 6495, 91, 68],
            [2002, 6496, 94, 71],
            [2002, 6497, 110, 82],
            [2002, 6498, 110, 82],
            [2002, 6499, 105, 78],
            [2002, 6500, 64, 57],
            [2002, 6501, 94, 71],
            [2002, 6502, 57, 57],
            [2002, 6503, 95, 70],
            [2002, 6504, 94, 80],
            [2002, 6505, 95, 70],
            [2002, 6506, 95, 79],
            [2002, 6507, 102, 75],
            [2002, 6508, 102, 75],
            [2002, 6509, 94, 71],
            [2002, 6510, 110, 82],
            [2002, 6511, 94, 71],
            [2002, 6512, 94, 71],
            [2002, 6513, 24, 22],
            [2002, 6514, 93, 69],
            [2002, 6515, 95, 78],
            [2002, 6516, 64, 53],
            [2002, 6517, 32, 29],
            [2002, 6518, 95, 79],
            [2002, 6519, 105, 79],
            [2002, 6520, 110, 82],
            [2002, 6521, 49, 48],
            [2002, 6522, 95, 70],
            [2002, 6523, 110, 82],
            [2002, 6524, 105, 79],
            [2002, 6525, 94, 71],
            [2002, 6526, 102, 75],
            [2002, 6527, 94, 71],
            [2002, 6528, 95, 70],
            [2002, 6529, 105, 80],
            [2002, 6530, 92, 68],
            [2002, 6531, 102, 82],
            [2002, 6532, 95, 70],
            [2002, 6533, 95, 70],
            [2002, 6534, 95, 79],
            [2002, 6535, 102, 75],
            [2002, 6536, 32, 33],
            [2002, 6537, 102, 75],
            [2002, 6538, 102, 82],
            [2002, 6539, 95, 70],
            [2002, 6540, 102, 82],
            [2002, 6541, 102, 75],
            [2002, 6542, 102, 75],
            [2002, 6543, 102, 75],
            [2002, 6544, 102, 75],
            [2002, 6546, 102, 75],
            [2002, 6547, 110, 82],
            [2002, 6548, 102, 75],
            [2002, 6549, 102, 82],
            [2002, 6550, 102, 75],
            [2002, 6551, 102, 75],
            [2002, 6552, 102, 82],
            [2002, 6553, 102, 75],
            [2002, 6554, 102, 75],
            [2002, 6555, 102, 75],
            [2002, 6556, 102, 75],
            [2002, 6557, 102, 75],
            [2002, 6558, 95, 70],
            [2002, 6559, 102, 75],
            [2002, 6560, 95, 70],
            [2002, 6561, 102, 82],
            [2002, 6562, 102, 75],
            [2002, 6563, 102, 75],
            [2002, 6564, 102, 75],
            [2002, 6565, 105, 80],
            [2002, 6566, 95, 63],
            [2002, 6567, 102, 75],
            [2002, 6568, 94, 71],
            [2002, 6569, 94, 71],
            [2002, 6570, 102, 75],
            [2002, 6572, 102, 75],
            [2002, 6573, 94, 71],
            [2002, 6574, 95, 70],
            [2002, 6575, 94, 70],
            [2002, 6576, 95, 70],
            [2002, 6577, 94, 71],
            [2002, 6578, 95, 70],
            [2002, 6579, 102, 75],
            [2002, 6580, 94, 71],
            [2002, 6581, 105, 79],
            [2002, 6582, 95, 70],
            [2002, 6583, 105, 78],
            [2002, 6584, 111, 83],
            [2002, 6585, 94, 71],
            [2002, 6586, 94, 71],
            [2002, 6587, 94, 71],
            [2002, 6588, 94, 70],
            [2002, 6589, 94, 70],
            [2002, 6590, 111, 83],
            [2002, 6591, 102, 75],
            [2002, 6592, 102, 75],
            [2002, 6593, 102, 75],
            [2002, 6594, 102, 75],
            [2002, 6595, 95, 70],
            [2002, 6596, 95, 70],
            [2002, 6597, 102, 75],
            [2002, 6598, 102, 75],
            [2002, 6599, 105, 79],
            [2002, 6600, 95, 70],
            [2002, 6601, 102, 75],
            [2002, 6602, 95, 70],
            [2002, 6603, 59, 57],
            [2002, 6604, 102, 82],
            [2002, 6605, 95, 70],
            [2002, 6606, 94, 71],
            [2002, 6607, 105, 70],
            [2002, 6608, 95, 70],
            [2002, 6609, 95, 70],
            [2002, 6610, 95, 70],
            [2002, 6611, 59, 57],
            [2002, 6612, 95, 79],
            [2002, 6613, 95, 70],
            [2002, 6614, 32, 33],
            [2002, 6615, 94, 71],
            [2002, 6616, 95, 70],
            [2002, 6617, 35, 31],
            [2002, 6618, 94, 71],
            [2002, 6619, 102, 75],
            [2002, 6620, 102, 75],
            [2002, 6621, 95, 70],
            [2002, 6622, 94, 71],
            [2002, 6623, 105, 79],
            [2002, 6624, 110, 75],
            [2002, 6625, 102, 75],
            [2002, 6626, 110, 82],
            [2002, 6627, 95, 70],
            [2002, 6628, 102, 82],
            [2002, 6629, 59, 63],
            [2002, 6630, 63, 63],
            [2002, 6631, 53, 60],
            [2002, 6632, 24, 28],
            [2002, 6633, 33, 37],
            [2002, 6634, 41, 39],
            [2002, 6635, 46, 43],
            [2002, 6636, 70, 65],
            [2002, 6637, 54, 39],
            [2002, 6638, 62, 48],
            [2002, 6639, 46, 53],
            [2002, 6640, 61, 67],
            [2002, 6643, 40, 38],
            [2002, 6649, 54, 41],
            [2002, 6650, 54, 39],
            [2002, 6651, 37, 27],
            [2002, 6652, 52, 40],
            [2002, 6653, 50, 46],
            [2002, 6654, 36, 36],
            [2002, 6655, 33, 31],
            [2002, 6656, 40, 36],
            [2002, 6657, 46, 43],
            [2002, 6660, 41, 29],
            [2002, 6661, 32, 32],
            [2002, 6662, 46, 40],
            [2002, 6663, 36, 36],
            [2002, 6664, 44, 42],
            [2002, 6665, 36, 36],
            [2002, 6666, 36, 32],
            [2002, 6667, 36, 36],
            [2002, 6668, 36, 27],
            [2002, 6669, 45, 42],
            [2002, 6670, 37, 36],
            [2002, 6671, 52, 36],
            [2002, 6672, 41, 31],
            [2002, 6673, 42, 35],
            [2002, 6674, 40, 40],
            [2002, 6675, 37, 36],
            [2002, 6676, 53, 51],
            [2002, 6677, 36, 36],
            [2002, 6678, 37, 36],
            [2002, 6679, 85, 80],
            [2002, 6680, 33, 31],
            [2002, 6682, 32, 32],
            [2002, 6683, 36, 36],
            [2002, 6684, 33, 42],
            [2002, 6685, 28, 32],
            [2002, 6686, 27, 32],
            [2002, 6687, 28, 33],
            [2002, 6688, 27, 32],
            [2002, 6689, 28, 33],
            [2002, 6690, 27, 32],
            [2002, 6697, 38, 29],
            [2002, 6699, 62, 53],
            [2002, 6700, 73, 66],
            [2002, 6701, 64, 78],
            [2002, 6702, 65, 43],
            [2002, 6704, 50, 42],
            [2002, 6706, 43, 41],
            [2002, 6708, 58, 56],
            [2002, 6715, 62, 51],
            [2002, 6716, 79, 52],
            [2002, 6718, 85, 64],
            [2002, 6722, 64, 52],
            [2002, 6723, 61, 46],
            [2002, 6725, 45, 45],
            [2002, 6726, 89, 60],
            [2002, 6728, 52, 50],
            [2002, 6730, 45, 45],
            [2002, 6734, 60, 45],
            [2002, 6737, 64, 54],
            [2002, 6738, 50, 49],
            [2002, 6741, 17, 19],
            [2002, 6748, 32, 32],
            [2002, 6749, 35, 35],
            [2002, 6750, 52, 51],
            [2002, 6752, 27, 32],
            [2002, 6753, 44, 40],
            [2002, 6754, 41, 39],
            [2002, 6755, 52, 52],
            [2002, 6756, 44, 44],
            [2002, 6757, 39, 39],
            [2002, 6758, 44, 55],
            [2002, 6759, 27, 32],
            [2002, 6760, 52, 52],
            [2002, 6761, 52, 51],
            [2002, 6762, 44, 44],
            [2002, 6763, 29, 27],
            [2002, 6764, 40, 44],
            [2002, 6766, 62, 60],
            [2002, 6767, 38, 38],
            [2002, 6768, 40, 40],
            [2002, 6769, 52, 65],
            [2002, 6770, 45, 51],
            [2002, 6771, 45, 47],
            [2002, 6772, 35, 44],
            [2002, 6773, 60, 55],
            [2002, 6777, 60, 58],
            [2002, 6778, 36, 36],
            [2002, 6779, 45, 51],
            [2002, 6780, 45, 48],
            [2002, 6781, 53, 51],
            [2002, 6782, 85, 72],
            [2002, 6783, 61, 59],
            [2002, 6784, 44, 44],
            [2002, 6785, 45, 44],
            [2002, 6786, 45, 51],
            [2002, 6787, 40, 49],
            [2002, 6789, 52, 51],
            [2002, 6790, 89, 67],
            [2002, 6791, 76, 53],
            [2002, 6794, 87, 66],
            [2002, 6795, 66, 58],
            [2002, 6798, 79, 56],
            [2002, 6803, 68, 59],
            [2002, 6804, 66, 58],
            [2002, 6805, 92, 70],
            [2002, 6806, 66, 59],
            [2002, 6807, 85, 59],
            [2002, 6808, 91, 69],
            [2002, 6812, 97, 84],
            [2002, 6813, 85, 65],
            [2002, 6814, 77, 71],
            [2002, 6816, 80, 66],
            [2002, 6818, 20, 22],
            [2002, 6819, 38, 46],
            [2002, 6820, 36, 40],
            [2002, 6821, 45, 48],
            [2002, 6822, 51, 51],
            [2002, 6823, 44, 46],
            [2002, 6833, 72, 58],
            [2002, 6834, 90, 75],
            [2002, 6835, 98, 75],
            [2002, 6836, 88, 69],
            [2002, 6837, 89, 68],
            [2002, 6838, 102, 78],
            [2002, 6841, 36, 27],
            [2002, 6845, 89, 67],
            [2002, 6846, 102, 88],
            [2002, 6847, 87, 66],
            [2002, 6848, 91, 70],
            [2002, 6849, 62, 59],
            [2002, 6850, 89, 67],
            [2002, 6851, 87, 66],
            [2002, 6852, 92, 70],
            [2002, 6853, 94, 71],
            [2002, 6854, 85, 70],
            [2002, 6855, 89, 68],
            [2002, 6856, 88, 67],
            [2002, 6857, 90, 75],
            [2002, 6858, 98, 74],
            [2002, 6859, 71, 56],
            [2002, 6860, 88, 67],
            [2002, 6861, 94, 78],
            [2002, 6862, 92, 70],
            [2002, 6867, 12, 20],
            [2002, 6868, 12, 16],
            [2002, 6869, 15, 17],
            [2002, 6870, 15, 20],
            [2002, 6871, 15, 18],
            [2002, 6872, 12, 18],
            [2002, 6873, 20, 20],
            [2002, 6874, 16, 20],
            [2002, 6875, 16, 19],
            [2002, 6876, 15, 20],
            [2002, 6877, 18, 20],
            [2002, 6878, 15, 18],
            [2002, 6879, 15, 20],
            [2002, 6880, 20, 25],
            [2002, 6881, 15, 15],
            [2002, 6882, 16, 20],
            [2002, 6883, 15, 21],
            [2002, 6884, 7, 8],
            [2002, 6885, 25, 16],
            [2002, 6886, 11, 16],
            [2002, 6887, 116, 39],
            [2002, 6888, 11, 12],
            [2002, 6889, 21, 14],
            [2002, 6890, 8, 10],
            [2002, 6891, 18, 17],
            [2002, 6892, 9, 10],
            [2002, 6893, 22, 15],
            [2002, 6894, 7, 9],
            [2002, 6895, 28, 16],
            [2002, 6896, 9, 11],
            [2002, 6897, 16, 15],
            [2002, 6898, 6, 8],
            [2002, 6899, 28, 14],
            [2002, 6900, 6, 7],
            [2002, 6901, 24, 16],
            [2002, 6902, 10, 15],
            [2002, 6903, 34, 23],
            [2002, 6904, 11, 11],
            [2002, 6905, 42, 25],
            [2002, 6906, 8, 9],
            [2002, 6907, 25, 16],
            [2002, 6908, 8, 8],
            [2002, 6909, 24, 18],
            [2002, 6910, 34, 30],
            [2002, 6911, 63, 43],
            [2002, 6912, 38, 24],
            [2002, 6913, 66, 41],
            [2002, 6914, 13, 12],
            [2002, 6915, 42, 39],
            [2002, 6916, 11, 12],
            [2002, 6917, 30, 34],
            [2002, 6918, 30, 23],
            [2002, 6919, 30, 29],
            [2002, 6920, 29, 23],
            [2002, 6921, 52, 38],
            [2002, 6922, 14, 13],
            [2002, 6923, 57, 41],
            [2002, 6924, 11, 12],
            [2002, 6925, 44, 42],
            [2002, 6926, 67, 29],
            [2002, 6927, 71, 39],
            [2002, 6928, 21, 20],
            [2002, 6929, 58, 42],
            [2002, 6930, 22, 15],
            [2002, 6931, 42, 42],
            [2002, 6932, 21, 14],
            [2002, 6933, 30, 28],
            [2002, 6934, 20, 15],
            [2002, 6935, 49, 51],
            [2002, 6936, 24, 22],
            [2002, 6937, 52, 42],
            [2002, 6938, 21, 15],
            [2002, 6939, 53, 40],
            [2002, 6940, 13, 11],
            [2002, 6941, 31, 24],
            [2002, 6942, 33, 29],
            [2002, 6943, 62, 41],
            [2002, 6944, 12, 12],
            [2002, 6945, 74, 57],
            [2002, 6946, 63, 35],
            [2002, 6947, 70, 51],
            [2002, 6948, 15, 13],
            [2002, 6949, 52, 39],
            [2002, 6950, 17, 15],
            [2002, 6951, 57, 42],
            [2002, 6952, 62, 27],
            [2002, 6953, 67, 39],
            [2002, 6954, 30, 17],
            [2002, 6955, 52, 39],
            [2002, 6956, 19, 16],
            [2002, 6957, 77, 65],
            [2002, 6958, 15, 12],
            [2002, 6959, 52, 42],
            [2002, 6960, 12, 11],
            [2002, 6961, 30, 27],
            [2002, 6962, 13, 12],
            [2002, 6963, 12, 10],
            [2002, 6964, 27, 17],
            [2002, 6965, 9, 10],
            [2002, 6966, 29, 60],
            [2002, 6967, 23, 60],
            [2002, 6968, 41, 85],
            [2002, 6969, 23, 53],
            [2002, 6970, 31, 63],
            [2002, 6971, 36, 28],
            [2002, 6972, 73, 34],
            [2002, 6973, 23, 12],
            [2002, 6974, 6, 7],
            [2002, 6975, 9, 10],
            [2002, 6976, 21, 17],
            [2002, 6977, 7, 8],
            [2002, 6978, 51, 21],
            [2002, 6979, 7, 9],
            [2002, 6980, 19, 15],
            [2002, 6981, 9, 9],
            [2002, 6982, 28, 16],
            [2002, 6983, 12, 13],
            [2002, 6984, 33, 24],
            [2002, 6985, 56, 31],
            [2002, 6986, 112, 47],
            [2002, 6987, 9, 9],
            [2002, 6988, 26, 12],
            [2002, 6989, 14, 14],
            [2002, 6990, 30, 22],
            [2002, 6991, 7, 5],
            [2002, 6992, 23, 13],
            [2002, 6993, 8, 8],
            [2002, 6994, 58, 26],
            [2002, 6995, 11, 10],
            [2002, 6996, 21, 16],
            [2002, 6997, 7, 6],
            [2002, 6998, 15, 8],
            [2002, 6999, 7, 7],
            [2002, 7000, 21, 15],
            [2002, 7001, 7, 7],
            [2002, 7002, 18, 13],
            [2002, 7003, 8, 8],
            [2002, 7004, 18, 14],
            [2002, 7005, 14, 15],
            [2002, 7006, 29, 24],
            [2002, 7007, 40, 31],
            [2002, 7008, 40, 30],
            [2002, 7009, 21, 15],
            [2002, 7010, 20, 15],
            [2002, 7011, 10, 10],
            [2002, 7012, 23, 22],
            [2002, 7013, 29, 20],
            [2002, 7014, 13, 10],
            [2002, 7015, 12, 9],
            [2002, 7019, 11, 10],
            [2002, 7020, 42, 42],
            [2002, 7021, 13, 12],
            [2002, 7022, 23, 22],
            [2002, 7023, 18, 18],
            [2002, 7024, 29, 28],
            [2002, 7025, 15, 13],
            [2002, 7026, 29, 23],
            [2002, 7027, 20, 20],
            [2002, 7028, 42, 42],
            [2002, 7029, 42, 30],
            [2002, 7030, 58, 42],
            [2002, 7031, 15, 13],
            [2002, 7032, 31, 23],
            [2002, 7033, 24, 23],
            [2002, 7034, 37, 31],
            [2002, 7035, 11, 12],
            [2002, 7036, 31, 31],
            [2002, 7037, 29, 30],
            [2002, 7038, 38, 40],
            [2002, 7039, 24, 14],
            [2002, 7040, 31, 29],
            [2002, 7041, 15, 13],
            [2002, 7042, 58, 55],
            [2002, 7043, 21, 29],
            [2002, 7044, 29, 28],
            [2002, 7045, 38, 24],
            [2002, 7046, 56, 40],
            [2002, 7047, 19, 15],
            [2002, 7048, 29, 24],
            [2002, 7049, 54, 40],
            [2002, 7050, 21, 16],
            [2002, 7051, 59, 43],
            [2002, 7052, 16, 15],
            [2002, 7053, 54, 43],
            [2002, 7054, 18, 15],
            [2002, 7055, 41, 29],
            [2002, 7056, 14, 15],
            [2002, 7057, 64, 43],
            [2002, 7058, 30, 19],
            [2002, 7059, 59, 43],
            [2002, 7060, 30, 20],
            [2002, 7061, 54, 43],
            [2002, 7062, 19, 14],
            [2002, 7063, 50, 24],
            [2002, 7064, 30, 15],
            [2002, 7065, 44, 43],
            [2002, 7066, 13, 13],
            [2002, 7067, 55, 43],
            [2002, 7068, 42, 33],
            [2002, 7069, 72, 59],
            [2002, 7070, 30, 21],
            [2002, 7071, 59, 42],
            [2002, 7072, 11, 12],
            [2002, 7073, 30, 30],
            [2002, 7074, 26, 21],
            [2002, 7075, 56, 59],
            [2002, 7076, 30, 24],
            [2002, 7077, 41, 28],
            [2002, 7078, 11, 12],
            [2002, 7079, 30, 24],
            [2002, 7080, 44, 38],
            [2002, 7081, 74, 58],
            [2002, 7082, 29, 24],
            [2002, 7083, 44, 42],
            [2002, 7084, 61, 23],
            [2002, 7085, 66, 42],
            [2002, 7086, 13, 12],
            [2002, 7087, 45, 39],
            [2002, 7088, 29, 26],
            [2002, 7089, 58, 42],
            [2002, 7090, 20, 12],
            [2002, 7091, 57, 42],
            [2002, 7092, 56, 25],
            [2002, 7093, 74, 63],
            [2002, 7094, 40, 29],
            [2002, 7095, 60, 42],
            [2002, 7096, 30, 24],
            [2002, 7097, 42, 29],
            [2002, 7098, 29, 28],
            [2002, 7099, 55, 43],
            [2002, 7100, 15, 13],
            [2002, 7101, 21, 19],
            [2002, 7102, 14, 11],
            [2002, 7103, 34, 18],
            [2002, 7104, 10, 7],
            [2002, 7105, 22, 13],
            [2002, 7106, 5, 7],
            [2002, 7107, 22, 12],
            [2002, 7108, 11, 9],
            [2002, 7109, 28, 15],
            [2002, 7110, 9, 11],
            [2002, 7111, 27, 14],
            [2002, 7112, 5, 5],
            [2002, 7113, 32, 14],
            [2002, 7114, 27, 20],
            [2002, 7115, 48, 26],
            [2002, 7116, 10, 11],
            [2002, 7117, 34, 22],
            [2002, 7118, 8, 15],
            [2002, 7119, 17, 15],
            [2002, 7120, 11, 13],
            [2002, 7121, 39, 35],
            [2002, 7122, 9, 8],
            [2002, 7123, 28, 16],
            [2002, 7124, 7, 10],
            [2002, 7125, 16, 16],
            [2002, 7126, 8, 7],
            [2002, 7127, 20, 16],
            [2002, 7128, 9, 8],
            [2002, 7129, 21, 14],
            [2002, 7130, 8, 9],
            [2002, 7131, 23, 14],
            [2002, 7132, 8, 8],
            [2002, 7133, 33, 20],
            [2002, 7134, 17, 11],
            [2002, 7135, 25, 11],
            [2002, 7136, 17, 13],
            [2002, 7137, 33, 19],
            [2002, 7138, 9, 9],
            [2002, 7139, 24, 18],
            [2002, 7140, 6, 7],
            [2002, 7141, 14, 12],
            [2002, 7142, 9, 10],
            [2002, 7143, 25, 14],
            [2002, 7144, 9, 9],
            [2002, 7145, 18, 14],
            [2002, 7146, 10, 11],
            [2002, 7147, 27, 20],
            [2002, 7148, 8, 11],
            [2002, 7149, 35, 21],
            [2002, 7150, 5, 8],
            [2002, 7151, 18, 14],
            [2002, 7152, 8, 8],
            [2002, 7153, 27, 21],
            [2002, 7154, 17, 19],
            [2002, 7155, 25, 24],
            [2002, 7156, 19, 19],
            [2002, 7157, 9, 8],
            [2002, 7158, 42, 23],
            [2002, 7159, 19, 14],
            [2002, 7160, 48, 31],
            [2002, 7161, 9, 11],
            [2002, 7162, 26, 21],
            [2002, 7163, 8, 7],
            [2002, 7164, 21, 13],
            [2002, 7165, 12, 11],
            [2002, 7166, 56, 31],
            [2002, 7167, 7, 7],
            [2002, 7168, 27, 18],
            [2002, 7169, 5, 5],
            [2002, 7170, 36, 22],
            [2002, 7171, 6, 7],
            [2002, 7172, 40, 25],
            [2002, 7173, 14, 13],
            [2002, 7174, 67, 41],
            [2002, 7175, 6, 5],
            [2002, 7176, 17, 13],
            [2002, 7177, 15, 9],
            [2002, 7178, 23, 13],
            [2002, 7179, 15, 14],
            [2002, 7180, 49, 30],
            [2002, 7181, 10, 10],
            [2002, 7182, 40, 19],
            [2002, 7183, 18, 11],
            [2002, 7184, 88, 59],
            [2002, 7185, 17, 14],
            [2002, 7186, 50, 26],
            [2002, 7187, 13, 10],
            [2002, 7188, 47, 25],
            [2002, 7189, 16, 15],
            [2002, 7190, 44, 26],
            [2002, 7191, 16, 13],
            [2002, 7192, 26, 16],
            [2002, 7193, 14, 13],
            [2002, 7194, 21, 12],
            [2002, 7195, 14, 12],
            [2002, 7196, 40, 23],
            [2002, 7197, 8, 6],
            [2002, 7198, 21, 11],
            [2002, 7199, 14, 11],
            [2002, 7200, 32, 17],
            [2002, 7201, 6, 5],
            [2002, 7202, 14, 9],
            [2002, 7203, 10, 7],
            [2002, 7204, 18, 16],
            [2002, 7205, 18, 16],
            [2002, 7206, 54, 31],
            [2002, 7207, 14, 14],
            [2002, 7208, 40, 25],
            [2002, 7209, 16, 10],
            [2002, 7210, 49, 39],
            [2002, 7211, 9, 10],
            [2002, 7212, 27, 16],
            [2002, 7213, 8, 8],
            [2002, 7214, 66, 34],
            [2002, 7215, 8, 6],
            [2002, 7216, 54, 27],
            [2002, 7217, 12, 10],
            [2002, 7218, 30, 20],
            [2002, 7219, 16, 16],
            [2002, 7220, 35, 23],
            [2002, 7221, 14, 11],
            [2002, 7222, 32, 23],
            [2002, 7223, 12, 11],
            [2002, 7224, 40, 21],
            [2002, 7225, 7, 8],
            [2002, 7226, 27, 17],
            [2002, 7227, 10, 11],
            [2002, 7228, 30, 22],
            [2002, 7229, 13, 9],
            [2002, 7230, 59, 29],
            [2002, 7231, 10, 9],
            [2002, 7232, 30, 19],
            [2002, 7233, 8, 6],
            [2002, 7234, 26, 16],
            [2002, 7235, 12, 10],
            [2002, 7236, 21, 16],
            [2002, 7237, 7, 7],
            [2002, 7238, 21, 14],
            [2002, 7239, 8, 8],
            [2002, 7240, 19, 13],
            [2002, 7241, 20, 20],
            [2002, 7242, 27, 15],
            [2002, 7243, 5, 6],
            [2002, 7244, 18, 12],
            [2002, 7245, 5, 7],
            [2002, 7246, 26, 15],
            [2002, 7247, 7, 8],
            [2002, 7248, 25, 17],
            [2002, 7249, 7, 8],
            [2002, 7250, 24, 15],
            [2002, 7251, 17, 19],
            [2002, 7252, 29, 23],
            [2002, 7253, 14, 10],
            [2002, 7254, 57, 17],
            [2002, 7255, 47, 24],
            [2002, 7256, 24, 16],
            [2002, 7257, 111, 83],
            [2002, 7258, 111, 83],
            [2002, 7259, 96, 60],
            [2002, 7260, 118, 91],
            [2002, 7261, 96, 82],
            [2002, 7262, 99, 112],
            [2002, 7263, 103, 89],
            [2002, 7264, 109, 123],
            [2002, 7265, 98, 85],
            [2002, 7266, 121, 91],
            [2002, 7267, 97, 83],
            [2002, 7268, 121, 91],
            [2002, 7269, 121, 91],
            [2002, 7270, 94, 59],
            [2002, 7271, 68, 66],
            [2002, 7272, 118, 89],
            [2002, 7273, 110, 124],
            [2002, 7274, 117, 88],
            [2002, 7275, 101, 88],
            [2002, 7276, 65, 59],
            [2002, 7277, 97, 83],
            [2002, 7278, 100, 113],
            [2002, 7279, 110, 81],
            [2002, 7280, 121, 92],
            [2002, 7281, 96, 82],
            [2002, 7282, 98, 111],
            [2002, 7283, 14, 23],
            [2002, 7284, 11, 10],
            [2002, 7285, 12, 11],
            [2002, 7286, 18, 27],
            [2002, 7287, 16, 31],
            [2002, 7288, 34, 36],
            [2002, 7289, 36, 27],
            [2002, 7290, 60, 39],
            [2002, 7291, 45, 37],
            [2002, 7292, 43, 45],
            [2002, 7293, 29, 27],
            [2002, 7294, 28, 27],
            [2002, 7295, 14, 13],
            [2002, 7296, 25, 22],
            [2002, 7297, 27, 23],
            [2002, 7298, 16, 19],
            [2002, 7299, 16, 21],
            [2002, 7300, 20, 32],
            [2002, 7301, 13, 28],
            [2002, 7302, 49, 56],
            [2002, 7303, 81, 78],
            [2002, 7304, 38, 42],
            [2002, 7305, 51, 52],
            [2002, 7306, 35, 41],
            [2002, 7307, 53, 59],
            [2002, 7308, 43, 49],
            [2002, 7309, 38, 44],
            [2002, 7310, 85, 73],
            [2002, 7311, 70, 69],
            [2002, 7312, 49, 52],
            [2002, 7313, 109, 80],
            [2002, 7314, 98, 74],
            [2002, 7315, 95, 72],
            [2002, 7316, 99, 74],
            [2002, 7317, 100, 75],
            [2002, 7318, 98, 75],
            [2002, 7319, 112, 83],
            [2002, 7320, 97, 73],
            [2002, 7321, 126, 94],
            [2002, 7322, 98, 73],
            [2002, 7323, 121, 91],
            [2002, 7324, 109, 80],
            [2002, 7325, 100, 75],
            [2002, 7326, 99, 74],
            [2002, 7327, 122, 91],
            [2002, 7328, 36, 42],
            [2002, 7329, 66, 63],
            [2002, 7330, 45, 45],
            [2002, 7331, 45, 45],
            [2002, 7332, 35, 40],
            [2002, 7333, 67, 82],
            [2002, 7337, 15, 15],
            [2002, 7342, 13, 8],
            [2002, 7343, 13, 9],
            [2002, 7344, 12, 9],
            [2002, 7348, 12, 8],
            [2002, 7352, 11, 9],
            [2002, 7354, 14, 13],
            [2002, 7356, 11, 8],
            [2002, 7357, 21, 11],
            [2002, 7358, 15, 11],
            [2002, 7359, 25, 12],
            [2002, 7360, 13, 10],
            [2002, 7362, 11, 9],
            [2002, 7363, 12, 12],
            [2002, 7364, 12, 12],
            [2002, 7367, 13, 8],
            [2002, 7370, 12, 11],
            [2002, 7371, 16, 12],
            [2002, 7372, 18, 10],
            [2002, 7373, 15, 11],
            [2002, 7374, 11, 8],
            [2002, 7375, 12, 8],
            [2002, 7376, 9, 8],
            [2002, 7377, 11, 8],
            [2002, 7378, 20, 19],
            [2002, 7379, 34, 26],
            [2002, 7396, 44, 44],
            [2002, 7397, 73, 58],
            [2002, 7398, 44, 45],
            [2002, 7399, 34, 39],
            [2002, 7400, 56, 54],
            [2002, 7401, 34, 40],
            [2002, 7402, 69, 85],
            [2002, 7403, 28, 34],
            [2002, 7404, 82, 63],
            [2002, 7405, 43, 44],
            [2002, 7406, 62, 74],
            [2002, 7407, 45, 44],
            [2002, 7408, 56, 67],
            [2002, 7409, 22, 27],
            [2002, 7410, 24, 29],
            [2002, 7411, 24, 29],
            [2002, 7412, 48, 51],
            [2002, 7413, 22, 28],
            [2002, 7414, 22, 27],
            [2002, 7415, 21, 31],
            [2002, 7416, 28, 35],
            [2002, 7417, 23, 29],
            [2002, 7418, 26, 28],
            [2002, 7419, 54, 58],
            [2002, 7420, 22, 29],
            [2002, 7421, 40, 47],
            [2002, 7422, 22, 27],
            [2002, 7423, 33, 35],
            [2002, 7424, 56, 50],
            [2002, 7425, 38, 34],
            [2002, 7426, 63, 56],
            [2002, 7427, 49, 46],
            [2002, 7428, 52, 51],
            [2002, 7429, 30, 33],
            [2002, 7430, 48, 37],
            [2002, 7431, 34, 36],
            [2002, 7432, 79, 60],
            [2002, 7433, 50, 48],
            [2002, 7434, 84, 54],
            [2002, 7435, 58, 53],
            [2002, 7436, 67, 61],
            [2002, 7437, 29, 37],
            [2002, 7438, 52, 50],
            [2002, 7439, 44, 41],
            [2002, 7440, 71, 62],
            [2002, 7441, 41, 38],
            [2002, 7442, 62, 53],
            [2002, 7443, 67, 59],
            [2002, 7444, 77, 63],
            [2002, 7445, 66, 56],
            [2002, 7446, 92, 70],
            [2002, 7447, 39, 39],
            [2002, 7448, 68, 65],
            [2002, 7449, 25, 24],
            [2002, 7450, 25, 28],
            [2002, 7451, 16, 18],
            [2002, 7452, 29, 20],
            [2002, 7453, 70, 35],
            [2002, 7454, 21, 22],
            [2002, 7455, 30, 27],
            [2002, 7456, 91, 68],
            [2002, 7457, 66, 64],
            [2002, 7458, 46, 45],
            [2002, 7459, 66, 64],
            [2002, 7460, 66, 72],
            [2002, 7461, 46, 44],
            [2002, 7462, 55, 53],
            [2002, 7463, 62, 61],
            [2002, 7464, 74, 56],
            [2002, 7465, 70, 53],
            [2002, 7466, 62, 46],
            [2002, 7467, 66, 64],
            [2002, 7468, 54, 53],
            [2002, 7469, 74, 56],
            [2002, 7470, 83, 61],
            [2002, 7471, 103, 76],
            [2002, 7472, 37, 79],
            [2002, 7473, 46, 53],
            [2002, 7474, 66, 64],
            [2002, 7475, 66, 64],
            [2002, 7476, 58, 56],
            [2002, 7477, 51, 49],
            [2002, 7478, 54, 53],
            [2002, 7479, 54, 53],
            [2002, 7480, 66, 55],
            [2002, 7481, 46, 53],
            [2002, 7482, 62, 46],
            [2002, 7483, 66, 64],
            [2002, 7484, 49, 56],
            [2002, 7485, 107, 79],
            [2002, 7486, 86, 64],
            [2002, 7487, 58, 56],
            [2002, 7488, 70, 53],
            [2002, 7489, 78, 51],
            [2002, 7490, 55, 53],
            [2002, 7491, 70, 53],
            [2002, 7492, 86, 64],
            [2002, 7493, 62, 60],
            [2002, 7494, 62, 60],
            [2002, 7495, 66, 64],
            [2002, 7496, 107, 79],
            [2002, 7497, 71, 53],
            [2002, 7498, 46, 53],
            [2002, 7499, 54, 45],
            [2002, 7500, 57, 56],
            [2002, 7501, 74, 56],
            [2002, 7502, 70, 53],
            [2002, 7503, 78, 59],
            [2002, 7504, 74, 55],
            [2002, 7505, 62, 60],
            [2002, 7506, 74, 56],
            [2002, 7507, 59, 56],
            [2002, 7508, 70, 53],
            [2002, 7509, 66, 64],
            [2002, 7510, 66, 64],
            [2002, 7511, 74, 56],
            [2002, 7512, 66, 64],
            [2002, 7513, 70, 53],
            [2002, 7514, 113, 85],
            [2002, 7515, 78, 58],
            [2002, 7516, 66, 64],
            [2002, 7517, 107, 79],
            [2002, 7518, 74, 56],
            [2002, 7519, 62, 60],
            [2002, 7520, 62, 61],
            [2002, 7521, 46, 53],
            [2002, 7522, 83, 61],
            [2002, 7523, 62, 61],
            [2002, 7524, 101, 98],
            [2002, 7525, 66, 64],
            [2002, 7526, 74, 55],
            [2002, 7527, 46, 53],
            [2002, 7528, 91, 68],
            [2002, 7529, 107, 103],
            [2002, 7530, 83, 61],
            [2002, 7531, 49, 56],
            [2002, 7532, 66, 64],
            [2002, 7533, 91, 68],
            [2002, 7534, 107, 103],
            [2002, 7535, 62, 61],
            [2002, 7536, 83, 61],
            [2002, 7537, 82, 61],
            [2002, 7538, 91, 68],
            [2002, 7539, 62, 61],
            [2002, 7540, 91, 68],
            [2002, 7541, 78, 58],
            [2002, 7542, 91, 68],
            [2002, 7543, 78, 58],
            [2002, 7544, 82, 61],
            [2002, 7545, 58, 56],
            [2002, 7546, 71, 53],
            [2002, 7547, 70, 53],
            [2002, 7548, 57, 56],
            [2002, 7549, 66, 64],
            [2002, 7550, 54, 53],
            [2002, 7551, 55, 53],
            [2002, 7552, 55, 53],
            [2002, 7553, 62, 61],
            [2002, 7554, 99, 88],
            [2002, 7555, 91, 72],
            [2002, 7556, 66, 64],
            [2002, 7557, 107, 79],
            [2002, 7558, 46, 45],
            [2002, 7559, 70, 53],
            [2002, 7560, 55, 53],
            [2002, 7561, 107, 79],
            [2002, 7562, 107, 79],
            [2002, 7563, 83, 61],
            [2002, 7564, 78, 58],
            [2002, 7565, 62, 61],
            [2002, 7566, 62, 60],
            [2002, 7567, 66, 64],
            [2002, 7568, 62, 61],
            [2002, 7569, 62, 61],
            [2002, 7570, 62, 60],
            [2002, 7571, 62, 60],
            [2002, 7572, 107, 79],
            [2002, 7573, 66, 56],
            [2002, 7574, 62, 60],
            [2002, 7575, 74, 56],
            [2002, 7576, 74, 56],
            [2002, 7577, 83, 61],
            [2002, 7578, 62, 61],
            [2002, 7579, 83, 61],
            [2002, 7580, 83, 61],
            [2002, 7581, 78, 59],
            [2002, 7582, 78, 68],
            [2002, 7583, 66, 64],
            [2002, 7584, 58, 56],
            [2002, 7585, 58, 57],
            [2002, 7586, 107, 79],
            [2002, 7587, 57, 56],
            [2002, 7588, 62, 61],
            [2002, 7589, 107, 79],
            [2002, 7590, 66, 64],
            [2002, 7591, 70, 53],
            [2002, 7592, 83, 61],
            [2002, 7593, 82, 61],
            [2002, 7594, 62, 60],
            [2002, 7595, 62, 61],
            [2002, 7596, 54, 53],
            [2002, 7597, 62, 61],
            [2002, 7598, 74, 56],
            [2002, 7599, 66, 64],
            [2002, 7600, 66, 64],
            [2002, 7601, 55, 53],
            [2002, 7602, 51, 49],
            [2002, 7603, 66, 64],
            [2002, 7604, 66, 64],
            [2002, 7605, 66, 64],
            [2002, 7606, 66, 56],
            [2002, 7607, 83, 61],
            [2002, 7608, 55, 53],
            [2002, 7609, 66, 64],
            [2002, 7610, 54, 54],
            [2002, 7611, 44, 64],
            [2002, 7612, 66, 61],
            [2002, 7613, 62, 61],
            [2002, 7614, 70, 60],
            [2002, 7615, 83, 61],
            [2002, 7616, 78, 58],
            [2002, 7617, 70, 54],
            [2002, 7618, 78, 58],
            [2002, 7619, 66, 64],
            [2002, 7620, 57, 56],
            [2002, 7621, 66, 64],
            [2002, 7622, 83, 61],
            [2002, 7623, 62, 60],
            [2002, 7624, 91, 68],
            [2002, 7625, 54, 53],
            [2002, 7626, 78, 58],
            [2002, 7627, 59, 56],
            [2002, 7628, 83, 61],
            [2002, 7629, 54, 53],
            [2002, 7630, 58, 56],
            [2002, 7631, 62, 60],
            [2002, 7632, 78, 58],
            [2002, 7633, 54, 53],
            [2002, 7634, 17, 29],
            [2002, 7635, 17, 25],
            [2002, 7636, 20, 28],
            [2002, 7637, 37, 36],
            [2002, 7638, 26, 22],
            [2002, 7639, 13, 15],
            [2002, 7640, 11, 13],
            [2002, 7641, 15, 18],
            [2002, 7642, 35, 41],
            [2002, 7643, 18, 19],
            [2002, 7644, 34, 45],
            [2002, 7645, 18, 24],
            [2002, 7646, 32, 30],
            [2002, 7647, 43, 28],
            [2002, 7648, 12, 13],
            [2002, 7649, 13, 13],
            [2002, 7650, 19, 21],
            [2002, 7651, 15, 13],
            [2002, 7652, 17, 14],
            [2002, 7653, 49, 38],
            [2002, 7654, 14, 16],
            [2002, 7655, 17, 17],
            [2002, 7656, 15, 14],
            [2002, 7657, 30, 31],
            [2002, 7658, 22, 30],
            [2002, 7659, 13, 19],
            [2002, 7661, 10, 10],
            [2002, 7662, 15, 13],
            [2002, 7663, 18, 19],
            [2002, 7664, 26, 37],
            [2002, 7665, 39, 55],
            [2002, 7666, 16, 19],
            [2002, 7667, 16, 19],
            [2002, 7668, 17, 13],
            [2002, 7669, 11, 8],
            [2002, 7670, 31, 25],
            [2002, 7671, 42, 36],
            [2002, 7672, 10, 9],
            [2002, 7673, 8, 7],
            [2002, 7674, 21, 18],
            [2002, 7675, 9, 10],
            [2002, 7676, 6, 7],
            [2002, 7677, 6, 6],
            [2002, 7678, 10, 8],
            [2002, 7679, 13, 10],
            [2002, 7680, 20, 21],
            [2002, 7681, 5, 3],
            [2002, 7682, 16, 13],
            [2002, 7683, 5, 3],
            [2002, 7684, 15, 15],
            [2002, 7685, 12, 11],
            [2002, 7686, 22, 19],
            [2002, 7687, 5, 3],
            [2002, 7688, 16, 15],
            [2002, 7689, 12, 12],
            [2002, 7690, 7, 8],
            [2002, 7691, 21, 25],
            [2002, 7692, 11, 10],
            [2002, 7693, 9, 9],
            [2002, 7694, 10, 9],
            [2002, 7695, 30, 20],
            [2002, 7696, 5, 3],
            [2002, 7697, 16, 12],
            [2002, 7698, 10, 8],
            [2002, 7699, 13, 15],
            [2002, 7700, 11, 10],
            [2002, 7701, 9, 8],
            [2002, 7702, 17, 13],
            [2002, 7703, 13, 14],
            [2002, 7704, 18, 18],
            [2002, 7705, 22, 14],
            [2002, 7706, 11, 10],
            [2002, 7707, 10, 10],
            [2002, 7708, 9, 7],
            [2002, 7709, 12, 15],
            [2002, 7710, 6, 6],
            [2002, 7711, 16, 12],
            [2002, 7712, 13, 10],
            [2002, 7713, 20, 12],
            [2002, 7714, 11, 9],
            [2002, 7715, 38, 45],
            [2002, 7716, 44, 44],
            [2002, 7717, 67, 81],
            [2002, 7718, 45, 45],
            [2002, 7719, 34, 40],
            [2002, 7720, 70, 86],
            [2002, 7721, 46, 45],
            [2002, 7722, 56, 46],
            [2002, 7723, 33, 39],
            [2002, 7724, 64, 77],
            [2002, 7725, 21, 28],
            [2002, 7726, 37, 43],
            [2002, 7727, 48, 47],
            [2002, 7728, 62, 60],
            [2002, 7729, 46, 46],
            [2002, 7730, 33, 38],
            [2002, 7731, 66, 79],
            [2002, 7732, 36, 42],
            [2002, 7733, 57, 67],
            [2002, 7734, 70, 55],
            [2002, 7735, 86, 83],
            [2002, 7736, 34, 40],
            [2002, 7737, 54, 52],
            [2002, 7738, 34, 39],
            [2002, 7739, 42, 53],
            [2002, 7740, 34, 40],
            [2002, 7741, 55, 64],
            [2002, 7742, 59, 62],
            [2002, 7743, 45, 44],
            [2002, 7744, 65, 78],
            [2002, 7745, 67, 52],
            [2002, 7746, 46, 46],
            [2002, 7747, 57, 71],
            [2002, 7748, 58, 56],
            [2002, 7749, 47, 47],
            [2002, 7750, 62, 75],
            [2002, 7751, 71, 56],
            [2002, 7752, 85, 81],
            [2002, 7753, 56, 54],
            [2002, 7754, 47, 47],
            [2002, 7755, 35, 40],
            [2002, 7756, 82, 54],
            [2002, 7757, 63, 54],
            [2002, 7758, 93, 71],
            [2002, 7759, 33, 37],
            [2002, 7760, 61, 61],
            [2002, 7761, 37, 46],
            [2002, 7762, 71, 66],
            [2002, 7763, 17, 25],
            [2002, 7764, 17, 22],
            [2002, 7765, 19, 27],
            [2002, 7766, 11, 20],
            [2002, 7767, 27, 34],
            [2002, 7768, 11, 22],
            [2002, 7769, 39, 37],
            [2002, 7770, 56, 42],
            [2002, 7771, 16, 18],
            [2002, 7772, 15, 19],
            [2002, 7773, 24, 27],
            [2002, 7774, 14, 24],
            [2002, 7775, 41, 40],
            [2002, 7776, 17, 34],
            [2002, 7777, 23, 37],
            [2002, 7778, 9, 13],
            [2002, 7779, 15, 20],
            [2002, 7780, 21, 21],
            [2002, 7781, 27, 31],
            [2002, 7782, 33, 27],
            [2002, 7783, 34, 26],
            [2002, 7784, 14, 32],
            [2002, 7785, 24, 42],
            [2002, 7786, 15, 17],
            [2002, 7787, 25, 31],
            [2002, 7788, 21, 24],
            [2002, 7789, 23, 29],
            [2002, 7790, 22, 29],
            [2002, 7791, 43, 41],
            [2002, 7792, 19, 24],
            [2002, 7793, 36, 36],
            [2002, 7795, 53, 47],
            [2002, 7796, 76, 60],
            [2002, 7797, 53, 49],
            [2002, 7798, 53, 47],
            [2002, 7799, 53, 50],
            [2002, 7800, 52, 51],
            [2002, 7801, 56, 50],
            [2002, 7802, 53, 45],
            [2002, 7803, 57, 54],
            [2002, 7804, 80, 60],
            [2002, 7805, 54, 49],
            [2002, 7806, 56, 49],
            [2002, 7807, 53, 45],
            [2002, 7808, 83, 62],
            [2002, 7809, 82, 61],
            [2002, 7810, 52, 45],
            [2002, 7811, 54, 48],
            [2002, 7812, 53, 47],
            [2002, 7813, 55, 48],
            [2002, 7815, 55, 49],
            [2002, 7816, 54, 46],
            [2002, 7817, 82, 61],
            [2002, 7818, 55, 49],
            [2002, 7819, 55, 48],
            [2002, 7820, 56, 62],
            [2002, 7821, 53, 47],
            [2002, 7822, 82, 64],
            [2002, 7823, 75, 59],
            [2002, 7824, 88, 66],
            [2002, 7825, 54, 47],
            [2002, 7826, 82, 61],
            [2002, 7827, 40, 41],
            [2002, 7828, 54, 48],
            [2002, 7829, 51, 51],
            [2002, 7830, 54, 47],
            [2002, 7831, 54, 51],
            [2002, 7832, 55, 48],
            [2002, 7833, 52, 46],
            [2002, 7834, 41, 42],
            [2002, 7835, 55, 48],
            [2002, 7836, 87, 65],
            [2002, 7837, 54, 47],
            [2002, 7838, 81, 60],
            [2002, 7839, 55, 48],
            [2002, 7840, 82, 61],
            [2002, 7841, 53, 46],
            [2002, 7842, 53, 49],
            [2002, 7843, 53, 47],
            [2002, 7844, 52, 45],
            [2002, 7845, 21, 13],
            [2002, 7846, 55, 48],
            [2002, 7847, 83, 62],
            [2002, 7848, 83, 62],
            [2002, 7849, 89, 66],
            [2002, 7850, 40, 41],
            [2002, 7851, 53, 45],
            [2002, 7852, 35, 38],
            [2002, 7853, 41, 43],
            [2002, 7854, 40, 40],
            [2002, 7855, 40, 41],
            [2002, 7856, 37, 42],
            [2002, 7857, 54, 46],
            [2002, 7858, 53, 48],
            [2002, 7859, 51, 50],
            [2002, 7860, 54, 47],
            [2002, 7861, 50, 43],
            [2002, 7862, 93, 68],
            [2002, 7863, 95, 71],
            [2002, 7864, 53, 49],
            [2002, 7865, 57, 51],
            [2002, 7866, 82, 61],
            [2002, 7867, 55, 48],
            [2002, 7868, 54, 47],
            [2002, 7869, 80, 59],
            [2002, 7870, 54, 47],
            [2002, 7871, 53, 50],
            [2002, 7872, 81, 60],
            [2002, 7873, 53, 46],
            [2002, 7874, 54, 47],
            [2002, 7875, 40, 41],
            [2002, 7876, 53, 46],
            [2002, 7877, 85, 63],
            [2002, 7878, 56, 53],
            [2002, 7879, 53, 49],
            [2002, 7880, 53, 50],
            [2002, 7881, 53, 49],
            [2002, 7882, 39, 34],
            [2002, 7883, 41, 42],
            [2002, 7884, 53, 47],
            [2002, 7885, 52, 49],
            [2002, 7886, 53, 49],
            [2002, 7887, 54, 47],
            [2002, 7888, 54, 47],
            [2002, 7889, 81, 60],
            [2002, 7890, 53, 49],
            [2002, 7891, 40, 41],
            [2002, 7892, 55, 48],
            [2002, 7893, 54, 47],
            [2002, 7894, 56, 49],
            [2002, 7895, 54, 51],
            [2002, 7896, 81, 60],
            [2002, 7897, 84, 63],
            [2002, 7898, 54, 47],
            [2002, 7899, 55, 52],
            [2002, 7900, 81, 60],
            [2002, 7901, 52, 45],
            [2002, 7902, 52, 52],
            [2002, 7903, 81, 60],
            [2002, 7904, 54, 47],
            [2002, 7905, 53, 45],
            [2002, 7906, 54, 48],
            [2002, 7907, 82, 61],
            [2002, 7908, 76, 60],
            [2002, 7909, 54, 49],
            [2002, 7910, 55, 48],
            [2002, 7911, 53, 45],
            [2002, 7912, 55, 48],
            [2002, 7913, 53, 49],
            [2002, 7914, 53, 49],
            [2002, 7915, 81, 60],
            [2002, 7916, 78, 61],
            [2002, 7917, 84, 63],
            [2002, 7918, 53, 46],
            [2002, 7919, 54, 47],
            [2002, 7920, 83, 62],
            [2002, 7921, 54, 47],
            [2002, 7922, 56, 50],
            [2002, 7923, 52, 46],
            [2002, 7924, 54, 47],
            [2002, 7925, 54, 47],
            [2002, 7926, 79, 62],
            [2002, 7927, 55, 48],
            [2002, 7928, 36, 42],
            [2002, 7929, 85, 63],
            [2002, 7930, 53, 46],
            [2002, 7931, 54, 47],
            [2002, 7932, 54, 47],
            [2002, 7933, 40, 43],
            [2002, 7934, 37, 42],
            [2002, 7935, 56, 49],
            [2002, 7936, 55, 48],
            [2002, 7937, 54, 46],
            [2002, 7938, 53, 47],
            [2002, 7939, 81, 63],
            [2002, 7940, 80, 59],
            [2002, 7941, 81, 61],
            [2002, 7942, 53, 50],
            [2002, 7943, 55, 48],
            [2002, 7944, 36, 41],
            [2002, 7945, 81, 60],
            [2002, 7946, 54, 48],
            [2002, 7947, 81, 60],
            [2002, 7948, 41, 42],
            [2002, 7949, 82, 61],
            [2002, 7950, 89, 66],
            [2002, 7951, 52, 46],
            [2002, 7952, 44, 38],
            [2002, 7953, 41, 42],
            [2002, 7954, 55, 48],
            [2002, 7955, 55, 48],
            [2002, 7956, 56, 49],
            [2002, 7957, 77, 61],
            [2002, 7958, 85, 63],
            [2002, 7959, 55, 48],
            [2002, 7960, 48, 48],
            [2002, 7961, 55, 50],
            [2002, 7962, 56, 50],
            [2002, 7963, 40, 41],
            [2002, 7964, 82, 61],
            [2002, 7965, 55, 52],
            [2002, 7966, 52, 48],
            [2002, 7967, 54, 46],
            [2002, 7968, 95, 70],
            [2002, 7969, 81, 61],
            [2002, 7970, 55, 48],
            [2002, 7971, 40, 42],
            [2002, 7972, 53, 46],
            [2002, 7974, 41, 43],
            [2002, 7975, 55, 48],
            [2002, 7976, 84, 62],
            [2002, 7977, 54, 48],
            [2002, 7978, 81, 60],
            [2002, 7979, 83, 62],
            [2002, 7980, 54, 46],
            [2002, 7981, 82, 61],
            [2002, 7982, 55, 48],
            [2002, 7983, 53, 47],
            [2002, 7984, 83, 62],
            [2002, 7985, 53, 50],
            [2002, 7986, 54, 46],
            [2002, 7987, 53, 50],
            [2002, 7988, 80, 60],
            [2002, 7989, 44, 49],
            [2002, 7990, 54, 41],
            [2002, 7992, 56, 50],
            [2002, 7993, 81, 63],
            [2002, 7994, 52, 46],
            [2002, 7995, 53, 48],
            [2002, 7996, 53, 49],
            [2002, 7997, 55, 48],
            [2002, 7998, 55, 48],
            [2002, 7999, 53, 47],
            [2002, 8000, 40, 42],
            [2002, 8001, 52, 49],
            [2002, 8002, 40, 41],
            [2002, 8003, 37, 42],
            [2002, 8004, 40, 41],
            [2002, 8005, 23, 29],
            [2002, 8006, 16, 21],
            [2002, 8007, 27, 34],
            [2002, 8008, 22, 28],
            [2002, 8009, 18, 19],
            [2002, 8010, 15, 18],
            [2002, 8011, 18, 20],
            [2002, 8012, 13, 16],
            [2002, 8013, 8, 8],
            [2002, 8014, 9, 10],
            [2002, 8015, 11, 11],
            [2002, 8016, 6, 5],
            [2002, 8017, 13, 14],
            [2002, 8018, 7, 8],
            [2002, 8019, 17, 18],
            [2002, 8020, 14, 15],
            [2002, 8021, 7, 7],
            [2002, 8022, 28, 36],
            [2002, 8023, 17, 19],
            [2002, 8024, 23, 20],
            [2002, 8025, 17, 23],
            [2002, 8026, 19, 21],
            [2002, 8027, 13, 11],
            [2002, 8028, 15, 15],
            [2002, 8029, 28, 26],
            [2002, 8030, 18, 17],
            [2002, 8031, 12, 11],
            [2002, 8032, 19, 26],
            [2002, 8033, 27, 30],
            [2002, 8034, 26, 36],
            [2002, 8035, 22, 21],
            [2002, 8036, 18, 23],
            [2002, 8037, 24, 29],
            [2002, 8038, 45, 44],
            [2002, 8039, 36, 66],
            [2002, 8040, 22, 66],
            [2002, 8041, 7, 16],
            [2002, 8042, 7, 10],
            [2002, 8043, 11, 17],
            [2002, 8044, 12, 16],
            [2002, 8045, 5, 3],
            [2002, 8046, 5, 3],
            [2002, 8047, 5, 6],
            [2002, 8048, 16, 21],
            [2002, 8049, 12, 16],
            [2002, 8050, 9, 11],
            [2002, 8051, 21, 24],
            [2002, 8052, 38, 47],
            [2002, 8053, 26, 36],
            [2002, 8054, 22, 32],
            [2002, 8055, 32, 48],
            [2002, 8056, 43, 51],
            [2002, 8057, 25, 34],
            [2002, 8058, 21, 27],
            [2002, 8059, 26, 32],
            [2002, 8060, 29, 35],
            [2002, 8061, 56, 64],
            [2002, 8062, 58, 76],
            [2002, 8063, 12, 9],
            [2002, 8064, 13, 15],
            [2002, 8065, 17, 13],
            [2002, 8066, 79, 50],
            [2002, 8067, 42, 32],
            [2002, 8068, 12, 10],
            [2002, 8069, 13, 28],
            [2002, 8070, 17, 18],
            [2002, 8071, 49, 22],
            [2002, 8072, 40, 24],
            [2002, 8073, 60, 31],
            [2002, 8074, 13, 15],
            [2002, 8075, 14, 18],
            [2002, 8076, 60, 43],
            [2002, 8079, 64, 51],
            [2002, 8080, 83, 25],
            [2002, 8081, 99, 53],
            [2002, 8082, 69, 41],
            [2002, 8083, 106, 45],
            [2002, 8084, 61, 52],
            [2002, 8085, 47, 33],
            [2002, 8086, 17, 48],
            [2002, 8087, 15, 33],
            [2002, 8088, 19, 39],
            [2002, 8089, 23, 51],
            [2002, 8090, 24, 36],
            [2002, 8091, 24, 66],
            [2002, 8092, 22, 50],
            [2002, 8093, 25, 66],
            [2002, 8094, 14, 66],
            [2002, 8095, 22, 28],
            [2002, 8096, 25, 40],
            [2002, 8097, 21, 35],
            [2002, 8098, 9, 27],
            [2002, 8099, 45, 45],
            [2002, 8100, 44, 44],
            [2002, 8101, 45, 45],
            [2002, 8102, 34, 39],
            [2002, 8103, 46, 45],
            [2002, 8104, 45, 44],
            [2002, 8105, 72, 57],
            [2002, 8106, 47, 47],
            [2002, 8107, 34, 40],
            [2002, 8108, 54, 52],
            [2002, 8109, 46, 46],
            [2002, 8110, 34, 40],
            [2002, 8111, 53, 50],
            [2002, 8112, 45, 44],
            [2002, 8113, 72, 57],
            [2002, 8114, 34, 39],
            [2002, 8115, 70, 87],
            [2002, 8116, 47, 47],
            [2002, 8117, 55, 81],
            [2002, 8118, 35, 41],
            [2002, 8119, 46, 46],
            [2002, 8120, 53, 51],
            [2002, 8121, 35, 40],
            [2002, 8122, 45, 45],
            [2002, 8123, 73, 58],
            [2002, 8124, 46, 47],
            [2002, 8125, 73, 58],
            [2002, 8126, 41, 42],
            [2002, 8127, 47, 47],
            [2002, 8128, 90, 87],
            [2002, 8129, 45, 45],
            [2002, 8130, 73, 57],
            [2002, 8131, 33, 39],
            [2002, 8132, 55, 52],
            [2002, 8133, 35, 41],
            [2002, 8134, 56, 53],
            [2002, 8135, 73, 57],
            [2002, 8136, 27, 33],
            [2002, 8137, 45, 46],
            [2002, 8138, 47, 48],
            [2002, 8139, 64, 74],
            [2002, 8140, 54, 67],
            [2002, 8141, 44, 44],
            [2002, 8142, 45, 45],
            [2002, 8143, 69, 85],
            [2002, 8144, 31, 37],
            [2002, 8145, 34, 39],
            [2002, 8146, 53, 62],
            [2002, 8147, 44, 44],
            [2002, 8148, 46, 46],
            [2002, 8149, 35, 41],
            [2002, 8150, 73, 90],
            [2002, 8151, 33, 39],
            [2002, 8152, 62, 77],
            [2002, 8153, 45, 46],
            [2002, 8154, 44, 44],
            [2002, 8155, 67, 53],
            [2002, 8156, 79, 101],
            [2002, 8157, 47, 47],
            [2002, 8158, 45, 45],
            [2002, 8159, 42, 42],
            [2002, 8160, 45, 45],
            [2002, 8161, 73, 58],
            [2002, 8162, 75, 59],
            [2002, 8163, 56, 49],
            [2002, 8164, 44, 44],
            [2002, 8165, 47, 46],
            [2002, 8166, 86, 65],
            [2002, 8167, 73, 58],
            [2002, 8168, 45, 46],
            [2002, 8169, 55, 50],
            [2002, 8170, 46, 46],
            [2002, 8171, 45, 46],
            [2002, 8172, 86, 64],
            [2002, 8173, 45, 45],
            [2002, 8174, 46, 45],
            [2002, 8175, 35, 40],
            [2002, 8176, 34, 39],
            [2002, 8177, 36, 42],
            [2002, 8178, 47, 47],
            [2002, 8179, 53, 51],
            [2002, 8180, 45, 44],
            [2002, 8181, 85, 64],
            [2002, 8182, 73, 57],
            [2002, 8183, 48, 47],
            [2002, 8184, 44, 44],
            [2002, 8185, 44, 45],
            [2002, 8186, 47, 46],
            [2002, 8187, 36, 41],
            [2002, 8188, 27, 33],
            [2002, 8189, 54, 51],
            [2002, 8190, 34, 39],
            [2002, 8191, 71, 71],
            [2002, 8192, 47, 47],
            [2002, 8193, 84, 63],
            [2002, 8194, 44, 44],
            [2002, 8195, 46, 45],
            [2002, 8196, 36, 41],
            [2002, 8197, 48, 47],
            [2002, 8198, 36, 41],
            [2002, 8199, 66, 80],
            [2002, 8200, 34, 40],
            [2002, 8201, 87, 66],
            [2002, 8202, 58, 58],
            [2002, 8203, 81, 57],
            [2002, 8204, 72, 57],
            [2002, 8205, 32, 37],
            [2002, 8206, 58, 57],
            [2002, 8207, 45, 45],
            [2002, 8208, 34, 39],
            [2002, 8209, 87, 66],
            [2002, 8210, 47, 47],
            [2002, 8211, 69, 85],
            [2002, 8212, 34, 39],
            [2002, 8213, 46, 46],
            [2002, 8214, 67, 82],
            [2002, 8215, 46, 45],
            [2002, 8216, 45, 45],
            [2002, 8217, 47, 47],
            [2002, 8218, 21, 29],
            [2002, 8219, 58, 56],
            [2002, 8220, 33, 39],
            [2002, 8221, 54, 51],
            [2002, 8222, 29, 34],
            [2002, 8223, 34, 39],
            [2002, 8224, 52, 61],
            [2002, 8225, 39, 46],
            [2002, 8226, 69, 84],
            [2002, 8227, 45, 45],
            [2002, 8228, 32, 37],
            [2002, 8229, 44, 44],
            [2002, 8230, 46, 46],
            [2002, 8231, 28, 33],
            [2002, 8232, 63, 62],
            [2002, 8233, 45, 45],
            [2002, 8234, 32, 37],
            [2002, 8235, 67, 81],
            [2002, 8236, 34, 40],
            [2002, 8237, 62, 59],
            [2002, 8238, 45, 44],
            [2002, 8239, 99, 75],
            [2002, 8240, 46, 45],
            [2002, 8241, 35, 41],
            [2002, 8242, 56, 54],
            [2002, 8245, 46, 46],
            [2002, 8246, 48, 47],
            [2002, 8247, 72, 57],
            [2002, 8248, 28, 34],
            [2002, 8249, 55, 52],
            [2002, 8250, 44, 44],
            [2002, 8251, 46, 45],
            [2002, 8252, 53, 51],
            [2002, 8253, 71, 56],
            [2002, 8254, 39, 47],
            [2002, 8255, 45, 44],
            [2002, 8256, 35, 40],
            [2002, 8257, 67, 81],
            [2002, 8258, 45, 45],
            [2002, 8259, 45, 44],
            [2002, 8260, 47, 47],
            [2002, 8261, 66, 79],
            [2002, 8262, 57, 57],
            [2002, 8263, 80, 61],
            [2002, 8264, 37, 44],
            [2002, 8265, 57, 86],
            [2002, 8267, 71, 56],
            [2002, 8268, 46, 45],
            [2002, 8269, 45, 45],
            [2002, 8270, 27, 33],
            [2002, 8271, 35, 41],
            [2002, 8272, 54, 51],
            [2002, 8273, 45, 45],
            [2002, 8274, 45, 44],
            [2002, 8275, 36, 42],
            [2002, 8276, 45, 44],
            [2002, 8277, 42, 30],
            [2002, 8278, 73, 57],
            [2002, 8279, 45, 45],
            [2002, 8280, 48, 47],
            [2002, 8281, 45, 45],
            [2002, 8282, 48, 47],
            [2002, 8283, 47, 46],
            [2002, 8284, 46, 45],
            [2002, 8285, 48, 47],
            [2002, 8286, 48, 47],
            [2002, 8287, 47, 47],
            [2002, 8288, 35, 41],
            [2002, 8289, 55, 52],
            [2002, 8290, 47, 47],
            [2002, 8291, 48, 47],
            [2002, 8292, 46, 46],
            [2002, 8293, 45, 44],
            [2002, 8294, 45, 45],
            [2002, 8295, 72, 57],
            [2002, 8296, 72, 47],
            [2002, 8297, 46, 46],
            [2002, 8298, 29, 53],
            [2002, 8299, 28, 34],
            [2002, 8300, 86, 65],
            [2002, 8301, 47, 47],
            [2002, 8302, 45, 44],
            [2002, 8303, 73, 58],
            [2002, 8304, 45, 44],
            [2002, 8305, 71, 56],
            [2002, 8306, 36, 41],
            [2002, 8307, 27, 33],
            [2002, 8308, 45, 44],
            [2002, 8309, 20, 26],
            [2002, 8310, 54, 52],
            [2002, 8311, 18, 22],
            [2002, 8312, 17, 19],
            [2002, 8313, 16, 19],
            [2002, 8314, 19, 22],
            [2002, 8315, 17, 19],
            [2002, 8316, 16, 18],
            [2002, 8317, 50, 50],
            [2002, 8318, 78, 59],
            [2002, 8319, 27, 30],
            [2002, 8320, 73, 58],
            [2002, 8321, 47, 36],
            [2002, 8322, 47, 46],
            [2002, 8323, 35, 41],
            [2002, 8324, 82, 61],
            [2002, 8325, 77, 60],
            [2002, 8326, 72, 57],
            [2002, 8327, 70, 56],
            [2002, 8328, 74, 59],
            [2002, 8329, 45, 45],
            [2002, 8330, 74, 59],
            [2002, 8331, 71, 56],
            [2002, 8332, 72, 57],
            [2002, 8333, 24, 31],
            [2002, 8334, 20, 27],
            [2002, 8335, 16, 26],
            [2002, 8336, 23, 19],
            [2002, 8337, 14, 18],
            [2002, 8338, 13, 14],
            [2002, 8339, 44, 45],
            [2002, 8340, 16, 19],
            [2002, 8341, 31, 35],
            [2002, 8342, 17, 17],
            [2002, 8343, 19, 20],
            [2002, 8344, 15, 14],
            [2002, 8345, 20, 16],
            [2002, 8346, 20, 28],
            [2002, 8347, 17, 20],
            [2002, 8348, 24, 31],
            [2002, 8349, 16, 19],
            [2002, 8350, 18, 20],
            [2002, 8351, 15, 11],
            [2002, 8352, 21, 31],
            [2002, 8353, 16, 19],
            [2002, 8354, 25, 31],
            [2002, 8355, 17, 18],
            [2002, 8356, 25, 31],
            [2002, 8357, 17, 17],
            [2002, 8358, 25, 19],
            [2002, 8359, 35, 44],
            [2002, 8360, 37, 44],
            [2002, 8361, 17, 15],
            [2002, 8362, 19, 27],
            [2002, 8363, 25, 34],
            [2002, 8364, 30, 26],
            [2002, 8365, 13, 15],
            [2002, 8366, 25, 22],
            [2002, 8367, 16, 17],
            [2002, 8368, 19, 27],
            [2002, 8369, 20, 27],
            [2002, 8370, 21, 23],
            [2002, 8371, 21, 21],
            [2002, 8372, 26, 22],
            [2002, 8373, 26, 32],
            [2002, 8374, 24, 33],
            [2002, 8375, 17, 15],
            [2002, 8376, 29, 31],
            [2002, 8377, 22, 18],
            [2002, 8378, 23, 19],
            [2002, 8379, 27, 24],
            [2002, 8380, 31, 31],
            [2002, 8381, 28, 36],
            [2002, 8382, 21, 24],
            [2002, 8383, 26, 31],
            [2002, 8384, 24, 37],
            [2002, 8385, 22, 28],
            [2002, 8386, 16, 19],
            [2002, 8387, 26, 27],
            [2002, 8388, 18, 19],
            [2002, 8389, 18, 21],
            [2002, 8390, 15, 17],
            [2002, 8391, 18, 22],
            [2002, 8392, 21, 24],
            [2002, 8393, 40, 55],
            [2002, 8394, 27, 21],
            [2002, 8395, 21, 23],
            [2002, 8396, 56, 52],
            [2002, 8397, 82, 61],
            [2002, 8398, 56, 43],
            [2002, 8399, 76, 48],
            [2002, 8400, 66, 60],
            [2002, 8401, 77, 47],
            [2002, 8402, 59, 48],
            [2002, 8403, 68, 46],
            [2002, 8404, 52, 49],
            [2002, 8405, 69, 46],
            [2002, 8406, 58, 48],
            [2002, 8407, 56, 54],
            [2002, 8408, 52, 59],
            [2002, 8409, 39, 34],
            [2002, 8410, 66, 51],
            [2002, 8411, 86, 61],
            [2002, 8412, 54, 52],
            [2002, 8413, 68, 54],
            [2002, 8414, 93, 46],
            [2002, 8415, 102, 66],
            [2002, 8416, 37, 38],
            [2002, 8417, 73, 49],
            [2002, 8418, 28, 32],
            [2002, 8419, 63, 46],
            [2002, 8420, 72, 55],
            [2002, 8421, 80, 60],
            [2002, 8422, 36, 39],
            [2002, 8423, 59, 57],
            [2002, 8424, 76, 81],
            [2002, 8425, 44, 57],
            [2002, 8426, 50, 46],
            [2002, 8427, 52, 44],
            [2002, 8428, 59, 48],
            [2002, 8429, 36, 35],
            [2002, 8430, 59, 57],
            [2002, 8431, 78, 59],
            [2002, 8432, 61, 57],
            [2002, 8433, 58, 55],
            [2002, 8434, 76, 50],
            [2002, 8435, 117, 58],
            [2002, 8436, 82, 61],
            [2002, 8438, 40, 35],
            [2002, 8439, 45, 42],
            [2002, 8440, 94, 57],
            [2002, 8441, 79, 50],
            [2002, 8442, 51, 49],
            [2002, 8443, 67, 60],
            [2002, 8444, 59, 57],
            [2002, 8445, 33, 31],
            [2002, 8446, 44, 38],
            [2002, 8447, 65, 53],
            [2002, 8448, 53, 48],
            [2002, 8449, 103, 44],
            [2002, 8450, 82, 56],
            [2002, 8451, 22, 31],
            [2002, 8452, 30, 43],
            [2002, 8453, 20, 27],
            [2002, 8454, 30, 39],
            [2002, 8455, 24, 31],
            [2002, 8456, 24, 31],
            [2002, 8457, 59, 57],
            [2002, 8458, 48, 39],
            [2002, 8459, 68, 48],
            [2002, 8460, 54, 50],
            [2002, 8461, 84, 48],
            [2002, 8462, 73, 50],
            [2002, 8463, 72, 59],
            [2002, 8464, 81, 60],
            [2002, 8465, 39, 30],
            [2002, 8466, 42, 51],
            [2002, 8467, 47, 43],
            [2002, 8468, 63, 53],
            [2002, 8469, 54, 48],
            [2002, 8470, 81, 62],
            [2002, 8471, 39, 46],
            [2002, 8472, 89, 45],
            [2002, 8473, 66, 60],
            [2002, 8474, 52, 49],
            [2002, 8475, 76, 58],
            [2002, 8476, 77, 59],
            [2002, 8477, 77, 58],
            [2002, 8478, 33, 36],
            [2002, 8479, 52, 49],
            [2002, 8480, 81, 61],
            [2002, 8481, 56, 47],
            [2002, 8482, 56, 47],
            [2002, 8483, 57, 48],
            [2002, 8484, 68, 52],
            [2002, 8485, 74, 61],
            [2002, 8486, 37, 32],
            [2002, 8487, 65, 48],
            [2002, 8488, 51, 46],
            [2002, 8489, 36, 59],
            [2002, 8490, 68, 53],
            [2002, 8491, 58, 58],
            [2002, 8492, 60, 47],
            [2002, 8493, 75, 47],
            [2002, 8494, 36, 31],
            [2002, 8495, 83, 85],
            [2002, 8496, 36, 48],
            [2002, 8497, 60, 63],
            [2002, 8498, 42, 48],
            [2002, 8499, 53, 47],
            [2002, 8500, 78, 50],
            [2002, 8501, 59, 70],
            [2002, 8502, 81, 49],
            [2002, 8503, 78, 59],
            [2002, 8504, 53, 51],
            [2002, 8505, 79, 60],
            [2002, 8506, 81, 61],
            [2002, 8507, 81, 61],
            [2002, 8508, 43, 44],
            [2002, 8509, 52, 48],
            [2002, 8510, 84, 59],
            [2002, 8511, 74, 57],
            [2002, 8512, 59, 57],
            [2002, 8513, 61, 58],
            [2002, 8514, 67, 66],
            [2002, 8515, 54, 52],
            [2002, 8516, 138, 77],
            [2002, 8517, 70, 29],
            [2002, 8518, 83, 77],
            [2002, 8519, 42, 39],
            [2002, 8520, 57, 47],
            [2002, 8521, 51, 47],
            [2002, 8522, 54, 50],
            [2002, 8523, 52, 48],
            [2002, 8524, 51, 46],
            [2002, 8525, 67, 48],
            [2002, 8526, 77, 58],
            [2002, 8527, 69, 69],
            [2002, 8528, 79, 65],
            [2002, 8529, 86, 65],
            [2002, 8530, 40, 38],
            [2002, 8531, 81, 76],
            [2002, 8532, 68, 69],
            [2002, 8533, 81, 75],
            [2002, 8534, 57, 56],
            [2002, 8535, 77, 78],
            [2002, 8536, 22, 45],
            [2002, 8537, 55, 36],
            [2002, 8538, 54, 36],
            [2002, 8539, 47, 40],
            [2002, 8540, 38, 61],
            [2002, 8541, 48, 70],
            [2002, 8542, 43, 65],
            [2002, 8543, 26, 62],
            [2002, 8544, 32, 73],
            [2002, 8546, 35, 62],
            [2002, 8547, 38, 72],
            [2002, 8548, 15, 21],
            [2002, 8549, 25, 33],
            [2002, 8550, 20, 31],
            [2002, 8551, 37, 31],
            [2002, 8552, 33, 41],
            [2002, 8553, 48, 65],
            [2002, 8554, 23, 21],
            [2002, 8555, 40, 38],
            [2002, 8556, 45, 64],
            [2002, 8557, 63, 62],
            [2002, 8558, 31, 34],
            [2002, 8559, 40, 39],
            [2002, 8560, 32, 38],
            [2002, 8561, 25, 31],
            [2002, 8562, 38, 38],
            [2002, 8563, 47, 52],
            [2002, 8564, 92, 74],
            [2002, 8565, 10, 12],
            [2002, 8566, 16, 14],
            [2002, 8567, 23, 22],
            [2002, 8568, 17, 16],
            [2002, 8569, 18, 16],
            [2002, 8570, 10, 10],
            [2002, 8571, 14, 11],
            [2002, 8572, 14, 11],
            [2002, 8573, 12, 11],
            [2002, 8574, 15, 13],
            [2002, 8575, 10, 10],
            [2002, 8576, 22, 16],
            [2002, 8577, 18, 17],
            [2002, 8578, 24, 24],
            [2002, 8579, 19, 21],
            [2002, 8580, 17, 17],
            [2002, 8581, 12, 10],
            [2002, 8582, 18, 17],
            [2002, 8583, 19, 19],
            [2002, 8584, 15, 14],
            [2002, 8585, 12, 12],
            [2002, 8586, 33, 19],
            [2002, 8587, 10, 9],
            [2002, 8588, 39, 17],
            [2002, 8589, 14, 13],
            [2002, 8590, 23, 16],
            [2002, 8591, 20, 16],
            [2002, 8592, 32, 32],
            [2002, 8593, 27, 26],
            [2002, 8594, 41, 27],
            [2002, 8595, 14, 14],
            [2002, 8596, 18, 15],
            [2002, 8597, 21, 21],
            [2002, 8598, 28, 21],
            [2002, 8599, 15, 12],
            [2002, 8600, 23, 16],
            [2002, 8601, 31, 23],
            [2002, 8602, 31, 21],
            [2002, 8603, 25, 16],
            [2002, 8604, 42, 22],
            [2002, 8605, 25, 24],
            [2002, 8606, 42, 25],
            [2002, 8607, 19, 25],
            [2002, 8608, 30, 28],
            [2002, 8609, 28, 21],
            [2002, 8610, 25, 25],
            [2002, 8611, 27, 19],
            [2002, 8612, 38, 23],
            [2002, 8613, 15, 12],
            [2002, 8614, 28, 19],
            [2002, 8615, 12, 12],
            [2002, 8616, 32, 22],
            [2002, 8617, 33, 16],
            [2002, 8618, 20, 13],
            [2002, 8619, 36, 25],
            [2002, 8622, 60, 31],
            [2002, 8623, 61, 32],
            [2002, 8624, 19, 20],
            [2002, 8625, 49, 30],
            [2002, 8626, 25, 18],
            [2002, 8627, 39, 22],
            [2002, 8628, 35, 26],
            [2002, 8629, 34, 28],
            [2002, 8630, 23, 17],
            [2002, 8631, 30, 22],
            [2002, 8632, 23, 17],
            [2002, 8633, 26, 20],
            [2002, 8634, 15, 14],
            [2002, 8635, 27, 15],
            [2002, 8636, 12, 9],
            [2002, 8637, 22, 15],
            [2002, 8638, 16, 13],
            [2002, 8639, 20, 13],
            [2002, 8640, 25, 19],
            [2002, 8641, 45, 21],
            [2002, 8642, 28, 23],
            [2002, 8643, 31, 27],
            [2002, 8644, 48, 28],
            [2002, 8645, 24, 21],
            [2002, 8646, 28, 22],
            [2002, 8647, 20, 15],
            [2002, 8648, 20, 15],
            [2002, 8649, 25, 22],
            [2002, 8650, 35, 18],
            [2002, 8651, 34, 23],
            [2002, 8652, 47, 33],
            [2002, 8653, 30, 27],
            [2002, 8654, 65, 32],
            [2002, 8655, 23, 23],
            [2002, 8656, 24, 20],
            [2002, 8657, 9, 12],
            [2002, 8658, 22, 18],
            [2002, 8659, 34, 23],
            [2002, 8660, 15, 12],
            [2002, 8661, 18, 13],
            [2002, 8662, 22, 14],
            [2002, 8663, 24, 15],
            [2002, 8664, 30, 21],
            [2002, 8665, 46, 33],
            [2002, 8666, 20, 19],
            [2002, 8667, 23, 21],
            [2002, 8668, 20, 26],
            [2002, 8669, 41, 37],
            [2002, 8670, 19, 22],
            [2002, 8671, 29, 30],
            [2002, 8672, 16, 20],
            [2002, 8673, 27, 26],
            [2002, 8674, 27, 18],
            [2002, 8675, 55, 24],
            [2002, 8676, 44, 30],
            [2002, 8677, 51, 31],
            [2002, 8678, 40, 22],
            [2002, 8679, 47, 21],
            [2002, 8680, 26, 20],
            [2002, 8681, 38, 25],
            [2002, 8682, 42, 23],
            [2002, 8683, 38, 14],
            [2002, 8684, 30, 23],
            [2002, 8685, 22, 20],
            [2002, 8686, 31, 19],
            [2002, 8687, 28, 19],
            [2002, 8688, 42, 26],
            [2002, 8689, 35, 24],
            [2002, 8690, 45, 25],
            [2002, 8691, 25, 27],
            [2002, 8692, 47, 29],
            [2002, 8693, 38, 14],
            [2002, 8694, 44, 24],
            [2002, 8695, 15, 16],
            [2002, 8696, 22, 20],
            [2002, 8697, 20, 16],
            [2002, 8698, 37, 18],
            [2002, 8699, 32, 18],
            [2002, 8700, 34, 18],
            [2002, 8701, 29, 16],
            [2002, 8702, 30, 19],
            [2002, 8703, 26, 23],
            [2002, 8704, 34, 27],
            [2002, 8705, 30, 19],
            [2002, 8706, 38, 21],
            [2002, 8707, 23, 23],
            [2002, 8708, 33, 26],
            [2002, 8709, 40, 21],
            [2002, 8710, 35, 22],
            [2002, 8711, 18, 12],
            [2002, 8712, 24, 22],
            [2002, 8713, 36, 23],
            [2002, 8714, 7, 6],
            [2002, 8715, 8, 7],
            [2002, 8716, 8, 8],
            [2002, 8717, 13, 12],
            [2002, 8718, 9, 8],
            [2002, 8719, 22, 24],
            [2002, 8720, 28, 31],
            [2002, 8721, 28, 31],
            [2002, 8722, 27, 24],
            [2002, 8723, 29, 27],
            [2002, 8724, 27, 26],
            [2002, 8725, 24, 20],
            [2002, 8726, 27, 22],
            [2002, 8727, 23, 24],
            [2002, 8728, 21, 22],
            [2002, 8729, 26, 21],
            [2002, 8730, 20, 17],
            [2002, 8731, 21, 20],
            [2002, 8732, 27, 20],
            [2002, 8733, 28, 21],
            [2002, 8734, 23, 19],
            [2002, 8735, 21, 17],
            [2002, 8736, 21, 21],
            [2002, 8737, 21, 18],
            [2002, 8738, 22, 19],
            [2002, 8739, 22, 20],
            [2002, 8740, 22, 19],
            [2002, 8741, 27, 20],
            [2002, 8742, 24, 21],
            [2002, 8743, 24, 20],
            [2002, 8744, 25, 21],
            [2002, 8745, 28, 19],
            [2002, 8746, 30, 23],
            [2002, 8747, 30, 23],
            [2002, 8748, 31, 25],
            [2002, 8749, 25, 20],
            [2002, 8750, 23, 26],
            [2002, 8751, 24, 26],
            [2002, 8752, 19, 17],
            [2002, 8753, 20, 18],
            [2002, 8754, 20, 22],
            [2002, 8755, 21, 19],
            [2002, 8756, 32, 24],
            [2002, 8757, 20, 18],
            [2002, 8758, 20, 20],
            [2002, 8759, 24, 23],
            [2002, 8760, 32, 34],
            [2002, 8761, 24, 20],
            [2002, 8762, 31, 21],
            [2002, 8763, 18, 17],
            [2002, 8764, 33, 26],
            [2002, 8765, 28, 19],
            [2002, 8766, 27, 21],
            [2002, 8767, 33, 25],
            [2002, 8768, 32, 25],
            [2002, 8769, 21, 21],
            [2002, 8770, 33, 26],
            [2002, 8771, 32, 27],
            [2002, 8772, 33, 26],
            [2002, 8773, 19, 17],
            [2002, 8774, 20, 20],
            [2002, 8775, 21, 18],
            [2002, 8776, 20, 19],
            [2002, 8777, 25, 20],
            [2002, 8778, 34, 26],
            [2002, 8779, 9, 14],
            [2002, 8780, 14, 11],
            [2002, 8781, 15, 11],
            [2002, 8782, 17, 11],
            [2002, 8783, 10, 8],
            [2002, 8784, 14, 10],
            [2002, 8785, 8, 7],
            [2002, 8786, 9, 11],
            [2002, 8787, 12, 12],
            [2002, 8788, 14, 10],
            [2002, 8790, 8, 7],
            [2002, 8791, 6, 6],
            [2002, 8792, 13, 11],
            [2002, 8793, 8, 8],
            [2002, 8794, 8, 7],
            [2002, 8795, 9, 8],
            [2002, 8796, 14, 10],
            [2002, 8797, 16, 11],
            [2002, 8798, 9, 9],
            [2002, 8799, 11, 9],
            [2002, 8800, 10, 8],
            [2002, 8801, 12, 10],
            [2002, 8802, 7, 7],
            [2002, 8803, 8, 9],
            [2002, 8804, 7, 10],
            [2002, 8805, 9, 9],
            [2002, 8806, 10, 11],
            [2002, 8807, 15, 14],
            [2002, 8808, 8, 7],
            [2002, 8809, 6, 7],
            [2002, 8810, 12, 11],
            [2002, 8811, 7, 9],
            [2002, 8812, 12, 10],
            [2002, 8814, 6, 6],
            [2002, 8815, 9, 8],
            [2002, 8816, 12, 8],
            [2002, 8817, 18, 10],
            [2002, 8818, 51, 42],
            [2002, 8819, 37, 23],
            [2002, 8820, 56, 47],
            [2002, 8821, 45, 31],
            [2002, 8822, 58, 48],
            [2002, 8823, 32, 27],
            [2002, 8824, 23, 19],
            [2002, 8825, 36, 31],
            [2002, 8826, 23, 22],
            [2002, 8827, 40, 31],
            [2002, 8828, 41, 34],
            [2002, 8829, 44, 35],
            [2002, 8830, 29, 31],
            [2002, 8831, 35, 30],
            [2002, 8832, 19, 11],
            [2002, 8833, 34, 29],
            [2002, 8834, 38, 33],
            [2002, 8835, 34, 20],
            [2002, 8836, 49, 40],
            [2002, 8837, 33, 20],
            [2002, 8838, 43, 38],
            [2002, 8839, 27, 13],
            [2002, 8840, 39, 26],
            [2002, 8841, 27, 13],
            [2002, 8842, 16, 21],
            [2002, 8843, 20, 12],
            [2002, 8844, 28, 23],
            [2002, 8845, 15, 18],
            [2002, 8846, 35, 30],
            [2002, 8847, 19, 21],
            [2002, 8848, 50, 41],
            [2002, 8849, 30, 24],
            [2002, 8850, 39, 34],
            [2002, 8851, 24, 25],
            [2002, 8852, 36, 27],
            [2002, 8853, 14, 18],
            [2002, 8854, 36, 31],
            [2002, 8855, 21, 11],
            [2002, 8856, 32, 27],
            [2002, 8857, 24, 13],
            [2002, 8858, 30, 14],
            [2002, 8859, 47, 41],
            [2002, 8860, 32, 12],
            [2002, 8861, 36, 30],
            [2002, 8862, 27, 22],
            [2002, 8863, 40, 35],
            [2002, 8864, 21, 22],
            [2002, 8865, 32, 27],
            [2002, 8866, 21, 22],
            [2002, 8867, 54, 48],
            [2002, 8868, 40, 34],
            [2002, 8869, 52, 47],
            [2002, 8870, 48, 38],
            [2002, 8871, 38, 32],
            [2002, 8872, 28, 25],
            [2002, 8873, 41, 35],
            [2002, 8874, 35, 29],
            [2002, 8875, 36, 30],
            [2002, 8876, 20, 17],
            [2002, 8877, 44, 38],
            [2002, 8878, 18, 11],
            [2002, 8879, 31, 26],
            [2002, 8880, 32, 27],
            [2002, 8881, 54, 45],
            [2002, 8882, 31, 27],
            [2002, 8883, 51, 46],
            [2002, 8884, 19, 17],
            [2002, 8885, 63, 41],
            [2002, 8886, 35, 30],
            [2002, 8887, 20, 12],
            [2002, 8888, 32, 23],
            [2002, 8889, 48, 38],
            [2002, 8890, 14, 17],
            [2002, 8891, 36, 30],
            [2002, 8892, 14, 11],
            [2002, 8893, 36, 32],
            [2002, 8894, 19, 19],
            [2002, 8895, 15, 11],
            [2002, 8896, 28, 22],
            [2002, 8897, 15, 11],
            [2002, 8898, 21, 19],
            [2002, 8899, 51, 45],
            [2002, 8900, 38, 32],
            [2002, 8901, 50, 31],
            [2002, 8902, 36, 31],
            [2002, 8903, 26, 17],
            [2002, 8904, 36, 30],
            [2002, 8905, 25, 16],
            [2002, 8906, 32, 26],
            [2002, 8907, 22, 20],
            [2002, 8908, 32, 27],
            [2002, 8909, 23, 20],
            [2002, 8910, 24, 13],
            [2002, 8911, 24, 13],
            [2002, 8912, 44, 39],
            [2002, 8913, 29, 25],
            [2002, 8914, 42, 37],
            [2002, 8915, 29, 25],
            [2002, 8916, 50, 41],
            [2002, 8917, 37, 24],
            [2002, 8918, 47, 41],
            [2002, 8919, 34, 32],
            [2002, 8920, 36, 33],
            [2002, 8921, 36, 34],
            [2002, 8922, 32, 26],
            [2002, 8923, 25, 20],
            [2002, 8924, 15, 14],
            [2002, 8925, 11, 11],
            [2002, 8926, 15, 13],
            [2002, 8927, 17, 16],
            [2002, 8928, 14, 13],
            [2002, 8929, 11, 10],
            [2002, 8930, 9, 11],
            [2002, 8931, 14, 15],
            [2002, 8932, 19, 20],
            [2002, 8933, 26, 25],
            [2002, 8934, 28, 27],
            [2002, 8935, 51, 41],
            [2002, 8936, 27, 20],
            [2002, 8937, 35, 30],
            [2002, 8938, 27, 20],
            [2002, 8939, 32, 27],
            [2002, 8940, 19, 17],
            [2002, 8941, 31, 26],
            [2002, 8942, 19, 17],
            [2002, 8943, 29, 20],
            [2002, 8944, 32, 27],
            [2002, 8945, 24, 14],
            [2002, 8946, 32, 27],
            [2002, 8947, 23, 14],
            [2002, 8948, 32, 27],
            [2002, 8949, 23, 14],
            [2002, 8950, 24, 20],
            [2002, 8951, 32, 27],
            [2002, 8952, 24, 20],
            [2002, 8953, 51, 46],
            [2002, 8954, 28, 20],
            [2002, 8955, 44, 39],
            [2002, 8956, 30, 26],
            [2002, 8957, 28, 20],
            [2002, 8958, 52, 43],
            [2002, 8959, 29, 21],
            [2002, 8960, 51, 42],
            [2002, 8961, 29, 20],
            [2002, 8962, 47, 42],
            [2002, 8963, 32, 30],
            [2002, 8964, 20, 12],
            [2002, 8965, 46, 41],
            [2002, 8966, 39, 31],
            [2002, 8967, 43, 34],
            [2002, 8968, 32, 26],
            [2002, 8969, 20, 13],
            [2002, 8970, 43, 37],
            [2002, 8971, 44, 35],
            [2002, 8972, 19, 13],
            [2002, 8973, 44, 35],
            [2002, 8974, 14, 20],
            [2002, 8975, 49, 40],
            [2002, 8976, 53, 47],
            [2002, 8977, 28, 22],
            [2002, 8978, 14, 11],
            [2002, 8979, 40, 35],
            [2002, 8980, 32, 27],
            [2002, 8981, 31, 26],
            [2002, 8983, 36, 30],
            [2002, 8984, 25, 21],
            [2002, 8985, 36, 31],
            [2002, 8986, 25, 21],
            [2002, 8987, 28, 27],
            [2002, 8988, 19, 12],
            [2002, 8989, 36, 31],
            [2002, 8990, 19, 12],
            [2002, 8991, 35, 30],
            [2002, 8992, 19, 12],
            [2002, 8993, 37, 27],
            [2002, 8994, 40, 28],
            [2002, 8995, 40, 29],
            [2002, 8996, 50, 41],
            [2002, 8997, 23, 14],
            [2002, 8998, 28, 23],
            [2002, 8999, 20, 11],
            [2002, 9000, 56, 46],
            [2002, 9001, 48, 31],
            [2002, 9002, 42, 33],
            [2002, 9003, 25, 22],
            [2002, 9004, 51, 42],
            [2002, 9005, 23, 19],
            [2002, 9006, 36, 31],
            [2002, 9007, 29, 20],
            [2002, 9008, 40, 26],
            [2002, 9009, 34, 26],
            [2002, 9010, 28, 23],
            [2002, 9011, 20, 11],
            [2002, 9012, 28, 27],
            [2002, 9013, 14, 14],
            [2002, 9014, 42, 33],
            [2002, 9015, 21, 16],
            [2002, 9016, 20, 15],
            [2002, 9017, 44, 35],
            [2002, 9018, 28, 30],
            [2002, 9019, 33, 32],
            [2002, 9020, 19, 23],
            [2002, 9021, 36, 31],
            [2002, 9022, 25, 26],
            [2002, 9023, 35, 28],
            [2002, 9024, 42, 33],
            [2002, 9025, 32, 27],
            [2002, 9026, 36, 19],
            [2002, 9027, 30, 18],
            [2002, 9028, 42, 33],
            [2002, 9030, 46, 33],
            [2002, 9031, 38, 29],
            [2002, 9032, 46, 33],
            [2002, 9033, 32, 30],
            [2002, 9034, 50, 41],
            [2002, 9035, 42, 37],
            [2002, 9036, 39, 34],
            [2002, 9037, 17, 14],
            [2002, 9038, 28, 28],
            [2002, 9039, 15, 21],
            [2002, 9040, 39, 33],
            [2002, 9041, 26, 22],
            [2002, 9042, 43, 34],
            [2002, 9043, 35, 30],
            [2002, 9044, 28, 14],
            [2002, 9045, 36, 27],
            [2002, 9046, 30, 22],
            [2002, 9047, 38, 29],
            [2002, 9048, 33, 23],
            [2002, 9049, 62, 38],
            [2002, 9050, 31, 22],
            [2002, 9051, 44, 35],
            [2002, 9052, 21, 18],
            [2002, 9053, 29, 21],
            [2002, 9054, 32, 23],
            [2002, 9055, 25, 13],
            [2002, 9056, 36, 24],
            [2002, 9057, 47, 31],
            [2002, 9058, 29, 20],
            [2002, 9059, 51, 35],
            [2002, 9060, 45, 31],
            [2002, 9061, 24, 19],
            [2002, 9062, 14, 14],
            [2002, 9063, 36, 27],
            [2002, 9064, 14, 19],
            [2002, 9065, 24, 23],
            [2002, 9066, 18, 19],
            [2002, 9067, 32, 23],
            [2002, 9068, 28, 19],
            [2002, 9069, 36, 41],
            [2002, 9070, 14, 14],
            [2002, 9071, 28, 34],
            [2002, 9072, 14, 17],
            [2002, 9073, 14, 17],
            [2002, 9074, 31, 29],
            [2002, 9075, 22, 25],
            [2002, 9076, 24, 27],
            [2002, 9077, 36, 23],
            [2002, 9078, 28, 17],
            [2002, 9079, 47, 38],
            [2002, 9080, 22, 19],
            [2002, 9081, 31, 25],
            [2002, 9082, 51, 35],
            [2002, 9083, 24, 20],
            [2002, 9084, 31, 22],
            [2002, 9085, 20, 21],
            [2002, 9086, 39, 30],
            [2002, 9087, 44, 31],
            [2002, 9088, 32, 18],
            [2002, 9089, 18, 15],
            [2002, 9090, 24, 19],
            [2002, 9091, 24, 16],
            [2002, 9092, 46, 30],
            [2002, 9093, 23, 20],
            [2002, 9094, 50, 47],
            [2002, 9095, 14, 12],
            [2002, 9096, 27, 33],
            [2002, 9097, 33, 22],
            [2002, 9098, 39, 25],
            [2002, 9099, 20, 11],
            [2002, 9100, 40, 25],
            [2002, 9101, 14, 14],
            [2002, 9102, 41, 32],
            [2002, 9103, 29, 30],
            [2002, 9104, 39, 30],
            [2002, 9105, 19, 12],
            [2002, 9106, 24, 13],
            [2002, 9107, 36, 27],
            [2002, 9108, 36, 27],
            [2002, 9109, 39, 28],
            [2002, 9110, 48, 31],
            [2002, 9111, 27, 13],
            [2002, 9112, 51, 42],
            [2002, 9113, 26, 21],
            [2002, 9114, 32, 27],
            [2002, 9115, 14, 11],
            [2002, 9116, 20, 15],
            [2002, 9117, 32, 12],
            [2002, 9118, 48, 32],
            [2002, 9119, 19, 12],
            [2002, 9120, 28, 23],
            [2002, 9121, 34, 30],
            [2002, 9122, 42, 37],
            [2002, 9123, 31, 20],
            [2002, 9124, 40, 32],
            [2002, 9125, 17, 25],
            [2002, 9126, 44, 39],
            [2002, 9127, 30, 22],
            [2002, 9128, 36, 27],
            [2002, 9129, 48, 38],
            [2002, 9130, 55, 43],
            [2002, 9131, 29, 30],
            [2002, 9132, 49, 44],
            [2002, 9133, 28, 20],
            [2002, 9134, 36, 28],
            [2002, 9135, 50, 35],
            [2002, 9136, 45, 31],
            [2002, 9137, 20, 15],
            [2002, 9138, 16, 11],
            [2002, 9139, 32, 28],
            [2002, 9140, 44, 39],
            [2002, 9141, 29, 25],
            [2002, 9142, 52, 43],
            [2002, 9143, 21, 21],
            [2002, 9144, 24, 28],
            [2002, 9145, 37, 31],
            [2002, 9146, 45, 36],
            [2002, 9149, 20, 17],
            [2002, 9150, 23, 25],
            [2002, 9151, 19, 18],
            [2002, 9152, 27, 28],
            [2002, 9153, 14, 18],
            [2002, 9154, 16, 16],
            [2002, 9155, 25, 27],
            [2002, 9156, 29, 27],
            [2002, 9157, 30, 33],
            [2002, 9158, 12, 16],
            [2002, 9159, 22, 31],
            [2002, 9160, 15, 15],
            [2002, 9161, 19, 20],
            [2002, 9162, 28, 30],
            [2002, 9163, 30, 25],
            [2002, 9164, 21, 20],
            [2002, 9165, 20, 40],
            [2002, 9166, 24, 27],
            [2002, 9167, 19, 21],
            [2002, 9168, 30, 33],
            [2002, 9169, 22, 22],
            [2002, 9170, 29, 35],
            [2002, 9171, 19, 18],
            [2002, 9172, 21, 26],
            [2002, 9173, 23, 31],
            [2002, 9174, 18, 18],
            [2002, 9175, 20, 22],
            [2002, 9176, 11, 11],
            [2002, 9177, 24, 22],
            [2002, 9178, 22, 35],
            [2002, 9179, 24, 32],
            [2002, 9180, 12, 15],
            [2002, 9181, 19, 17],
            [2002, 9182, 27, 34],
            [2002, 9183, 23, 22],
            [2002, 9184, 27, 28],
            [2002, 9185, 22, 22],
            [2002, 9186, 17, 20],
            [2002, 9187, 24, 23],
            [2002, 9188, 27, 29],
            [2002, 9189, 24, 24],
            [2002, 9190, 17, 20],
            [2002, 9191, 21, 20],
            [2002, 9192, 22, 24],
            [2002, 9193, 19, 18],
            [2002, 9194, 31, 20],
            [2002, 9195, 36, 43],
            [2002, 9196, 29, 29],
            [2002, 9197, 38, 26],
            [2002, 9198, 35, 27],
            [2002, 9199, 60, 40],
            [2002, 9200, 46, 53],
            [2002, 9201, 56, 34],
            [2002, 9202, 44, 42],
            [2002, 9203, 12, 18],
            [2002, 9204, 11, 14],
            [2002, 9205, 27, 25],
            [2002, 9206, 18, 21],
            [2002, 9207, 31, 34],
            [2002, 9208, 43, 42],
            [2002, 9209, 31, 28],
            [2002, 9210, 51, 43],
            [2002, 9211, 29, 33],
            [2002, 9212, 46, 45],
            [2002, 9213, 67, 59],
            [2002, 9214, 43, 40],
            [2002, 9215, 19, 25],
            [2002, 9216, 62, 63],
            [2002, 9217, 55, 43],
            [2002, 9218, 28, 25],
            [2002, 9219, 46, 51],
            [2002, 9220, 34, 31],
            [2002, 9221, 29, 33],
            [2002, 9222, 44, 51],
            [2002, 9223, 39, 48],
            [2002, 9224, 54, 42],
            [2002, 9225, 44, 36],
            [2002, 9226, 64, 43],
            [2002, 9227, 62, 51],
            [2002, 9228, 66, 67],
            [2002, 9229, 49, 51],
            [2002, 9230, 40, 37],
            [2002, 9231, 68, 56],
            [2002, 9232, 47, 41],
            [2002, 9233, 40, 39],
            [2002, 9234, 28, 34],
            [2002, 9235, 40, 44],
            [2002, 9236, 24, 20],
            [2002, 9237, 39, 23],
            [2002, 9238, 38, 50],
            [2002, 9239, 56, 66],
            [2002, 9240, 40, 44],
            [2002, 9241, 31, 42],
            [2002, 9242, 45, 38],
            [2002, 9243, 55, 51],
            [2002, 9244, 43, 41],
            [2002, 9245, 25, 31],
            [2002, 9246, 34, 28],
            [2002, 9247, 48, 38],
            [2002, 9248, 42, 32],
            [2002, 9249, 29, 22],
            [2002, 9250, 32, 22],
            [2002, 9251, 34, 30],
            [2002, 9252, 20, 27],
            [2002, 9253, 78, 58],
            [2002, 9254, 102, 111],
            [2002, 9255, 50, 36],
            [2002, 9257, 80, 72],
            [2002, 9258, 44, 62],
            [2002, 9259, 65, 66],
            [2002, 9260, 54, 41],
            [2002, 9261, 87, 109],
            [2002, 9263, 58, 63],
            [2002, 9264, 53, 57],
            [2002, 9265, 57, 63],
            [2002, 9266, 91, 108],
            [2002, 9267, 70, 72],
            [2002, 9268, 63, 67],
            [2002, 9269, 96, 104],
            [2002, 9270, 91, 108],
            [2002, 9271, 92, 111],
            [2002, 9272, 96, 117],
            [2002, 9273, 98, 119],
            [2002, 9274, 90, 86],
            [2002, 9275, 67, 64],
            [2002, 9276, 91, 85],
            [2002, 9277, 88, 73],
            [2002, 9278, 85, 86],
            [2002, 9279, 83, 79],
            [2002, 9280, 67, 66],
            [2002, 9281, 87, 79],
            [2002, 9282, 100, 91],
            [2002, 9283, 93, 102],
            [2002, 9284, 110, 130],
            [2002, 9285, 81, 98],
            [2002, 9286, 104, 126],
            [2002, 9287, 107, 124],
            [2002, 9288, 59, 46],
            [2002, 9289, 105, 122],
            [2002, 9290, 83, 97],
            [2002, 9291, 100, 114],
            [2002, 9292, 99, 114],
            [2002, 9293, 67, 48],
            [2002, 9294, 68, 67],
            [2002, 9295, 83, 79],
            [2002, 9296, 63, 46],
            [2002, 9297, 80, 56],
            [2002, 9298, 82, 103],
            [2002, 9299, 95, 116],
            [2002, 9300, 102, 119],
            [2002, 9301, 87, 106],
            [2002, 9302, 107, 124],
            [2002, 9303, 97, 120],
            [2002, 9304, 60, 81],
            [2002, 9305, 90, 111],
            [2002, 9306, 108, 133],
            [2002, 9307, 47, 68],
            [2002, 9308, 56, 77],
            [2002, 9309, 57, 70],
            [2002, 9310, 66, 77],
            [2002, 9311, 62, 74],
            [2002, 9312, 66, 77],
            [2002, 9313, 61, 73],
            [2002, 9314, 74, 89],
            [2002, 9315, 42, 40],
            [2002, 9316, 28, 28],
            [2002, 9317, 12, 13],
            [2002, 9318, 15, 17],
            [2002, 9319, 39, 45],
            [2002, 9320, 57, 57],
            [2002, 9327, 13, 15],
            [2002, 9328, 25, 30],
            [2002, 9329, 34, 41],
            [2002, 9330, 46, 50],
            [2002, 9331, 33, 33],
            [2002, 9332, 31, 35],
            [2002, 9333, 13, 15],
            [2002, 9334, 11, 14],
            [2002, 9335, 34, 34],
            [2002, 9336, 28, 33],
            [2002, 9337, 19, 23],
            [2002, 9338, 12, 13],
            [2002, 9339, 17, 21],
            [2002, 9340, 48, 52],
            [2002, 9341, 25, 29],
            [2002, 9342, 33, 33],
            [2002, 9343, 9, 10],
            [2002, 9344, 19, 21],
            [2002, 9345, 20, 24],
            [2002, 9346, 14, 16],
            [2002, 9347, 11, 14],
            [2002, 9348, 21, 24],
            [2002, 9349, 18, 21],
            [2002, 9350, 48, 55],
            [2002, 9351, 36, 33],
            [2002, 9352, 39, 39],
            [2002, 9353, 20, 23],
            [2002, 9354, 27, 27],
            [2002, 9355, 19, 18],
            [2002, 9356, 33, 38],
            [2002, 9357, 19, 22],
            [2002, 9358, 26, 25],
            [2002, 9359, 20, 20],
            [2002, 9360, 30, 35],
            [2002, 9361, 27, 32],
            [2002, 9362, 36, 34],
            [2002, 9363, 31, 35],
            [2002, 9364, 40, 31],
            [2002, 9365, 19, 23],
            [2002, 9366, 31, 36],
            [2002, 9367, 21, 20],
            [2002, 9368, 31, 31],
            [2002, 9369, 33, 32],
            [2002, 9370, 17, 20],
            [2002, 9371, 32, 31],
            [2002, 9372, 27, 26],
            [2002, 9373, 23, 23],
            [2002, 9374, 38, 38],
            [2002, 9375, 23, 27],
            [2002, 9376, 42, 41],
            [2002, 9377, 13, 17],
            [2002, 9378, 19, 22],
            [2002, 9379, 33, 39],
            [2002, 9380, 29, 34],
            [2002, 9381, 56, 67],
            [2002, 9382, 33, 39],
            [2002, 9383, 37, 37],
            [2002, 9384, 19, 21],
            [2002, 9385, 22, 24],
            [2002, 9386, 21, 23],
            [2002, 9387, 17, 19],
            [2002, 9388, 17, 22],
            [2002, 9389, 19, 21],
            [2002, 9390, 21, 25],
            [2002, 9391, 24, 28],
            [2002, 9392, 22, 26],
            [2002, 9393, 25, 24],
            [2002, 9394, 17, 19],
            [2002, 9395, 23, 25],
            [2002, 9396, 25, 30],
            [2002, 9397, 47, 54],
            [2002, 9398, 42, 49],
            [2002, 9399, 64, 71],
            [2002, 9400, 28, 34],
            [2002, 9401, 42, 40],
            [2002, 9402, 44, 34],
            [2002, 9403, 112, 83],
            [2002, 9404, 111, 82],
            [2002, 9405, 113, 83],
            [2002, 9406, 102, 83],
            [2002, 9407, 70, 66],
            [2002, 9408, 113, 83],
            [2002, 9409, 110, 83],
            [2002, 9410, 113, 83],
            [2002, 9411, 109, 80],
            [2002, 9412, 109, 82],
            [2002, 9413, 113, 83],
            [2002, 9414, 112, 82],
            [2002, 9415, 113, 83],
            [2002, 9416, 103, 78],
            [2002, 9417, 113, 83],
            [2002, 9418, 109, 77],
            [2002, 9419, 111, 83],
            [2002, 9420, 111, 82],
            [2002, 9421, 109, 77],
            [2002, 9422, 111, 83],
            [2002, 9423, 102, 75],
            [2002, 9424, 112, 82],
            [2002, 9425, 113, 83],
            [2002, 9426, 111, 83],
            [2002, 9427, 113, 83],
            [2002, 9428, 109, 80],
            [2002, 9429, 110, 83],
            [2002, 9430, 113, 83],
            [2002, 9431, 110, 81],
            [2002, 9432, 64, 61],
            [2002, 9433, 102, 75],
            [2002, 9434, 110, 81],
            [2002, 9435, 113, 83],
            [2002, 9436, 110, 81],
            [2002, 9437, 112, 82],
            [2002, 9438, 113, 83],
            [2002, 9439, 110, 80],
            [2002, 9440, 113, 83],
            [2002, 9441, 111, 83],
            [2002, 9442, 113, 83],
            [2002, 9443, 111, 82],
            [2002, 9444, 109, 80],
            [2002, 9445, 110, 83],
            [2002, 9446, 113, 83],
            [2002, 9447, 110, 83],
            [2002, 9448, 113, 83],
            [2002, 9449, 72, 57],
            [2002, 9450, 102, 75],
            [2002, 9451, 102, 83],
            [2002, 9452, 110, 81],
            [2002, 9453, 109, 82],
            [2002, 9454, 110, 83],
            [2002, 9455, 113, 83],
            [2002, 9456, 111, 82],
            [2002, 9457, 102, 83],
            [2002, 9458, 111, 82],
            [2002, 9459, 110, 83],
            [2002, 9460, 113, 83],
            [2002, 9461, 110, 83],
            [2002, 9462, 113, 83],
            [2002, 9463, 79, 75],
            [2002, 9464, 79, 75],
            [2002, 9465, 64, 61],
            [2002, 9466, 110, 83],
            [2002, 9467, 112, 83],
            [2002, 9468, 112, 66],
            [2002, 9469, 113, 83],
            [2002, 9470, 110, 81],
            [2002, 9471, 144, 87],
            [2002, 9472, 170, 158],
            [2002, 9473, 48, 79],
            [2002, 9474, 79, 123],
            [2002, 9475, 111, 96],
            [2002, 9476, 111, 174],
            [2002, 9477, 36, 49],
            [2002, 9478, 57, 75],
            [2002, 9479, 82, 88],
            [2002, 9480, 120, 129],
            [2002, 9481, 27, 70],
            [2002, 9482, 41, 109],
            [2002, 9483, 111, 83],
            [2002, 9484, 151, 76],
            [2002, 9485, 71, 47],
            [2002, 9486, 93, 73],
            [2002, 9487, 27, 49],
            [2002, 9488, 45, 75],
            [2002, 9489, 102, 75],
            [2002, 9490, 100, 95],
            [2002, 9491, 44, 70],
            [2002, 9492, 73, 83],
            [2002, 9493, 111, 91],
            [2002, 9494, 117, 123],
            [2002, 9495, 44, 42],
            [2002, 9496, 79, 53],
            [2002, 9497, 43, 30],
            [2002, 9498, 69, 48],
            [2002, 9499, 64, 75],
            [2002, 9500, 102, 109],
            [2002, 9501, 67, 107],
            [2002, 9502, 110, 174],
            [2002, 9503, 64, 53],
            [2002, 9504, 78, 63],
            [2002, 9505, 64, 97],
            [2002, 9506, 102, 151],
            [2002, 9507, 74, 75],
            [2002, 9508, 101, 138],
            [2002, 9509, 102, 70],
            [2002, 9510, 102, 101],
            [2002, 9511, 64, 61],
            [2002, 9512, 64, 98],
            [2002, 9513, 75, 77],
            [2002, 9514, 102, 111],
            [2002, 9515, 67, 65],
            [2002, 9516, 110, 94],
            [2002, 9517, 102, 83],
            [2002, 9518, 130, 124],
            [2002, 9519, 32, 36],
            [2002, 9520, 54, 59],
            [2002, 9521, 67, 156],
            [2002, 9522, 101, 183],
            [2002, 9523, 102, 83],
            [2002, 9524, 124, 129],
            [2002, 9525, 30, 38],
            [2002, 9526, 47, 58],
            [2002, 9527, 80, 78],
            [2002, 9528, 101, 104],
            [2002, 9529, 43, 49],
            [2002, 9530, 69, 75],
            [2002, 9531, 43, 56],
            [2002, 9532, 53, 89],
            [2002, 9533, 102, 104],
            [2002, 9534, 143, 136],
            [2002, 9535, 33, 73],
            [2002, 9536, 59, 134],
            [2002, 9537, 119, 83],
            [2002, 9538, 160, 127],
            [2002, 9539, 59, 57],
            [2002, 9540, 79, 89],
            [2002, 9541, 43, 41],
            [2002, 9542, 67, 64],
            [2002, 9543, 36, 45],
            [2002, 9544, 58, 70],
            [2002, 9545, 64, 61],
            [2002, 9546, 71, 82],
            [2002, 9547, 39, 47],
            [2002, 9548, 64, 78],
            [2002, 9549, 33, 34],
            [2002, 9550, 52, 61],
            [2002, 9551, 35, 52],
            [2002, 9552, 56, 88],
            [2002, 9553, 44, 49],
            [2002, 9554, 64, 75],
            [2002, 9555, 61, 127],
            [2002, 9556, 94, 150],
            [2002, 9557, 36, 56],
            [2002, 9558, 64, 89],
            [2002, 9559, 42, 42],
            [2002, 9560, 56, 65],
            [2002, 9561, 43, 64],
            [2002, 9562, 68, 100],
            [2002, 9563, 60, 125],
            [2002, 9564, 95, 151],
            [2002, 9565, 64, 61],
            [2002, 9566, 70, 96],
            [2002, 9567, 56, 70],
            [2002, 9568, 74, 114],
            [2002, 9569, 102, 97],
            [2002, 9570, 129, 131],
            [2002, 9571, 88, 158],
            [2002, 9572, 132, 174],
            [2002, 9573, 79, 75],
            [2002, 9574, 102, 120],
            [2002, 9575, 67, 72],
            [2002, 9576, 113, 121],
            [2002, 9577, 111, 74],
            [2002, 9578, 140, 125],
            [2002, 9579, 44, 97],
            [2002, 9580, 63, 125],
            [2002, 9581, 48, 61],
            [2002, 9582, 56, 78],
            [2002, 9583, 102, 128],
            [2002, 9584, 151, 151],
            [2002, 9585, 102, 68],
            [2002, 9586, 108, 78],
            [2002, 9587, 59, 56],
            [2002, 9588, 63, 76],
            [2002, 9589, 35, 73],
            [2002, 9590, 52, 110],
            [2002, 9591, 64, 53],
            [2002, 9592, 69, 61],
            [2002, 9593, 36, 52],
            [2002, 9594, 57, 92],
            [2002, 9595, 40, 53],
            [2002, 9596, 68, 82],
            [2002, 9597, 27, 27],
            [2002, 9598, 38, 52],
            [2002, 9599, 102, 68],
            [2002, 9600, 102, 75],
            [2002, 9601, 48, 75],
            [2002, 9602, 92, 135],
            [2002, 9603, 61, 75],
            [2002, 9604, 90, 97],
            [2002, 9605, 59, 42],
            [2002, 9606, 64, 51],
            [2002, 9607, 53, 63],
            [2002, 9608, 84, 75],
            [2002, 9609, 39, 43],
            [2002, 9610, 52, 61],
            [2002, 9611, 44, 49],
            [2002, 9612, 64, 68],
            [2002, 9613, 66, 125],
            [2002, 9614, 98, 151],
            [2002, 9615, 53, 45],
            [2002, 9616, 83, 71],
            [2002, 9617, 22, 29],
            [2002, 9618, 64, 61],
            [2002, 9619, 33, 44],
            [2002, 9620, 33, 44],
            [2002, 9621, 39, 68],
            [2002, 9622, 52, 75],
            [2002, 9623, 64, 53],
            [2002, 9624, 64, 61],
            [2002, 9625, 102, 75],
            [2002, 9626, 100, 100],
            [2002, 9627, 64, 45],
            [2002, 9628, 79, 61],
            [2002, 9629, 46, 53],
            [2002, 9630, 79, 71],
            [2002, 9631, 44, 44],
            [2002, 9632, 58, 71],
            [2002, 9633, 57, 69],
            [2002, 9634, 99, 131],
            [2002, 9635, 137, 125],
            [2002, 9636, 159, 151],
            [2002, 9637, 74, 77],
            [2002, 9638, 108, 113],
            [2002, 9639, 21, 29],
            [2002, 9640, 38, 61],
            [2002, 9641, 57, 45],
            [2002, 9642, 71, 75],
            [2002, 9643, 28, 49],
            [2002, 9644, 45, 78],
            [2002, 9645, 64, 115],
            [2002, 9646, 72, 151],
            [2002, 9647, 102, 75],
            [2002, 9648, 115, 137],
            [2002, 9651, 55, 55],
            [2002, 9652, 79, 76],
            [2002, 9653, 48, 45],
            [2002, 9654, 84, 64],
            [2002, 9655, 39, 40],
            [2002, 9656, 67, 66],
            [2002, 9657, 54, 53],
            [2002, 9658, 63, 55],
            [2002, 9659, 42, 37],
            [2002, 9660, 66, 66],
            [2002, 9661, 37, 38],
            [2002, 9662, 64, 60],
            [2002, 9663, 39, 37],
            [2002, 9664, 67, 61],
            [2002, 9665, 55, 55],
            [2002, 9666, 65, 65],
            [2002, 9667, 49, 42],
            [2002, 9668, 67, 59],
            [2002, 9669, 40, 40],
            [2002, 9670, 60, 58],
            [2002, 9671, 41, 42],
            [2002, 9672, 77, 67],
            [2002, 9673, 44, 43],
            [2002, 9674, 57, 57],
            [2002, 9675, 49, 50],
            [2002, 9676, 91, 68],
            [2002, 9677, 41, 40],
            [2002, 9678, 65, 60],
            [2002, 9679, 41, 42],
            [2002, 9680, 66, 64],
            [2002, 9681, 52, 43],
            [2002, 9682, 73, 65],
            [2002, 9683, 53, 49],
            [2002, 9684, 69, 65],
            [2002, 9685, 48, 48],
            [2002, 9686, 71, 67],
            [2002, 9687, 46, 41],
            [2002, 9688, 71, 67],
            [2002, 9689, 78, 78],
            [2002, 9690, 73, 69],
            [2002, 9691, 44, 40],
            [2002, 9692, 68, 60],
            [2002, 9693, 60, 47],
            [2002, 9694, 88, 60],
            [2002, 9695, 37, 38],
            [2002, 9696, 65, 58],
            [2002, 9697, 42, 39],
            [2002, 9698, 80, 56],
            [2002, 9699, 38, 43],
            [2002, 9700, 68, 68],
            [2002, 9701, 38, 38],
            [2002, 9702, 53, 49],
            [2002, 9703, 34, 35],
            [2002, 9704, 69, 64],
            [2002, 9705, 35, 35],
            [2002, 9706, 75, 69],
            [2002, 9707, 48, 40],
            [2002, 9708, 63, 50],
            [2002, 9709, 41, 42],
            [2002, 9710, 51, 49],
            [2002, 9711, 96, 73],
            [2002, 9712, 95, 74],
            [2002, 9713, 96, 73],
            [2002, 9714, 91, 69],
            [2002, 9715, 87, 66],
            [2002, 9716, 46, 37],
            [2002, 9717, 54, 47],
            [2002, 9718, 40, 38],
            [2002, 9719, 64, 59],
            [2002, 9720, 84, 62],
            [2002, 9721, 77, 68],
            [2002, 9722, 37, 37],
            [2002, 9723, 80, 76],
            [2002, 9724, 64, 59],
            [2002, 9725, 83, 76],
            [2002, 9726, 26, 34],
            [2002, 9727, 59, 55],
            [2002, 9728, 52, 48],
            [2002, 9729, 59, 55],
            [2002, 9730, 31, 31],
            [2002, 9731, 83, 62],
            [2002, 9735, 62, 52],
            [2002, 9736, 48, 47],
            [2002, 9737, 51, 45],
            [2002, 9738, 101, 70],
            [2002, 9739, 60, 58],
            [2002, 9740, 72, 69],
            [2002, 9741, 65, 59],
            [2002, 9742, 63, 57],
            [2002, 9743, 49, 42],
            [2002, 9744, 90, 66],
            [2002, 9745, 58, 55],
            [2002, 9746, 56, 56],
            [2002, 9747, 61, 57],
            [2002, 9748, 52, 53],
            [2002, 9751, 43, 37],
            [2002, 9752, 52, 47],
            [2002, 9753, 38, 38],
            [2002, 9754, 63, 63],
            [2002, 9755, 40, 40],
            [2002, 9756, 75, 71],
            [2002, 9757, 39, 40],
            [2002, 9758, 62, 58],
            [2002, 9759, 24, 15],
            [2002, 9760, 47, 29],
            [2002, 9761, 49, 30],
            [2002, 9762, 44, 20],
            [2002, 9763, 25, 17],
            [2002, 9764, 30, 15],
            [2002, 9765, 48, 30],
            [2002, 9766, 46, 23],
            [2002, 9767, 45, 52],
            [2002, 9768, 39, 26],
            [2002, 9769, 27, 19],
            [2002, 9770, 51, 45],
            [2002, 9771, 59, 24],
            [2002, 9772, 34, 17],
            [2002, 9773, 46, 35],
            [2002, 9774, 26, 21],
            [2002, 9775, 27, 20],
            [2002, 9776, 33, 15],
            [2002, 9777, 49, 30],
            [2002, 9778, 49, 33],
            [2002, 9779, 44, 32],
            [2002, 9780, 46, 36],
            [2002, 9781, 34, 18],
            [2002, 9782, 48, 34],
            [2002, 9783, 40, 23],
            [2002, 9784, 40, 32],
            [2002, 9785, 32, 26],
            [2002, 9786, 25, 18],
            [2002, 9787, 46, 30],
            [2002, 9788, 25, 19],
            [2002, 9789, 50, 23],
            [2002, 9790, 46, 29],
            [2002, 9791, 56, 35],
            [2002, 9792, 48, 42],
            [2002, 9793, 19, 14],
            [2002, 9794, 16, 15],
            [2002, 9795, 15, 14],
            [2002, 9796, 23, 17],
            [2002, 9797, 19, 14],
            [2002, 9798, 16, 15],
            [2002, 9799, 54, 44],
            [2002, 9800, 28, 24],
            [2002, 9801, 23, 19],
            [2002, 9802, 23, 19],
            [2002, 9803, 12, 10],
            [2002, 9804, 21, 17],
            [2002, 9805, 42, 31],
            [2002, 9806, 27, 21],
            [2002, 9807, 36, 23],
            [2002, 9808, 94, 57],
            [2002, 9809, 50, 19],
            [2002, 9811, 53, 29],
            [2002, 9812, 92, 54],
            [2002, 9813, 74, 31],
            [2002, 9814, 27, 16],
            [2002, 9815, 54, 29],
            [2002, 9816, 40, 17],
            [2002, 9817, 33, 15],
            [2002, 9818, 74, 22],
            [2002, 9819, 65, 45],
            [2002, 9820, 80, 48],
            [2002, 9821, 59, 32],
            [2002, 9822, 27, 22],
            [2002, 9823, 35, 23],
            [2002, 9824, 37, 30],
            [2002, 9825, 25, 19],
            [2002, 9826, 64, 44],
            [2002, 9827, 59, 33],
            [2002, 9828, 67, 44],
            [2002, 9829, 51, 32],
            [2002, 9830, 40, 31],
            [2002, 9831, 50, 30],
            [2002, 9832, 41, 26],
            [2002, 9833, 42, 29],
            [2002, 9834, 74, 47],
            [2002, 9835, 42, 37],
            [2002, 9836, 59, 41],
            [2002, 9837, 38, 25],
            [2002, 9838, 66, 49],
            [2002, 9839, 21, 18],
            [2002, 9840, 54, 39],
            [2002, 9841, 102, 58],
            [2002, 9842, 40, 23],
            [2002, 9843, 35, 25],
            [2002, 9844, 45, 29],
            [2002, 9845, 38, 31],
            [2002, 9846, 35, 21],
            [2002, 9847, 18, 15],
            [2002, 9848, 32, 20],
            [2002, 9849, 31, 19],
            [2002, 9850, 31, 15],
            [2002, 9851, 29, 14],
            [2002, 9852, 25, 14],
            [2002, 9853, 28, 19],
            [2002, 9854, 17, 14],
            [2002, 9855, 37, 31],
            [2002, 9856, 19, 20],
            [2002, 9857, 19, 15],
            [2002, 9858, 54, 33],
            [2002, 9859, 68, 41],
            [2002, 9860, 58, 43],
            [2002, 9861, 70, 60],
            [2002, 9862, 35, 38],
            [2002, 9863, 55, 39],
            [2002, 9864, 68, 27],
            [2002, 9865, 45, 28],
            [2002, 9866, 68, 27],
            [2002, 9867, 27, 19],
            [2002, 9868, 57, 37],
            [2002, 9869, 52, 31],
            [2002, 9870, 46, 54],
            [2002, 9871, 57, 34],
            [2002, 9872, 31, 27],
            [2002, 9873, 43, 40],
            [2002, 9874, 52, 25],
            [2002, 9875, 42, 28],
            [2002, 9876, 31, 27],
            [2002, 9877, 44, 34],
            [2002, 9878, 51, 31],
            [2002, 9879, 47, 27],
            [2002, 9880, 50, 39],
            [2002, 9881, 64, 34],
            [2002, 9882, 48, 38],
            [2002, 9883, 43, 25],
            [2002, 9884, 43, 23],
            [2002, 9885, 53, 27],
            [2002, 9886, 53, 26],
            [2002, 9887, 46, 31],
            [2002, 9888, 59, 44],
            [2002, 9889, 57, 35],
            [2002, 9890, 51, 35],
            [2002, 9891, 43, 27],
            [2002, 9892, 36, 28],
            [2002, 9893, 30, 21],
            [2002, 9894, 59, 38],
            [2002, 9895, 29, 17],
            [2002, 9896, 12, 15],
            [2002, 9897, 44, 28],
            [2002, 9898, 46, 34],
            [2002, 9899, 31, 24],
            [2002, 9900, 72, 63],
            [2002, 9901, 66, 43],
            [2002, 9902, 100, 73],
            [2002, 9903, 89, 54],
            [2002, 9904, 78, 56],
            [2002, 9905, 50, 38],
            [2002, 9906, 53, 30],
            [2002, 9907, 38, 34],
            [2002, 9908, 78, 51],
            [2002, 9909, 19, 16],
            [2002, 9910, 69, 58],
            [2002, 9911, 99, 54],
            [2002, 9912, 64, 38],
            [2002, 9913, 29, 24],
            [2002, 9914, 40, 29],
            [2002, 9915, 38, 32],
            [2002, 9916, 40, 36],
            [2002, 9917, 35, 31],
            [2002, 9918, 98, 35],
            [2002, 9919, 91, 74],
            [2002, 9920, 103, 72],
            [2002, 9921, 31, 24],
            [2002, 9922, 35, 19],
            [2002, 9923, 39, 25],
            [2002, 9924, 55, 29],
            [2002, 9925, 66, 61],
            [2002, 9926, 50, 60],
            [2002, 9927, 39, 27],
            [2002, 9928, 70, 36],
            [2002, 9929, 57, 49],
            [2002, 9930, 51, 32],
            [2002, 9931, 67, 40],
            [2002, 9932, 68, 33],
            [2002, 9933, 63, 48],
            [2002, 9934, 61, 34],
            [2002, 9935, 49, 27],
            [2002, 9936, 52, 35],
            [2002, 9937, 35, 32],
            [2002, 9938, 21, 19],
            [2002, 9939, 56, 27],
            [2002, 9940, 45, 38],
            [2002, 9941, 48, 26],
            [2002, 9942, 26, 20],
            [2002, 9943, 128, 74],
            [2002, 9944, 60, 31],
            [2002, 9945, 86, 38],
            [2002, 9946, 44, 22],
            [2002, 9947, 64, 32],
            [2002, 9948, 112, 54],
            [2002, 9949, 104, 61],
            [2002, 9950, 78, 57],
            [2002, 9951, 41, 27],
            [2002, 9952, 64, 31],
            [2002, 9953, 32, 25],
            [2002, 9954, 81, 53],
            [2002, 9955, 31, 26],
            [2002, 9956, 71, 31],
            [2002, 9957, 106, 51],
            [2002, 9958, 35, 28],
            [2002, 9959, 99, 50],
            [2002, 9960, 64, 31],
            [2002, 9961, 34, 32],
            [2002, 9962, 43, 27],
            [2002, 9963, 77, 47],
            [2002, 9964, 41, 37],
            [2002, 9965, 38, 18],
            [2002, 9966, 71, 36],
            [2002, 9967, 85, 40],
            [2002, 9968, 49, 44],
            [2002, 9969, 46, 26],
            [2002, 9970, 66, 31],
            [2002, 9971, 40, 30],
            [2002, 9972, 119, 51],
            [2002, 9973, 54, 43],
            [2002, 9974, 38, 17],
            [2002, 9975, 99, 42],
            [2002, 9976, 122, 52],
            [2002, 9977, 46, 23],
            [2002, 9978, 51, 24],
            [2002, 9979, 105, 48],
            [2002, 9980, 56, 26],
            [2002, 9981, 34, 20],
            [2002, 9982, 21, 15],
            [2002, 9983, 94, 39],
            [2002, 9984, 50, 30],
            [2002, 9985, 52, 29],
            [2002, 9986, 55, 32],
            [2002, 9987, 56, 46],
            [2002, 9988, 51, 32],
            [2002, 9989, 43, 34],
            [2002, 9990, 37, 22],
            [2002, 9991, 53, 38],
            [2002, 9992, 55, 41],
            [2002, 9993, 39, 43],
            [2002, 9994, 35, 31],
            [2002, 9995, 51, 41],
            [2002, 9996, 42, 36],
            [2002, 9997, 20, 26],
            [2002, 9998, 22, 18],
            [2002, 9999, 34, 38],
            [2002, 10000, 28, 19],
            [2002, 10001, 24, 18],
            [2002, 10002, 21, 17],
            [2002, 10003, 55, 31],
            [2002, 10004, 24, 19],
            [2002, 10005, 24, 19],
            [2002, 10006, 18, 14],
            [2002, 10007, 41, 46],
            [2002, 10008, 57, 56],
            [2002, 10009, 57, 39],
            [2002, 10010, 66, 37],
            [2002, 10011, 52, 34],
            [2002, 10012, 70, 31],
            [2002, 10013, 37, 33],
            [2002, 10014, 47, 49],
            [2002, 10015, 36, 34],
            [2002, 10016, 41, 44],
            [2002, 10017, 48, 40],
            [2002, 10018, 50, 44],
            [2002, 10019, 49, 41],
            [2002, 10020, 62, 52],
            [2002, 10021, 77, 51],
            [2002, 10022, 65, 53],
            [2002, 10023, 70, 51],
            [2002, 10024, 93, 64],
            [2002, 10025, 79, 64],
            [2002, 10026, 75, 55],
            [2002, 10027, 70, 55],
            [2002, 10030, 65, 53],
            [2002, 10031, 85, 74],
            [2002, 10032, 87, 65],
            [2002, 10033, 51, 38],
            [2002, 10034, 58, 38],
            [2002, 10035, 96, 51],
            [2002, 10036, 93, 43],
            [2002, 10037, 102, 53],
            [2002, 10038, 34, 23],
            [2002, 10039, 20, 23],
            [2002, 10040, 33, 23],
            [2002, 10041, 31, 19],
            [2002, 10042, 55, 37],
            [2002, 10043, 58, 29],
            [2002, 10044, 66, 29],
            [2002, 10045, 41, 24],
            [2002, 10046, 61, 39],
            [2002, 10047, 58, 31],
            [2002, 10048, 54, 32],
            [2002, 10049, 38, 29],
            [2002, 10050, 51, 36],
            [2002, 10051, 59, 41],
            [2002, 10052, 71, 61],
            [2002, 10053, 78, 62],
            [2002, 10054, 68, 63],
            [2002, 10055, 75, 65],
            [2002, 10056, 64, 63],
            [2002, 10057, 73, 66],
            [2002, 10058, 40, 45],
            [2002, 10059, 81, 47],
            [2002, 10060, 60, 43],
            [2002, 10061, 71, 67],
            [2002, 10063, 23, 25],
            [2002, 10064, 41, 34],
            [2002, 10065, 37, 46],
            [2002, 10066, 48, 43],
            [2002, 10067, 69, 54],
            [2002, 10068, 77, 58],
            [2002, 10069, 70, 55],
            [2002, 10070, 46, 27],
            [2002, 10071, 68, 49],
            [2002, 10072, 68, 26],
            [2002, 10073, 70, 31],
            [2002, 10074, 69, 32],
            [2002, 10075, 80, 43],
            [2002, 10076, 71, 43],
            [2002, 10077, 69, 43],
            [2002, 10078, 86, 53],
            [2002, 10079, 54, 39],
            [2002, 10080, 47, 41],
            [2002, 10081, 83, 53],
            [2002, 10082, 56, 60],
            [2002, 10083, 46, 44],
            [2002, 10084, 51, 35],
            [2002, 10085, 49, 24],
            [2002, 10086, 54, 32],
            [2002, 10087, 49, 22],
            [2002, 10088, 71, 46],
            [2002, 10089, 71, 47],
            [2002, 10090, 57, 45],
            [2002, 10091, 70, 34],
            [2002, 10092, 78, 35],
            [2002, 10093, 53, 45],
            [2002, 10094, 90, 56],
            [2002, 10095, 81, 54],
            [2002, 10096, 69, 42],
            [2002, 10097, 56, 41],
            [2002, 10098, 64, 46],
            [2002, 10099, 77, 54],
            [2002, 10101, 82, 66],
            [2002, 10102, 70, 57],
            [2002, 10103, 72, 67],
            [2002, 10104, 20, 20],
            [2002, 10105, 34, 23],
            [2002, 10106, 34, 32],
            [2002, 10107, 66, 62],
            [2002, 10108, 79, 72],
            [2002, 10109, 127, 80],
            [2002, 10110, 64, 56],
            [2002, 10111, 91, 69],
            [2002, 10112, 94, 75],
            [2002, 10113, 112, 92],
            [2002, 10114, 81, 50],
            [2002, 10115, 49, 36],
            [2002, 10116, 56, 46],
            [2002, 10117, 53, 54],
            [2002, 10118, 57, 62],
            [2002, 10119, 26, 18],
            [2002, 10120, 34, 22],
            [2002, 10121, 78, 68],
            [2002, 10122, 78, 68],
            [2002, 10123, 91, 77],
            [2002, 10124, 79, 75],
            [2002, 10125, 83, 51],
            [2002, 10126, 71, 43],
            [2002, 10127, 71, 45],
            [2002, 10128, 72, 50],
            [2002, 10129, 92, 59],
            [2002, 10130, 85, 58],
            [2002, 10131, 54, 43],
            [2002, 10132, 55, 44],
            [2002, 10133, 72, 42],
            [2002, 10134, 96, 67],
            [2002, 10135, 93, 74],
            [2002, 10136, 60, 31],
            [2002, 10137, 71, 48],
            [2002, 10138, 64, 35],
            [2002, 10139, 63, 40],
            [2002, 10141, 57, 36],
            [2002, 10142, 62, 38],
            [2002, 10144, 79, 40],
            [2002, 10145, 49, 49],
            [2002, 10146, 57, 54],
            [2002, 10148, 58, 31],
            [2002, 10149, 60, 64],
            [2002, 10150, 29, 38],
            [2002, 10151, 50, 47],
            [2002, 10152, 69, 54],
            [2002, 10153, 76, 60],
            [2002, 10154, 30, 30],
            [2002, 10155, 59, 60],
            [2002, 10156, 41, 40],
            [2002, 10157, 73, 54],
            [2002, 10158, 40, 42],
            [2002, 10159, 56, 44],
            [2002, 10160, 59, 38],
            [2002, 10161, 85, 49],
            [2002, 10162, 64, 33],
            [2002, 10163, 87, 42],
            [2002, 10164, 66, 34],
            [2002, 10165, 71, 37],
            [2002, 10166, 53, 31],
            [2002, 10167, 64, 49],
            [2002, 10168, 65, 50],
            [2002, 10169, 71, 51],
            [2002, 10170, 33, 41],
            [2002, 10171, 57, 48],
            [2002, 10172, 44, 39],
            [2002, 10173, 57, 47],
            [2002, 10174, 54, 37],
            [2002, 10175, 70, 48],
            [2002, 10176, 22, 23],
            [2002, 10177, 20, 21],
            [2002, 10178, 25, 24],
            [2002, 10179, 20, 22],
            [2002, 10180, 42, 34],
            [2002, 10181, 26, 18],
            [2002, 10182, 41, 45],
            [2002, 10183, 53, 30],
            [2002, 10184, 52, 20],
            [2002, 10185, 18, 15],
            [2002, 10186, 16, 13],
            [2002, 10187, 24, 18],
            [2002, 10188, 25, 17],
            [2002, 10189, 69, 37],
            [2002, 10190, 24, 16],
            [2002, 10191, 54, 30],
            [2002, 10192, 39, 24],
            [2002, 10193, 23, 21],
            [2002, 10194, 17, 12],
            [2002, 10195, 16, 14],
            [2002, 10196, 44, 32],
            [2002, 10197, 42, 30],
            [2002, 10198, 30, 34],
            [2002, 10199, 30, 33],
            [2002, 10200, 29, 34],
            [2002, 10201, 28, 31],
            [2002, 10202, 69, 59],
            [2002, 10203, 57, 40],
            [2002, 10204, 58, 40],
            [2002, 10205, 48, 36],
            [2002, 10206, 45, 31],
            [2002, 10207, 41, 29],
            [2002, 10208, 45, 33],
            [2002, 10209, 42, 30],
            [2002, 10210, 50, 40],
            [2002, 10211, 47, 37],
            [2002, 10212, 53, 34],
            [2002, 10213, 51, 32],
            [2002, 10214, 45, 39],
            [2002, 10215, 42, 37],
            [2002, 10216, 48, 34],
            [2002, 10217, 51, 36],
            [2002, 10218, 47, 38],
            [2002, 10219, 46, 39],
            [2002, 10220, 44, 36],
            [2002, 10221, 47, 32],
            [2002, 10222, 45, 34],
            [2002, 10223, 57, 47],
            [2002, 10224, 64, 53],
            [2002, 10225, 59, 56],
            [2002, 10226, 33, 32],
            [2002, 10227, 34, 32],
            [2002, 10228, 32, 29],
            [2002, 10234, 57, 45],
            [2002, 10235, 42, 36],
            [2002, 10236, 42, 39],
            [2002, 10237, 36, 35],
            [2002, 10238, 44, 43],
            [2002, 10239, 60, 48],
            [2002, 10240, 38, 38],
            [2002, 10241, 31, 41],
            [2002, 10242, 42, 33],
            [2002, 10243, 44, 37],
            [2002, 10244, 41, 45],
            [2002, 10245, 21, 30],
            [2002, 10246, 37, 33],
            [2002, 10247, 26, 30],
            [2002, 10248, 41, 33],
            [2002, 10249, 27, 33],
            [2002, 10250, 40, 38],
            [2002, 10251, 43, 36],
            [2002, 10252, 41, 38],
            [2002, 10253, 41, 42],
            [2002, 10255, 43, 40],
            [2002, 10256, 48, 45],
            [2002, 10257, 42, 36],
            [2002, 10258, 45, 44],
            [2002, 10259, 20, 33],
            [2002, 10260, 41, 39],
            [2002, 10261, 46, 37],
            [2002, 10263, 26, 32],
            [2002, 10264, 42, 38],
            [2002, 10267, 31, 29],
            [2002, 10268, 45, 34],
            [2002, 10269, 31, 32],
            [2002, 10270, 35, 38],
            [2002, 10271, 42, 33],
            [2002, 10272, 34, 33],
            [2002, 10276, 37, 36],
            [2002, 10277, 46, 41],
            [2002, 10278, 27, 33],
            [2002, 10279, 44, 42],
            [2002, 10280, 26, 38],
            [2002, 10281, 41, 44],
            [2002, 10283, 27, 30],
            [2002, 10284, 37, 37],
            [2002, 10285, 28, 29],
            [2002, 10286, 34, 31],
            [2002, 10287, 34, 31],
            [2002, 10288, 41, 30],
            [2002, 10289, 44, 35],
            [2002, 10290, 42, 33],
            [2002, 10291, 42, 36],
            [2002, 10292, 30, 35],
            [2002, 10293, 42, 42],
            [2002, 10294, 20, 29],
            [2002, 10295, 27, 33],
            [2002, 10296, 39, 38],
            [2002, 10297, 27, 30],
            [2002, 10298, 35, 35],
            [2002, 10299, 27, 30],
            [2002, 10300, 35, 35],
            [2002, 10301, 35, 38],
            [2002, 10302, 27, 33],
            [2002, 10303, 40, 39],
            [2002, 10304, 27, 33],
            [2002, 10305, 36, 38],
            [2002, 10306, 32, 40],
            [2002, 10307, 36, 40],
            [2002, 10309, 37, 34],
            [2002, 10310, 27, 33],
            [2002, 10311, 36, 39],
            [2002, 10312, 36, 35],
            [2002, 10313, 46, 38],
            [2002, 10314, 42, 36],
            [2002, 10315, 40, 31],
            [2002, 10317, 31, 32],
            [2002, 10318, 48, 39],
            [2002, 10319, 32, 39],
            [2002, 10320, 68, 43],
            [2002, 10321, 32, 31],
            [2002, 10322, 44, 44],
            [2002, 10323, 31, 40],
            [2002, 10326, 57, 45],
            [2002, 10327, 31, 35],
            [2002, 10329, 34, 31],
            [2002, 10330, 36, 41],
            [2002, 10332, 26, 29],
            [2002, 10333, 42, 42],
            [2002, 10334, 46, 42],
            [2002, 10335, 40, 43],
            [2002, 10337, 30, 32],
            [2002, 10338, 46, 38],
            [2002, 10339, 32, 34],
            [2002, 10340, 47, 38],
            [2002, 10341, 26, 29],
            [2002, 10342, 36, 32],
            [2002, 10343, 37, 33],
            [2002, 10344, 33, 37],
            [2002, 10347, 26, 38],
            [2002, 10354, 25, 31],
            [2002, 10355, 44, 38],
            [2002, 10356, 32, 36],
            [2002, 10357, 43, 43],
            [2002, 10358, 40, 36],
            [2002, 10360, 26, 30],
            [2002, 10361, 41, 35],
            [2002, 10362, 42, 42],
            [2002, 10363, 65, 43],
            [2002, 10364, 72, 41],
            [2002, 10366, 44, 43],
            [2002, 10367, 64, 41],
            [2002, 10368, 70, 45],
            [2002, 10369, 64, 41],
            [2002, 10370, 72, 46],
            [2002, 10371, 35, 45],
            [2002, 10372, 26, 31],
            [2002, 10374, 27, 33],
            [2002, 10376, 26, 29],
            [2002, 10377, 29, 32],
            [2002, 10378, 41, 41],
            [2002, 10380, 35, 37],
            [2002, 10381, 57, 44],
            [2002, 10382, 36, 38],
            [2002, 10383, 71, 44],
            [2002, 10384, 41, 41],
            [2002, 10385, 73, 45],
            [2002, 10388, 21, 33],
            [2002, 10390, 28, 32],
            [2002, 10391, 38, 31],
            [2002, 10392, 38, 37],
            [2002, 10394, 26, 29],
            [2002, 10395, 36, 35],
            [2002, 10396, 27, 30],
            [2002, 10398, 27, 33],
            [2002, 10399, 40, 38],
            [2002, 10400, 28, 31],
            [2002, 10402, 26, 38],
            [2002, 10403, 42, 45],
            [2002, 10404, 29, 35],
            [2002, 10408, 26, 38],
            [2002, 10409, 40, 45],
            [2002, 10410, 29, 38],
            [2002, 10411, 45, 43],
            [2002, 10412, 49, 29],
            [2002, 10413, 76, 45],
            [2002, 10417, 41, 45],
            [2002, 10418, 26, 30],
            [2002, 10419, 41, 41],
            [2002, 10420, 44, 44],
            [2002, 10422, 37, 41],
            [2002, 10424, 43, 41],
            [2002, 10425, 26, 35],
            [2002, 10426, 39, 43],
            [2002, 10427, 33, 31],
            [2002, 10428, 34, 38],
            [2002, 10431, 27, 34],
            [2002, 10432, 41, 38],
            [2002, 10433, 26, 32],
            [2002, 10434, 41, 38],
            [2002, 10435, 43, 34],
            [2002, 10436, 32, 31],
            [2002, 10437, 41, 30],
            [2002, 10438, 27, 31],
            [2002, 10439, 40, 44],
            [2002, 10440, 26, 35],
            [2002, 10441, 42, 37],
            [2002, 10442, 33, 34],
            [2002, 10443, 26, 29],
            [2002, 10444, 44, 31],
            [2002, 10445, 46, 38],
            [2002, 10447, 26, 29],
            [2002, 10448, 37, 33],
            [2002, 10450, 26, 33],
            [2002, 10453, 67, 36],
            [2002, 10454, 62, 36],
            [2002, 10455, 67, 42],
            [2002, 10456, 25, 32],
            [2002, 10458, 26, 30],
            [2002, 10459, 34, 31],
            [2002, 10461, 27, 34],
            [2002, 10463, 21, 27],
            [2002, 10464, 30, 33],
            [2002, 10467, 26, 36],
            [2002, 10469, 31, 32],
            [2002, 10471, 31, 29],
            [2002, 10474, 18, 17],
            [2002, 10475, 18, 17],
            [2002, 10476, 19, 20],
            [2002, 10477, 21, 21],
            [2002, 10478, 28, 41],
            [2002, 10479, 40, 31],
            [2002, 10480, 25, 29],
            [2002, 10482, 26, 33],
            [2002, 10483, 32, 38],
            [2002, 10484, 26, 33],
            [2002, 10485, 31, 38],
            [2002, 10486, 26, 32],
            [2002, 10487, 31, 39],
            [2002, 10490, 16, 29],
            [2002, 10491, 9, 22],
            [2002, 10492, 8, 14],
            [2002, 10493, 36, 38],
            [2002, 10494, 11, 39],
            [2002, 10495, 13, 31],
            [2002, 10496, 10, 21],
            [2002, 10497, 29, 57],
            [2002, 10498, 10, 27],
            [2002, 10499, 9, 55],
            [2002, 10500, 12, 57],
            [2002, 10501, 12, 57],
            [2002, 10502, 33, 84],
            [2002, 10503, 12, 59],
            [2002, 10504, 15, 79],
            [2002, 10505, 34, 63],
            [2002, 10506, 16, 42],
            [2002, 10507, 10, 24],
            [2002, 10508, 26, 64],
            [2002, 10509, 29, 43],
            [2002, 10510, 15, 41],
            [2002, 10511, 8, 21],
            [2002, 10512, 26, 29],
            [2002, 10513, 35, 36],
            [2002, 10514, 18, 26],
            [2002, 10515, 19, 31],
            [2002, 10516, 17, 26],
            [2002, 10517, 26, 36],
            [2002, 10518, 20, 23],
            [2002, 10519, 23, 26],
            [2002, 10520, 12, 15],
            [2002, 10521, 20, 26],
            [2002, 10522, 20, 26],
            [2002, 10523, 20, 26],
            [2002, 10524, 19, 24],
            [2002, 10525, 20, 25],
            [2002, 10526, 20, 26],
            [2002, 10527, 18, 22],
            [2002, 10528, 26, 25],
            [2002, 10529, 20, 25],
            [2002, 10530, 20, 25],
            [2002, 10531, 19, 24],
            [2002, 10532, 23, 22],
            [2002, 10533, 35, 30],
            [2002, 10534, 16, 14],
            [2002, 10535, 32, 27],
            [2002, 10536, 18, 22],
            [2002, 10537, 24, 22],
            [2002, 10538, 31, 26],
            [2002, 10539, 18, 19],
            [2002, 10540, 34, 27],
            [2002, 10541, 42, 36],
            [2002, 10542, 48, 32],
            [2002, 10543, 7, 7],
            [2002, 10544, 12, 11],
            [2002, 10545, 7, 7],
            [2002, 10546, 8, 8],
            [2002, 10547, 8, 8],
            [2002, 10548, 12, 12],
            [2002, 10549, 8, 8],
            [2002, 10550, 15, 11],
            [2002, 10551, 8, 8],
            [2002, 10552, 8, 8],
            [2002, 10553, 20, 15],
            [2002, 10554, 20, 13],
            [2002, 10555, 13, 9],
            [2002, 10556, 22, 15],
            [2002, 10557, 16, 11],
            [2002, 10558, 31, 18],
            [2002, 10559, 20, 13],
            [2002, 10560, 20, 14],
            [2002, 10577, 19, 12],
            [2002, 10578, 44, 52],
            [2002, 10579, 59, 50],
            [2002, 10580, 77, 63],
            [2002, 10581, 97, 82],
            [2002, 10582, 74, 61],
            [2002, 10583, 66, 60],
            [2002, 10584, 81, 67],
            [2002, 10585, 62, 65],
            [2002, 10586, 88, 77],
            [2002, 10587, 78, 64],
            [2002, 10588, 48, 47],
            [2002, 10589, 74, 67],
            [2002, 10590, 93, 73],
            [2002, 10591, 90, 85],
            [2002, 10592, 77, 43],
            [2002, 10593, 60, 51],
            [2002, 10594, 79, 76],
            [2002, 10595, 44, 50],
            [2002, 10596, 53, 51],
            [2002, 10597, 66, 54],
            [2002, 10598, 62, 49],
            [2002, 10600, 17, 20],
            [2002, 10601, 18, 17],
            [2002, 10602, 32, 38],
            [2002, 10603, 45, 45],
            [2002, 10604, 51, 33],
            [2002, 10605, 21, 11],
            [2002, 10606, 17, 11],
            [2002, 10607, 27, 15],
            [2002, 10608, 15, 11],
            [2002, 10609, 15, 11],
            [2002, 10610, 24, 11],
            [2002, 10611, 24, 16],
            [2002, 10612, 22, 17],
            [2002, 10613, 55, 18],
            [2002, 10614, 45, 29],
            [2002, 10615, 51, 27],
            [2002, 10616, 44, 38],
            [2002, 10617, 59, 34],
            [2002, 10618, 62, 34],
            [2002, 10619, 45, 26],
            [2002, 10620, 33, 23],
            [2002, 10621, 45, 19],
            [2002, 10622, 40, 21],
            [2002, 10623, 46, 21],
            [2002, 10624, 45, 21],
            [2002, 10625, 38, 26],
            [2002, 10626, 60, 32],
            [2002, 10627, 53, 26],
            [2002, 10628, 60, 40],
            [2002, 10629, 58, 38],
            [2002, 10630, 35, 21],
            [2002, 10631, 53, 21],
            [2002, 10632, 40, 21],
            [2002, 10633, 58, 29],
            [2002, 10634, 58, 21],
            [2002, 10635, 59, 21],
            [2002, 10636, 45, 29],
            [2002, 10637, 45, 26],
            [2002, 10638, 27, 19],
            [2002, 10639, 60, 33],
            [2002, 10640, 55, 33],
            [2002, 10641, 55, 34],
            [2002, 10642, 57, 35],
            [2002, 10643, 45, 31],
            [2002, 10644, 55, 33],
            [2002, 10645, 40, 34],
            [2002, 10646, 56, 33],
            [2002, 10647, 56, 33],
            [2002, 10648, 46, 40],
            [2002, 10649, 50, 30],
            [2002, 10650, 56, 27],
            [2002, 10651, 55, 28],
            [2002, 10652, 44, 28],
            [2002, 10653, 60, 27],
            [2002, 10654, 43, 33],
            [2002, 10655, 56, 32],
            [2002, 10656, 56, 33],
            [2002, 10657, 44, 25],
            [2002, 10658, 53, 23],
            [2002, 10659, 24, 19],
            [2002, 10660, 62, 28],
            [2002, 10661, 93, 35],
            [2002, 10662, 57, 35],
            [2002, 10663, 50, 21],
            [2002, 10664, 60, 28],
            [2002, 10665, 59, 29],
            [2002, 10666, 62, 25],
            [2002, 10667, 58, 25],
            [2002, 10668, 53, 27],
            [2002, 10669, 24, 19],
            [2002, 10670, 55, 25],
            [2002, 10671, 55, 35],
            [2002, 10672, 62, 34],
            [2002, 10673, 40, 18],
            [2002, 10674, 45, 22],
            [2002, 10675, 46, 44],
            [2002, 10676, 46, 43],
            [2002, 10677, 40, 21],
            [2002, 10678, 48, 31],
            [2002, 10679, 71, 33],
            [2002, 10680, 28, 23],
            [2002, 10681, 52, 27],
            [2002, 10682, 46, 28],
            [2002, 10683, 44, 28],
            [2002, 10684, 31, 33],
            [2002, 10685, 101, 44],
            [2002, 10686, 53, 45],
            [2002, 10687, 45, 48],
            [2002, 10688, 72, 48],
            [2002, 10689, 72, 46],
            [2002, 10690, 73, 48],
            [2002, 10691, 74, 48],
            [2002, 10692, 78, 31],
            [2002, 10693, 102, 32],
            [2002, 10694, 77, 31],
            [2002, 10695, 61, 32],
            [2002, 10696, 61, 32],
            [2002, 10697, 40, 31],
            [2002, 10698, 46, 41],
            [2002, 10699, 54, 41],
            [2002, 10700, 24, 25],
            [2002, 10701, 91, 30],
            [2002, 10702, 92, 30],
            [2002, 10703, 93, 30],
            [2002, 10704, 60, 30],
            [2002, 10705, 69, 28],
            [2002, 10706, 61, 28],
            [2002, 10707, 49, 53],
            [2002, 10708, 55, 53],
            [2002, 10709, 57, 53],
            [2002, 10710, 89, 24],
            [2002, 10711, 57, 24],
            [2002, 10712, 62, 44],
            [2002, 10713, 62, 44],
            [2002, 10714, 53, 35],
            [2002, 10715, 93, 28],
            [2002, 10716, 60, 53],
            [2002, 10717, 58, 53],
            [2002, 10718, 53, 53],
            [2002, 10719, 74, 48],
            [2002, 10720, 79, 48],
            [2002, 10721, 33, 28],
            [2002, 10722, 76, 47],
            [2002, 10723, 60, 47],
            [2002, 10724, 61, 47],
            [2002, 10725, 55, 48],
            [2002, 10726, 43, 32],
            [2002, 10727, 57, 33],
            [2002, 10728, 59, 35],
            [2002, 10729, 57, 34],
            [2002, 10730, 61, 33],
            [2002, 10731, 44, 27],
            [2002, 10732, 60, 28],
            [2002, 10733, 61, 28],
            [2002, 10734, 61, 28],
            [2002, 10735, 61, 23],
            [2002, 10736, 60, 22],
            [2002, 10737, 103, 24],
            [2002, 10738, 62, 35],
            [2002, 10739, 32, 19],
            [2002, 10740, 56, 26],
            [2002, 10741, 46, 27],
            [2002, 10742, 55, 40],
            [2002, 10743, 48, 36],
            [2002, 10744, 46, 29],
            [2002, 10745, 55, 33],
            [2002, 10746, 55, 29],
            [2002, 10747, 33, 24],
            [2002, 10748, 53, 21],
            [2002, 10749, 55, 29],
            [2002, 10750, 56, 12],
            [2002, 10751, 55, 26],
            [2002, 10752, 56, 26],
            [2002, 10753, 61, 33],
            [2002, 10754, 53, 25],
            [2002, 10755, 22, 16],
            [2002, 10756, 100, 77],
            [2002, 10757, 23, 15],
            [2002, 10758, 32, 13],
            [2002, 10759, 67, 30],
            [2002, 10760, 68, 39],
            [2002, 10761, 54, 38],
            [2002, 10762, 55, 30],
            [2002, 10763, 45, 30],
            [2002, 10764, 32, 30],
            [2002, 10765, 40, 29],
            [2002, 10766, 57, 29],
            [2002, 10767, 60, 22],
            [2002, 10768, 53, 22],
            [2002, 10769, 57, 22],
            [2002, 10770, 59, 45],
            [2002, 10771, 61, 45],
            [2002, 10772, 40, 53],
            [2002, 10773, 56, 61],
            [2002, 10774, 45, 29],
            [2002, 10775, 55, 28],
            [2002, 10776, 46, 21],
            [2002, 10777, 36, 24],
            [2002, 10778, 99, 24],
            [2002, 10779, 45, 33],
            [2002, 10780, 53, 23],
            [2002, 10781, 48, 23],
            [2002, 10782, 45, 21],
            [2002, 10783, 67, 41],
            [2002, 10784, 60, 29],
            [2002, 10785, 61, 30],
            [2002, 10786, 44, 23],
            [2002, 10787, 52, 23],
            [2002, 10788, 57, 53],
            [2002, 10789, 49, 30],
            [2002, 10790, 61, 30],
            [2002, 10791, 62, 30],
            [2002, 10792, 32, 21],
            [2002, 10793, 57, 21],
            [2002, 10794, 61, 22],
            [2002, 10795, 62, 22],
            [2002, 10796, 63, 22],
            [2002, 10797, 56, 22],
            [2002, 10798, 37, 22],
            [2002, 10799, 27, 20],
            [2002, 10800, 56, 39],
            [2002, 10801, 55, 29],
            [2002, 10802, 46, 29],
            [2002, 10803, 41, 23],
            [2002, 10804, 72, 26],
            [2002, 10805, 74, 27],
            [2002, 10806, 45, 27],
            [2002, 10807, 55, 27],
            [2002, 10808, 36, 19],
            [2002, 10809, 33, 23],
            [2002, 10810, 45, 23],
            [2002, 10811, 45, 20],
            [2002, 10812, 82, 61],
            [2002, 10813, 55, 49],
            [2002, 10814, 45, 26],
            [2002, 10815, 56, 26],
            [2002, 10816, 60, 25],
            [2002, 10817, 56, 25],
            [2002, 10818, 61, 40],
            [2002, 10819, 60, 38],
            [2002, 10820, 61, 32],
            [2002, 10821, 54, 21],
            [2002, 10822, 56, 21],
            [2002, 10823, 49, 21],
            [2002, 10824, 44, 28],
            [2002, 10825, 45, 29],
            [2002, 10826, 50, 30],
            [2002, 10827, 46, 30],
            [2002, 10828, 38, 23],
            [2002, 10829, 58, 34],
            [2002, 10830, 55, 33],
            [2002, 10831, 58, 32],
            [2002, 10832, 55, 32],
            [2002, 10833, 55, 32],
            [2002, 10834, 55, 33],
            [2002, 10835, 56, 33],
            [2002, 10836, 53, 33],
            [2002, 10837, 62, 34],
            [2002, 10838, 56, 33],
            [2002, 10839, 45, 33],
            [2002, 10840, 32, 27],
            [2002, 10841, 91, 23],
            [2002, 10842, 40, 21],
            [2002, 10843, 56, 29],
            [2002, 10844, 41, 35],
            [2002, 10845, 36, 32],
            [2002, 10846, 44, 31],
            [2002, 10847, 42, 22],
            [2002, 10848, 56, 22],
            [2002, 10849, 56, 22],
            [2002, 10850, 49, 33],
            [2002, 10851, 42, 30],
            [2002, 10852, 46, 29],
            [2002, 10853, 61, 43],
            [2002, 10854, 57, 30],
            [2002, 10855, 61, 30],
            [2002, 10856, 61, 38],
            [2002, 10857, 60, 38],
            [2002, 10858, 54, 34],
            [2002, 10859, 61, 34],
            [2002, 10860, 78, 35],
            [2002, 10861, 72, 35],
            [2002, 10862, 53, 34],
            [2002, 10863, 30, 27],
            [2002, 10864, 80, 36],
            [2002, 10865, 55, 23],
            [2002, 10866, 41, 26],
            [2002, 10867, 56, 33],
            [2002, 10868, 56, 33],
            [2002, 10869, 62, 22],
            [2002, 10870, 61, 29],
            [2002, 10871, 61, 30],
            [2002, 10872, 60, 22],
            [2002, 10873, 73, 23],
            [2002, 10874, 62, 22],
            [2002, 10875, 59, 27],
            [2002, 10876, 72, 30],
            [2002, 10877, 87, 37],
            [2002, 10878, 61, 30],
            [2002, 10879, 61, 28],
            [2002, 10880, 62, 29],
            [2002, 10881, 45, 21],
            [2002, 10882, 75, 29],
            [2002, 10883, 90, 29],
            [2002, 10884, 101, 29],
            [2002, 10885, 45, 40],
            [2002, 10886, 60, 30],
            [2002, 10887, 45, 30],
            [2002, 10888, 79, 38],
            [2002, 10889, 57, 32],
            [2002, 10890, 46, 24],
            [2002, 10891, 33, 23],
            [2002, 10892, 41, 28],
            [2002, 10893, 62, 50],
            [2002, 10894, 60, 50],
            [2002, 10895, 91, 43],
            [2002, 10896, 59, 44],
            [2002, 10897, 61, 44],
            [2002, 10898, 61, 44],
            [2002, 10899, 52, 27],
            [2002, 10900, 46, 23],
            [2002, 10901, 52, 20],
            [2002, 10902, 53, 21],
            [2002, 10903, 55, 27],
            [2002, 10904, 56, 28],
            [2002, 10905, 45, 27],
            [2002, 10906, 61, 42],
            [2002, 10907, 61, 41],
            [2002, 10908, 55, 24],
            [2002, 10909, 90, 25],
            [2002, 10910, 56, 26],
            [2002, 10911, 76, 61],
            [2002, 10912, 76, 61],
            [2002, 10913, 48, 44],
            [2002, 10914, 99, 43],
            [2002, 10915, 62, 49],
            [2002, 10916, 71, 48],
            [2002, 10917, 77, 48],
            [2002, 10918, 41, 38],
            [2002, 10978, 56, 21],
            [2002, 10979, 54, 35],
            [2002, 10980, 53, 29],
            [2002, 11091, 9, 6],
            [2002, 11092, 13, 9],
            [2002, 11093, 12, 7],
            [2002, 11094, 19, 10],
            [2002, 11095, 9, 7],
            [2002, 11096, 24, 18],
            [2002, 11097, 11, 7],
            [2002, 11098, 10, 7],
            [2002, 11099, 45, 37],
            [2002, 11100, 9, 6],
            [2002, 11101, 13, 8],
            [2002, 11102, 11, 7],
            [2002, 11103, 17, 10],
            [2002, 11104, 59, 35],
            [2002, 11105, 35, 35],
            [2002, 11106, 30, 18],
            [2002, 11107, 21, 12],
            [2002, 11108, 10, 5],
            [2002, 11109, 23, 19],
            [2002, 11110, 20, 10],
            [2002, 11111, 8, 8],
            [2002, 11112, 32, 19],
            [2002, 11113, 28, 16],
            [2002, 11114, 43, 29],
            [2002, 11115, 9, 5],
            [2002, 11116, 9, 5],
            [2002, 11117, 10, 7],
            [2002, 11118, 18, 12],
            [2002, 11119, 43, 24],
            [2002, 11120, 33, 23],
            [2002, 11121, 11, 8],
            [2002, 11122, 12, 7],
            [2002, 11123, 16, 9],
            [2002, 11124, 10, 8],
            [2002, 11125, 32, 16],
            [2002, 11126, 15, 9],
            [2002, 11127, 8, 8],
            [2002, 11128, 14, 7],
            [2002, 11129, 8, 5],
            [2002, 11130, 16, 10],
            [2002, 11131, 8, 6],
            [2002, 11132, 20, 12],
            [2002, 11133, 13, 8],
            [2002, 11134, 7, 4],
            [2002, 11135, 59, 30],
            [2002, 11136, 12, 8],
            [2002, 11137, 7, 5],
            [2002, 11138, 21, 15],
            [2002, 11139, 14, 9],
            [2002, 11140, 12, 10],
            [2002, 11141, 11, 7],
            [2002, 11142, 10, 7],
            [2002, 11143, 9, 6],
            [2002, 11144, 11, 8],
            [2002, 11145, 29, 23],
            [2002, 11146, 8, 6],
            [2002, 11147, 5, 3],
            [2002, 11148, 35, 31],
            [2002, 11149, 15, 11],
            [2002, 11150, 24, 17],
            [2002, 11151, 15, 13],
            [2002, 11152, 14, 12],
            [2002, 11153, 15, 10],
            [2002, 11154, 27, 17],
            [2002, 11155, 17, 10],
            [2002, 11156, 12, 11],
            [2002, 11157, 12, 10],
            [2002, 11158, 13, 11],
            [2002, 11159, 13, 12],
            [2002, 11160, 14, 10],
            [2002, 11161, 14, 11],
            [2002, 11162, 13, 12],
            [2002, 11163, 13, 13],
            [2002, 11164, 18, 17],
            [2002, 11165, 13, 10],
            [2002, 11166, 53, 33],
            [2002, 11167, 93, 51],
            [2002, 11168, 26, 18],
            [2002, 11169, 11, 10],
            [2002, 11170, 14, 12],
            [2002, 11171, 15, 12],
            [2002, 11172, 10, 10],
            [2002, 11173, 15, 13],
            [2002, 11174, 8, 8],
            [2002, 11175, 7, 7],
            [2002, 11176, 5, 5],
            [2002, 11177, 21, 16],
            [2002, 11178, 8, 9],
            [2002, 11179, 12, 10],
            [2002, 11180, 11, 8],
            [2002, 11181, 16, 13],
            [2002, 11182, 14, 13],
            [2002, 11183, 13, 11],
            [2002, 11184, 112, 87],
            [2002, 11185, 112, 87],
            [2002, 11186, 112, 87],
            [2002, 11187, 112, 87],
            [2002, 11188, 112, 87],
            [2002, 11189, 79, 123],
            [2002, 11190, 102, 83],
            [2002, 11191, 102, 83],
            [2002, 11192, 102, 83],
            [2002, 11193, 102, 83],
            [2002, 11194, 62, 40],
            [2002, 11195, 60, 37],
            [2002, 11196, 76, 34],
            [2002, 11197, 88, 30],
            [2002, 11198, 22, 23],
            [2002, 11199, 33, 25],
            [2002, 11200, 47, 33],
            [2002, 11201, 11, 11],
            [2002, 11202, 14, 18],
            [2002, 11203, 14, 15],
            [2002, 11204, 75, 58],
            [2002, 11205, 57, 37],
            [2002, 11206, 56, 55],
            [2002, 11207, 13, 15],
            [2002, 11208, 33, 18],
            [2002, 11292, 14, 18],
            [2002, 11293, 10, 12],
            [2002, 11294, 12, 15],
            [2002, 11295, 12, 15],
            [2003, 2, 80, 34],
            [2003, 7, 27, 26],
            [2003, 25, 13, 9],
            [2003, 42, 19, 20],
            [2003, 48, 66, 54],
            [2003, 49, 31, 22],
            [2003, 51, 34, 29],
            [2003, 62, 19, 28],
            [2003, 65, 21, 19],
            [2003, 78, 25, 18],
            [2003, 82, 12, 19],
            [2003, 83, 33, 37],
            [2003, 87, 31, 27],
            [2003, 99, 26, 26],
            [2003, 101, 53, 45],
            [2003, 119, 36, 25],
            [2003, 122, 28, 30],
            [2003, 125, 27, 28],
            [2003, 135, 37, 32],
            [2003, 138, 56, 35],
            [2003, 163, 36, 34],
            [2003, 166, 30, 29],
            [2003, 169, 31, 19],
            [2003, 186, 18, 18],
            [2003, 190, 27, 26],
            [2003, 194, 20, 22],
            [2003, 200, 36, 27],
            [2003, 204, 12, 21],
            [2003, 211, 20, 42],
            [2003, 215, 28, 27],
            [2003, 216, 21, 18],
            [2003, 218, 47, 23],
            [2003, 220, 16, 17],
            [2003, 226, 21, 15],
            [2003, 231, 48, 42],
            [2003, 233, 18, 19],
            [2003, 234, 11, 15],
            [2003, 239, 57, 50],
            [2003, 240, 51, 29],
            [2003, 242, 60, 30],
            [2003, 243, 56, 32],
            [2003, 246, 41, 27],
            [2003, 248, 36, 18],
            [2003, 270, 48, 38],
            [2003, 272, 39, 16],
            [2003, 282, 39, 20],
            [2003, 285, 31, 18],
            [2003, 286, 25, 28],
            [2003, 299, 25, 18],
            [2003, 305, 27, 29],
            [2003, 306, 31, 27],
            [2003, 308, 11, 35],
            [2003, 310, 18, 18],
            [2003, 312, 19, 18],
            [2003, 314, 17, 24],
            [2003, 317, 56, 37],
            [2003, 320, 21, 25],
            [2003, 324, 38, 33],
            [2003, 327, 40, 36],
            [2003, 329, 36, 27],
            [2003, 330, 51, 30],
            [2003, 332, 57, 29],
            [2003, 334, 31, 38],
            [2003, 337, 28, 27],
            [2003, 339, 33, 24],
            [2003, 344, 38, 37],
            [2003, 346, 47, 38],
            [2003, 355, 43, 28],
            [2003, 361, 27, 26],
            [2003, 365, 72, 44],
            [2003, 378, 18, 21],
            [2003, 379, 14, 12],
            [2003, 389, 17, 22],
            [2003, 392, 18, 18],
            [2003, 399, 65, 34],
            [2003, 402, 88, 50],
            [2003, 403, 42, 26],
            [2003, 418, 20, 19],
            [2003, 424, 22, 21],
            [2003, 425, 14, 21],
            [2003, 428, 26, 19],
            [2003, 430, 20, 24],
            [2003, 432, 63, 38],
            [2003, 436, 42, 36],
            [2003, 455, 48, 26],
            [2003, 471, 18, 22],
            [2003, 479, 28, 28],
            [2003, 480, 53, 23],
            [2003, 487, 28, 26],
            [2003, 493, 67, 52],
            [2003, 494, 16, 17],
            [2003, 497, 10, 14],
            [2003, 503, 81, 22],
            [2003, 504, 12, 10],
            [2003, 505, 46, 27],
            [2003, 519, 18, 24],
            [2003, 525, 19, 29],
            [2003, 536, 28, 18],
            [2003, 541, 112, 45],
            [2003, 545, 25, 28],
            [2003, 568, 18, 18],
            [2003, 569, 87, 28],
            [2003, 570, 24, 19],
            [2003, 573, 28, 26],
            [2003, 577, 47, 22],
            [2003, 585, 50, 48],
            [2003, 590, 47, 54],
            [2003, 593, 37, 33],
            [2003, 595, 45, 27],
            [2003, 597, 34, 16],
            [2003, 599, 51, 29],
            [2003, 604, 117, 58],
            [2003, 608, 25, 18],
            [2003, 612, 33, 39],
            [2003, 618, 23, 19],
            [2003, 625, 37, 17],
            [2003, 628, 34, 27],
            [2003, 631, 35, 25],
            [2003, 654, 15, 12],
            [2003, 660, 56, 37],
            [2003, 662, 58, 43],
            [2003, 663, 60, 33],
            [2003, 669, 26, 20],
            [2003, 678, 18, 23],
            [2003, 686, 15, 21],
            [2003, 691, 26, 32],
            [2003, 694, 36, 29],
            [2003, 695, 60, 45],
            [2003, 700, 51, 38],
            [2003, 703, 12, 16],
            [2003, 704, 45, 26],
            [2003, 716, 53, 51],
            [2003, 717, 38, 27],
            [2003, 719, 55, 43],
            [2003, 720, 22, 35],
            [2003, 724, 27, 35],
            [2003, 734, 19, 31],
            [2003, 737, 14, 12],
            [2003, 750, 36, 24],
            [2003, 751, 30, 16],
            [2003, 754, 28, 27],
            [2003, 766, 82, 43],
            [2003, 769, 52, 37],
            [2003, 773, 44, 33],
            [2003, 781, 26, 20],
            [2003, 785, 50, 44],
            [2003, 790, 36, 26],
            [2003, 801, 19, 20],
            [2003, 803, 32, 29],
            [2003, 805, 31, 24],
            [2003, 811, 36, 21],
            [2003, 815, 16, 16],
            [2003, 820, 56, 38],
            [2003, 821, 38, 27],
            [2003, 822, 16, 20],
            [2003, 826, 19, 18],
            [2003, 827, 10, 14],
            [2003, 835, 52, 28],
            [2003, 843, 34, 27],
            [2003, 844, 25, 23],
            [2003, 845, 49, 39],
            [2003, 848, 23, 22],
            [2003, 865, 65, 29],
            [2003, 871, 36, 23],
            [2003, 878, 7, 6],
            [2003, 882, 40, 29],
            [2003, 890, 34, 32],
            [2003, 894, 26, 12],
            [2003, 909, 99, 34],
            [2003, 913, 21, 21],
            [2003, 915, 48, 32],
            [2003, 922, 38, 28],
            [2003, 926, 50, 19],
            [2003, 938, 11, 12],
            [2003, 940, 11, 14],
            [2003, 941, 34, 30],
            [2003, 944, 40, 22],
            [2003, 949, 57, 30],
            [2003, 950, 14, 18],
            [2003, 964, 11, 15],
            [2003, 969, 48, 39],
            [2003, 971, 19, 16],
            [2003, 972, 33, 25],
            [2003, 978, 43, 43],
            [2003, 979, 18, 18],
            [2003, 985, 77, 36],
            [2003, 990, 21, 18],
            [2003, 993, 63, 35],
            [2003, 998, 34, 19],
            [2003, 1003, 8, 6],
            [2003, 1008, 21, 23],
            [2003, 1016, 11, 14],
            [2003, 1030, 9, 14],
            [2003, 1033, 19, 19],
            [2003, 1042, 118, 64],
            [2003, 1048, 34, 32],
            [2003, 1051, 22, 18],
            [2003, 1056, 20, 39],
            [2003, 1059, 40, 40],
            [2003, 1073, 61, 29],
            [2003, 1082, 93, 39],
            [2003, 1094, 23, 19],
            [2003, 1095, 18, 18],
            [2003, 1097, 30, 20],
            [2003, 1100, 31, 24],
            [2003, 1102, 15, 16],
            [2003, 1106, 75, 28],
            [2003, 1109, 30, 27],
            [2003, 1111, 45, 46],
            [2003, 1131, 53, 39],
            [2003, 1132, 11, 14],
            [2003, 1136, 38, 39],
            [2003, 1141, 64, 35],
            [2003, 1142, 22, 23],
            [2003, 1144, 25, 20],
            [2003, 1145, 28, 23],
            [2003, 1150, 33, 24],
            [2003, 1155, 29, 26],
            [2003, 1156, 26, 18],
            [2003, 1157, 40, 33],
            [2003, 1159, 83, 38],
            [2003, 1167, 25, 21],
            [2003, 1169, 31, 26],
            [2003, 1174, 28, 41],
            [2003, 1175, 28, 21],
            [2003, 1177, 31, 26],
            [2003, 1186, 15, 18],
            [2003, 1194, 92, 39],
            [2003, 1200, 19, 19],
            [2003, 1203, 11, 17],
            [2003, 1205, 25, 22],
            [2003, 1213, 22, 19],
            [2003, 1217, 47, 26],
            [2003, 1219, 31, 18],
            [2003, 1221, 18, 18],
            [2003, 1224, 78, 47],
            [2003, 1226, 19, 26],
            [2003, 1228, 31, 22],
            [2003, 1234, 12, 15],
            [2003, 1235, 25, 20],
            [2003, 1238, 14, 25],
            [2003, 1247, 49, 29],
            [2003, 1254, 48, 24],
            [2003, 1262, 39, 29],
            [2003, 1268, 37, 28],
            [2003, 1275, 32, 13],
            [2003, 1281, 14, 18],
            [2003, 1295, 40, 47],
            [2003, 1302, 48, 55],
            [2003, 1303, 73, 35],
            [2003, 1305, 20, 18],
            [2003, 1319, 50, 24],
            [2003, 1320, 39, 35],
            [2003, 1323, 43, 27],
            [2003, 1334, 83, 50],
            [2003, 1358, 57, 36],
            [2003, 1359, 37, 27],
            [2003, 1361, 46, 27],
            [2003, 1363, 55, 47],
            [2003, 1367, 52, 39],
            [2003, 1370, 13, 20],
            [2003, 1375, 34, 33],
            [2003, 1396, 11, 20],
            [2003, 1420, 46, 43],
            [2003, 1445, 70, 25],
            [2003, 1454, 23, 25],
            [2003, 1456, 26, 26],
            [2003, 1465, 17, 18],
            [2003, 1466, 33, 21],
            [2003, 1471, 50, 37],
            [2003, 1473, 14, 19],
            [2003, 1475, 59, 27],
            [2003, 1476, 51, 37],
            [2003, 1477, 52, 19],
            [2003, 1481, 40, 26],
            [2003, 1482, 13, 17],
            [2003, 1484, 47, 32],
            [2003, 1486, 14, 13],
            [2003, 1490, 35, 18],
            [2003, 1491, 11, 9],
            [2003, 1493, 26, 19],
            [2003, 1507, 35, 22],
            [2003, 1508, 27, 27],
            [2003, 1510, 16, 19],
            [2003, 1511, 32, 26],
            [2003, 1515, 23, 18],
            [2003, 1522, 26, 20],
            [2003, 1525, 37, 36],
            [2003, 1527, 35, 31],
            [2003, 1530, 73, 50],
            [2003, 1536, 17, 20],
            [2003, 1537, 70, 51],
            [2003, 1548, 40, 38],
            [2003, 1553, 46, 27],
            [2003, 1556, 37, 29],
            [2003, 1557, 31, 27],
            [2003, 1561, 18, 18],
            [2003, 1562, 49, 36],
            [2003, 1568, 29, 27],
            [2003, 1575, 178, 74],
            [2003, 1577, 26, 18],
            [2003, 1580, 41, 34],
            [2003, 1582, 23, 23],
            [2003, 1587, 17, 17],
            [2003, 1589, 38, 18],
            [2003, 1598, 14, 8],
            [2003, 1610, 27, 26],
            [2003, 1628, 33, 21],
            [2003, 1635, 17, 16],
            [2003, 1638, 46, 40],
            [2003, 1644, 116, 66],
            [2003, 1645, 40, 25],
            [2003, 1659, 24, 21],
            [2003, 1660, 54, 31],
            [2003, 1662, 14, 11],
            [2003, 1663, 45, 35],
            [2003, 1664, 17, 15],
            [2003, 1672, 50, 32],
            [2003, 1673, 83, 37],
            [2003, 1680, 131, 51],
            [2003, 1685, 38, 35],
            [2003, 1704, 16, 19],
            [2003, 1717, 50, 25],
            [2003, 1724, 36, 30],
            [2003, 1730, 17, 12],
            [2003, 1744, 47, 30],
            [2003, 1748, 45, 27],
            [2003, 1756, 28, 26],
            [2003, 1760, 13, 16],
            [2003, 1763, 22, 21],
            [2003, 1769, 51, 43],
            [2003, 1771, 18, 18],
            [2003, 1772, 12, 14],
            [2003, 1774, 22, 24],
            [2003, 1780, 37, 32],
            [2003, 1781, 35, 30],
            [2003, 1786, 19, 24],
            [2003, 1790, 18, 18],
            [2003, 1792, 26, 26],
            [2003, 1794, 31, 32],
            [2003, 1795, 13, 10],
            [2003, 1797, 53, 35],
            [2003, 1798, 37, 47],
            [2003, 1804, 33, 20],
            [2003, 1812, 14, 17],
            [2003, 1816, 156, 44],
            [2003, 1818, 18, 18],
            [2003, 1824, 31, 35],
            [2003, 1825, 18, 24],
            [2003, 1829, 17, 25],
            [2003, 1841, 38, 37],
            [2003, 1845, 43, 27],
            [2003, 1848, 54, 29],
            [2003, 1853, 51, 24],
            [2003, 1864, 110, 65],
            [2003, 1866, 54, 29],
            [2003, 1876, 47, 29],
            [2003, 1879, 38, 18],
            [2003, 1882, 16, 18],
            [2003, 1891, 35, 33],
            [2003, 1894, 33, 15],
            [2003, 1901, 36, 24],
            [2003, 1903, 74, 31],
            [2003, 1915, 42, 33],
            [2003, 1916, 23, 19],
            [2003, 1917, 49, 33],
            [2003, 1921, 17, 14],
            [2003, 1925, 33, 26],
            [2003, 1930, 10, 8],
            [2003, 1933, 11, 14],
            [2003, 1945, 51, 36],
            [2003, 1948, 21, 30],
            [2003, 1950, 20, 31],
            [2003, 1952, 192, 62],
            [2003, 1962, 12, 15],
            [2003, 1965, 66, 42],
            [2003, 1995, 50, 30],
            [2003, 2000, 35, 26],
            [2003, 2001, 34, 25],
            [2003, 2006, 21, 19],
            [2003, 2011, 12, 17],
            [2003, 2017, 33, 34],
            [2003, 2021, 30, 26],
            [2003, 2023, 11, 11],
            [2003, 2025, 67, 52],
            [2003, 2026, 138, 54],
            [2003, 2028, 48, 33],
            [2003, 2029, 41, 28],
            [2003, 2032, 16, 18],
            [2003, 2035, 54, 29],
            [2003, 2042, 29, 29],
            [2003, 2048, 14, 29],
            [2003, 2056, 28, 46],
            [2003, 2057, 68, 34],
            [2003, 2064, 62, 32],
            [2003, 2081, 34, 17],
            [2003, 2084, 72, 27],
            [2003, 2098, 13, 16],
            [2003, 2099, 36, 26],
            [2003, 2101, 36, 21],
            [2003, 2104, 51, 34],
            [2003, 2121, 17, 16],
            [2003, 2127, 15, 15],
            [2003, 2128, 28, 27],
            [2003, 2131, 26, 35],
            [2003, 2138, 27, 26],
            [2003, 2142, 9, 10],
            [2003, 2144, 21, 55],
            [2003, 2162, 31, 32],
            [2003, 2163, 46, 42],
            [2003, 2170, 29, 19],
            [2003, 2171, 24, 23],
            [2003, 2174, 25, 22],
            [2003, 2178, 12, 18],
            [2003, 2180, 41, 26],
            [2003, 2181, 65, 49],
            [2003, 2182, 34, 26],
            [2003, 2190, 26, 20],
            [2003, 2198, 21, 17],
            [2003, 2201, 27, 27],
            [2003, 2208, 42, 30],
            [2003, 2213, 41, 34],
            [2003, 2216, 36, 27],
            [2003, 2220, 30, 19],
            [2003, 2224, 37, 30],
            [2003, 2227, 19, 21],
            [2003, 2232, 27, 27],
            [2003, 2236, 36, 25],
            [2003, 2238, 34, 26],
            [2003, 2239, 49, 19],
            [2003, 2244, 23, 24],
            [2003, 2250, 40, 26],
            [2003, 2255, 42, 26],
            [2003, 2258, 26, 26],
            [2003, 2277, 29, 22],
            [2003, 2280, 9, 7],
            [2003, 2282, 18, 55],
            [2003, 2293, 51, 48],
            [2003, 2300, 36, 41],
            [2003, 2303, 32, 28],
            [2003, 2311, 36, 34],
            [2003, 2312, 37, 19],
            [2003, 2316, 48, 28],
            [2003, 2332, 14, 15],
            [2003, 2335, 53, 39],
            [2003, 2343, 38, 27],
            [2003, 2352, 38, 34],
            [2003, 2366, 15, 16],
            [2003, 2367, 46, 27],
            [2003, 2371, 51, 29],
            [2003, 2383, 48, 36],
            [2003, 2384, 23, 31],
            [2003, 2404, 26, 26],
            [2003, 2405, 33, 29],
            [2003, 2428, 28, 30],
            [2003, 2429, 12, 12],
            [2003, 2433, 47, 21],
            [2003, 2435, 16, 12],
            [2003, 2443, 50, 29],
            [2003, 2447, 23, 18],
            [2003, 2458, 32, 24],
            [2003, 2459, 28, 15],
            [2003, 2467, 12, 15],
            [2003, 2472, 28, 20],
            [2003, 2483, 50, 48],
            [2003, 2485, 13, 16],
            [2003, 2488, 31, 23],
            [2003, 2493, 50, 18],
            [2003, 2494, 37, 27],
            [2003, 2497, 35, 18],
            [2003, 2500, 23, 17],
            [2003, 2501, 55, 24],
            [2003, 2505, 40, 26],
            [2003, 2509, 15, 17],
            [2003, 2514, 109, 43],
            [2003, 2516, 42, 26],
            [2003, 2518, 52, 31],
            [2003, 2524, 10, 10],
            [2003, 2527, 37, 32],
            [2003, 2533, 10, 16],
            [2003, 2539, 89, 27],
            [2003, 2540, 18, 20],
            [2003, 2543, 18, 21],
            [2003, 2547, 17, 32],
            [2003, 2551, 93, 37],
            [2003, 2554, 12, 21],
            [2003, 2562, 104, 36],
            [2003, 2564, 29, 20],
            [2003, 2574, 76, 43],
            [2003, 2576, 50, 25],
            [2003, 2585, 48, 38],
            [2003, 2587, 43, 26],
            [2003, 2593, 42, 27],
            [2003, 2595, 38, 31],
            [2003, 2603, 60, 38],
            [2003, 2604, 27, 27],
            [2003, 2606, 18, 14],
            [2003, 2607, 13, 10],
            [2003, 2612, 43, 28],
            [2003, 2615, 71, 29],
            [2003, 2617, 34, 21],
            [2003, 2619, 11, 12],
            [2003, 2622, 24, 19],
            [2003, 2627, 52, 29],
            [2003, 2628, 50, 35],
            [2003, 2632, 50, 35],
            [2003, 2633, 46, 27],
            [2003, 2635, 12, 18],
            [2003, 2644, 31, 19],
            [2003, 2647, 28, 24],
            [2003, 2650, 28, 25],
            [2003, 2656, 19, 18],
            [2003, 2658, 44, 27],
            [2003, 2667, 43, 26],
            [2003, 2668, 61, 44],
            [2003, 2669, 74, 36],
            [2003, 2670, 39, 26],
            [2003, 2671, 45, 49],
            [2003, 2687, 46, 23],
            [2003, 2692, 51, 23],
            [2003, 2695, 12, 13],
            [2003, 2720, 32, 35],
            [2003, 2723, 36, 55],
            [2003, 2743, 26, 26],
            [2003, 2747, 39, 33],
            [2003, 2748, 44, 33],
            [2003, 2758, 30, 26],
            [2003, 2762, 60, 37],
            [2003, 2775, 50, 29],
            [2003, 2785, 12, 14],
            [2003, 2788, 40, 26],
            [2003, 2797, 22, 16],
            [2003, 2798, 12, 18],
            [2003, 2813, 47, 27],
            [2003, 2822, 26, 21],
            [2003, 2823, 25, 18],
            [2003, 2827, 12, 17],
            [2003, 2832, 16, 16],
            [2003, 2833, 42, 29],
            [2003, 2835, 29, 27],
            [2003, 2836, 26, 19],
            [2003, 2838, 33, 28],
            [2003, 2846, 26, 37],
            [2003, 2851, 19, 16],
            [2003, 2854, 43, 29],
            [2003, 2856, 56, 31],
            [2003, 2867, 63, 43],
            [2003, 2872, 18, 19],
            [2003, 2876, 60, 34],
            [2003, 2879, 23, 21],
            [2003, 2880, 38, 26],
            [2003, 2883, 40, 42],
            [2003, 2884, 33, 39],
            [2003, 2897, 67, 41],
            [2003, 2901, 54, 44],
            [2003, 2904, 60, 28],
            [2003, 2910, 18, 18],
            [2003, 2914, 41, 27],
            [2003, 2918, 92, 31],
            [2003, 2922, 14, 15],
            [2003, 2923, 87, 50],
            [2003, 2929, 51, 33],
            [2003, 2932, 28, 29],
            [2003, 2934, 19, 18],
            [2003, 2935, 55, 28],
            [2003, 2936, 37, 25],
            [2003, 2946, 37, 27],
            [2003, 2950, 39, 27],
            [2003, 2969, 24, 16],
            [2003, 2973, 35, 43],
            [2003, 2974, 34, 20],
            [2003, 2978, 27, 26],
            [2003, 2979, 22, 15],
            [2003, 2991, 36, 39],
            [2003, 2995, 39, 36],
            [2003, 3011, 40, 26],
            [2003, 3016, 40, 26],
            [2003, 3019, 37, 20],
            [2003, 3027, 18, 19],
            [2003, 3033, 59, 37],
            [2003, 3035, 19, 19],
            [2003, 3046, 57, 25],
            [2003, 3048, 48, 28],
            [2003, 3050, 26, 19],
            [2003, 3053, 57, 54],
            [2003, 3061, 51, 26],
            [2003, 3066, 51, 26],
            [2003, 3070, 40, 31],
            [2003, 3077, 57, 47],
            [2003, 3086, 114, 39],
            [2003, 3091, 15, 14],
            [2003, 3092, 40, 21],
            [2003, 3098, 38, 38],
            [2003, 3106, 18, 21],
            [2003, 3112, 49, 30],
            [2003, 3114, 57, 29],
            [2003, 3119, 11, 25],
            [2003, 3121, 24, 22],
            [2003, 3122, 37, 31],
            [2003, 3126, 40, 19],
            [2003, 3129, 82, 45],
            [2003, 3133, 43, 33],
            [2003, 3134, 38, 33],
            [2003, 3137, 33, 27],
            [2003, 3142, 29, 34],
            [2003, 3148, 38, 27],
            [2003, 3154, 60, 27],
            [2003, 3155, 23, 19],
            [2003, 3158, 15, 17],
            [2003, 3160, 19, 18],
            [2003, 3161, 18, 18],
            [2003, 3164, 49, 31],
            [2003, 3167, 19, 25],
            [2003, 3171, 34, 18],
            [2003, 3175, 44, 29],
            [2003, 3182, 154, 48],
            [2003, 3188, 52, 31],
            [2003, 3189, 48, 27],
            [2003, 3195, 31, 22],
            [2003, 3206, 55, 27],
            [2003, 3217, 34, 26],
            [2003, 3221, 40, 19],
            [2003, 3228, 50, 27],
            [2003, 3231, 18, 18],
            [2003, 3234, 45, 23],
            [2003, 3246, 91, 29],
            [2003, 3248, 17, 25],
            [2003, 3252, 35, 22],
            [2003, 3254, 25, 26],
            [2003, 3256, 29, 20],
            [2003, 3264, 25, 26],
            [2003, 3268, 30, 27],
            [2003, 3272, 43, 30],
            [2003, 3273, 66, 17],
            [2003, 3274, 23, 20],
            [2003, 3277, 40, 25],
            [2003, 3280, 36, 27],
            [2003, 3283, 23, 20],
            [2003, 3284, 45, 33],
            [2003, 3289, 95, 57],
            [2003, 3301, 39, 36],
            [2003, 3306, 19, 23],
            [2003, 3308, 55, 34],
            [2003, 3309, 34, 32],
            [2003, 3320, 47, 49],
            [2003, 3321, 41, 22],
            [2003, 3326, 18, 19],
            [2003, 3327, 43, 43],
            [2003, 3331, 35, 21],
            [2003, 3336, 22, 19],
            [2003, 3344, 22, 18],
            [2003, 3346, 35, 39],
            [2003, 3348, 50, 26],
            [2003, 3357, 12, 17],
            [2003, 3358, 19, 16],
            [2003, 3363, 51, 26],
            [2003, 3364, 11, 16],
            [2003, 3372, 47, 27],
            [2003, 3382, 32, 22],
            [2003, 3404, 43, 38],
            [2003, 3407, 36, 34],
            [2003, 3418, 62, 32],
            [2003, 3422, 42, 30],
            [2003, 3429, 42, 35],
            [2003, 3434, 7, 6],
            [2003, 3438, 48, 26],
            [2003, 3439, 31, 24],
            [2003, 3441, 53, 39],
            [2003, 3442, 24, 18],
            [2003, 3451, 41, 42],
            [2003, 3453, 18, 19],
            [2003, 3454, 11, 11],
            [2003, 3457, 67, 50],
            [2003, 3459, 24, 21],
            [2003, 3462, 51, 24],
            [2003, 3468, 28, 24],
            [2003, 3469, 25, 17],
            [2003, 3494, 11, 14],
            [2003, 3498, 17, 22],
            [2003, 3503, 62, 42],
            [2003, 3511, 18, 28],
            [2003, 3515, 14, 44],
            [2003, 3517, 47, 20],
            [2003, 3531, 24, 18],
            [2003, 3541, 25, 23],
            [2003, 3557, 10, 13],
            [2003, 3559, 41, 36],
            [2003, 3566, 15, 12],
            [2003, 3569, 55, 55],
            [2003, 3572, 32, 24],
            [2003, 3579, 19, 29],
            [2003, 3590, 25, 27],
            [2003, 3593, 54, 56],
            [2003, 3598, 16, 13],
            [2003, 3602, 18, 18],
            [2003, 3608, 41, 27],
            [2003, 3632, 26, 26],
            [2003, 3639, 35, 23],
            [2003, 3642, 59, 26],
            [2003, 3644, 39, 26],
            [2003, 3650, 35, 27],
            [2003, 3653, 24, 18],
            [2003, 3656, 46, 27],
            [2003, 3659, 42, 29],
            [2003, 3661, 26, 26],
            [2003, 3667, 29, 31],
            [2003, 3669, 11, 18],
            [2003, 3670, 110, 48],
            [2003, 3679, 17, 18],
            [2003, 3700, 20, 22],
            [2003, 3703, 40, 25],
            [2003, 3718, 47, 25],
            [2003, 3726, 11, 12],
            [2003, 3729, 125, 48],
            [2003, 3731, 55, 69],
            [2003, 3747, 58, 31],
            [2003, 3751, 39, 26],
            [2003, 3755, 35, 26],
            [2003, 3761, 19, 21],
            [2003, 3765, 21, 20],
            [2003, 3777, 25, 29],
            [2003, 3782, 58, 32],
            [2003, 3786, 13, 12],
            [2003, 3795, 52, 37],
            [2003, 3796, 26, 26],
            [2003, 3807, 19, 18],
            [2003, 3827, 32, 26],
            [2003, 3828, 19, 20],
            [2003, 3832, 55, 50],
            [2003, 3833, 63, 33],
            [2003, 3834, 30, 41],
            [2003, 3841, 63, 29],
            [2003, 3845, 55, 26],
            [2003, 3854, 33, 26],
            [2003, 3855, 48, 38],
            [2003, 3859, 12, 15],
            [2003, 3870, 55, 35],
            [2003, 3874, 41, 27],
            [2003, 3883, 55, 34],
            [2003, 3884, 52, 30],
            [2003, 3889, 70, 26],
            [2003, 3897, 37, 26],
            [2003, 3905, 25, 25],
            [2003, 3915, 27, 27],
            [2003, 3921, 27, 26],
            [2003, 3925, 56, 41],
            [2003, 3932, 23, 27],
            [2003, 3942, 31, 29],
            [2003, 3943, 30, 24],
            [2003, 3947, 39, 33],
            [2003, 3953, 39, 34],
            [2003, 3956, 41, 51],
            [2003, 3959, 28, 18],
            [2003, 3960, 64, 52],
            [2003, 3963, 21, 15],
            [2003, 3969, 70, 45],
            [2003, 3970, 52, 35],
            [2003, 3972, 150, 72],
            [2003, 3976, 17, 14],
            [2003, 3985, 27, 22],
            [2003, 3988, 23, 28],
            [2003, 3992, 75, 36],
            [2003, 3993, 11, 12],
            [2003, 3999, 41, 27],
            [2003, 4015, 51, 27],
            [2003, 4022, 38, 23],
            [2003, 4023, 27, 27],
            [2003, 4026, 30, 18],
            [2003, 4027, 69, 33],
            [2003, 4028, 26, 33],
            [2003, 4031, 16, 14],
            [2003, 4034, 65, 39],
            [2003, 4035, 19, 18],
            [2003, 4038, 76, 34],
            [2003, 4040, 73, 35],
            [2003, 4043, 18, 17],
            [2003, 4047, 47, 38],
            [2003, 4074, 19, 27],
            [2003, 4082, 68, 34],
            [2003, 4084, 11, 16],
            [2003, 4091, 35, 15],
            [2003, 4095, 26, 26],
            [2003, 4096, 47, 31],
            [2003, 4106, 47, 30],
            [2003, 4107, 64, 28],
            [2003, 4109, 17, 17],
            [2003, 4111, 19, 13],
            [2003, 4116, 25, 26],
            [2003, 4118, 27, 26],
            [2003, 4120, 63, 32],
            [2003, 4122, 53, 48],
            [2003, 4124, 40, 28],
            [2003, 4125, 12, 16],
            [2003, 4134, 114, 49],
            [2003, 4152, 87, 42],
            [2003, 4156, 18, 19],
            [2003, 4164, 26, 18],
            [2003, 4165, 34, 33],
            [2003, 4169, 26, 20],
            [2003, 4173, 11, 16],
            [2003, 4176, 11, 14],
            [2003, 4177, 101, 57],
            [2003, 4182, 47, 26],
            [2003, 4185, 17, 19],
            [2003, 4188, 74, 23],
            [2003, 4189, 17, 26],
            [2003, 4199, 87, 37],
            [2003, 4203, 49, 27],
            [2003, 4206, 14, 18],
            [2003, 4209, 41, 38],
            [2003, 4229, 26, 20],
            [2003, 4242, 33, 30],
            [2003, 4246, 11, 22],
            [2003, 4250, 63, 18],
            [2003, 4272, 49, 31],
            [2003, 4279, 42, 35],
            [2003, 4283, 29, 22],
            [2003, 4285, 28, 31],
            [2003, 4298, 39, 44],
            [2003, 4299, 32, 30],
            [2003, 4301, 52, 51],
            [2003, 4310, 30, 24],
            [2003, 4312, 46, 27],
            [2003, 4318, 18, 18],
            [2003, 4320, 28, 29],
            [2003, 4325, 63, 26],
            [2003, 4326, 10, 13],
            [2003, 4329, 22, 26],
            [2003, 4333, 47, 31],
            [2003, 4338, 28, 26],
            [2003, 4345, 31, 24],
            [2003, 4349, 64, 32],
            [2003, 4350, 19, 18],
            [2003, 4352, 18, 18],
            [2003, 4353, 24, 23],
            [2003, 4358, 14, 15],
            [2003, 4362, 83, 52],
            [2003, 4364, 24, 27],
            [2003, 4380, 17, 19],
            [2003, 4382, 101, 41],
            [2003, 4384, 55, 37],
            [2003, 4386, 14, 16],
            [2003, 4391, 51, 28],
            [2003, 4406, 55, 26],
            [2003, 4413, 11, 12],
            [2003, 4414, 15, 22],
            [2003, 4415, 73, 33],
            [2003, 4421, 32, 26],
            [2003, 4426, 11, 14],
            [2003, 4438, 49, 32],
            [2003, 4440, 41, 28],
            [2003, 4441, 16, 13],
            [2003, 4442, 14, 18],
            [2003, 4446, 65, 32],
            [2003, 4454, 19, 18],
            [2003, 4461, 38, 26],
            [2003, 4464, 48, 26],
            [2003, 4470, 28, 30],
            [2003, 4471, 18, 18],
            [2003, 4477, 28, 31],
            [2003, 4487, 25, 31],
            [2003, 4491, 44, 29],
            [2003, 4494, 18, 20],
            [2003, 4495, 25, 20],
            [2003, 4500, 24, 18],
            [2003, 4504, 63, 38],
            [2003, 4506, 17, 18],
            [2003, 4508, 29, 25],
            [2003, 4510, 31, 33],
            [2003, 4515, 57, 43],
            [2003, 4518, 52, 35],
            [2003, 4521, 50, 27],
            [2003, 4524, 27, 27],
            [2003, 4532, 31, 18],
            [2003, 4536, 20, 19],
            [2003, 4542, 33, 23],
            [2003, 4545, 44, 32],
            [2003, 4550, 41, 28],
            [2003, 4552, 14, 16],
            [2003, 4558, 27, 25],
            [2003, 4563, 40, 27],
            [2003, 4572, 30, 26],
            [2003, 4587, 56, 22],
            [2003, 4591, 37, 25],
            [2003, 4602, 22, 25],
            [2003, 4606, 29, 29],
            [2003, 4608, 19, 22],
            [2003, 4610, 50, 24],
            [2003, 4611, 29, 18],
            [2003, 4613, 39, 33],
            [2003, 4616, 21, 17],
            [2003, 4617, 124, 52],
            [2003, 4618, 24, 22],
            [2003, 4623, 15, 18],
            [2003, 4626, 32, 21],
            [2003, 4633, 22, 19],
            [2003, 4634, 29, 27],
            [2003, 4635, 57, 13],
            [2003, 4638, 107, 34],
            [2003, 4643, 24, 22],
            [2003, 4644, 13, 17],
            [2003, 4648, 29, 11],
            [2003, 4660, 53, 25],
            [2003, 4668, 60, 33],
            [2003, 4670, 52, 23],
            [2003, 4676, 15, 18],
            [2003, 4684, 20, 18],
            [2003, 4689, 41, 28],
            [2003, 4693, 59, 29],
            [2003, 4694, 34, 20],
            [2003, 4703, 12, 14],
            [2003, 4710, 9, 7],
            [2003, 4711, 16, 15],
            [2003, 4712, 39, 33],
            [2003, 4717, 18, 29],
            [2003, 4724, 28, 20],
            [2003, 4728, 25, 23],
            [2003, 4729, 69, 50],
            [2003, 4732, 61, 69],
            [2003, 4734, 16, 16],
            [2003, 4738, 38, 45],
            [2003, 4745, 17, 20],
            [2003, 4747, 49, 33],
            [2003, 4749, 40, 28],
            [2003, 4753, 26, 21],
            [2003, 4762, 47, 45],
            [2003, 4764, 25, 36],
            [2003, 4777, 24, 23],
            [2003, 4780, 44, 39],
            [2003, 4789, 37, 22],
            [2003, 4791, 23, 28],
            [2003, 4794, 24, 18],
            [2003, 4800, 51, 41],
            [2003, 4801, 11, 18],
            [2003, 4802, 26, 18],
            [2003, 4805, 15, 20],
            [2003, 4815, 37, 27],
            [2003, 4819, 35, 22],
            [2003, 4820, 46, 44],
            [2003, 4826, 18, 18],
            [2003, 4828, 67, 50],
            [2003, 4829, 36, 32],
            [2003, 4832, 12, 16],
            [2003, 4835, 22, 21],
            [2003, 4839, 31, 19],
            [2003, 4840, 49, 31],
            [2003, 4844, 29, 19],
            [2003, 4849, 21, 20],
            [2003, 4863, 41, 24],
            [2003, 4864, 18, 20],
            [2003, 4865, 30, 21],
            [2003, 4871, 15, 19],
            [2003, 4872, 119, 49],
            [2003, 4877, 22, 18],
            [2003, 4880, 17, 20],
            [2003, 4881, 33, 32],
            [2003, 4888, 47, 44],
            [2003, 4897, 15, 21],
            [2003, 4910, 38, 27],
            [2003, 4912, 10, 18],
            [2003, 4914, 32, 21],
            [2003, 4915, 18, 16],
            [2003, 4918, 46, 26],
            [2003, 4922, 60, 45],
            [2003, 4926, 54, 50],
            [2003, 4927, 18, 18],
            [2003, 4931, 17, 18],
            [2003, 4939, 22, 21],
            [2003, 4940, 38, 23],
            [2003, 4944, 14, 15],
            [2003, 4950, 59, 27],
            [2003, 4951, 37, 33],
            [2003, 4955, 44, 30],
            [2003, 4957, 31, 24],
            [2003, 4960, 88, 48],
            [2003, 4973, 29, 30],
            [2003, 4975, 26, 26],
            [2003, 4976, 11, 16],
            [2003, 4978, 56, 43],
            [2003, 4979, 150, 31],
            [2003, 4983, 19, 18],
            [2003, 4987, 29, 19],
            [2003, 4990, 42, 26],
            [2003, 4992, 23, 21],
            [2003, 4995, 29, 25],
            [2003, 4996, 47, 27],
            [2003, 4997, 24, 22],
            [2003, 4998, 78, 27],
            [2003, 5005, 41, 36],
            [2003, 5006, 81, 36],
            [2003, 5008, 55, 27],
            [2003, 5009, 18, 18],
            [2003, 5011, 57, 41],
            [2003, 5012, 40, 46],
            [2003, 5013, 19, 16],
            [2003, 5017, 26, 26],
            [2003, 5019, 47, 30],
            [2003, 5022, 159, 68],
            [2003, 5027, 36, 26],
            [2003, 5031, 10, 14],
            [2003, 5032, 45, 26],
            [2003, 5033, 32, 22],
            [2003, 5035, 27, 27],
            [2003, 5037, 81, 34],
            [2003, 5038, 12, 18],
            [2003, 5046, 52, 27],
            [2003, 5048, 32, 28],
            [2003, 5050, 18, 14],
            [2003, 5051, 11, 12],
            [2003, 5053, 27, 21],
            [2003, 5058, 50, 27],
            [2003, 5062, 41, 34],
            [2003, 5063, 21, 28],
            [2003, 5064, 53, 34],
            [2003, 5065, 62, 32],
            [2003, 5068, 40, 21],
            [2003, 5069, 51, 32],
            [2003, 5070, 23, 20],
            [2003, 5071, 25, 26],
            [2003, 5073, 61, 39],
            [2003, 5075, 24, 27],
            [2003, 5079, 18, 18],
            [2003, 5081, 41, 16],
            [2003, 5091, 85, 41],
            [2003, 5092, 11, 16],
            [2003, 5095, 14, 16],
            [2003, 5098, 29, 19],
            [2003, 5102, 19, 12],
            [2003, 5103, 84, 44],
            [2003, 5104, 83, 33],
            [2003, 5107, 95, 39],
            [2003, 5108, 21, 29],
            [2003, 5109, 47, 19],
            [2003, 5116, 36, 28],
            [2003, 5121, 24, 18],
            [2003, 5122, 36, 28],
            [2003, 5126, 27, 22],
            [2003, 5127, 18, 18],
            [2003, 5130, 43, 48],
            [2003, 5138, 15, 14],
            [2003, 5149, 21, 19],
            [2003, 5150, 54, 34],
            [2003, 5153, 61, 34],
            [2003, 5159, 76, 29],
            [2003, 5162, 21, 20],
            [2003, 5173, 37, 22],
            [2003, 5180, 27, 41],
            [2003, 5181, 17, 18],
            [2003, 5182, 38, 21],
            [2003, 5183, 39, 33],
            [2003, 5184, 33, 21],
            [2003, 5185, 29, 17],
            [2003, 5186, 12, 16],
            [2003, 5187, 12, 12],
            [2003, 5188, 11, 14],
            [2003, 5189, 18, 10],
            [2003, 5217, 50, 35],
            [2003, 5219, 17, 49],
            [2003, 5220, 14, 51],
            [2003, 5221, 12, 39],
            [2003, 5222, 15, 21],
            [2003, 5223, 11, 29],
            [2003, 5224, 15, 42],
            [2003, 5225, 16, 51],
            [2003, 5226, 12, 52],
            [2003, 5227, 29, 61],
            [2003, 5228, 19, 58],
            [2003, 5229, 11, 41],
            [2003, 5230, 16, 36],
            [2003, 5231, 13, 31],
            [2003, 5232, 19, 55],
            [2003, 5233, 23, 74],
            [2003, 5234, 11, 25],
            [2003, 5235, 38, 40],
            [2003, 5236, 15, 39],
            [2003, 5237, 26, 52],
            [2003, 5238, 16, 40],
            [2003, 5239, 23, 60],
            [2003, 5240, 18, 64],
            [2003, 5241, 27, 60],
            [2003, 5242, 20, 42],
            [2003, 5243, 26, 65],
            [2003, 5244, 19, 72],
            [2003, 5245, 25, 64],
            [2003, 5247, 32, 13],
            [2003, 5248, 33, 19],
            [2003, 5273, 25, 16],
            [2003, 5276, 28, 44],
            [2003, 5279, 20, 22],
            [2003, 5287, 12, 12],
            [2003, 5290, 20, 19],
            [2003, 5298, 12, 12],
            [2003, 5299, 17, 19],
            [2003, 5303, 30, 20],
            [2003, 5305, 24, 21],
            [2003, 5314, 20, 21],
            [2003, 5315, 18, 23],
            [2003, 5317, 35, 48],
            [2003, 5321, 21, 20],
            [2003, 5323, 14, 20],
            [2003, 5328, 18, 18],
            [2003, 5332, 19, 23],
            [2003, 5333, 12, 14],
            [2003, 5336, 14, 16],
            [2003, 5337, 16, 16],
            [2003, 5338, 26, 22],
            [2003, 5339, 20, 21],
            [2003, 5340, 25, 28],
            [2003, 5343, 14, 13],
            [2003, 5344, 37, 37],
            [2003, 5347, 18, 20],
            [2003, 5349, 20, 23],
            [2003, 5350, 19, 24],
            [2003, 5353, 17, 21],
            [2003, 5355, 20, 30],
            [2003, 5357, 23, 18],
            [2003, 5359, 17, 21],
            [2003, 5366, 25, 21],
            [2003, 5371, 29, 30],
            [2003, 5372, 21, 20],
            [2003, 5375, 17, 16],
            [2003, 5377, 15, 16],
            [2003, 5383, 23, 23],
            [2003, 5385, 27, 21],
            [2003, 5387, 15, 14],
            [2003, 5400, 14, 13],
            [2003, 5403, 21, 21],
            [2003, 5404, 21, 21],
            [2003, 5407, 19, 21],
            [2003, 5408, 17, 20],
            [2003, 5411, 21, 18],
            [2003, 5412, 19, 16],
            [2003, 5414, 12, 14],
            [2003, 5415, 35, 37],
            [2003, 5418, 24, 29],
            [2003, 5420, 16, 15],
            [2003, 5421, 16, 13],
            [2003, 5422, 22, 27],
            [2003, 5425, 16, 18],
            [2003, 5426, 18, 23],
            [2003, 5428, 17, 21],
            [2003, 5431, 21, 22],
            [2003, 5432, 21, 25],
            [2003, 5434, 14, 15],
            [2003, 5436, 18, 20],
            [2003, 5437, 25, 21],
            [2003, 5440, 30, 24],
            [2003, 5441, 25, 30],
            [2003, 5444, 21, 29],
            [2003, 5447, 18, 20],
            [2003, 5449, 22, 26],
            [2003, 5450, 24, 25],
            [2003, 5452, 20, 26],
            [2003, 5453, 27, 26],
            [2003, 5454, 13, 14],
            [2003, 5455, 22, 18],
            [2003, 5457, 14, 20],
            [2003, 5459, 21, 21],
            [2003, 5462, 20, 22],
            [2003, 5463, 13, 16],
            [2003, 5464, 17, 16],
            [2003, 5465, 20, 20],
            [2003, 5472, 19, 22],
            [2003, 5473, 16, 20],
            [2003, 5476, 15, 18],
            [2003, 5479, 19, 17],
            [2003, 5480, 29, 25],
            [2003, 5482, 16, 17],
            [2003, 5486, 20, 19],
            [2003, 5489, 26, 41],
            [2003, 5492, 22, 32],
            [2003, 5494, 22, 24],
            [2003, 5495, 24, 21],
            [2003, 5498, 32, 31],
            [2003, 5499, 26, 20],
            [2003, 5501, 23, 32],
            [2003, 5505, 16, 23],
            [2003, 5508, 21, 27],
            [2003, 5528, 18, 17],
            [2003, 5532, 21, 20],
            [2003, 5534, 15, 13],
            [2003, 5539, 15, 18],
            [2003, 5541, 23, 19],
            [2003, 5544, 20, 25],
            [2003, 5545, 15, 19],
            [2003, 5547, 25, 23],
            [2003, 5550, 16, 16],
            [2003, 5571, 22, 18],
            [2003, 5659, 9, 7],
            [2003, 5944, 7, 8],
            [2003, 5945, 11, 9],
            [2003, 5946, 6, 5],
            [2003, 5962, 71, 83],
            [2003, 5996, 47, 27],
            [2003, 6068, 51, 40],
            [2003, 6069, 54, 47],
            [2003, 6070, 54, 47],
            [2003, 6071, 31, 27],
            [2003, 6072, 21, 36],
            [2003, 6073, 33, 34],
            [2003, 6074, 38, 33],
            [2003, 6075, 54, 47],
            [2003, 6076, 39, 36],
            [2003, 6077, 33, 31],
            [2003, 6078, 39, 42],
            [2003, 6079, 41, 35],
            [2003, 6080, 39, 40],
            [2003, 6081, 26, 28],
            [2003, 6082, 38, 33],
            [2003, 6083, 35, 30],
            [2003, 6084, 48, 33],
            [2003, 6085, 42, 36],
            [2003, 6086, 26, 23],
            [2003, 6087, 94, 31],
            [2003, 6088, 39, 36],
            [2003, 6089, 33, 30],
            [2003, 6090, 54, 38],
            [2003, 6091, 31, 30],
            [2003, 6092, 35, 35],
            [2003, 6093, 38, 33],
            [2003, 6094, 38, 33],
            [2003, 6095, 26, 24],
            [2003, 6096, 35, 27],
            [2003, 6097, 41, 31],
            [2003, 6098, 35, 30],
            [2003, 6099, 48, 33],
            [2003, 6100, 38, 33],
            [2003, 6101, 38, 27],
            [2003, 6102, 26, 26],
            [2003, 6103, 35, 30],
            [2003, 6104, 42, 29],
            [2003, 6105, 48, 33],
            [2003, 6106, 30, 27],
            [2003, 6107, 30, 27],
            [2003, 6108, 38, 32],
            [2003, 6109, 23, 27],
            [2003, 6110, 35, 33],
            [2003, 6111, 17, 24],
            [2003, 6112, 32, 31],
            [2003, 6113, 26, 25],
            [2003, 6114, 26, 25],
            [2003, 6115, 26, 29],
            [2003, 6116, 36, 31],
            [2003, 6117, 29, 29],
            [2003, 6118, 36, 34],
            [2003, 6119, 32, 31],
            [2003, 6120, 22, 25],
            [2003, 6121, 32, 32],
            [2003, 6122, 32, 28],
            [2003, 6123, 25, 25],
            [2003, 6124, 35, 29],
            [2003, 6125, 29, 29],
            [2003, 6126, 32, 32],
            [2003, 6127, 32, 32],
            [2003, 6128, 27, 34],
            [2003, 6130, 32, 31],
            [2003, 6131, 35, 30],
            [2003, 6132, 38, 33],
            [2003, 6133, 35, 30],
            [2003, 6134, 35, 30],
            [2003, 6135, 84, 73],
            [2003, 6136, 72, 63],
            [2003, 6137, 19, 22],
            [2003, 6138, 29, 33],
            [2003, 6139, 33, 32],
            [2003, 6140, 23, 28],
            [2003, 6141, 33, 36],
            [2003, 6142, 27, 32],
            [2003, 6143, 29, 29],
            [2003, 6144, 24, 24],
            [2003, 6145, 35, 35],
            [2003, 6146, 17, 24],
            [2003, 6147, 24, 34],
            [2003, 6148, 24, 29],
            [2003, 6149, 32, 32],
            [2003, 6150, 18, 24],
            [2003, 6151, 24, 24],
            [2003, 6152, 21, 25],
            [2003, 6153, 22, 27],
            [2003, 6154, 32, 32],
            [2003, 6155, 23, 27],
            [2003, 6156, 26, 29],
            [2003, 6157, 38, 35],
            [2003, 6158, 26, 27],
            [2003, 6159, 36, 34],
            [2003, 6160, 22, 25],
            [2003, 6161, 17, 23],
            [2003, 6162, 20, 24],
            [2003, 6163, 51, 43],
            [2003, 6164, 33, 34],
            [2003, 6165, 29, 28],
            [2003, 6166, 46, 32],
            [2003, 6167, 51, 42],
            [2003, 6244, 50, 37],
            [2003, 6353, 40, 40],
            [2003, 6357, 40, 40],
            [2003, 6358, 91, 41],
            [2003, 6359, 22, 22],
            [2003, 6360, 84, 62],
            [2003, 6361, 84, 70],
            [2003, 6362, 54, 52],
            [2003, 6363, 54, 56],
            [2003, 6364, 84, 63],
            [2003, 6365, 93, 69],
            [2003, 6366, 93, 69],
            [2003, 6367, 51, 52],
            [2003, 6368, 84, 63],
            [2003, 6369, 58, 56],
            [2003, 6370, 83, 62],
            [2003, 6371, 84, 69],
            [2003, 6372, 93, 69],
            [2003, 6373, 93, 74],
            [2003, 6374, 84, 62],
            [2003, 6375, 93, 62],
            [2003, 6376, 58, 52],
            [2003, 6377, 92, 68],
            [2003, 6378, 54, 52],
            [2003, 6379, 59, 55],
            [2003, 6380, 58, 51],
            [2003, 6381, 58, 52],
            [2003, 6382, 84, 62],
            [2003, 6383, 58, 52],
            [2003, 6384, 84, 63],
            [2003, 6385, 84, 52],
            [2003, 6386, 84, 62],
            [2003, 6387, 83, 68],
            [2003, 6388, 84, 62],
            [2003, 6389, 93, 69],
            [2003, 6390, 84, 63],
            [2003, 6391, 53, 49],
            [2003, 6392, 84, 62],
            [2003, 6393, 93, 69],
            [2003, 6394, 93, 69],
            [2003, 6395, 84, 63],
            [2003, 6396, 93, 69],
            [2003, 6397, 84, 62],
            [2003, 6398, 100, 74],
            [2003, 6399, 93, 69],
            [2003, 6400, 80, 59],
            [2003, 6401, 58, 57],
            [2003, 6402, 93, 69],
            [2003, 6403, 100, 74],
            [2003, 6404, 93, 69],
            [2003, 6405, 93, 69],
            [2003, 6406, 84, 62],
            [2003, 6407, 84, 63],
            [2003, 6408, 84, 63],
            [2003, 6409, 84, 62],
            [2003, 6410, 84, 63],
            [2003, 6411, 78, 58],
            [2003, 6412, 84, 62],
            [2003, 6413, 100, 74],
            [2003, 6414, 93, 62],
            [2003, 6415, 83, 62],
            [2003, 6416, 93, 69],
            [2003, 6417, 93, 69],
            [2003, 6418, 100, 74],
            [2003, 6419, 93, 74],
            [2003, 6420, 100, 74],
            [2003, 6421, 84, 62],
            [2003, 6422, 84, 63],
            [2003, 6423, 29, 27],
            [2003, 6424, 58, 57],
            [2003, 6425, 58, 52],
            [2003, 6426, 84, 69],
            [2003, 6427, 100, 74],
            [2003, 6428, 93, 69],
            [2003, 6429, 100, 74],
            [2003, 6430, 54, 57],
            [2003, 6431, 84, 63],
            [2003, 6432, 84, 69],
            [2003, 6433, 48, 50],
            [2003, 6434, 83, 62],
            [2003, 6435, 57, 49],
            [2003, 6436, 93, 62],
            [2003, 6437, 93, 69],
            [2003, 6438, 84, 62],
            [2003, 6439, 84, 62],
            [2003, 6440, 93, 69],
            [2003, 6441, 79, 59],
            [2003, 6442, 53, 49],
            [2003, 6443, 84, 62],
            [2003, 6444, 66, 70],
            [2003, 6445, 84, 62],
            [2003, 6446, 93, 69],
            [2003, 6447, 52, 39],
            [2003, 6448, 84, 62],
            [2003, 6449, 93, 74],
            [2003, 6450, 93, 69],
            [2003, 6451, 93, 74],
            [2003, 6452, 93, 62],
            [2003, 6453, 84, 62],
            [2003, 6454, 84, 62],
            [2003, 6455, 84, 62],
            [2003, 6456, 84, 62],
            [2003, 6457, 32, 33],
            [2003, 6458, 24, 27],
            [2003, 6459, 100, 69],
            [2003, 6460, 93, 69],
            [2003, 6461, 84, 62],
            [2003, 6462, 82, 68],
            [2003, 6463, 83, 68],
            [2003, 6464, 100, 74],
            [2003, 6465, 93, 74],
            [2003, 6466, 83, 62],
            [2003, 6467, 92, 68],
            [2003, 6468, 93, 69],
            [2003, 6469, 84, 62],
            [2003, 6470, 84, 63],
            [2003, 6471, 84, 62],
            [2003, 6472, 93, 69],
            [2003, 6473, 93, 69],
            [2003, 6474, 84, 62],
            [2003, 6475, 84, 62],
            [2003, 6476, 84, 62],
            [2003, 6477, 106, 80],
            [2003, 6478, 84, 62],
            [2003, 6479, 84, 62],
            [2003, 6480, 84, 62],
            [2003, 6481, 93, 69],
            [2003, 6482, 93, 74],
            [2003, 6483, 84, 62],
            [2003, 6484, 59, 43],
            [2003, 6485, 79, 63],
            [2003, 6486, 93, 69],
            [2003, 6487, 84, 63],
            [2003, 6488, 84, 63],
            [2003, 6489, 84, 62],
            [2003, 6490, 84, 62],
            [2003, 6491, 84, 62],
            [2003, 6492, 27, 27],
            [2003, 6493, 84, 63],
            [2003, 6494, 27, 27],
            [2003, 6495, 80, 59],
            [2003, 6496, 84, 63],
            [2003, 6498, 100, 74],
            [2003, 6499, 93, 69],
            [2003, 6500, 58, 52],
            [2003, 6501, 84, 63],
            [2003, 6502, 51, 52],
            [2003, 6503, 84, 62],
            [2003, 6504, 84, 70],
            [2003, 6505, 84, 62],
            [2003, 6506, 84, 69],
            [2003, 6507, 93, 69],
            [2003, 6508, 93, 69],
            [2003, 6509, 84, 63],
            [2003, 6510, 100, 74],
            [2003, 6511, 84, 63],
            [2003, 6512, 84, 63],
            [2003, 6513, 22, 20],
            [2003, 6514, 82, 61],
            [2003, 6515, 84, 69],
            [2003, 6516, 59, 48],
            [2003, 6517, 31, 27],
            [2003, 6518, 84, 69],
            [2003, 6519, 92, 69],
            [2003, 6520, 100, 74],
            [2003, 6521, 46, 44],
            [2003, 6522, 84, 62],
            [2003, 6523, 100, 74],
            [2003, 6524, 93, 69],
            [2003, 6525, 84, 63],
            [2003, 6526, 93, 69],
            [2003, 6527, 84, 63],
            [2003, 6528, 84, 62],
            [2003, 6529, 92, 70],
            [2003, 6530, 80, 59],
            [2003, 6531, 93, 74],
            [2003, 6532, 84, 62],
            [2003, 6533, 84, 62],
            [2003, 6534, 84, 69],
            [2003, 6535, 93, 69],
            [2003, 6536, 30, 30],
            [2003, 6537, 93, 69],
            [2003, 6538, 93, 74],
            [2003, 6539, 84, 62],
            [2003, 6540, 93, 74],
            [2003, 6541, 93, 69],
            [2003, 6542, 93, 69],
            [2003, 6543, 93, 69],
            [2003, 6544, 93, 69],
            [2003, 6546, 93, 69],
            [2003, 6547, 100, 74],
            [2003, 6548, 93, 69],
            [2003, 6549, 93, 74],
            [2003, 6550, 93, 69],
            [2003, 6551, 93, 69],
            [2003, 6552, 93, 74],
            [2003, 6553, 93, 69],
            [2003, 6554, 93, 69],
            [2003, 6555, 93, 69],
            [2003, 6556, 93, 69],
            [2003, 6557, 93, 69],
            [2003, 6558, 84, 62],
            [2003, 6559, 93, 69],
            [2003, 6560, 84, 62],
            [2003, 6561, 93, 74],
            [2003, 6562, 93, 69],
            [2003, 6563, 93, 69],
            [2003, 6564, 93, 69],
            [2003, 6565, 92, 70],
            [2003, 6566, 84, 56],
            [2003, 6567, 93, 69],
            [2003, 6568, 84, 63],
            [2003, 6569, 84, 63],
            [2003, 6570, 93, 69],
            [2003, 6572, 93, 69],
            [2003, 6573, 84, 63],
            [2003, 6574, 84, 62],
            [2003, 6575, 83, 61],
            [2003, 6576, 84, 62],
            [2003, 6577, 84, 63],
            [2003, 6578, 84, 62],
            [2003, 6579, 93, 69],
            [2003, 6580, 84, 63],
            [2003, 6581, 92, 69],
            [2003, 6582, 84, 62],
            [2003, 6583, 92, 68],
            [2003, 6584, 106, 80],
            [2003, 6585, 84, 63],
            [2003, 6586, 84, 63],
            [2003, 6587, 84, 63],
            [2003, 6588, 83, 62],
            [2003, 6589, 84, 62],
            [2003, 6590, 106, 80],
            [2003, 6591, 93, 69],
            [2003, 6592, 93, 69],
            [2003, 6593, 93, 69],
            [2003, 6594, 93, 69],
            [2003, 6595, 84, 62],
            [2003, 6596, 84, 62],
            [2003, 6597, 93, 69],
            [2003, 6598, 93, 69],
            [2003, 6599, 93, 69],
            [2003, 6600, 84, 62],
            [2003, 6601, 93, 69],
            [2003, 6602, 84, 62],
            [2003, 6603, 54, 52],
            [2003, 6604, 93, 74],
            [2003, 6605, 84, 62],
            [2003, 6606, 84, 63],
            [2003, 6607, 93, 62],
            [2003, 6608, 84, 62],
            [2003, 6609, 84, 62],
            [2003, 6610, 84, 62],
            [2003, 6611, 54, 52],
            [2003, 6612, 84, 69],
            [2003, 6613, 84, 62],
            [2003, 6614, 30, 30],
            [2003, 6615, 84, 63],
            [2003, 6616, 84, 62],
            [2003, 6617, 33, 30],
            [2003, 6618, 84, 63],
            [2003, 6619, 93, 69],
            [2003, 6620, 93, 69],
            [2003, 6621, 84, 62],
            [2003, 6622, 84, 63],
            [2003, 6623, 93, 69],
            [2003, 6624, 100, 69],
            [2003, 6625, 93, 69],
            [2003, 6626, 100, 74],
            [2003, 6627, 84, 62],
            [2003, 6628, 93, 74],
            [2003, 6629, 54, 57],
            [2003, 6630, 58, 57],
            [2003, 6631, 46, 49],
            [2003, 6632, 23, 25],
            [2003, 6633, 30, 32],
            [2003, 6634, 36, 34],
            [2003, 6635, 42, 36],
            [2003, 6636, 61, 53],
            [2003, 6637, 48, 33],
            [2003, 6638, 54, 40],
            [2003, 6639, 42, 43],
            [2003, 6640, 52, 56],
            [2003, 6643, 31, 30],
            [2003, 6649, 48, 34],
            [2003, 6650, 48, 33],
            [2003, 6651, 33, 24],
            [2003, 6652, 45, 35],
            [2003, 6653, 45, 39],
            [2003, 6654, 32, 31],
            [2003, 6655, 31, 27],
            [2003, 6656, 36, 31],
            [2003, 6657, 42, 36],
            [2003, 6660, 36, 26],
            [2003, 6661, 29, 29],
            [2003, 6662, 40, 35],
            [2003, 6663, 32, 31],
            [2003, 6664, 39, 36],
            [2003, 6665, 32, 32],
            [2003, 6666, 32, 29],
            [2003, 6667, 32, 31],
            [2003, 6668, 32, 24],
            [2003, 6669, 41, 36],
            [2003, 6670, 33, 31],
            [2003, 6671, 45, 31],
            [2003, 6672, 36, 27],
            [2003, 6673, 38, 30],
            [2003, 6674, 36, 35],
            [2003, 6675, 33, 31],
            [2003, 6676, 46, 43],
            [2003, 6677, 32, 32],
            [2003, 6678, 33, 31],
            [2003, 6679, 72, 63],
            [2003, 6680, 30, 27],
            [2003, 6682, 29, 28],
            [2003, 6683, 32, 32],
            [2003, 6684, 30, 36],
            [2003, 6685, 25, 28],
            [2003, 6686, 24, 28],
            [2003, 6687, 26, 29],
            [2003, 6688, 24, 28],
            [2003, 6689, 25, 29],
            [2003, 6690, 24, 28],
            [2003, 6697, 35, 28],
            [2003, 6699, 53, 46],
            [2003, 6700, 61, 54],
            [2003, 6701, 56, 65],
            [2003, 6702, 56, 38],
            [2003, 6704, 42, 35],
            [2003, 6706, 39, 35],
            [2003, 6708, 48, 46],
            [2003, 6715, 53, 42],
            [2003, 6716, 67, 44],
            [2003, 6718, 71, 54],
            [2003, 6722, 52, 44],
            [2003, 6723, 53, 40],
            [2003, 6725, 39, 38],
            [2003, 6726, 76, 53],
            [2003, 6728, 44, 41],
            [2003, 6730, 39, 37],
            [2003, 6734, 52, 39],
            [2003, 6737, 55, 47],
            [2003, 6738, 42, 40],
            [2003, 6741, 17, 17],
            [2003, 6748, 29, 28],
            [2003, 6749, 31, 30],
            [2003, 6750, 45, 43],
            [2003, 6752, 24, 28],
            [2003, 6753, 38, 35],
            [2003, 6754, 36, 34],
            [2003, 6755, 44, 44],
            [2003, 6756, 38, 38],
            [2003, 6757, 34, 33],
            [2003, 6758, 38, 46],
            [2003, 6759, 24, 28],
            [2003, 6760, 44, 44],
            [2003, 6761, 45, 43],
            [2003, 6762, 38, 38],
            [2003, 6763, 26, 24],
            [2003, 6764, 35, 38],
            [2003, 6766, 54, 49],
            [2003, 6767, 35, 33],
            [2003, 6768, 36, 35],
            [2003, 6769, 44, 54],
            [2003, 6770, 39, 43],
            [2003, 6771, 39, 40],
            [2003, 6772, 31, 37],
            [2003, 6773, 50, 46],
            [2003, 6777, 52, 48],
            [2003, 6778, 32, 32],
            [2003, 6779, 39, 43],
            [2003, 6780, 39, 40],
            [2003, 6781, 46, 42],
            [2003, 6782, 72, 58],
            [2003, 6783, 52, 48],
            [2003, 6784, 38, 38],
            [2003, 6785, 39, 37],
            [2003, 6786, 39, 43],
            [2003, 6787, 36, 42],
            [2003, 6789, 45, 43],
            [2003, 6790, 76, 58],
            [2003, 6791, 61, 43],
            [2003, 6794, 74, 57],
            [2003, 6795, 59, 51],
            [2003, 6798, 64, 47],
            [2003, 6803, 58, 51],
            [2003, 6804, 55, 49],
            [2003, 6805, 80, 61],
            [2003, 6806, 57, 51],
            [2003, 6807, 72, 51],
            [2003, 6808, 79, 60],
            [2003, 6812, 81, 69],
            [2003, 6813, 71, 55],
            [2003, 6814, 62, 57],
            [2003, 6816, 65, 54],
            [2003, 6818, 19, 21],
            [2003, 6819, 36, 45],
            [2003, 6820, 34, 37],
            [2003, 6821, 39, 45],
            [2003, 6822, 48, 47],
            [2003, 6823, 38, 41],
            [2003, 6833, 56, 46],
            [2003, 6834, 78, 64],
            [2003, 6835, 85, 65],
            [2003, 6836, 76, 59],
            [2003, 6837, 76, 58],
            [2003, 6838, 90, 68],
            [2003, 6841, 32, 24],
            [2003, 6845, 76, 58],
            [2003, 6846, 91, 78],
            [2003, 6847, 73, 56],
            [2003, 6848, 80, 61],
            [2003, 6849, 56, 53],
            [2003, 6850, 76, 58],
            [2003, 6851, 74, 57],
            [2003, 6852, 81, 62],
            [2003, 6853, 83, 63],
            [2003, 6854, 71, 59],
            [2003, 6855, 77, 59],
            [2003, 6856, 76, 58],
            [2003, 6857, 78, 64],
            [2003, 6858, 89, 68],
            [2003, 6859, 55, 44],
            [2003, 6860, 75, 57],
            [2003, 6861, 83, 68],
            [2003, 6862, 81, 62],
            [2003, 6867, 12, 20],
            [2003, 6868, 12, 16],
            [2003, 6869, 14, 16],
            [2003, 6870, 15, 19],
            [2003, 6871, 15, 16],
            [2003, 6872, 12, 18],
            [2003, 6873, 19, 19],
            [2003, 6874, 16, 18],
            [2003, 6875, 15, 18],
            [2003, 6876, 15, 18],
            [2003, 6877, 17, 19],
            [2003, 6878, 15, 17],
            [2003, 6879, 15, 18],
            [2003, 6880, 19, 22],
            [2003, 6881, 15, 14],
            [2003, 6882, 15, 19],
            [2003, 6883, 15, 19],
            [2003, 6884, 7, 8],
            [2003, 6885, 24, 15],
            [2003, 6886, 11, 14],
            [2003, 6887, 112, 38],
            [2003, 6888, 10, 11],
            [2003, 6889, 21, 14],
            [2003, 6890, 8, 10],
            [2003, 6891, 18, 16],
            [2003, 6892, 9, 9],
            [2003, 6893, 21, 15],
            [2003, 6894, 7, 9],
            [2003, 6895, 26, 15],
            [2003, 6896, 8, 11],
            [2003, 6897, 16, 15],
            [2003, 6898, 6, 8],
            [2003, 6899, 27, 14],
            [2003, 6900, 6, 7],
            [2003, 6901, 23, 16],
            [2003, 6902, 10, 13],
            [2003, 6903, 33, 22],
            [2003, 6904, 11, 11],
            [2003, 6905, 40, 24],
            [2003, 6906, 8, 9],
            [2003, 6907, 24, 16],
            [2003, 6908, 8, 8],
            [2003, 6909, 24, 18],
            [2003, 6910, 32, 28],
            [2003, 6911, 60, 41],
            [2003, 6912, 35, 23],
            [2003, 6913, 61, 38],
            [2003, 6914, 12, 12],
            [2003, 6915, 41, 36],
            [2003, 6916, 10, 11],
            [2003, 6917, 29, 32],
            [2003, 6918, 28, 21],
            [2003, 6919, 29, 27],
            [2003, 6920, 27, 22],
            [2003, 6921, 50, 36],
            [2003, 6922, 13, 12],
            [2003, 6923, 54, 38],
            [2003, 6924, 10, 11],
            [2003, 6925, 43, 39],
            [2003, 6926, 60, 27],
            [2003, 6927, 67, 36],
            [2003, 6928, 20, 19],
            [2003, 6929, 55, 39],
            [2003, 6930, 21, 15],
            [2003, 6931, 41, 39],
            [2003, 6932, 20, 14],
            [2003, 6933, 29, 26],
            [2003, 6934, 19, 15],
            [2003, 6935, 47, 46],
            [2003, 6936, 23, 20],
            [2003, 6937, 50, 39],
            [2003, 6938, 19, 14],
            [2003, 6939, 51, 37],
            [2003, 6940, 12, 11],
            [2003, 6941, 29, 23],
            [2003, 6942, 30, 27],
            [2003, 6943, 59, 39],
            [2003, 6944, 11, 11],
            [2003, 6945, 64, 49],
            [2003, 6946, 57, 32],
            [2003, 6947, 66, 46],
            [2003, 6948, 14, 12],
            [2003, 6949, 49, 37],
            [2003, 6950, 16, 14],
            [2003, 6951, 53, 39],
            [2003, 6952, 55, 25],
            [2003, 6953, 62, 37],
            [2003, 6954, 28, 16],
            [2003, 6955, 49, 37],
            [2003, 6956, 17, 15],
            [2003, 6957, 70, 58],
            [2003, 6958, 14, 11],
            [2003, 6959, 50, 39],
            [2003, 6960, 11, 11],
            [2003, 6961, 28, 25],
            [2003, 6962, 12, 11],
            [2003, 6963, 11, 10],
            [2003, 6964, 26, 17],
            [2003, 6965, 9, 10],
            [2003, 6966, 25, 46],
            [2003, 6967, 20, 48],
            [2003, 6968, 39, 75],
            [2003, 6969, 21, 42],
            [2003, 6970, 27, 50],
            [2003, 6971, 34, 27],
            [2003, 6972, 70, 33],
            [2003, 6973, 22, 12],
            [2003, 6974, 6, 7],
            [2003, 6975, 9, 10],
            [2003, 6976, 21, 17],
            [2003, 6977, 7, 8],
            [2003, 6978, 50, 21],
            [2003, 6979, 7, 9],
            [2003, 6980, 19, 15],
            [2003, 6981, 8, 9],
            [2003, 6982, 26, 16],
            [2003, 6983, 11, 13],
            [2003, 6984, 31, 23],
            [2003, 6985, 52, 29],
            [2003, 6986, 105, 45],
            [2003, 6987, 9, 9],
            [2003, 6988, 25, 12],
            [2003, 6989, 13, 13],
            [2003, 6990, 28, 21],
            [2003, 6991, 7, 5],
            [2003, 6992, 22, 13],
            [2003, 6993, 8, 8],
            [2003, 6994, 56, 25],
            [2003, 6995, 10, 10],
            [2003, 6996, 21, 15],
            [2003, 6997, 7, 6],
            [2003, 6998, 15, 8],
            [2003, 6999, 7, 7],
            [2003, 7000, 20, 15],
            [2003, 7001, 7, 7],
            [2003, 7002, 18, 13],
            [2003, 7003, 8, 8],
            [2003, 7004, 18, 14],
            [2003, 7005, 14, 14],
            [2003, 7006, 28, 22],
            [2003, 7007, 36, 28],
            [2003, 7008, 36, 28],
            [2003, 7009, 20, 14],
            [2003, 7010, 19, 14],
            [2003, 7011, 10, 10],
            [2003, 7012, 22, 20],
            [2003, 7013, 29, 20],
            [2003, 7014, 12, 9],
            [2003, 7015, 11, 8],
            [2003, 7019, 11, 9],
            [2003, 7020, 41, 39],
            [2003, 7021, 12, 11],
            [2003, 7022, 22, 21],
            [2003, 7023, 16, 16],
            [2003, 7024, 27, 26],
            [2003, 7025, 14, 12],
            [2003, 7026, 27, 21],
            [2003, 7027, 18, 18],
            [2003, 7028, 41, 39],
            [2003, 7029, 39, 28],
            [2003, 7030, 55, 38],
            [2003, 7031, 15, 13],
            [2003, 7032, 31, 21],
            [2003, 7033, 23, 22],
            [2003, 7034, 34, 29],
            [2003, 7035, 11, 12],
            [2003, 7036, 31, 30],
            [2003, 7037, 27, 27],
            [2003, 7038, 34, 36],
            [2003, 7039, 23, 14],
            [2003, 7040, 29, 27],
            [2003, 7041, 14, 12],
            [2003, 7042, 55, 51],
            [2003, 7043, 20, 27],
            [2003, 7044, 28, 26],
            [2003, 7045, 35, 23],
            [2003, 7046, 54, 38],
            [2003, 7047, 18, 15],
            [2003, 7048, 28, 22],
            [2003, 7049, 52, 38],
            [2003, 7050, 18, 15],
            [2003, 7051, 57, 41],
            [2003, 7052, 15, 14],
            [2003, 7053, 52, 41],
            [2003, 7054, 18, 15],
            [2003, 7055, 37, 26],
            [2003, 7056, 13, 14],
            [2003, 7057, 61, 41],
            [2003, 7058, 28, 18],
            [2003, 7059, 57, 41],
            [2003, 7060, 28, 19],
            [2003, 7061, 52, 41],
            [2003, 7062, 17, 13],
            [2003, 7063, 46, 22],
            [2003, 7064, 28, 15],
            [2003, 7065, 43, 41],
            [2003, 7066, 12, 12],
            [2003, 7067, 53, 40],
            [2003, 7068, 39, 30],
            [2003, 7069, 68, 52],
            [2003, 7070, 28, 20],
            [2003, 7071, 57, 39],
            [2003, 7072, 10, 11],
            [2003, 7073, 29, 28],
            [2003, 7074, 26, 21],
            [2003, 7075, 56, 57],
            [2003, 7076, 28, 23],
            [2003, 7077, 37, 25],
            [2003, 7078, 11, 11],
            [2003, 7079, 28, 22],
            [2003, 7080, 41, 36],
            [2003, 7081, 68, 52],
            [2003, 7082, 27, 23],
            [2003, 7083, 42, 39],
            [2003, 7084, 53, 21],
            [2003, 7085, 61, 39],
            [2003, 7086, 12, 12],
            [2003, 7087, 43, 36],
            [2003, 7088, 27, 24],
            [2003, 7089, 54, 39],
            [2003, 7090, 19, 12],
            [2003, 7091, 53, 39],
            [2003, 7092, 49, 22],
            [2003, 7093, 68, 56],
            [2003, 7094, 37, 28],
            [2003, 7095, 56, 39],
            [2003, 7096, 28, 23],
            [2003, 7097, 39, 27],
            [2003, 7098, 27, 24],
            [2003, 7099, 52, 40],
            [2003, 7100, 15, 13],
            [2003, 7101, 20, 18],
            [2003, 7102, 13, 10],
            [2003, 7103, 31, 17],
            [2003, 7104, 9, 7],
            [2003, 7105, 21, 13],
            [2003, 7106, 5, 7],
            [2003, 7107, 22, 12],
            [2003, 7108, 11, 9],
            [2003, 7109, 27, 15],
            [2003, 7110, 8, 10],
            [2003, 7111, 25, 14],
            [2003, 7112, 5, 5],
            [2003, 7113, 30, 13],
            [2003, 7114, 25, 18],
            [2003, 7115, 47, 26],
            [2003, 7116, 10, 11],
            [2003, 7117, 33, 22],
            [2003, 7118, 8, 14],
            [2003, 7119, 17, 15],
            [2003, 7120, 10, 12],
            [2003, 7121, 36, 31],
            [2003, 7122, 9, 8],
            [2003, 7123, 26, 16],
            [2003, 7124, 7, 9],
            [2003, 7125, 16, 15],
            [2003, 7126, 7, 7],
            [2003, 7127, 20, 16],
            [2003, 7128, 9, 8],
            [2003, 7129, 20, 14],
            [2003, 7130, 8, 8],
            [2003, 7131, 22, 14],
            [2003, 7132, 8, 8],
            [2003, 7133, 31, 20],
            [2003, 7134, 16, 11],
            [2003, 7135, 25, 11],
            [2003, 7136, 15, 12],
            [2003, 7137, 30, 19],
            [2003, 7138, 9, 8],
            [2003, 7139, 23, 18],
            [2003, 7140, 6, 7],
            [2003, 7141, 14, 12],
            [2003, 7142, 9, 10],
            [2003, 7143, 24, 14],
            [2003, 7144, 9, 9],
            [2003, 7145, 18, 14],
            [2003, 7146, 10, 11],
            [2003, 7147, 25, 19],
            [2003, 7148, 8, 10],
            [2003, 7149, 33, 20],
            [2003, 7150, 5, 8],
            [2003, 7151, 18, 14],
            [2003, 7152, 8, 8],
            [2003, 7153, 26, 20],
            [2003, 7154, 15, 17],
            [2003, 7155, 25, 23],
            [2003, 7156, 18, 19],
            [2003, 7157, 9, 8],
            [2003, 7158, 39, 22],
            [2003, 7159, 18, 13],
            [2003, 7160, 46, 30],
            [2003, 7161, 9, 10],
            [2003, 7162, 25, 20],
            [2003, 7163, 8, 7],
            [2003, 7164, 21, 13],
            [2003, 7165, 11, 10],
            [2003, 7166, 53, 29],
            [2003, 7167, 7, 7],
            [2003, 7168, 26, 17],
            [2003, 7169, 5, 5],
            [2003, 7170, 35, 22],
            [2003, 7171, 6, 7],
            [2003, 7172, 37, 24],
            [2003, 7173, 13, 12],
            [2003, 7174, 64, 39],
            [2003, 7175, 6, 5],
            [2003, 7176, 17, 13],
            [2003, 7177, 14, 9],
            [2003, 7178, 23, 13],
            [2003, 7179, 14, 13],
            [2003, 7180, 48, 29],
            [2003, 7181, 9, 9],
            [2003, 7182, 37, 19],
            [2003, 7183, 17, 11],
            [2003, 7184, 84, 57],
            [2003, 7185, 16, 13],
            [2003, 7186, 47, 25],
            [2003, 7187, 13, 10],
            [2003, 7188, 45, 24],
            [2003, 7189, 15, 14],
            [2003, 7190, 42, 25],
            [2003, 7191, 15, 12],
            [2003, 7192, 26, 16],
            [2003, 7193, 13, 12],
            [2003, 7194, 20, 12],
            [2003, 7195, 13, 11],
            [2003, 7196, 38, 22],
            [2003, 7197, 7, 6],
            [2003, 7198, 21, 11],
            [2003, 7199, 13, 10],
            [2003, 7200, 30, 17],
            [2003, 7201, 6, 5],
            [2003, 7202, 14, 9],
            [2003, 7203, 9, 7],
            [2003, 7204, 18, 16],
            [2003, 7205, 17, 14],
            [2003, 7206, 52, 30],
            [2003, 7207, 13, 13],
            [2003, 7208, 38, 24],
            [2003, 7209, 16, 10],
            [2003, 7210, 47, 38],
            [2003, 7211, 9, 10],
            [2003, 7212, 26, 16],
            [2003, 7213, 7, 7],
            [2003, 7214, 63, 33],
            [2003, 7215, 8, 6],
            [2003, 7216, 52, 27],
            [2003, 7217, 11, 10],
            [2003, 7218, 28, 19],
            [2003, 7219, 15, 15],
            [2003, 7220, 32, 22],
            [2003, 7221, 13, 11],
            [2003, 7222, 30, 22],
            [2003, 7223, 11, 10],
            [2003, 7224, 37, 19],
            [2003, 7225, 7, 8],
            [2003, 7226, 26, 16],
            [2003, 7227, 10, 10],
            [2003, 7228, 28, 21],
            [2003, 7229, 12, 9],
            [2003, 7230, 56, 28],
            [2003, 7231, 10, 8],
            [2003, 7232, 28, 18],
            [2003, 7233, 8, 6],
            [2003, 7234, 25, 15],
            [2003, 7235, 11, 9],
            [2003, 7236, 20, 16],
            [2003, 7237, 7, 7],
            [2003, 7238, 20, 14],
            [2003, 7239, 8, 8],
            [2003, 7240, 18, 13],
            [2003, 7241, 18, 19],
            [2003, 7242, 26, 15],
            [2003, 7243, 5, 6],
            [2003, 7244, 17, 12],
            [2003, 7245, 5, 7],
            [2003, 7246, 25, 14],
            [2003, 7247, 7, 8],
            [2003, 7248, 24, 17],
            [2003, 7249, 7, 8],
            [2003, 7250, 23, 15],
            [2003, 7251, 17, 19],
            [2003, 7252, 28, 22],
            [2003, 7253, 13, 10],
            [2003, 7254, 55, 17],
            [2003, 7255, 45, 24],
            [2003, 7256, 22, 15],
            [2003, 7257, 93, 69],
            [2003, 7258, 93, 69],
            [2003, 7259, 89, 56],
            [2003, 7260, 112, 86],
            [2003, 7261, 90, 74],
            [2003, 7262, 84, 91],
            [2003, 7263, 100, 84],
            [2003, 7264, 96, 104],
            [2003, 7265, 93, 78],
            [2003, 7266, 116, 87],
            [2003, 7267, 90, 75],
            [2003, 7268, 116, 87],
            [2003, 7269, 116, 87],
            [2003, 7270, 87, 54],
            [2003, 7271, 67, 63],
            [2003, 7272, 113, 84],
            [2003, 7273, 98, 105],
            [2003, 7274, 111, 82],
            [2003, 7275, 96, 82],
            [2003, 7276, 62, 54],
            [2003, 7277, 91, 76],
            [2003, 7278, 84, 92],
            [2003, 7279, 100, 73],
            [2003, 7280, 117, 88],
            [2003, 7281, 89, 74],
            [2003, 7282, 82, 89],
            [2003, 7283, 13, 21],
            [2003, 7284, 11, 10],
            [2003, 7285, 12, 11],
            [2003, 7286, 16, 23],
            [2003, 7287, 15, 26],
            [2003, 7288, 31, 32],
            [2003, 7289, 31, 24],
            [2003, 7290, 52, 35],
            [2003, 7291, 39, 32],
            [2003, 7292, 37, 39],
            [2003, 7293, 26, 24],
            [2003, 7294, 24, 23],
            [2003, 7295, 13, 12],
            [2003, 7296, 24, 20],
            [2003, 7297, 26, 22],
            [2003, 7298, 15, 17],
            [2003, 7299, 16, 19],
            [2003, 7300, 19, 29],
            [2003, 7301, 13, 26],
            [2003, 7302, 44, 49],
            [2003, 7303, 78, 75],
            [2003, 7304, 34, 36],
            [2003, 7305, 45, 45],
            [2003, 7306, 32, 37],
            [2003, 7307, 50, 54],
            [2003, 7308, 41, 45],
            [2003, 7309, 34, 38],
            [2003, 7310, 82, 69],
            [2003, 7311, 68, 66],
            [2003, 7312, 43, 45],
            [2003, 7313, 104, 75],
            [2003, 7314, 88, 67],
            [2003, 7315, 84, 64],
            [2003, 7316, 89, 67],
            [2003, 7317, 91, 68],
            [2003, 7318, 89, 68],
            [2003, 7319, 108, 79],
            [2003, 7320, 87, 66],
            [2003, 7321, 113, 84],
            [2003, 7322, 89, 66],
            [2003, 7323, 107, 80],
            [2003, 7324, 104, 75],
            [2003, 7325, 91, 68],
            [2003, 7326, 90, 67],
            [2003, 7327, 108, 81],
            [2003, 7328, 30, 35],
            [2003, 7329, 56, 52],
            [2003, 7330, 36, 36],
            [2003, 7331, 37, 36],
            [2003, 7332, 29, 33],
            [2003, 7333, 58, 68],
            [2003, 7337, 14, 14],
            [2003, 7342, 13, 8],
            [2003, 7343, 12, 8],
            [2003, 7344, 12, 9],
            [2003, 7348, 12, 8],
            [2003, 7352, 11, 9],
            [2003, 7354, 13, 13],
            [2003, 7356, 10, 8],
            [2003, 7357, 21, 10],
            [2003, 7358, 15, 11],
            [2003, 7359, 25, 12],
            [2003, 7360, 13, 10],
            [2003, 7362, 11, 9],
            [2003, 7363, 11, 11],
            [2003, 7364, 11, 11],
            [2003, 7367, 12, 7],
            [2003, 7370, 11, 10],
            [2003, 7371, 16, 12],
            [2003, 7372, 17, 9],
            [2003, 7373, 14, 10],
            [2003, 7374, 11, 8],
            [2003, 7375, 11, 7],
            [2003, 7376, 9, 8],
            [2003, 7377, 11, 8],
            [2003, 7378, 20, 18],
            [2003, 7379, 32, 24],
            [2003, 7396, 35, 34],
            [2003, 7397, 57, 47],
            [2003, 7398, 35, 36],
            [2003, 7399, 28, 32],
            [2003, 7400, 50, 47],
            [2003, 7401, 28, 32],
            [2003, 7402, 61, 71],
            [2003, 7403, 23, 27],
            [2003, 7404, 68, 52],
            [2003, 7405, 34, 35],
            [2003, 7406, 52, 58],
            [2003, 7407, 36, 35],
            [2003, 7408, 50, 57],
            [2003, 7409, 19, 23],
            [2003, 7410, 22, 27],
            [2003, 7411, 22, 27],
            [2003, 7412, 39, 41],
            [2003, 7413, 20, 25],
            [2003, 7414, 19, 23],
            [2003, 7415, 19, 27],
            [2003, 7416, 24, 29],
            [2003, 7417, 21, 25],
            [2003, 7418, 24, 25],
            [2003, 7419, 45, 46],
            [2003, 7420, 21, 26],
            [2003, 7421, 33, 38],
            [2003, 7422, 20, 24],
            [2003, 7423, 27, 28],
            [2003, 7424, 48, 43],
            [2003, 7425, 31, 27],
            [2003, 7426, 50, 45],
            [2003, 7427, 40, 38],
            [2003, 7428, 46, 44],
            [2003, 7429, 25, 28],
            [2003, 7430, 41, 32],
            [2003, 7431, 29, 30],
            [2003, 7432, 64, 49],
            [2003, 7433, 43, 41],
            [2003, 7434, 70, 46],
            [2003, 7435, 51, 46],
            [2003, 7436, 58, 53],
            [2003, 7437, 24, 30],
            [2003, 7438, 45, 43],
            [2003, 7439, 36, 34],
            [2003, 7440, 59, 52],
            [2003, 7441, 34, 32],
            [2003, 7442, 51, 43],
            [2003, 7443, 60, 53],
            [2003, 7444, 64, 52],
            [2003, 7445, 58, 50],
            [2003, 7446, 81, 61],
            [2003, 7447, 33, 33],
            [2003, 7448, 59, 56],
            [2003, 7449, 23, 22],
            [2003, 7450, 23, 24],
            [2003, 7451, 15, 16],
            [2003, 7452, 26, 18],
            [2003, 7453, 60, 32],
            [2003, 7454, 19, 19],
            [2003, 7455, 27, 25],
            [2003, 7456, 82, 60],
            [2003, 7457, 61, 57],
            [2003, 7458, 42, 40],
            [2003, 7459, 61, 57],
            [2003, 7460, 61, 64],
            [2003, 7461, 42, 39],
            [2003, 7462, 49, 45],
            [2003, 7463, 55, 53],
            [2003, 7464, 68, 51],
            [2003, 7465, 61, 45],
            [2003, 7466, 55, 41],
            [2003, 7467, 61, 57],
            [2003, 7468, 48, 45],
            [2003, 7469, 64, 49],
            [2003, 7470, 75, 55],
            [2003, 7471, 91, 67],
            [2003, 7472, 33, 70],
            [2003, 7473, 42, 45],
            [2003, 7474, 61, 57],
            [2003, 7475, 61, 57],
            [2003, 7476, 51, 48],
            [2003, 7477, 45, 43],
            [2003, 7478, 48, 46],
            [2003, 7479, 48, 45],
            [2003, 7480, 61, 50],
            [2003, 7481, 42, 46],
            [2003, 7482, 55, 41],
            [2003, 7483, 61, 57],
            [2003, 7484, 47, 51],
            [2003, 7485, 94, 70],
            [2003, 7486, 73, 54],
            [2003, 7487, 51, 48],
            [2003, 7488, 61, 45],
            [2003, 7489, 72, 47],
            [2003, 7490, 49, 45],
            [2003, 7491, 61, 46],
            [2003, 7492, 73, 54],
            [2003, 7493, 54, 51],
            [2003, 7494, 54, 51],
            [2003, 7495, 61, 57],
            [2003, 7496, 94, 70],
            [2003, 7497, 61, 45],
            [2003, 7498, 42, 46],
            [2003, 7499, 48, 40],
            [2003, 7500, 54, 51],
            [2003, 7501, 68, 51],
            [2003, 7502, 61, 45],
            [2003, 7503, 67, 51],
            [2003, 7504, 64, 47],
            [2003, 7505, 54, 51],
            [2003, 7506, 68, 51],
            [2003, 7507, 52, 48],
            [2003, 7508, 61, 46],
            [2003, 7509, 61, 57],
            [2003, 7510, 61, 57],
            [2003, 7511, 68, 51],
            [2003, 7512, 61, 57],
            [2003, 7513, 61, 45],
            [2003, 7514, 106, 80],
            [2003, 7515, 67, 50],
            [2003, 7516, 61, 57],
            [2003, 7517, 94, 70],
            [2003, 7518, 68, 51],
            [2003, 7519, 54, 51],
            [2003, 7520, 55, 52],
            [2003, 7521, 42, 45],
            [2003, 7522, 75, 55],
            [2003, 7523, 55, 53],
            [2003, 7524, 84, 80],
            [2003, 7525, 61, 57],
            [2003, 7526, 64, 47],
            [2003, 7527, 42, 45],
            [2003, 7528, 82, 60],
            [2003, 7529, 94, 88],
            [2003, 7530, 75, 55],
            [2003, 7531, 47, 51],
            [2003, 7532, 61, 57],
            [2003, 7533, 82, 60],
            [2003, 7534, 94, 88],
            [2003, 7535, 55, 52],
            [2003, 7536, 75, 55],
            [2003, 7537, 70, 52],
            [2003, 7538, 82, 60],
            [2003, 7539, 55, 53],
            [2003, 7540, 82, 60],
            [2003, 7541, 67, 50],
            [2003, 7542, 82, 60],
            [2003, 7543, 67, 50],
            [2003, 7544, 70, 52],
            [2003, 7545, 51, 48],
            [2003, 7546, 61, 45],
            [2003, 7547, 61, 45],
            [2003, 7548, 54, 51],
            [2003, 7549, 61, 57],
            [2003, 7550, 48, 45],
            [2003, 7551, 49, 45],
            [2003, 7552, 49, 45],
            [2003, 7553, 55, 52],
            [2003, 7554, 88, 76],
            [2003, 7555, 82, 64],
            [2003, 7556, 61, 57],
            [2003, 7557, 94, 70],
            [2003, 7558, 42, 40],
            [2003, 7559, 61, 45],
            [2003, 7560, 49, 45],
            [2003, 7561, 94, 70],
            [2003, 7562, 94, 70],
            [2003, 7563, 75, 55],
            [2003, 7564, 67, 50],
            [2003, 7565, 55, 53],
            [2003, 7566, 54, 51],
            [2003, 7567, 61, 57],
            [2003, 7568, 55, 52],
            [2003, 7569, 55, 52],
            [2003, 7570, 54, 51],
            [2003, 7571, 54, 51],
            [2003, 7572, 94, 70],
            [2003, 7573, 61, 51],
            [2003, 7574, 54, 51],
            [2003, 7575, 68, 51],
            [2003, 7576, 68, 51],
            [2003, 7577, 75, 55],
            [2003, 7578, 55, 53],
            [2003, 7579, 75, 55],
            [2003, 7580, 75, 55],
            [2003, 7581, 67, 51],
            [2003, 7582, 67, 57],
            [2003, 7583, 61, 57],
            [2003, 7584, 51, 48],
            [2003, 7585, 52, 49],
            [2003, 7586, 94, 70],
            [2003, 7587, 54, 51],
            [2003, 7588, 55, 53],
            [2003, 7589, 94, 70],
            [2003, 7590, 61, 57],
            [2003, 7591, 61, 46],
            [2003, 7592, 75, 55],
            [2003, 7593, 70, 52],
            [2003, 7594, 54, 51],
            [2003, 7595, 55, 53],
            [2003, 7596, 48, 45],
            [2003, 7597, 55, 53],
            [2003, 7598, 68, 51],
            [2003, 7599, 61, 57],
            [2003, 7600, 61, 57],
            [2003, 7601, 49, 45],
            [2003, 7602, 45, 43],
            [2003, 7603, 61, 57],
            [2003, 7604, 61, 57],
            [2003, 7605, 61, 57],
            [2003, 7606, 61, 51],
            [2003, 7607, 75, 55],
            [2003, 7608, 49, 45],
            [2003, 7609, 61, 57],
            [2003, 7610, 48, 47],
            [2003, 7611, 43, 57],
            [2003, 7612, 61, 55],
            [2003, 7613, 55, 53],
            [2003, 7614, 61, 51],
            [2003, 7615, 75, 55],
            [2003, 7616, 67, 50],
            [2003, 7617, 61, 47],
            [2003, 7618, 67, 50],
            [2003, 7619, 61, 57],
            [2003, 7620, 54, 51],
            [2003, 7621, 61, 57],
            [2003, 7622, 75, 55],
            [2003, 7623, 54, 51],
            [2003, 7624, 82, 60],
            [2003, 7625, 48, 46],
            [2003, 7626, 67, 50],
            [2003, 7627, 52, 48],
            [2003, 7628, 75, 55],
            [2003, 7629, 48, 46],
            [2003, 7630, 51, 48],
            [2003, 7631, 57, 54],
            [2003, 7632, 67, 50],
            [2003, 7633, 48, 46],
            [2003, 7634, 16, 26],
            [2003, 7635, 16, 22],
            [2003, 7636, 19, 25],
            [2003, 7637, 32, 31],
            [2003, 7638, 25, 21],
            [2003, 7639, 12, 14],
            [2003, 7640, 11, 12],
            [2003, 7641, 15, 17],
            [2003, 7642, 32, 37],
            [2003, 7643, 18, 18],
            [2003, 7644, 31, 40],
            [2003, 7645, 18, 22],
            [2003, 7646, 28, 27],
            [2003, 7647, 36, 25],
            [2003, 7648, 12, 12],
            [2003, 7649, 12, 13],
            [2003, 7650, 18, 19],
            [2003, 7651, 14, 13],
            [2003, 7652, 15, 13],
            [2003, 7653, 45, 33],
            [2003, 7654, 13, 14],
            [2003, 7655, 16, 15],
            [2003, 7656, 14, 13],
            [2003, 7657, 27, 27],
            [2003, 7658, 22, 28],
            [2003, 7659, 13, 18],
            [2003, 7661, 10, 10],
            [2003, 7662, 15, 13],
            [2003, 7663, 17, 19],
            [2003, 7664, 23, 32],
            [2003, 7665, 34, 44],
            [2003, 7666, 14, 17],
            [2003, 7667, 15, 17],
            [2003, 7668, 16, 13],
            [2003, 7669, 11, 8],
            [2003, 7672, 10, 9],
            [2003, 7673, 8, 7],
            [2003, 7674, 20, 17],
            [2003, 7676, 6, 7],
            [2003, 7677, 6, 6],
            [2003, 7678, 10, 8],
            [2003, 7679, 13, 10],
            [2003, 7680, 20, 21],
            [2003, 7681, 5, 3],
            [2003, 7682, 16, 13],
            [2003, 7683, 5, 3],
            [2003, 7684, 15, 14],
            [2003, 7685, 12, 11],
            [2003, 7686, 21, 19],
            [2003, 7687, 5, 3],
            [2003, 7688, 15, 14],
            [2003, 7690, 7, 8],
            [2003, 7691, 20, 24],
            [2003, 7692, 11, 10],
            [2003, 7693, 9, 9],
            [2003, 7694, 10, 9],
            [2003, 7695, 28, 20],
            [2003, 7696, 5, 3],
            [2003, 7697, 16, 12],
            [2003, 7698, 10, 8],
            [2003, 7699, 13, 15],
            [2003, 7700, 11, 10],
            [2003, 7701, 9, 8],
            [2003, 7702, 17, 13],
            [2003, 7703, 12, 13],
            [2003, 7705, 21, 13],
            [2003, 7706, 11, 10],
            [2003, 7707, 10, 10],
            [2003, 7708, 9, 7],
            [2003, 7709, 12, 14],
            [2003, 7710, 6, 6],
            [2003, 7711, 16, 12],
            [2003, 7713, 20, 12],
            [2003, 7714, 10, 9],
            [2003, 7715, 33, 38],
            [2003, 7716, 34, 35],
            [2003, 7717, 57, 66],
            [2003, 7718, 36, 36],
            [2003, 7719, 28, 33],
            [2003, 7720, 62, 73],
            [2003, 7721, 37, 36],
            [2003, 7722, 44, 37],
            [2003, 7723, 27, 31],
            [2003, 7724, 54, 62],
            [2003, 7725, 19, 24],
            [2003, 7726, 31, 36],
            [2003, 7727, 39, 39],
            [2003, 7728, 54, 51],
            [2003, 7729, 38, 37],
            [2003, 7730, 26, 30],
            [2003, 7731, 56, 64],
            [2003, 7732, 31, 35],
            [2003, 7733, 51, 58],
            [2003, 7734, 54, 43],
            [2003, 7735, 73, 68],
            [2003, 7736, 28, 32],
            [2003, 7737, 48, 45],
            [2003, 7738, 27, 31],
            [2003, 7739, 38, 46],
            [2003, 7740, 28, 32],
            [2003, 7741, 48, 54],
            [2003, 7742, 51, 52],
            [2003, 7743, 36, 35],
            [2003, 7744, 55, 63],
            [2003, 7745, 57, 45],
            [2003, 7746, 37, 37],
            [2003, 7747, 45, 54],
            [2003, 7748, 52, 50],
            [2003, 7749, 38, 39],
            [2003, 7750, 54, 62],
            [2003, 7751, 54, 44],
            [2003, 7752, 71, 67],
            [2003, 7753, 50, 47],
            [2003, 7754, 38, 39],
            [2003, 7755, 29, 32],
            [2003, 7756, 71, 48],
            [2003, 7757, 54, 47],
            [2003, 7758, 81, 63],
            [2003, 7759, 29, 33],
            [2003, 7760, 51, 50],
            [2003, 7761, 55, 51],
            [2003, 7762, 32, 39],
            [2003, 7763, 16, 22],
            [2003, 7764, 15, 18],
            [2003, 7765, 17, 24],
            [2003, 7766, 10, 19],
            [2003, 7767, 26, 31],
            [2003, 7768, 11, 21],
            [2003, 7769, 37, 35],
            [2003, 7770, 51, 38],
            [2003, 7771, 15, 17],
            [2003, 7772, 14, 18],
            [2003, 7773, 23, 25],
            [2003, 7774, 13, 22],
            [2003, 7775, 38, 38],
            [2003, 7776, 15, 31],
            [2003, 7777, 22, 35],
            [2003, 7778, 9, 12],
            [2003, 7779, 15, 20],
            [2003, 7780, 19, 19],
            [2003, 7781, 25, 29],
            [2003, 7782, 30, 26],
            [2003, 7783, 31, 25],
            [2003, 7784, 13, 29],
            [2003, 7785, 23, 39],
            [2003, 7786, 14, 17],
            [2003, 7787, 24, 29],
            [2003, 7788, 19, 22],
            [2003, 7789, 22, 27],
            [2003, 7790, 20, 27],
            [2003, 7791, 40, 38],
            [2003, 7792, 18, 22],
            [2003, 7793, 34, 34],
            [2003, 7795, 171, 98],
            [2003, 7796, 296, 75],
            [2003, 7797, 320, 85],
            [2003, 7798, 164, 40],
            [2003, 7799, 175, 76],
            [2003, 7800, 100, 44],
            [2003, 7801, 266, 78],
            [2003, 7802, 185, 40],
            [2003, 7803, 492, 157],
            [2003, 7804, 228, 91],
            [2003, 7805, 158, 55],
            [2003, 7806, 160, 89],
            [2003, 7807, 106, 83],
            [2003, 7808, 180, 140],
            [2003, 7809, 120, 77],
            [2003, 7810, 292, 119],
            [2003, 7811, 732, 150],
            [2003, 7812, 45, 40],
            [2003, 7813, 90, 40],
            [2003, 7815, 88, 40],
            [2003, 7816, 406, 140],
            [2003, 7817, 73, 50],
            [2003, 7818, 86, 81],
            [2003, 7819, 60, 72],
            [2003, 7820, 96, 52],
            [2003, 7821, 266, 71],
            [2003, 7822, 142, 73],
            [2003, 7823, 120, 51],
            [2003, 7824, 208, 73],
            [2003, 7825, 213, 75],
            [2003, 7826, 120, 91],
            [2003, 7827, 173, 66],
            [2003, 7828, 205, 118],
            [2003, 7829, 103, 54],
            [2003, 7830, 147, 60],
            [2003, 7831, 165, 43],
            [2003, 7832, 187, 94],
            [2003, 7833, 63, 40],
            [2003, 7834, 175, 90],
            [2003, 7835, 128, 40],
            [2003, 7836, 177, 86],
            [2003, 7837, 48, 40],
            [2003, 7838, 183, 80],
            [2003, 7839, 122, 98],
            [2003, 7840, 277, 110],
            [2003, 7841, 175, 72],
            [2003, 7842, 46, 41],
            [2003, 7843, 51, 40],
            [2003, 7844, 196, 65],
            [2003, 7845, 53, 51],
            [2003, 7846, 274, 140],
            [2003, 7847, 489, 140],
            [2003, 7848, 356, 133],
            [2003, 7849, 356, 200],
            [2003, 7850, 103, 93],
            [2003, 7851, 190, 90],
            [2003, 7852, 101, 48],
            [2003, 7853, 92, 62],
            [2003, 7854, 40, 40],
            [2003, 7855, 40, 40],
            [2003, 7856, 247, 140],
            [2003, 7857, 67, 40],
            [2003, 7858, 46, 40],
            [2003, 7859, 186, 74],
            [2003, 7860, 124, 79],
            [2003, 7861, 51, 40],
            [2003, 7862, 402, 69],
            [2003, 7863, 554, 103],
            [2003, 7864, 45, 41],
            [2003, 7865, 51, 44],
            [2003, 7866, 160, 76],
            [2003, 7867, 55, 40],
            [2003, 7868, 53, 40],
            [2003, 7869, 160, 79],
            [2003, 7870, 50, 40],
            [2003, 7871, 64, 42],
            [2003, 7872, 180, 169],
            [2003, 7873, 278, 119],
            [2003, 7874, 48, 40],
            [2003, 7875, 302, 125],
            [2003, 7876, 180, 140],
            [2003, 7877, 120, 74],
            [2003, 7878, 236, 56],
            [2003, 7879, 190, 103],
            [2003, 7880, 97, 72],
            [2003, 7881, 120, 66],
            [2003, 7882, 51, 40],
            [2003, 7883, 120, 93],
            [2003, 7884, 67, 64],
            [2003, 7885, 70, 50],
            [2003, 7886, 80, 41],
            [2003, 7887, 55, 40],
            [2003, 7888, 140, 51],
            [2003, 7889, 322, 120],
            [2003, 7890, 170, 111],
            [2003, 7891, 75, 40],
            [2003, 7892, 64, 40],
            [2003, 7893, 64, 40],
            [2003, 7894, 140, 97],
            [2003, 7895, 80, 43],
            [2003, 7896, 329, 90],
            [2003, 7897, 270, 62],
            [2003, 7898, 120, 59],
            [2003, 7899, 566, 113],
            [2003, 7900, 304, 93],
            [2003, 7901, 120, 60],
            [2003, 7902, 161, 88],
            [2003, 7903, 272, 110],
            [2003, 7904, 120, 83],
            [2003, 7905, 140, 71],
            [2003, 7906, 146, 111],
            [2003, 7907, 172, 62],
            [2003, 7908, 170, 60],
            [2003, 7909, 120, 50],
            [2003, 7910, 124, 58],
            [2003, 7911, 180, 140],
            [2003, 7912, 449, 195],
            [2003, 7913, 247, 61],
            [2003, 7914, 120, 68],
            [2003, 7915, 120, 90],
            [2003, 7916, 150, 57],
            [2003, 7917, 120, 52],
            [2003, 7918, 71, 40],
            [2003, 7919, 120, 40],
            [2003, 7920, 91, 51],
            [2003, 7921, 60, 40],
            [2003, 7922, 120, 42],
            [2003, 7923, 133, 40],
            [2003, 7924, 47, 40],
            [2003, 7925, 62, 40],
            [2003, 7926, 86, 51],
            [2003, 7927, 140, 57],
            [2003, 7928, 120, 53],
            [2003, 7929, 232, 96],
            [2003, 7930, 340, 57],
            [2003, 7931, 59, 40],
            [2003, 7932, 89, 40],
            [2003, 7933, 120, 75],
            [2003, 7934, 176, 141],
            [2003, 7935, 246, 90],
            [2003, 7936, 179, 60],
            [2003, 7937, 75, 52],
            [2003, 7938, 120, 40],
            [2003, 7939, 395, 140],
            [2003, 7940, 167, 86],
            [2003, 7941, 341, 133],
            [2003, 7942, 176, 111],
            [2003, 7943, 61, 40],
            [2003, 7944, 120, 43],
            [2003, 7945, 270, 53],
            [2003, 7946, 124, 91],
            [2003, 7947, 101, 64],
            [2003, 7948, 120, 40],
            [2003, 7949, 199, 111],
            [2003, 7950, 120, 57],
            [2003, 7951, 169, 73],
            [2003, 7952, 125, 90],
            [2003, 7953, 69, 40],
            [2003, 7954, 120, 40],
            [2003, 7955, 200, 60],
            [2003, 7956, 425, 149],
            [2003, 7957, 120, 50],
            [2003, 7958, 216, 53],
            [2003, 7959, 188, 65],
            [2003, 7960, 120, 45],
            [2003, 7961, 206, 207],
            [2003, 7962, 386, 112],
            [2003, 7963, 120, 40],
            [2003, 7964, 200, 112],
            [2003, 7965, 179, 70],
            [2003, 7966, 142, 93],
            [2003, 7967, 182, 40],
            [2003, 7968, 495, 159],
            [2003, 7969, 420, 220],
            [2003, 7970, 203, 83],
            [2003, 7971, 45, 40],
            [2003, 7972, 77, 47],
            [2003, 7974, 120, 40],
            [2003, 7975, 378, 120],
            [2003, 7976, 400, 64],
            [2003, 7977, 278, 164],
            [2003, 7978, 172, 79],
            [2003, 7979, 128, 74],
            [2003, 7980, 331, 80],
            [2003, 7981, 169, 50],
            [2003, 7982, 83, 44],
            [2003, 7983, 120, 40],
            [2003, 7984, 180, 140],
            [2003, 7985, 91, 59],
            [2003, 7986, 97, 40],
            [2003, 7987, 106, 51],
            [2003, 7988, 120, 49],
            [2003, 7989, 900, 98],
            [2003, 7990, 83, 40],
            [2003, 7992, 120, 75],
            [2003, 7993, 231, 103],
            [2003, 7994, 120, 52],
            [2003, 7995, 543, 201],
            [2003, 7996, 136, 59],
            [2003, 7997, 315, 145],
            [2003, 7998, 120, 40],
            [2003, 7999, 138, 100],
            [2003, 8000, 120, 40],
            [2003, 8001, 248, 99],
            [2003, 8002, 167, 93],
            [2003, 8003, 120, 40],
            [2003, 8004, 189, 218],
            [2003, 8005, 20, 25],
            [2003, 8006, 15, 19],
            [2003, 8007, 26, 31],
            [2003, 8008, 21, 26],
            [2003, 8009, 16, 17],
            [2003, 8010, 14, 16],
            [2003, 8011, 16, 18],
            [2003, 8012, 12, 15],
            [2003, 8013, 7, 7],
            [2003, 8014, 9, 9],
            [2003, 8015, 10, 9],
            [2003, 8016, 6, 5],
            [2003, 8017, 12, 13],
            [2003, 8018, 7, 7],
            [2003, 8019, 16, 16],
            [2003, 8020, 13, 14],
            [2003, 8021, 6, 6],
            [2003, 8022, 24, 30],
            [2003, 8023, 16, 17],
            [2003, 8024, 21, 19],
            [2003, 8025, 17, 21],
            [2003, 8026, 18, 19],
            [2003, 8027, 13, 11],
            [2003, 8028, 14, 14],
            [2003, 8029, 24, 22],
            [2003, 8030, 17, 16],
            [2003, 8031, 12, 11],
            [2003, 8032, 18, 23],
            [2003, 8033, 24, 26],
            [2003, 8034, 24, 31],
            [2003, 8035, 20, 19],
            [2003, 8036, 17, 21],
            [2003, 8037, 21, 25],
            [2003, 8038, 36, 35],
            [2003, 8039, 33, 61],
            [2003, 8040, 21, 61],
            [2003, 8041, 7, 14],
            [2003, 8042, 7, 10],
            [2003, 8043, 11, 16],
            [2003, 8044, 11, 15],
            [2003, 8045, 5, 3],
            [2003, 8046, 5, 3],
            [2003, 8047, 5, 5],
            [2003, 8048, 15, 20],
            [2003, 8049, 12, 15],
            [2003, 8050, 9, 11],
            [2003, 8051, 19, 23],
            [2003, 8052, 35, 44],
            [2003, 8053, 23, 35],
            [2003, 8054, 20, 30],
            [2003, 8055, 30, 46],
            [2003, 8056, 41, 48],
            [2003, 8057, 22, 32],
            [2003, 8058, 19, 26],
            [2003, 8059, 24, 29],
            [2003, 8060, 27, 33],
            [2003, 8061, 52, 62],
            [2003, 8062, 54, 72],
            [2003, 8063, 10, 11],
            [2003, 8064, 17, 20],
            [2003, 8065, 14, 13],
            [2003, 8066, 117, 46],
            [2003, 8067, 39, 30],
            [2003, 8068, 11, 11],
            [2003, 8069, 13, 27],
            [2003, 8070, 16, 17],
            [2003, 8071, 42, 20],
            [2003, 8072, 34, 22],
            [2003, 8073, 52, 28],
            [2003, 8074, 14, 12],
            [2003, 8075, 29, 16],
            [2003, 8076, 58, 37],
            [2003, 8079, 53, 43],
            [2003, 8080, 96, 44],
            [2003, 8081, 84, 46],
            [2003, 8082, 60, 37],
            [2003, 8083, 89, 40],
            [2003, 8084, 85, 43],
            [2003, 8085, 39, 29],
            [2003, 8086, 16, 44],
            [2003, 8087, 15, 31],
            [2003, 8088, 18, 37],
            [2003, 8089, 21, 46],
            [2003, 8090, 21, 32],
            [2003, 8091, 23, 61],
            [2003, 8092, 20, 47],
            [2003, 8093, 23, 61],
            [2003, 8094, 14, 61],
            [2003, 8095, 21, 27],
            [2003, 8096, 24, 37],
            [2003, 8097, 20, 32],
            [2003, 8098, 9, 25],
            [2003, 8099, 36, 36],
            [2003, 8100, 35, 35],
            [2003, 8101, 37, 36],
            [2003, 8102, 28, 31],
            [2003, 8103, 37, 36],
            [2003, 8104, 35, 35],
            [2003, 8105, 56, 45],
            [2003, 8106, 39, 39],
            [2003, 8107, 28, 33],
            [2003, 8108, 48, 45],
            [2003, 8109, 38, 37],
            [2003, 8110, 28, 32],
            [2003, 8111, 45, 42],
            [2003, 8112, 35, 35],
            [2003, 8113, 55, 45],
            [2003, 8114, 28, 32],
            [2003, 8115, 62, 74],
            [2003, 8116, 39, 38],
            [2003, 8117, 49, 67],
            [2003, 8118, 29, 34],
            [2003, 8119, 37, 37],
            [2003, 8120, 46, 44],
            [2003, 8121, 29, 32],
            [2003, 8122, 36, 36],
            [2003, 8123, 56, 46],
            [2003, 8124, 37, 38],
            [2003, 8125, 57, 46],
            [2003, 8126, 31, 32],
            [2003, 8127, 38, 39],
            [2003, 8128, 78, 74],
            [2003, 8129, 36, 36],
            [2003, 8130, 56, 46],
            [2003, 8131, 27, 31],
            [2003, 8132, 48, 45],
            [2003, 8133, 29, 33],
            [2003, 8134, 49, 47],
            [2003, 8135, 57, 46],
            [2003, 8136, 23, 27],
            [2003, 8137, 36, 37],
            [2003, 8138, 39, 39],
            [2003, 8139, 57, 64],
            [2003, 8140, 42, 50],
            [2003, 8141, 35, 35],
            [2003, 8142, 36, 36],
            [2003, 8143, 61, 71],
            [2003, 8144, 27, 32],
            [2003, 8145, 28, 31],
            [2003, 8146, 46, 52],
            [2003, 8147, 35, 35],
            [2003, 8148, 38, 37],
            [2003, 8149, 29, 34],
            [2003, 8150, 65, 78],
            [2003, 8151, 27, 31],
            [2003, 8152, 55, 66],
            [2003, 8153, 36, 37],
            [2003, 8154, 35, 35],
            [2003, 8155, 50, 41],
            [2003, 8156, 70, 86],
            [2003, 8157, 39, 38],
            [2003, 8158, 36, 36],
            [2003, 8159, 32, 33],
            [2003, 8160, 36, 36],
            [2003, 8161, 57, 46],
            [2003, 8162, 59, 47],
            [2003, 8163, 49, 41],
            [2003, 8164, 35, 35],
            [2003, 8165, 38, 38],
            [2003, 8166, 73, 55],
            [2003, 8167, 57, 46],
            [2003, 8168, 36, 37],
            [2003, 8169, 48, 42],
            [2003, 8170, 37, 37],
            [2003, 8171, 36, 37],
            [2003, 8172, 73, 54],
            [2003, 8173, 36, 36],
            [2003, 8174, 37, 36],
            [2003, 8175, 29, 32],
            [2003, 8176, 28, 32],
            [2003, 8177, 30, 35],
            [2003, 8178, 38, 39],
            [2003, 8179, 46, 43],
            [2003, 8180, 36, 35],
            [2003, 8181, 71, 54],
            [2003, 8182, 56, 46],
            [2003, 8183, 39, 39],
            [2003, 8184, 35, 35],
            [2003, 8185, 35, 36],
            [2003, 8186, 38, 38],
            [2003, 8187, 30, 34],
            [2003, 8188, 22, 26],
            [2003, 8189, 47, 44],
            [2003, 8190, 28, 31],
            [2003, 8191, 55, 54],
            [2003, 8192, 39, 38],
            [2003, 8193, 71, 52],
            [2003, 8194, 35, 34],
            [2003, 8195, 37, 36],
            [2003, 8196, 30, 34],
            [2003, 8197, 39, 39],
            [2003, 8198, 30, 34],
            [2003, 8199, 57, 65],
            [2003, 8200, 28, 33],
            [2003, 8201, 74, 56],
            [2003, 8202, 47, 46],
            [2003, 8203, 66, 45],
            [2003, 8204, 55, 45],
            [2003, 8205, 26, 29],
            [2003, 8206, 53, 51],
            [2003, 8207, 36, 36],
            [2003, 8208, 28, 32],
            [2003, 8209, 74, 56],
            [2003, 8210, 38, 38],
            [2003, 8211, 60, 71],
            [2003, 8212, 28, 32],
            [2003, 8213, 38, 37],
            [2003, 8214, 58, 67],
            [2003, 8215, 37, 36],
            [2003, 8216, 37, 36],
            [2003, 8217, 38, 38],
            [2003, 8218, 18, 25],
            [2003, 8219, 52, 50],
            [2003, 8220, 27, 31],
            [2003, 8221, 47, 44],
            [2003, 8222, 24, 28],
            [2003, 8223, 28, 32],
            [2003, 8224, 45, 50],
            [2003, 8225, 35, 41],
            [2003, 8226, 60, 70],
            [2003, 8227, 36, 36],
            [2003, 8228, 26, 29],
            [2003, 8229, 35, 34],
            [2003, 8230, 38, 37],
            [2003, 8231, 23, 27],
            [2003, 8232, 56, 54],
            [2003, 8233, 36, 36],
            [2003, 8234, 26, 29],
            [2003, 8235, 57, 66],
            [2003, 8236, 28, 32],
            [2003, 8237, 54, 51],
            [2003, 8238, 35, 35],
            [2003, 8239, 83, 63],
            [2003, 8240, 37, 36],
            [2003, 8241, 29, 34],
            [2003, 8242, 50, 47],
            [2003, 8245, 38, 37],
            [2003, 8246, 39, 39],
            [2003, 8247, 56, 46],
            [2003, 8248, 24, 28],
            [2003, 8249, 48, 45],
            [2003, 8250, 34, 35],
            [2003, 8251, 37, 36],
            [2003, 8252, 46, 43],
            [2003, 8253, 54, 44],
            [2003, 8254, 35, 41],
            [2003, 8255, 35, 35],
            [2003, 8256, 30, 33],
            [2003, 8257, 58, 67],
            [2003, 8258, 36, 36],
            [2003, 8259, 36, 35],
            [2003, 8260, 38, 39],
            [2003, 8261, 56, 64],
            [2003, 8262, 51, 52],
            [2003, 8263, 66, 50],
            [2003, 8264, 32, 37],
            [2003, 8265, 51, 73],
            [2003, 8267, 55, 44],
            [2003, 8268, 37, 37],
            [2003, 8269, 36, 36],
            [2003, 8270, 22, 27],
            [2003, 8271, 29, 34],
            [2003, 8272, 47, 44],
            [2003, 8273, 36, 36],
            [2003, 8274, 36, 35],
            [2003, 8275, 31, 35],
            [2003, 8276, 35, 35],
            [2003, 8277, 34, 26],
            [2003, 8278, 56, 46],
            [2003, 8279, 36, 36],
            [2003, 8280, 39, 39],
            [2003, 8281, 36, 36],
            [2003, 8282, 39, 39],
            [2003, 8283, 38, 37],
            [2003, 8284, 37, 36],
            [2003, 8285, 39, 39],
            [2003, 8286, 39, 39],
            [2003, 8287, 38, 38],
            [2003, 8288, 29, 34],
            [2003, 8289, 48, 45],
            [2003, 8290, 39, 39],
            [2003, 8291, 39, 39],
            [2003, 8292, 38, 37],
            [2003, 8293, 35, 35],
            [2003, 8294, 36, 35],
            [2003, 8295, 56, 46],
            [2003, 8296, 55, 38],
            [2003, 8297, 37, 37],
            [2003, 8298, 28, 50],
            [2003, 8299, 23, 27],
            [2003, 8300, 73, 56],
            [2003, 8301, 38, 38],
            [2003, 8302, 36, 35],
            [2003, 8303, 56, 46],
            [2003, 8304, 36, 35],
            [2003, 8305, 54, 44],
            [2003, 8306, 30, 34],
            [2003, 8307, 22, 26],
            [2003, 8308, 36, 35],
            [2003, 8309, 17, 22],
            [2003, 8310, 47, 45],
            [2003, 8311, 15, 17],
            [2003, 8312, 14, 15],
            [2003, 8313, 14, 15],
            [2003, 8314, 15, 17],
            [2003, 8315, 14, 15],
            [2003, 8316, 14, 14],
            [2003, 8317, 42, 42],
            [2003, 8318, 63, 48],
            [2003, 8319, 22, 23],
            [2003, 8320, 57, 46],
            [2003, 8321, 39, 30],
            [2003, 8322, 38, 38],
            [2003, 8323, 30, 34],
            [2003, 8324, 67, 50],
            [2003, 8325, 61, 49],
            [2003, 8326, 56, 45],
            [2003, 8327, 54, 44],
            [2003, 8328, 59, 47],
            [2003, 8329, 36, 36],
            [2003, 8330, 58, 47],
            [2003, 8331, 54, 44],
            [2003, 8332, 56, 46],
            [2003, 8336, 21, 18],
            [2003, 8337, 13, 16],
            [2003, 8338, 13, 13],
            [2003, 8339, 38, 39],
            [2003, 8340, 15, 18],
            [2003, 8341, 27, 30],
            [2003, 8342, 16, 16],
            [2003, 8343, 18, 19],
            [2003, 8344, 14, 13],
            [2003, 8345, 20, 16],
            [2003, 8346, 19, 24],
            [2003, 8347, 16, 18],
            [2003, 8348, 22, 27],
            [2003, 8349, 16, 18],
            [2003, 8350, 18, 18],
            [2003, 8351, 14, 11],
            [2003, 8352, 20, 27],
            [2003, 8353, 14, 17],
            [2003, 8354, 23, 28],
            [2003, 8355, 15, 16],
            [2003, 8356, 24, 29],
            [2003, 8357, 15, 15],
            [2003, 8358, 23, 18],
            [2003, 8359, 33, 39],
            [2003, 8360, 32, 37],
            [2003, 8361, 15, 14],
            [2003, 8362, 18, 24],
            [2003, 8363, 23, 30],
            [2003, 8364, 28, 24],
            [2003, 8365, 13, 14],
            [2003, 8366, 23, 20],
            [2003, 8367, 16, 17],
            [2003, 8368, 18, 24],
            [2003, 8369, 19, 24],
            [2003, 8370, 19, 20],
            [2003, 8371, 20, 19],
            [2003, 8372, 23, 20],
            [2003, 8373, 23, 28],
            [2003, 8374, 22, 28],
            [2003, 8375, 15, 14],
            [2003, 8376, 27, 27],
            [2003, 8377, 21, 16],
            [2003, 8378, 21, 18],
            [2003, 8379, 25, 23],
            [2003, 8380, 27, 28],
            [2003, 8381, 26, 31],
            [2003, 8382, 19, 22],
            [2003, 8383, 24, 28],
            [2003, 8384, 22, 31],
            [2003, 8385, 20, 25],
            [2003, 8386, 14, 17],
            [2003, 8387, 23, 24],
            [2003, 8388, 18, 18],
            [2003, 8389, 17, 19],
            [2003, 8390, 14, 16],
            [2003, 8391, 17, 20],
            [2003, 8392, 19, 22],
            [2003, 8393, 34, 45],
            [2003, 8394, 24, 20],
            [2003, 8395, 20, 21],
            [2003, 8396, 51, 46],
            [2003, 8397, 67, 50],
            [2003, 8398, 47, 36],
            [2003, 8399, 62, 40],
            [2003, 8400, 53, 49],
            [2003, 8401, 63, 38],
            [2003, 8402, 49, 39],
            [2003, 8403, 55, 37],
            [2003, 8404, 45, 41],
            [2003, 8405, 56, 37],
            [2003, 8406, 48, 40],
            [2003, 8407, 51, 48],
            [2003, 8408, 44, 48],
            [2003, 8409, 36, 31],
            [2003, 8410, 52, 41],
            [2003, 8411, 80, 56],
            [2003, 8412, 48, 45],
            [2003, 8413, 58, 45],
            [2003, 8414, 73, 38],
            [2003, 8415, 79, 53],
            [2003, 8416, 34, 33],
            [2003, 8417, 61, 40],
            [2003, 8418, 27, 29],
            [2003, 8419, 57, 42],
            [2003, 8420, 56, 43],
            [2003, 8421, 65, 49],
            [2003, 8422, 35, 36],
            [2003, 8423, 54, 51],
            [2003, 8424, 63, 64],
            [2003, 8425, 41, 51],
            [2003, 8426, 42, 37],
            [2003, 8427, 45, 37],
            [2003, 8428, 49, 40],
            [2003, 8429, 35, 32],
            [2003, 8430, 54, 51],
            [2003, 8431, 63, 48],
            [2003, 8432, 55, 51],
            [2003, 8433, 53, 49],
            [2003, 8434, 63, 41],
            [2003, 8435, 90, 47],
            [2003, 8436, 67, 50],
            [2003, 8438, 38, 32],
            [2003, 8439, 42, 39],
            [2003, 8440, 74, 46],
            [2003, 8441, 65, 43],
            [2003, 8442, 43, 41],
            [2003, 8443, 56, 49],
            [2003, 8444, 54, 51],
            [2003, 8445, 30, 27],
            [2003, 8446, 39, 33],
            [2003, 8447, 55, 45],
            [2003, 8448, 45, 40],
            [2003, 8449, 76, 35],
            [2003, 8450, 65, 45],
            [2003, 8451, 21, 29],
            [2003, 8452, 28, 39],
            [2003, 8453, 20, 26],
            [2003, 8454, 26, 32],
            [2003, 8455, 24, 29],
            [2003, 8456, 23, 29],
            [2003, 8457, 54, 51],
            [2003, 8458, 43, 34],
            [2003, 8459, 57, 40],
            [2003, 8460, 47, 42],
            [2003, 8461, 67, 40],
            [2003, 8462, 62, 42],
            [2003, 8463, 60, 50],
            [2003, 8464, 67, 49],
            [2003, 8465, 36, 28],
            [2003, 8466, 37, 43],
            [2003, 8467, 42, 37],
            [2003, 8468, 51, 44],
            [2003, 8469, 46, 39],
            [2003, 8470, 67, 51],
            [2003, 8471, 37, 42],
            [2003, 8472, 69, 37],
            [2003, 8473, 55, 49],
            [2003, 8474, 44, 41],
            [2003, 8475, 61, 46],
            [2003, 8476, 62, 47],
            [2003, 8477, 62, 47],
            [2003, 8478, 32, 33],
            [2003, 8479, 45, 41],
            [2003, 8480, 66, 51],
            [2003, 8481, 51, 41],
            [2003, 8482, 49, 40],
            [2003, 8483, 48, 40],
            [2003, 8484, 57, 43],
            [2003, 8485, 61, 50],
            [2003, 8486, 35, 29],
            [2003, 8487, 54, 40],
            [2003, 8488, 43, 37],
            [2003, 8489, 35, 53],
            [2003, 8490, 56, 44],
            [2003, 8491, 48, 46],
            [2003, 8492, 50, 38],
            [2003, 8493, 60, 39],
            [2003, 8494, 35, 29],
            [2003, 8495, 65, 66],
            [2003, 8496, 31, 40],
            [2003, 8497, 52, 52],
            [2003, 8498, 36, 40],
            [2003, 8499, 46, 39],
            [2003, 8500, 63, 42],
            [2003, 8501, 54, 62],
            [2003, 8502, 66, 41],
            [2003, 8503, 63, 48],
            [2003, 8504, 46, 43],
            [2003, 8505, 64, 49],
            [2003, 8506, 67, 50],
            [2003, 8507, 66, 51],
            [2003, 8508, 38, 38],
            [2003, 8509, 44, 40],
            [2003, 8510, 67, 48],
            [2003, 8511, 58, 45],
            [2003, 8512, 54, 51],
            [2003, 8513, 52, 48],
            [2003, 8514, 58, 57],
            [2003, 8515, 47, 44],
            [2003, 8516, 111, 64],
            [2003, 8517, 60, 26],
            [2003, 8518, 69, 63],
            [2003, 8519, 40, 36],
            [2003, 8520, 48, 39],
            [2003, 8521, 44, 39],
            [2003, 8522, 46, 42],
            [2003, 8523, 45, 40],
            [2003, 8524, 43, 38],
            [2003, 8525, 56, 40],
            [2003, 8526, 61, 47],
            [2003, 8527, 57, 56],
            [2003, 8528, 62, 51],
            [2003, 8529, 71, 51],
            [2003, 8530, 37, 34],
            [2003, 8531, 67, 61],
            [2003, 8532, 57, 55],
            [2003, 8533, 66, 61],
            [2003, 8534, 48, 47],
            [2003, 8535, 65, 64],
            [2003, 8536, 20, 37],
            [2003, 8537, 46, 31],
            [2003, 8538, 45, 31],
            [2003, 8539, 41, 35],
            [2003, 8540, 33, 47],
            [2003, 8541, 41, 56],
            [2003, 8542, 35, 50],
            [2003, 8543, 22, 47],
            [2003, 8544, 29, 60],
            [2003, 8546, 29, 47],
            [2003, 8547, 34, 60],
            [2003, 8548, 15, 19],
            [2003, 8549, 24, 31],
            [2003, 8550, 20, 29],
            [2003, 8551, 35, 29],
            [2003, 8552, 31, 38],
            [2003, 8553, 44, 58],
            [2003, 8554, 22, 20],
            [2003, 8555, 37, 35],
            [2003, 8556, 41, 57],
            [2003, 8557, 56, 55],
            [2003, 8558, 29, 32],
            [2003, 8559, 37, 35],
            [2003, 8560, 30, 35],
            [2003, 8561, 24, 29],
            [2003, 8562, 35, 35],
            [2003, 8563, 43, 46],
            [2003, 8564, 79, 64],
            [2003, 8565, 10, 12],
            [2003, 8566, 16, 14],
            [2003, 8567, 22, 21],
            [2003, 8568, 16, 16],
            [2003, 8569, 18, 15],
            [2003, 8570, 10, 10],
            [2003, 8571, 14, 11],
            [2003, 8572, 14, 11],
            [2003, 8573, 12, 11],
            [2003, 8574, 15, 13],
            [2003, 8575, 10, 10],
            [2003, 8576, 21, 16],
            [2003, 8577, 18, 16],
            [2003, 8578, 23, 22],
            [2003, 8579, 18, 20],
            [2003, 8580, 17, 17],
            [2003, 8581, 12, 10],
            [2003, 8582, 17, 17],
            [2003, 8583, 19, 18],
            [2003, 8584, 14, 14],
            [2003, 8585, 11, 11],
            [2003, 8586, 32, 19],
            [2003, 8587, 10, 9],
            [2003, 8588, 34, 16],
            [2003, 8589, 14, 13],
            [2003, 8590, 22, 15],
            [2003, 8591, 19, 15],
            [2003, 8592, 29, 28],
            [2003, 8593, 25, 23],
            [2003, 8594, 38, 25],
            [2003, 8595, 14, 14],
            [2003, 8596, 17, 15],
            [2003, 8597, 20, 21],
            [2003, 8598, 27, 21],
            [2003, 8599, 15, 12],
            [2003, 8600, 22, 15],
            [2003, 8601, 28, 20],
            [2003, 8602, 27, 19],
            [2003, 8603, 25, 15],
            [2003, 8604, 41, 21],
            [2003, 8605, 23, 23],
            [2003, 8606, 40, 23],
            [2003, 8607, 18, 24],
            [2003, 8608, 29, 26],
            [2003, 8609, 27, 19],
            [2003, 8610, 23, 24],
            [2003, 8611, 24, 18],
            [2003, 8612, 35, 22],
            [2003, 8613, 15, 11],
            [2003, 8614, 28, 19],
            [2003, 8615, 12, 11],
            [2003, 8616, 29, 21],
            [2003, 8617, 30, 15],
            [2003, 8618, 19, 13],
            [2003, 8619, 33, 25],
            [2003, 8622, 52, 27],
            [2003, 8623, 52, 28],
            [2003, 8624, 18, 20],
            [2003, 8625, 43, 26],
            [2003, 8626, 23, 17],
            [2003, 8627, 35, 20],
            [2003, 8628, 31, 24],
            [2003, 8629, 30, 25],
            [2003, 8630, 21, 16],
            [2003, 8631, 28, 20],
            [2003, 8632, 22, 16],
            [2003, 8633, 24, 19],
            [2003, 8634, 15, 14],
            [2003, 8635, 25, 14],
            [2003, 8636, 11, 9],
            [2003, 8637, 22, 14],
            [2003, 8638, 15, 12],
            [2003, 8639, 19, 13],
            [2003, 8640, 23, 18],
            [2003, 8641, 41, 20],
            [2003, 8642, 26, 21],
            [2003, 8643, 27, 27],
            [2003, 8644, 43, 24],
            [2003, 8645, 22, 19],
            [2003, 8646, 26, 20],
            [2003, 8647, 20, 15],
            [2003, 8648, 19, 14],
            [2003, 8649, 23, 21],
            [2003, 8650, 31, 17],
            [2003, 8651, 32, 21],
            [2003, 8652, 41, 29],
            [2003, 8653, 28, 25],
            [2003, 8654, 57, 27],
            [2003, 8655, 22, 21],
            [2003, 8656, 22, 19],
            [2003, 8657, 9, 12],
            [2003, 8658, 21, 18],
            [2003, 8659, 31, 23],
            [2003, 8660, 14, 12],
            [2003, 8661, 17, 13],
            [2003, 8662, 21, 13],
            [2003, 8663, 22, 14],
            [2003, 8664, 27, 19],
            [2003, 8665, 40, 29],
            [2003, 8666, 18, 17],
            [2003, 8667, 20, 19],
            [2003, 8668, 18, 23],
            [2003, 8669, 35, 33],
            [2003, 8670, 18, 20],
            [2003, 8671, 27, 28],
            [2003, 8672, 15, 18],
            [2003, 8673, 26, 25],
            [2003, 8674, 25, 18],
            [2003, 8675, 50, 22],
            [2003, 8676, 38, 26],
            [2003, 8677, 43, 27],
            [2003, 8678, 36, 20],
            [2003, 8679, 40, 19],
            [2003, 8680, 24, 19],
            [2003, 8681, 34, 22],
            [2003, 8682, 37, 21],
            [2003, 8683, 32, 13],
            [2003, 8684, 27, 21],
            [2003, 8685, 21, 18],
            [2003, 8686, 30, 18],
            [2003, 8687, 24, 17],
            [2003, 8688, 37, 24],
            [2003, 8689, 31, 22],
            [2003, 8690, 39, 22],
            [2003, 8691, 23, 24],
            [2003, 8692, 41, 26],
            [2003, 8693, 34, 13],
            [2003, 8694, 37, 22],
            [2003, 8695, 14, 15],
            [2003, 8696, 21, 19],
            [2003, 8697, 19, 15],
            [2003, 8698, 35, 17],
            [2003, 8699, 29, 16],
            [2003, 8700, 32, 16],
            [2003, 8701, 25, 15],
            [2003, 8702, 27, 18],
            [2003, 8703, 24, 21],
            [2003, 8704, 31, 25],
            [2003, 8705, 28, 18],
            [2003, 8706, 35, 19],
            [2003, 8707, 20, 21],
            [2003, 8708, 29, 23],
            [2003, 8709, 36, 20],
            [2003, 8710, 31, 20],
            [2003, 8711, 11, 10],
            [2003, 8712, 21, 20],
            [2003, 8713, 31, 21],
            [2003, 8714, 6, 5],
            [2003, 8715, 7, 6],
            [2003, 8716, 7, 7],
            [2003, 8717, 12, 11],
            [2003, 8718, 8, 8],
            [2003, 8719, 21, 23],
            [2003, 8720, 26, 29],
            [2003, 8721, 27, 29],
            [2003, 8722, 25, 23],
            [2003, 8723, 27, 25],
            [2003, 8724, 25, 25],
            [2003, 8725, 22, 18],
            [2003, 8726, 25, 21],
            [2003, 8727, 22, 22],
            [2003, 8728, 19, 20],
            [2003, 8729, 24, 20],
            [2003, 8730, 19, 16],
            [2003, 8731, 20, 18],
            [2003, 8732, 25, 19],
            [2003, 8733, 27, 20],
            [2003, 8734, 22, 18],
            [2003, 8735, 20, 16],
            [2003, 8736, 20, 19],
            [2003, 8737, 20, 17],
            [2003, 8738, 21, 18],
            [2003, 8739, 21, 19],
            [2003, 8740, 21, 18],
            [2003, 8741, 25, 19],
            [2003, 8742, 23, 20],
            [2003, 8743, 23, 19],
            [2003, 8744, 24, 20],
            [2003, 8745, 26, 18],
            [2003, 8746, 28, 22],
            [2003, 8747, 28, 22],
            [2003, 8748, 29, 23],
            [2003, 8749, 23, 19],
            [2003, 8750, 22, 24],
            [2003, 8751, 23, 25],
            [2003, 8752, 18, 16],
            [2003, 8753, 19, 17],
            [2003, 8754, 19, 20],
            [2003, 8755, 20, 18],
            [2003, 8756, 30, 22],
            [2003, 8757, 19, 17],
            [2003, 8758, 19, 18],
            [2003, 8759, 22, 21],
            [2003, 8760, 30, 32],
            [2003, 8761, 23, 19],
            [2003, 8762, 29, 20],
            [2003, 8763, 17, 16],
            [2003, 8764, 31, 24],
            [2003, 8765, 26, 18],
            [2003, 8766, 26, 20],
            [2003, 8767, 31, 24],
            [2003, 8768, 30, 23],
            [2003, 8769, 20, 19],
            [2003, 8770, 31, 24],
            [2003, 8771, 29, 26],
            [2003, 8772, 31, 25],
            [2003, 8773, 18, 16],
            [2003, 8774, 19, 18],
            [2003, 8775, 20, 17],
            [2003, 8776, 19, 18],
            [2003, 8777, 23, 19],
            [2003, 8778, 32, 25],
            [2003, 8779, 9, 13],
            [2003, 8780, 13, 11],
            [2003, 8781, 15, 10],
            [2003, 8782, 16, 11],
            [2003, 8783, 10, 8],
            [2003, 8784, 13, 10],
            [2003, 8785, 7, 7],
            [2003, 8786, 9, 10],
            [2003, 8787, 11, 11],
            [2003, 8788, 13, 10],
            [2003, 8790, 8, 7],
            [2003, 8791, 6, 6],
            [2003, 8792, 12, 11],
            [2003, 8793, 8, 7],
            [2003, 8794, 8, 7],
            [2003, 8795, 9, 7],
            [2003, 8796, 13, 10],
            [2003, 8797, 15, 10],
            [2003, 8798, 9, 8],
            [2003, 8799, 11, 9],
            [2003, 8800, 10, 8],
            [2003, 8801, 11, 10],
            [2003, 8802, 7, 7],
            [2003, 8803, 8, 8],
            [2003, 8804, 7, 9],
            [2003, 8805, 9, 9],
            [2003, 8806, 9, 10],
            [2003, 8807, 14, 13],
            [2003, 8808, 8, 7],
            [2003, 8809, 6, 7],
            [2003, 8810, 11, 11],
            [2003, 8811, 7, 9],
            [2003, 8812, 12, 10],
            [2003, 8814, 6, 6],
            [2003, 8815, 9, 8],
            [2003, 8816, 12, 7],
            [2003, 8817, 18, 10],
            [2003, 8818, 47, 38],
            [2003, 8819, 33, 22],
            [2003, 8820, 50, 41],
            [2003, 8821, 39, 27],
            [2003, 8822, 52, 43],
            [2003, 8823, 31, 25],
            [2003, 8824, 22, 18],
            [2003, 8825, 34, 29],
            [2003, 8826, 22, 21],
            [2003, 8827, 37, 29],
            [2003, 8828, 37, 30],
            [2003, 8829, 41, 32],
            [2003, 8830, 27, 28],
            [2003, 8831, 33, 27],
            [2003, 8832, 19, 11],
            [2003, 8833, 32, 26],
            [2003, 8834, 35, 30],
            [2003, 8835, 31, 19],
            [2003, 8836, 45, 36],
            [2003, 8837, 30, 18],
            [2003, 8838, 40, 34],
            [2003, 8839, 25, 13],
            [2003, 8840, 36, 24],
            [2003, 8841, 24, 13],
            [2003, 8842, 15, 19],
            [2003, 8843, 19, 12],
            [2003, 8844, 27, 22],
            [2003, 8845, 15, 17],
            [2003, 8846, 33, 28],
            [2003, 8847, 18, 19],
            [2003, 8848, 45, 36],
            [2003, 8849, 27, 21],
            [2003, 8850, 37, 31],
            [2003, 8851, 22, 22],
            [2003, 8852, 34, 25],
            [2003, 8853, 14, 17],
            [2003, 8854, 34, 29],
            [2003, 8855, 20, 11],
            [2003, 8856, 30, 25],
            [2003, 8857, 23, 13],
            [2003, 8858, 27, 14],
            [2003, 8859, 43, 37],
            [2003, 8860, 29, 12],
            [2003, 8861, 33, 28],
            [2003, 8862, 25, 21],
            [2003, 8863, 37, 32],
            [2003, 8864, 20, 21],
            [2003, 8865, 31, 25],
            [2003, 8866, 20, 21],
            [2003, 8867, 50, 43],
            [2003, 8868, 37, 31],
            [2003, 8869, 48, 43],
            [2003, 8870, 44, 35],
            [2003, 8871, 34, 29],
            [2003, 8872, 36, 30],
            [2003, 8873, 36, 30],
            [2003, 8874, 32, 27],
            [2003, 8875, 34, 28],
            [2003, 8876, 18, 16],
            [2003, 8877, 41, 35],
            [2003, 8878, 18, 11],
            [2003, 8879, 29, 24],
            [2003, 8880, 30, 25],
            [2003, 8881, 48, 39],
            [2003, 8882, 28, 24],
            [2003, 8883, 47, 41],
            [2003, 8884, 18, 16],
            [2003, 8885, 58, 38],
            [2003, 8886, 33, 27],
            [2003, 8887, 19, 11],
            [2003, 8888, 29, 21],
            [2003, 8889, 44, 35],
            [2003, 8890, 14, 16],
            [2003, 8891, 34, 28],
            [2003, 8892, 14, 11],
            [2003, 8893, 34, 30],
            [2003, 8894, 19, 18],
            [2003, 8895, 15, 11],
            [2003, 8896, 26, 21],
            [2003, 8897, 15, 11],
            [2003, 8898, 20, 18],
            [2003, 8899, 45, 39],
            [2003, 8900, 33, 28],
            [2003, 8901, 44, 29],
            [2003, 8902, 34, 29],
            [2003, 8903, 25, 16],
            [2003, 8904, 33, 28],
            [2003, 8905, 23, 15],
            [2003, 8906, 30, 24],
            [2003, 8907, 20, 19],
            [2003, 8908, 30, 25],
            [2003, 8909, 22, 19],
            [2003, 8910, 22, 13],
            [2003, 8911, 23, 13],
            [2003, 8912, 41, 36],
            [2003, 8913, 26, 23],
            [2003, 8914, 39, 33],
            [2003, 8915, 27, 23],
            [2003, 8916, 45, 36],
            [2003, 8917, 32, 22],
            [2003, 8918, 43, 38],
            [2003, 8919, 30, 28],
            [2003, 8920, 32, 29],
            [2003, 8921, 33, 31],
            [2003, 8922, 30, 24],
            [2003, 8923, 24, 19],
            [2003, 8924, 14, 13],
            [2003, 8925, 11, 11],
            [2003, 8926, 14, 13],
            [2003, 8927, 15, 15],
            [2003, 8928, 13, 12],
            [2003, 8929, 10, 10],
            [2003, 8930, 9, 10],
            [2003, 8931, 13, 14],
            [2003, 8932, 17, 18],
            [2003, 8933, 23, 23],
            [2003, 8934, 26, 25],
            [2003, 8935, 47, 38],
            [2003, 8936, 25, 19],
            [2003, 8937, 33, 28],
            [2003, 8938, 25, 19],
            [2003, 8939, 31, 25],
            [2003, 8940, 18, 16],
            [2003, 8941, 30, 24],
            [2003, 8942, 18, 16],
            [2003, 8943, 26, 19],
            [2003, 8944, 31, 25],
            [2003, 8945, 22, 13],
            [2003, 8946, 31, 25],
            [2003, 8947, 22, 13],
            [2003, 8948, 30, 25],
            [2003, 8949, 21, 13],
            [2003, 8950, 22, 19],
            [2003, 8951, 31, 25],
            [2003, 8952, 23, 19],
            [2003, 8953, 47, 41],
            [2003, 8954, 26, 18],
            [2003, 8955, 41, 36],
            [2003, 8956, 28, 23],
            [2003, 8957, 26, 18],
            [2003, 8958, 48, 40],
            [2003, 8959, 27, 19],
            [2003, 8960, 47, 38],
            [2003, 8961, 27, 19],
            [2003, 8962, 44, 38],
            [2003, 8963, 30, 28],
            [2003, 8964, 19, 12],
            [2003, 8965, 42, 36],
            [2003, 8966, 36, 28],
            [2003, 8967, 39, 31],
            [2003, 8968, 30, 25],
            [2003, 8969, 19, 13],
            [2003, 8970, 40, 34],
            [2003, 8971, 41, 32],
            [2003, 8972, 17, 13],
            [2003, 8973, 41, 33],
            [2003, 8974, 14, 19],
            [2003, 8975, 45, 36],
            [2003, 8976, 48, 42],
            [2003, 8977, 26, 21],
            [2003, 8978, 14, 11],
            [2003, 8979, 37, 32],
            [2003, 8980, 30, 25],
            [2003, 8981, 29, 24],
            [2003, 8983, 34, 28],
            [2003, 8984, 23, 19],
            [2003, 8985, 34, 29],
            [2003, 8986, 24, 20],
            [2003, 8987, 27, 25],
            [2003, 8988, 18, 12],
            [2003, 8989, 34, 28],
            [2003, 8990, 18, 12],
            [2003, 8991, 32, 27],
            [2003, 8992, 18, 12],
            [2003, 8993, 33, 24],
            [2003, 8994, 35, 25],
            [2003, 8995, 36, 27],
            [2003, 8996, 46, 37],
            [2003, 8997, 22, 13],
            [2003, 8998, 27, 21],
            [2003, 8999, 19, 11],
            [2003, 9000, 50, 41],
            [2003, 9001, 42, 28],
            [2003, 9002, 39, 30],
            [2003, 9003, 23, 21],
            [2003, 9004, 47, 38],
            [2003, 9005, 21, 18],
            [2003, 9006, 34, 29],
            [2003, 9007, 27, 19],
            [2003, 9008, 37, 24],
            [2003, 9009, 32, 24],
            [2003, 9010, 27, 21],
            [2003, 9011, 19, 11],
            [2003, 9012, 27, 25],
            [2003, 9013, 14, 13],
            [2003, 9014, 38, 30],
            [2003, 9015, 20, 15],
            [2003, 9016, 19, 14],
            [2003, 9017, 41, 32],
            [2003, 9018, 26, 26],
            [2003, 9019, 30, 29],
            [2003, 9020, 18, 21],
            [2003, 9021, 34, 29],
            [2003, 9022, 24, 24],
            [2003, 9023, 31, 25],
            [2003, 9024, 38, 30],
            [2003, 9025, 30, 25],
            [2003, 9026, 34, 18],
            [2003, 9027, 27, 17],
            [2003, 9028, 39, 30],
            [2003, 9030, 41, 30],
            [2003, 9031, 34, 26],
            [2003, 9032, 41, 30],
            [2003, 9033, 30, 28],
            [2003, 9034, 46, 37],
            [2003, 9035, 39, 33],
            [2003, 9036, 36, 31],
            [2003, 9037, 16, 14],
            [2003, 9038, 27, 26],
            [2003, 9039, 15, 20],
            [2003, 9040, 36, 30],
            [2003, 9041, 24, 20],
            [2003, 9042, 39, 31],
            [2003, 9043, 33, 28],
            [2003, 9044, 26, 14],
            [2003, 9045, 33, 25],
            [2003, 9046, 28, 20],
            [2003, 9047, 35, 27],
            [2003, 9048, 30, 21],
            [2003, 9049, 56, 35],
            [2003, 9050, 28, 20],
            [2003, 9051, 41, 33],
            [2003, 9052, 20, 17],
            [2003, 9053, 27, 20],
            [2003, 9054, 31, 22],
            [2003, 9055, 24, 13],
            [2003, 9056, 34, 23],
            [2003, 9057, 44, 29],
            [2003, 9058, 27, 19],
            [2003, 9059, 47, 32],
            [2003, 9060, 40, 28],
            [2003, 9061, 47, 32],
            [2003, 9062, 40, 28],
            [2003, 9063, 33, 25],
            [2003, 9064, 14, 18],
            [2003, 9065, 23, 21],
            [2003, 9066, 17, 17],
            [2003, 9067, 30, 22],
            [2003, 9068, 26, 18],
            [2003, 9069, 33, 37],
            [2003, 9070, 14, 13],
            [2003, 9071, 27, 31],
            [2003, 9072, 14, 16],
            [2003, 9073, 14, 16],
            [2003, 9074, 29, 27],
            [2003, 9075, 20, 23],
            [2003, 9076, 23, 25],
            [2003, 9077, 34, 22],
            [2003, 9078, 26, 16],
            [2003, 9079, 44, 35],
            [2003, 9080, 21, 18],
            [2003, 9081, 29, 22],
            [2003, 9082, 47, 32],
            [2003, 9083, 23, 18],
            [2003, 9084, 29, 21],
            [2003, 9085, 19, 19],
            [2003, 9086, 36, 28],
            [2003, 9087, 41, 29],
            [2003, 9088, 29, 17],
            [2003, 9089, 17, 14],
            [2003, 9090, 23, 18],
            [2003, 9091, 23, 15],
            [2003, 9092, 42, 27],
            [2003, 9093, 21, 19],
            [2003, 9094, 45, 42],
            [2003, 9095, 14, 12],
            [2003, 9096, 26, 30],
            [2003, 9097, 29, 21],
            [2003, 9098, 36, 23],
            [2003, 9099, 19, 11],
            [2003, 9100, 35, 23],
            [2003, 9101, 14, 13],
            [2003, 9102, 37, 28],
            [2003, 9103, 26, 26],
            [2003, 9104, 36, 28],
            [2003, 9105, 18, 12],
            [2003, 9106, 22, 13],
            [2003, 9107, 33, 25],
            [2003, 9108, 34, 25],
            [2003, 9109, 35, 26],
            [2003, 9110, 44, 29],
            [2003, 9111, 25, 13],
            [2003, 9112, 47, 38],
            [2003, 9113, 25, 20],
            [2003, 9114, 30, 25],
            [2003, 9115, 14, 11],
            [2003, 9116, 19, 14],
            [2003, 9117, 29, 12],
            [2003, 9118, 43, 29],
            [2003, 9119, 18, 12],
            [2003, 9120, 27, 21],
            [2003, 9121, 32, 27],
            [2003, 9122, 39, 33],
            [2003, 9123, 28, 18],
            [2003, 9124, 38, 30],
            [2003, 9125, 16, 23],
            [2003, 9126, 40, 34],
            [2003, 9127, 28, 20],
            [2003, 9128, 34, 25],
            [2003, 9129, 44, 34],
            [2003, 9130, 51, 40],
            [2003, 9131, 27, 27],
            [2003, 9132, 45, 40],
            [2003, 9133, 26, 18],
            [2003, 9134, 34, 26],
            [2003, 9135, 44, 31],
            [2003, 9136, 40, 28],
            [2003, 9137, 16, 11],
            [2003, 9138, 19, 15],
            [2003, 9139, 29, 25],
            [2003, 9140, 19, 15],
            [2003, 9141, 27, 23],
            [2003, 9142, 48, 40],
            [2003, 9143, 20, 20],
            [2003, 9144, 24, 26],
            [2003, 9145, 32, 26],
            [2003, 9146, 40, 32],
            [2003, 9149, 19, 16],
            [2003, 9150, 21, 22],
            [2003, 9151, 18, 16],
            [2003, 9152, 24, 25],
            [2003, 9153, 13, 17],
            [2003, 9154, 15, 15],
            [2003, 9155, 22, 24],
            [2003, 9156, 26, 24],
            [2003, 9157, 26, 29],
            [2003, 9158, 12, 15],
            [2003, 9159, 20, 27],
            [2003, 9160, 14, 14],
            [2003, 9161, 18, 19],
            [2003, 9162, 25, 26],
            [2003, 9163, 28, 23],
            [2003, 9164, 19, 19],
            [2003, 9165, 18, 33],
            [2003, 9166, 21, 24],
            [2003, 9167, 18, 19],
            [2003, 9168, 26, 28],
            [2003, 9169, 21, 20],
            [2003, 9170, 27, 30],
            [2003, 9171, 18, 17],
            [2003, 9172, 19, 23],
            [2003, 9173, 21, 27],
            [2003, 9174, 17, 17],
            [2003, 9175, 19, 20],
            [2003, 9176, 11, 11],
            [2003, 9177, 21, 19],
            [2003, 9178, 20, 30],
            [2003, 9179, 22, 28],
            [2003, 9180, 12, 14],
            [2003, 9181, 18, 16],
            [2003, 9182, 24, 29],
            [2003, 9183, 21, 20],
            [2003, 9184, 24, 25],
            [2003, 9185, 21, 20],
            [2003, 9186, 15, 18],
            [2003, 9187, 22, 21],
            [2003, 9188, 25, 26],
            [2003, 9189, 23, 22],
            [2003, 9190, 15, 18],
            [2003, 9191, 20, 19],
            [2003, 9192, 19, 21],
            [2003, 9193, 18, 17],
            [2003, 9194, 28, 19],
            [2003, 9195, 32, 37],
            [2003, 9196, 26, 26],
            [2003, 9198, 31, 24],
            [2003, 9199, 51, 35],
            [2003, 9200, 42, 47],
            [2003, 9201, 47, 31],
            [2003, 9202, 37, 36],
            [2003, 9203, 11, 15],
            [2003, 9204, 10, 12],
            [2003, 9209, 28, 25],
            [2003, 9211, 27, 29],
            [2003, 9214, 35, 33],
            [2003, 9218, 26, 22],
            [2003, 9226, 55, 37],
            [2003, 9227, 51, 42],
            [2003, 9228, 54, 55],
            [2003, 9229, 41, 43],
            [2003, 9230, 37, 32],
            [2003, 9232, 41, 35],
            [2003, 9233, 35, 34],
            [2003, 9234, 27, 31],
            [2003, 9235, 35, 38],
            [2003, 9237, 34, 22],
            [2003, 9238, 32, 41],
            [2003, 9242, 39, 34],
            [2003, 9244, 36, 35],
            [2003, 9245, 24, 29],
            [2003, 9248, 37, 29],
            [2003, 9254, 94, 97],
            [2003, 9255, 46, 34],
            [2003, 9257, 69, 61],
            [2003, 9258, 39, 52],
            [2003, 9259, 56, 56],
            [2003, 9260, 47, 37],
            [2003, 9261, 73, 90],
            [2003, 9263, 50, 55],
            [2003, 9264, 45, 47],
            [2003, 9265, 49, 53],
            [2003, 9266, 79, 89],
            [2003, 9267, 65, 64],
            [2003, 9268, 57, 58],
            [2003, 9269, 85, 89],
            [2003, 9270, 79, 89],
            [2003, 9271, 81, 93],
            [2003, 9272, 86, 99],
            [2003, 9273, 85, 98],
            [2003, 9274, 86, 81],
            [2003, 9275, 57, 54],
            [2003, 9276, 84, 79],
            [2003, 9277, 75, 63],
            [2003, 9278, 78, 81],
            [2003, 9279, 76, 70],
            [2003, 9280, 58, 57],
            [2003, 9281, 81, 71],
            [2003, 9282, 91, 82],
            [2003, 9283, 82, 86],
            [2003, 9284, 105, 116],
            [2003, 9285, 71, 81],
            [2003, 9286, 97, 111],
            [2003, 9287, 101, 108],
            [2003, 9288, 56, 43],
            [2003, 9289, 95, 107],
            [2003, 9290, 70, 80],
            [2003, 9291, 91, 97],
            [2003, 9292, 90, 96],
            [2003, 9293, 63, 45],
            [2003, 9294, 59, 58],
            [2003, 9295, 76, 71],
            [2003, 9296, 57, 42],
            [2003, 9297, 78, 55],
            [2003, 9298, 74, 88],
            [2003, 9299, 88, 100],
            [2003, 9300, 93, 102],
            [2003, 9301, 78, 90],
            [2003, 9302, 101, 109],
            [2003, 9303, 83, 99],
            [2003, 9304, 60, 77],
            [2003, 9305, 81, 98],
            [2003, 9306, 102, 122],
            [2003, 9307, 43, 60],
            [2003, 9308, 54, 70],
            [2003, 9309, 51, 62],
            [2003, 9310, 61, 68],
            [2003, 9311, 58, 68],
            [2003, 9312, 61, 68],
            [2003, 9313, 57, 65],
            [2003, 9314, 73, 84],
            [2003, 9315, 36, 35],
            [2003, 9316, 26, 26],
            [2003, 9317, 10, 11],
            [2003, 9318, 14, 16],
            [2003, 9319, 34, 38],
            [2003, 9320, 47, 46],
            [2003, 9327, 11, 13],
            [2003, 9328, 21, 25],
            [2003, 9329, 28, 33],
            [2003, 9330, 39, 41],
            [2003, 9331, 29, 29],
            [2003, 9332, 28, 31],
            [2003, 9333, 12, 14],
            [2003, 9334, 11, 13],
            [2003, 9335, 30, 29],
            [2003, 9336, 24, 28],
            [2003, 9337, 17, 20],
            [2003, 9338, 11, 11],
            [2003, 9339, 16, 19],
            [2003, 9340, 41, 43],
            [2003, 9341, 21, 24],
            [2003, 9342, 29, 29],
            [2003, 9343, 8, 9],
            [2003, 9344, 16, 16],
            [2003, 9345, 17, 21],
            [2003, 9346, 12, 13],
            [2003, 9347, 10, 12],
            [2003, 9348, 20, 22],
            [2003, 9349, 16, 19],
            [2003, 9350, 40, 45],
            [2003, 9351, 32, 29],
            [2003, 9352, 35, 34],
            [2003, 9353, 18, 20],
            [2003, 9354, 24, 24],
            [2003, 9355, 18, 16],
            [2003, 9356, 29, 32],
            [2003, 9357, 17, 19],
            [2003, 9358, 23, 22],
            [2003, 9359, 17, 18],
            [2003, 9360, 27, 30],
            [2003, 9361, 24, 28],
            [2003, 9362, 32, 30],
            [2003, 9363, 27, 31],
            [2003, 9364, 35, 27],
            [2003, 9365, 17, 20],
            [2003, 9366, 28, 31],
            [2003, 9367, 20, 18],
            [2003, 9368, 27, 27],
            [2003, 9369, 29, 28],
            [2003, 9370, 16, 18],
            [2003, 9371, 29, 27],
            [2003, 9372, 25, 23],
            [2003, 9373, 21, 21],
            [2003, 9374, 33, 32],
            [2003, 9375, 21, 24],
            [2003, 9376, 35, 34],
            [2003, 9377, 12, 14],
            [2003, 9378, 16, 19],
            [2003, 9379, 28, 33],
            [2003, 9380, 25, 28],
            [2003, 9381, 45, 53],
            [2003, 9382, 27, 32],
            [2003, 9383, 32, 31],
            [2003, 9384, 16, 17],
            [2003, 9385, 18, 19],
            [2003, 9386, 17, 18],
            [2003, 9387, 15, 15],
            [2003, 9388, 15, 17],
            [2003, 9389, 16, 16],
            [2003, 9390, 18, 22],
            [2003, 9391, 22, 25],
            [2003, 9392, 20, 22],
            [2003, 9393, 22, 22],
            [2003, 9394, 14, 15],
            [2003, 9395, 19, 19],
            [2003, 9396, 21, 25],
            [2003, 9397, 39, 44],
            [2003, 9398, 34, 39],
            [2003, 9399, 54, 58],
            [2003, 9400, 24, 29],
            [2003, 9401, 36, 34],
            [2003, 9402, 39, 30],
            [2003, 9403, 108, 79],
            [2003, 9404, 107, 78],
            [2003, 9405, 109, 80],
            [2003, 9406, 93, 80],
            [2003, 9407, 70, 64],
            [2003, 9408, 109, 80],
            [2003, 9409, 104, 79],
            [2003, 9410, 109, 80],
            [2003, 9411, 104, 75],
            [2003, 9412, 104, 78],
            [2003, 9413, 109, 80],
            [2003, 9414, 107, 79],
            [2003, 9415, 109, 80],
            [2003, 9416, 95, 73],
            [2003, 9417, 109, 80],
            [2003, 9418, 103, 71],
            [2003, 9419, 106, 80],
            [2003, 9420, 106, 77],
            [2003, 9421, 103, 71],
            [2003, 9422, 106, 80],
            [2003, 9423, 93, 69],
            [2003, 9424, 107, 79],
            [2003, 9425, 109, 80],
            [2003, 9426, 106, 80],
            [2003, 9427, 109, 80],
            [2003, 9428, 104, 75],
            [2003, 9429, 104, 79],
            [2003, 9430, 109, 80],
            [2003, 9431, 106, 77],
            [2003, 9432, 60, 56],
            [2003, 9433, 93, 69],
            [2003, 9434, 105, 77],
            [2003, 9435, 109, 80],
            [2003, 9436, 106, 77],
            [2003, 9437, 107, 79],
            [2003, 9438, 109, 80],
            [2003, 9439, 105, 76],
            [2003, 9440, 109, 80],
            [2003, 9441, 106, 80],
            [2003, 9442, 109, 80],
            [2003, 9443, 107, 78],
            [2003, 9444, 104, 75],
            [2003, 9445, 104, 79],
            [2003, 9446, 109, 80],
            [2003, 9447, 104, 79],
            [2003, 9448, 109, 80],
            [2003, 9449, 55, 45],
            [2003, 9450, 93, 69],
            [2003, 9451, 93, 80],
            [2003, 9452, 106, 77],
            [2003, 9453, 104, 79],
            [2003, 9454, 104, 79],
            [2003, 9455, 109, 80],
            [2003, 9456, 106, 77],
            [2003, 9457, 93, 80],
            [2003, 9458, 106, 78],
            [2003, 9459, 104, 79],
            [2003, 9460, 109, 80],
            [2003, 9461, 104, 79],
            [2003, 9462, 109, 80],
            [2003, 9463, 74, 69],
            [2003, 9464, 74, 69],
            [2003, 9465, 60, 56],
            [2003, 9466, 104, 79],
            [2003, 9467, 108, 79],
            [2003, 9468, 107, 64],
            [2003, 9469, 109, 80],
            [2003, 9470, 105, 76],
            [2003, 9471, 117, 72],
            [2003, 9472, 135, 121],
            [2003, 9473, 45, 69],
            [2003, 9474, 74, 108],
            [2003, 9475, 93, 78],
            [2003, 9476, 93, 131],
            [2003, 9477, 33, 44],
            [2003, 9478, 55, 69],
            [2003, 9479, 81, 84],
            [2003, 9480, 116, 120],
            [2003, 9481, 26, 62],
            [2003, 9482, 41, 97],
            [2003, 9483, 93, 69],
            [2003, 9484, 122, 69],
            [2003, 9485, 67, 45],
            [2003, 9486, 86, 67],
            [2003, 9487, 26, 45],
            [2003, 9488, 44, 69],
            [2003, 9489, 93, 69],
            [2003, 9490, 91, 84],
            [2003, 9491, 41, 62],
            [2003, 9492, 68, 75],
            [2003, 9493, 93, 75],
            [2003, 9494, 98, 97],
            [2003, 9495, 41, 38],
            [2003, 9496, 74, 50],
            [2003, 9497, 42, 29],
            [2003, 9498, 66, 45],
            [2003, 9499, 60, 69],
            [2003, 9500, 93, 97],
            [2003, 9501, 60, 86],
            [2003, 9502, 93, 131],
            [2003, 9503, 60, 50],
            [2003, 9504, 73, 58],
            [2003, 9505, 60, 87],
            [2003, 9506, 93, 131],
            [2003, 9507, 69, 69],
            [2003, 9508, 93, 121],
            [2003, 9509, 93, 65],
            [2003, 9510, 93, 90],
            [2003, 9511, 60, 57],
            [2003, 9512, 60, 88],
            [2003, 9513, 70, 70],
            [2003, 9514, 93, 99],
            [2003, 9515, 60, 56],
            [2003, 9516, 92, 76],
            [2003, 9517, 93, 75],
            [2003, 9518, 117, 108],
            [2003, 9519, 30, 33],
            [2003, 9520, 52, 55],
            [2003, 9521, 66, 131],
            [2003, 9522, 97, 152],
            [2003, 9523, 93, 75],
            [2003, 9524, 111, 112],
            [2003, 9525, 29, 35],
            [2003, 9526, 46, 53],
            [2003, 9527, 75, 71],
            [2003, 9528, 93, 93],
            [2003, 9529, 40, 45],
            [2003, 9530, 65, 69],
            [2003, 9531, 39, 49],
            [2003, 9532, 50, 79],
            [2003, 9533, 93, 93],
            [2003, 9534, 127, 118],
            [2003, 9535, 29, 57],
            [2003, 9536, 54, 110],
            [2003, 9537, 100, 69],
            [2003, 9538, 125, 97],
            [2003, 9539, 54, 51],
            [2003, 9540, 74, 80],
            [2003, 9541, 40, 37],
            [2003, 9542, 64, 59],
            [2003, 9543, 34, 41],
            [2003, 9544, 55, 64],
            [2003, 9545, 60, 56],
            [2003, 9546, 67, 74],
            [2003, 9547, 36, 43],
            [2003, 9548, 61, 71],
            [2003, 9549, 32, 32],
            [2003, 9550, 50, 56],
            [2003, 9551, 33, 47],
            [2003, 9552, 53, 79],
            [2003, 9553, 41, 45],
            [2003, 9554, 60, 69],
            [2003, 9555, 58, 111],
            [2003, 9556, 86, 130],
            [2003, 9557, 34, 50],
            [2003, 9558, 60, 80],
            [2003, 9559, 39, 38],
            [2003, 9560, 54, 56],
            [2003, 9561, 40, 57],
            [2003, 9562, 64, 89],
            [2003, 9563, 57, 110],
            [2003, 9564, 88, 131],
            [2003, 9565, 60, 56],
            [2003, 9566, 66, 86],
            [2003, 9567, 51, 62],
            [2003, 9568, 70, 101],
            [2003, 9569, 93, 87],
            [2003, 9570, 117, 115],
            [2003, 9571, 77, 121],
            [2003, 9572, 109, 131],
            [2003, 9573, 74, 69],
            [2003, 9574, 93, 106],
            [2003, 9575, 61, 63],
            [2003, 9576, 103, 107],
            [2003, 9577, 93, 63],
            [2003, 9578, 114, 98],
            [2003, 9579, 43, 87],
            [2003, 9580, 60, 110],
            [2003, 9581, 46, 56],
            [2003, 9582, 54, 71],
            [2003, 9583, 93, 113],
            [2003, 9584, 135, 131],
            [2003, 9585, 93, 63],
            [2003, 9586, 97, 71],
            [2003, 9587, 53, 50],
            [2003, 9588, 59, 68],
            [2003, 9589, 35, 67],
            [2003, 9590, 50, 98],
            [2003, 9591, 60, 50],
            [2003, 9592, 65, 56],
            [2003, 9593, 34, 47],
            [2003, 9594, 55, 83],
            [2003, 9595, 38, 48],
            [2003, 9596, 64, 74],
            [2003, 9597, 26, 25],
            [2003, 9598, 38, 49],
            [2003, 9599, 93, 63],
            [2003, 9600, 93, 69],
            [2003, 9601, 46, 69],
            [2003, 9602, 85, 117],
            [2003, 9603, 58, 69],
            [2003, 9604, 83, 87],
            [2003, 9605, 53, 38],
            [2003, 9606, 60, 48],
            [2003, 9607, 49, 56],
            [2003, 9608, 78, 69],
            [2003, 9609, 37, 40],
            [2003, 9610, 50, 56],
            [2003, 9611, 41, 45],
            [2003, 9612, 60, 63],
            [2003, 9613, 63, 110],
            [2003, 9614, 91, 131],
            [2003, 9615, 51, 43],
            [2003, 9616, 77, 65],
            [2003, 9617, 22, 27],
            [2003, 9618, 60, 56],
            [2003, 9619, 31, 39],
            [2003, 9620, 31, 39],
            [2003, 9621, 39, 63],
            [2003, 9622, 50, 69],
            [2003, 9623, 60, 50],
            [2003, 9624, 60, 56],
            [2003, 9625, 93, 69],
            [2003, 9626, 91, 89],
            [2003, 9627, 60, 43],
            [2003, 9628, 74, 56],
            [2003, 9629, 45, 50],
            [2003, 9630, 74, 65],
            [2003, 9631, 41, 40],
            [2003, 9632, 55, 65],
            [2003, 9633, 51, 60],
            [2003, 9634, 91, 115],
            [2003, 9635, 123, 110],
            [2003, 9636, 141, 131],
            [2003, 9637, 69, 71],
            [2003, 9638, 99, 100],
            [2003, 9639, 19, 25],
            [2003, 9640, 37, 56],
            [2003, 9641, 52, 40],
            [2003, 9642, 67, 69],
            [2003, 9643, 27, 44],
            [2003, 9644, 44, 71],
            [2003, 9645, 60, 102],
            [2003, 9646, 68, 131],
            [2003, 9647, 93, 69],
            [2003, 9648, 105, 120],
            [2003, 9651, 43, 43],
            [2003, 9652, 66, 63],
            [2003, 9653, 39, 36],
            [2003, 9654, 71, 54],
            [2003, 9655, 32, 32],
            [2003, 9656, 54, 54],
            [2003, 9657, 48, 45],
            [2003, 9658, 53, 46],
            [2003, 9659, 34, 30],
            [2003, 9660, 57, 57],
            [2003, 9661, 33, 33],
            [2003, 9662, 54, 49],
            [2003, 9663, 33, 31],
            [2003, 9664, 58, 51],
            [2003, 9665, 45, 45],
            [2003, 9666, 52, 52],
            [2003, 9667, 42, 36],
            [2003, 9668, 54, 48],
            [2003, 9669, 32, 32],
            [2003, 9670, 52, 49],
            [2003, 9671, 34, 34],
            [2003, 9672, 64, 55],
            [2003, 9673, 36, 35],
            [2003, 9674, 47, 47],
            [2003, 9675, 40, 41],
            [2003, 9676, 75, 56],
            [2003, 9677, 33, 32],
            [2003, 9678, 55, 49],
            [2003, 9679, 33, 33],
            [2003, 9680, 57, 54],
            [2003, 9681, 40, 34],
            [2003, 9682, 61, 53],
            [2003, 9683, 44, 41],
            [2003, 9684, 58, 52],
            [2003, 9685, 38, 38],
            [2003, 9686, 60, 54],
            [2003, 9687, 37, 34],
            [2003, 9688, 60, 55],
            [2003, 9689, 68, 69],
            [2003, 9690, 62, 57],
            [2003, 9691, 36, 33],
            [2003, 9692, 56, 48],
            [2003, 9693, 51, 41],
            [2003, 9694, 70, 48],
            [2003, 9695, 33, 33],
            [2003, 9696, 55, 47],
            [2003, 9697, 36, 34],
            [2003, 9698, 64, 46],
            [2003, 9699, 34, 38],
            [2003, 9700, 58, 56],
            [2003, 9701, 31, 31],
            [2003, 9702, 46, 41],
            [2003, 9703, 29, 29],
            [2003, 9704, 58, 52],
            [2003, 9705, 30, 30],
            [2003, 9706, 63, 57],
            [2003, 9707, 38, 32],
            [2003, 9708, 53, 42],
            [2003, 9709, 34, 35],
            [2003, 9710, 43, 40],
            [2003, 9711, 86, 66],
            [2003, 9712, 84, 66],
            [2003, 9713, 86, 65],
            [2003, 9714, 79, 60],
            [2003, 9715, 75, 57],
            [2003, 9716, 39, 30],
            [2003, 9717, 42, 37],
            [2003, 9718, 33, 31],
            [2003, 9720, 70, 52],
            [2003, 9721, 63, 56],
            [2003, 9722, 31, 32],
            [2003, 9723, 70, 66],
            [2003, 9724, 55, 49],
            [2003, 9725, 73, 66],
            [2003, 9726, 24, 30],
            [2003, 9727, 50, 45],
            [2003, 9728, 45, 40],
            [2003, 9729, 50, 45],
            [2003, 9730, 27, 27],
            [2003, 9731, 69, 51],
            [2003, 9735, 54, 45],
            [2003, 9736, 39, 39],
            [2003, 9737, 45, 40],
            [2003, 9738, 85, 59],
            [2003, 9739, 49, 46],
            [2003, 9740, 65, 61],
            [2003, 9741, 52, 48],
            [2003, 9742, 51, 47],
            [2003, 9743, 40, 35],
            [2003, 9744, 74, 54],
            [2003, 9745, 49, 46],
            [2003, 9746, 44, 44],
            [2003, 9747, 54, 49],
            [2003, 9748, 48, 48],
            [2003, 9751, 38, 31],
            [2003, 9752, 45, 40],
            [2003, 9753, 31, 32],
            [2003, 9754, 52, 51],
            [2003, 9755, 32, 33],
            [2003, 9756, 65, 60],
            [2003, 9757, 32, 33],
            [2003, 9758, 54, 50],
            [2003, 9759, 22, 15],
            [2003, 9760, 40, 25],
            [2003, 9761, 42, 27],
            [2003, 9762, 38, 19],
            [2003, 9763, 23, 16],
            [2003, 9764, 26, 14],
            [2003, 9765, 40, 27],
            [2003, 9766, 40, 20],
            [2003, 9767, 39, 45],
            [2003, 9768, 33, 24],
            [2003, 9769, 25, 18],
            [2003, 9770, 44, 39],
            [2003, 9771, 50, 22],
            [2003, 9772, 31, 16],
            [2003, 9773, 39, 29],
            [2003, 9774, 24, 19],
            [2003, 9775, 25, 19],
            [2003, 9776, 29, 15],
            [2003, 9777, 41, 26],
            [2003, 9778, 42, 28],
            [2003, 9779, 38, 28],
            [2003, 9780, 40, 31],
            [2003, 9781, 30, 17],
            [2003, 9782, 41, 29],
            [2003, 9783, 34, 21],
            [2003, 9784, 35, 27],
            [2003, 9785, 29, 24],
            [2003, 9786, 22, 16],
            [2003, 9787, 39, 26],
            [2003, 9788, 22, 18],
            [2003, 9789, 42, 21],
            [2003, 9790, 40, 25],
            [2003, 9791, 45, 30],
            [2003, 9792, 40, 35],
            [2003, 9793, 17, 13],
            [2003, 9794, 15, 14],
            [2003, 9795, 14, 13],
            [2003, 9796, 20, 16],
            [2003, 9797, 16, 13],
            [2003, 9798, 15, 14],
            [2003, 9799, 43, 37],
            [2003, 9800, 24, 21],
            [2003, 9801, 20, 17],
            [2003, 9802, 20, 17],
            [2003, 9803, 11, 10],
            [2003, 9804, 19, 15],
            [2003, 9805, 35, 27],
            [2003, 9806, 23, 18],
            [2003, 9807, 32, 21],
            [2003, 9808, 74, 47],
            [2003, 9809, 42, 18],
            [2003, 9811, 43, 26],
            [2003, 9812, 71, 44],
            [2003, 9813, 60, 28],
            [2003, 9814, 23, 15],
            [2003, 9815, 45, 26],
            [2003, 9816, 34, 17],
            [2003, 9817, 27, 14],
            [2003, 9818, 60, 20],
            [2003, 9819, 53, 37],
            [2003, 9820, 64, 40],
            [2003, 9821, 50, 28],
            [2003, 9822, 24, 21],
            [2003, 9823, 30, 21],
            [2003, 9824, 32, 26],
            [2003, 9825, 22, 18],
            [2003, 9826, 51, 37],
            [2003, 9827, 48, 28],
            [2003, 9828, 56, 38],
            [2003, 9829, 41, 27],
            [2003, 9830, 33, 26],
            [2003, 9831, 41, 26],
            [2003, 9832, 36, 23],
            [2003, 9833, 35, 25],
            [2003, 9834, 63, 41],
            [2003, 9835, 37, 32],
            [2003, 9836, 48, 34],
            [2003, 9837, 33, 22],
            [2003, 9838, 54, 40],
            [2003, 9839, 20, 17],
            [2003, 9840, 44, 33],
            [2003, 9841, 80, 47],
            [2003, 9842, 36, 22],
            [2003, 9843, 31, 22],
            [2003, 9844, 39, 25],
            [2003, 9845, 33, 27],
            [2003, 9846, 30, 20],
            [2003, 9847, 16, 14],
            [2003, 9848, 29, 19],
            [2003, 9849, 28, 17],
            [2003, 9850, 28, 15],
            [2003, 9851, 26, 13],
            [2003, 9852, 22, 13],
            [2003, 9853, 25, 18],
            [2003, 9854, 15, 13],
            [2003, 9855, 31, 26],
            [2003, 9856, 17, 18],
            [2003, 9857, 17, 14],
            [2003, 9858, 45, 29],
            [2003, 9859, 57, 36],
            [2003, 9860, 49, 37],
            [2003, 9861, 61, 52],
            [2003, 9862, 30, 32],
            [2003, 9863, 47, 33],
            [2003, 9864, 57, 25],
            [2003, 9865, 39, 25],
            [2003, 9866, 56, 24],
            [2003, 9867, 23, 18],
            [2003, 9868, 48, 32],
            [2003, 9869, 44, 27],
            [2003, 9870, 40, 45],
            [2003, 9871, 47, 29],
            [2003, 9872, 27, 24],
            [2003, 9873, 36, 34],
            [2003, 9874, 43, 23],
            [2003, 9875, 36, 25],
            [2003, 9876, 27, 24],
            [2003, 9877, 38, 29],
            [2003, 9878, 42, 27],
            [2003, 9879, 41, 25],
            [2003, 9880, 43, 33],
            [2003, 9881, 51, 29],
            [2003, 9882, 39, 32],
            [2003, 9883, 36, 22],
            [2003, 9884, 36, 21],
            [2003, 9885, 43, 24],
            [2003, 9886, 45, 23],
            [2003, 9887, 40, 28],
            [2003, 9888, 51, 38],
            [2003, 9889, 47, 30],
            [2003, 9890, 42, 30],
            [2003, 9891, 36, 24],
            [2003, 9892, 32, 25],
            [2003, 9893, 27, 19],
            [2003, 9894, 51, 34],
            [2003, 9895, 27, 17],
            [2003, 9896, 12, 14],
            [2003, 9897, 38, 25],
            [2003, 9898, 40, 30],
            [2003, 9899, 26, 21],
            [2003, 9900, 59, 51],
            [2003, 9901, 53, 36],
            [2003, 9902, 76, 56],
            [2003, 9903, 71, 50],
            [2003, 9904, 63, 46],
            [2003, 9905, 41, 32],
            [2003, 9906, 45, 27],
            [2003, 9907, 34, 30],
            [2003, 9908, 64, 42],
            [2003, 9909, 17, 15],
            [2003, 9910, 54, 46],
            [2003, 9911, 76, 44],
            [2003, 9912, 51, 32],
            [2003, 9913, 25, 22],
            [2003, 9914, 35, 26],
            [2003, 9915, 33, 28],
            [2003, 9916, 34, 31],
            [2003, 9917, 29, 26],
            [2003, 9918, 77, 30],
            [2003, 9919, 75, 61],
            [2003, 9920, 80, 57],
            [2003, 9921, 28, 22],
            [2003, 9922, 30, 18],
            [2003, 9923, 34, 23],
            [2003, 9924, 44, 26],
            [2003, 9925, 54, 49],
            [2003, 9926, 42, 47],
            [2003, 9927, 34, 24],
            [2003, 9928, 57, 31],
            [2003, 9929, 45, 40],
            [2003, 9930, 43, 28],
            [2003, 9931, 56, 34],
            [2003, 9932, 57, 29],
            [2003, 9933, 52, 40],
            [2003, 9934, 49, 29],
            [2003, 9935, 41, 24],
            [2003, 9936, 42, 30],
            [2003, 9937, 30, 28],
            [2003, 9938, 18, 17],
            [2003, 9939, 48, 24],
            [2003, 9940, 38, 33],
            [2003, 9941, 41, 23],
            [2003, 9942, 23, 18],
            [2003, 9943, 95, 58],
            [2003, 9944, 48, 27],
            [2003, 9945, 69, 33],
            [2003, 9946, 39, 20],
            [2003, 9947, 54, 29],
            [2003, 9948, 88, 45],
            [2003, 9949, 84, 51],
            [2003, 9950, 60, 46],
            [2003, 9951, 37, 24],
            [2003, 9952, 53, 27],
            [2003, 9953, 27, 22],
            [2003, 9954, 66, 44],
            [2003, 9955, 26, 22],
            [2003, 9956, 57, 27],
            [2003, 9957, 82, 42],
            [2003, 9958, 31, 25],
            [2003, 9959, 82, 44],
            [2003, 9960, 50, 26],
            [2003, 9961, 31, 28],
            [2003, 9962, 37, 24],
            [2003, 9963, 66, 40],
            [2003, 9964, 36, 32],
            [2003, 9965, 34, 17],
            [2003, 9966, 57, 31],
            [2003, 9967, 69, 34],
            [2003, 9968, 42, 38],
            [2003, 9969, 37, 22],
            [2003, 9970, 57, 28],
            [2003, 9971, 32, 25],
            [2003, 9972, 92, 42],
            [2003, 9973, 45, 37],
            [2003, 9974, 34, 16],
            [2003, 9975, 81, 37],
            [2003, 9976, 96, 44],
            [2003, 9977, 38, 21],
            [2003, 9978, 44, 22],
            [2003, 9979, 81, 39],
            [2003, 9980, 46, 24],
            [2003, 9981, 28, 18],
            [2003, 9982, 19, 14],
            [2003, 9983, 74, 34],
            [2003, 9984, 41, 26],
            [2003, 9985, 43, 26],
            [2003, 9986, 44, 27],
            [2003, 9987, 46, 38],
            [2003, 9988, 41, 27],
            [2003, 9989, 36, 29],
            [2003, 9990, 36, 22],
            [2003, 9991, 44, 32],
            [2003, 9992, 47, 36],
            [2003, 9993, 34, 36],
            [2003, 9994, 29, 26],
            [2003, 9995, 44, 35],
            [2003, 9996, 35, 30],
            [2003, 9997, 18, 23],
            [2003, 9998, 20, 16],
            [2003, 9999, 29, 32],
            [2003, 10000, 25, 18],
            [2003, 10001, 21, 17],
            [2003, 10002, 19, 15],
            [2003, 10003, 45, 27],
            [2003, 10004, 22, 18],
            [2003, 10005, 23, 18],
            [2003, 10006, 17, 14],
            [2003, 10007, 37, 39],
            [2003, 10008, 52, 49],
            [2003, 10009, 49, 33],
            [2003, 10010, 56, 32],
            [2003, 10011, 46, 30],
            [2003, 10012, 59, 26],
            [2003, 10013, 34, 28],
            [2003, 10014, 41, 40],
            [2003, 10015, 33, 30],
            [2003, 10016, 37, 38],
            [2003, 10017, 43, 34],
            [2003, 10018, 44, 37],
            [2003, 10019, 43, 34],
            [2003, 10020, 54, 44],
            [2003, 10021, 64, 43],
            [2003, 10022, 59, 46],
            [2003, 10023, 59, 43],
            [2003, 10024, 82, 55],
            [2003, 10025, 71, 55],
            [2003, 10026, 65, 47],
            [2003, 10027, 58, 45],
            [2003, 10030, 55, 44],
            [2003, 10031, 78, 66],
            [2003, 10032, 74, 55],
            [2003, 10033, 45, 34],
            [2003, 10034, 53, 34],
            [2003, 10035, 80, 44],
            [2003, 10036, 82, 38],
            [2003, 10037, 82, 45],
            [2003, 10038, 31, 21],
            [2003, 10039, 20, 21],
            [2003, 10040, 30, 21],
            [2003, 10041, 29, 18],
            [2003, 10042, 52, 35],
            [2003, 10043, 54, 28],
            [2003, 10044, 62, 28],
            [2003, 10045, 37, 22],
            [2003, 10046, 54, 35],
            [2003, 10047, 50, 27],
            [2003, 10048, 47, 29],
            [2003, 10049, 34, 25],
            [2003, 10050, 45, 32],
            [2003, 10051, 54, 37],
            [2003, 10052, 60, 50],
            [2003, 10053, 65, 49],
            [2003, 10054, 55, 50],
            [2003, 10055, 62, 52],
            [2003, 10056, 54, 51],
            [2003, 10057, 62, 53],
            [2003, 10058, 35, 38],
            [2003, 10059, 67, 38],
            [2003, 10060, 52, 36],
            [2003, 10061, 60, 55],
            [2003, 10063, 22, 22],
            [2003, 10064, 38, 30],
            [2003, 10065, 34, 39],
            [2003, 10066, 41, 36],
            [2003, 10067, 58, 45],
            [2003, 10068, 67, 49],
            [2003, 10069, 59, 45],
            [2003, 10070, 42, 24],
            [2003, 10071, 56, 41],
            [2003, 10072, 59, 23],
            [2003, 10073, 59, 28],
            [2003, 10074, 57, 28],
            [2003, 10075, 65, 36],
            [2003, 10076, 61, 37],
            [2003, 10077, 58, 37],
            [2003, 10078, 73, 44],
            [2003, 10079, 46, 33],
            [2003, 10080, 41, 36],
            [2003, 10081, 69, 45],
            [2003, 10082, 46, 49],
            [2003, 10083, 41, 38],
            [2003, 10084, 45, 31],
            [2003, 10085, 43, 22],
            [2003, 10086, 47, 29],
            [2003, 10087, 43, 20],
            [2003, 10088, 60, 39],
            [2003, 10089, 60, 40],
            [2003, 10090, 47, 37],
            [2003, 10091, 60, 29],
            [2003, 10092, 64, 31],
            [2003, 10093, 44, 37],
            [2003, 10094, 76, 48],
            [2003, 10095, 68, 45],
            [2003, 10096, 57, 36],
            [2003, 10097, 48, 34],
            [2003, 10098, 55, 38],
            [2003, 10099, 67, 47],
            [2003, 10101, 69, 55],
            [2003, 10102, 58, 45],
            [2003, 10103, 60, 55],
            [2003, 10104, 19, 19],
            [2003, 10105, 31, 21],
            [2003, 10106, 31, 28],
            [2003, 10107, 57, 52],
            [2003, 10108, 66, 58],
            [2003, 10109, 113, 72],
            [2003, 10110, 54, 46],
            [2003, 10111, 76, 57],
            [2003, 10112, 77, 61],
            [2003, 10113, 101, 83],
            [2003, 10114, 67, 43],
            [2003, 10115, 43, 31],
            [2003, 10116, 48, 39],
            [2003, 10117, 46, 43],
            [2003, 10118, 50, 52],
            [2003, 10119, 25, 16],
            [2003, 10120, 31, 21],
            [2003, 10121, 66, 56],
            [2003, 10122, 65, 55],
            [2003, 10123, 81, 68],
            [2003, 10124, 70, 64],
            [2003, 10125, 69, 42],
            [2003, 10126, 60, 37],
            [2003, 10127, 60, 37],
            [2003, 10128, 61, 43],
            [2003, 10129, 84, 54],
            [2003, 10130, 78, 54],
            [2003, 10131, 46, 36],
            [2003, 10132, 47, 37],
            [2003, 10133, 61, 35],
            [2003, 10134, 88, 61],
            [2003, 10135, 85, 67],
            [2003, 10136, 52, 27],
            [2003, 10137, 63, 43],
            [2003, 10138, 54, 30],
            [2003, 10139, 54, 34],
            [2003, 10141, 50, 32],
            [2003, 10142, 54, 33],
            [2003, 10144, 67, 34],
            [2003, 10145, 44, 42],
            [2003, 10146, 50, 45],
            [2003, 10148, 48, 28],
            [2003, 10149, 50, 52],
            [2003, 10150, 27, 33],
            [2003, 10151, 45, 41],
            [2003, 10152, 60, 46],
            [2003, 10153, 66, 51],
            [2003, 10154, 26, 26],
            [2003, 10155, 54, 53],
            [2003, 10156, 36, 33],
            [2003, 10157, 62, 46],
            [2003, 10158, 35, 37],
            [2003, 10159, 49, 38],
            [2003, 10160, 51, 33],
            [2003, 10161, 72, 42],
            [2003, 10162, 55, 28],
            [2003, 10163, 77, 38],
            [2003, 10164, 55, 29],
            [2003, 10165, 61, 33],
            [2003, 10166, 46, 28],
            [2003, 10167, 54, 41],
            [2003, 10168, 56, 43],
            [2003, 10169, 60, 43],
            [2003, 10170, 31, 35],
            [2003, 10171, 50, 41],
            [2003, 10172, 39, 33],
            [2003, 10173, 49, 40],
            [2003, 10174, 47, 32],
            [2003, 10175, 58, 40],
            [2003, 10176, 20, 21],
            [2003, 10177, 18, 19],
            [2003, 10178, 22, 21],
            [2003, 10179, 19, 20],
            [2003, 10180, 39, 31],
            [2003, 10181, 24, 17],
            [2003, 10182, 37, 39],
            [2003, 10183, 46, 27],
            [2003, 10184, 44, 18],
            [2003, 10185, 17, 14],
            [2003, 10186, 16, 12],
            [2003, 10187, 22, 18],
            [2003, 10188, 23, 16],
            [2003, 10189, 57, 32],
            [2003, 10190, 21, 15],
            [2003, 10191, 46, 27],
            [2003, 10192, 34, 22],
            [2003, 10193, 20, 19],
            [2003, 10194, 16, 12],
            [2003, 10195, 15, 13],
            [2003, 10196, 41, 30],
            [2003, 10197, 39, 28],
            [2003, 10198, 29, 31],
            [2003, 10199, 28, 31],
            [2003, 10200, 28, 32],
            [2003, 10201, 27, 29],
            [2003, 10202, 65, 54],
            [2003, 10203, 55, 38],
            [2003, 10204, 56, 38],
            [2003, 10205, 45, 33],
            [2003, 10206, 42, 29],
            [2003, 10207, 39, 28],
            [2003, 10208, 42, 31],
            [2003, 10209, 40, 28],
            [2003, 10210, 46, 37],
            [2003, 10211, 44, 35],
            [2003, 10212, 49, 32],
            [2003, 10213, 47, 30],
            [2003, 10214, 42, 36],
            [2003, 10215, 40, 34],
            [2003, 10216, 47, 33],
            [2003, 10217, 50, 35],
            [2003, 10218, 44, 35],
            [2003, 10219, 43, 36],
            [2003, 10220, 41, 33],
            [2003, 10221, 44, 30],
            [2003, 10222, 42, 32],
            [2003, 10223, 52, 42],
            [2003, 10224, 61, 50],
            [2003, 10225, 54, 50],
            [2003, 10226, 31, 29],
            [2003, 10227, 32, 29],
            [2003, 10228, 30, 28],
            [2003, 10234, 49, 39],
            [2003, 10235, 38, 32],
            [2003, 10236, 38, 34],
            [2003, 10237, 30, 29],
            [2003, 10238, 38, 36],
            [2003, 10239, 53, 43],
            [2003, 10240, 32, 31],
            [2003, 10241, 27, 34],
            [2003, 10242, 35, 29],
            [2003, 10243, 38, 31],
            [2003, 10244, 37, 39],
            [2003, 10245, 19, 26],
            [2003, 10246, 34, 30],
            [2003, 10247, 23, 26],
            [2003, 10248, 37, 29],
            [2003, 10249, 23, 28],
            [2003, 10250, 36, 33],
            [2003, 10251, 37, 31],
            [2003, 10252, 36, 33],
            [2003, 10253, 36, 36],
            [2003, 10255, 37, 34],
            [2003, 10256, 43, 39],
            [2003, 10257, 35, 31],
            [2003, 10258, 39, 37],
            [2003, 10259, 18, 28],
            [2003, 10260, 37, 34],
            [2003, 10261, 40, 32],
            [2003, 10263, 22, 26],
            [2003, 10264, 37, 34],
            [2003, 10267, 27, 25],
            [2003, 10268, 39, 30],
            [2003, 10269, 26, 27],
            [2003, 10270, 32, 33],
            [2003, 10271, 37, 30],
            [2003, 10272, 30, 29],
            [2003, 10276, 32, 31],
            [2003, 10277, 40, 36],
            [2003, 10278, 24, 29],
            [2003, 10279, 37, 35],
            [2003, 10280, 23, 32],
            [2003, 10281, 36, 38],
            [2003, 10283, 24, 26],
            [2003, 10284, 32, 31],
            [2003, 10285, 24, 24],
            [2003, 10286, 31, 27],
            [2003, 10287, 30, 27],
            [2003, 10288, 34, 26],
            [2003, 10289, 38, 30],
            [2003, 10290, 35, 29],
            [2003, 10291, 35, 31],
            [2003, 10292, 26, 29],
            [2003, 10293, 35, 35],
            [2003, 10294, 18, 25],
            [2003, 10295, 24, 29],
            [2003, 10296, 34, 33],
            [2003, 10297, 24, 26],
            [2003, 10298, 31, 31],
            [2003, 10299, 24, 26],
            [2003, 10300, 32, 30],
            [2003, 10301, 32, 34],
            [2003, 10302, 24, 28],
            [2003, 10303, 36, 35],
            [2003, 10304, 24, 29],
            [2003, 10305, 33, 33],
            [2003, 10306, 28, 33],
            [2003, 10307, 30, 33],
            [2003, 10309, 32, 29],
            [2003, 10310, 24, 29],
            [2003, 10311, 34, 34],
            [2003, 10312, 30, 29],
            [2003, 10313, 40, 32],
            [2003, 10314, 38, 32],
            [2003, 10315, 35, 27],
            [2003, 10317, 26, 27],
            [2003, 10318, 43, 34],
            [2003, 10319, 27, 32],
            [2003, 10320, 56, 36],
            [2003, 10321, 28, 27],
            [2003, 10322, 38, 37],
            [2003, 10323, 26, 33],
            [2003, 10326, 49, 38],
            [2003, 10327, 26, 29],
            [2003, 10329, 30, 27],
            [2003, 10330, 30, 33],
            [2003, 10332, 22, 25],
            [2003, 10333, 35, 35],
            [2003, 10334, 38, 35],
            [2003, 10335, 35, 37],
            [2003, 10337, 26, 26],
            [2003, 10338, 40, 33],
            [2003, 10339, 28, 29],
            [2003, 10340, 41, 33],
            [2003, 10341, 23, 25],
            [2003, 10342, 33, 29],
            [2003, 10343, 31, 28],
            [2003, 10344, 29, 32],
            [2003, 10347, 23, 32],
            [2003, 10354, 22, 26],
            [2003, 10355, 37, 33],
            [2003, 10356, 27, 30],
            [2003, 10357, 37, 37],
            [2003, 10358, 35, 30],
            [2003, 10360, 22, 25],
            [2003, 10361, 37, 31],
            [2003, 10362, 35, 35],
            [2003, 10363, 52, 36],
            [2003, 10364, 60, 35],
            [2003, 10366, 38, 36],
            [2003, 10367, 50, 34],
            [2003, 10368, 58, 39],
            [2003, 10369, 51, 34],
            [2003, 10370, 61, 40],
            [2003, 10371, 32, 39],
            [2003, 10372, 22, 26],
            [2003, 10374, 24, 28],
            [2003, 10376, 23, 25],
            [2003, 10377, 27, 28],
            [2003, 10378, 33, 33],
            [2003, 10380, 29, 30],
            [2003, 10381, 49, 37],
            [2003, 10382, 30, 31],
            [2003, 10383, 59, 37],
            [2003, 10384, 34, 34],
            [2003, 10385, 62, 38],
            [2003, 10388, 18, 28],
            [2003, 10390, 26, 29],
            [2003, 10391, 32, 27],
            [2003, 10392, 32, 31],
            [2003, 10394, 23, 25],
            [2003, 10395, 33, 31],
            [2003, 10396, 24, 26],
            [2003, 10398, 24, 29],
            [2003, 10399, 35, 32],
            [2003, 10400, 25, 27],
            [2003, 10402, 23, 32],
            [2003, 10403, 39, 39],
            [2003, 10404, 27, 31],
            [2003, 10408, 23, 31],
            [2003, 10409, 35, 39],
            [2003, 10410, 25, 32],
            [2003, 10411, 39, 37],
            [2003, 10412, 39, 25],
            [2003, 10413, 66, 40],
            [2003, 10417, 37, 39],
            [2003, 10418, 23, 25],
            [2003, 10419, 34, 34],
            [2003, 10420, 38, 38],
            [2003, 10422, 31, 34],
            [2003, 10424, 39, 35],
            [2003, 10425, 23, 29],
            [2003, 10426, 34, 36],
            [2003, 10427, 29, 27],
            [2003, 10428, 30, 33],
            [2003, 10431, 24, 29],
            [2003, 10432, 37, 33],
            [2003, 10433, 22, 27],
            [2003, 10434, 36, 32],
            [2003, 10435, 37, 30],
            [2003, 10436, 28, 27],
            [2003, 10437, 34, 26],
            [2003, 10438, 25, 27],
            [2003, 10439, 35, 37],
            [2003, 10440, 23, 30],
            [2003, 10441, 36, 32],
            [2003, 10442, 29, 30],
            [2003, 10443, 23, 25],
            [2003, 10444, 37, 28],
            [2003, 10445, 40, 34],
            [2003, 10447, 22, 24],
            [2003, 10448, 34, 30],
            [2003, 10450, 22, 27],
            [2003, 10453, 54, 31],
            [2003, 10454, 49, 30],
            [2003, 10455, 54, 35],
            [2003, 10456, 22, 27],
            [2003, 10458, 23, 26],
            [2003, 10459, 30, 27],
            [2003, 10461, 24, 30],
            [2003, 10463, 19, 24],
            [2003, 10464, 28, 30],
            [2003, 10467, 23, 31],
            [2003, 10469, 27, 27],
            [2003, 10471, 26, 25],
            [2003, 10474, 15, 14],
            [2003, 10475, 15, 14],
            [2003, 10476, 17, 18],
            [2003, 10477, 19, 19],
            [2003, 10478, 26, 34],
            [2003, 10479, 36, 27],
            [2003, 10480, 22, 24],
            [2003, 10482, 23, 28],
            [2003, 10483, 29, 33],
            [2003, 10484, 23, 28],
            [2003, 10485, 28, 33],
            [2003, 10486, 23, 27],
            [2003, 10487, 28, 34],
            [2003, 10490, 16, 27],
            [2003, 10491, 9, 21],
            [2003, 10492, 8, 13],
            [2003, 10493, 35, 36],
            [2003, 10494, 11, 38],
            [2003, 10495, 12, 29],
            [2003, 10496, 10, 20],
            [2003, 10497, 28, 54],
            [2003, 10498, 9, 25],
            [2003, 10499, 9, 54],
            [2003, 10500, 12, 56],
            [2003, 10501, 12, 56],
            [2003, 10502, 33, 78],
            [2003, 10503, 12, 57],
            [2003, 10504, 14, 77],
            [2003, 10505, 34, 57],
            [2003, 10506, 15, 37],
            [2003, 10507, 9, 23],
            [2003, 10508, 26, 59],
            [2003, 10509, 28, 40],
            [2003, 10510, 15, 40],
            [2003, 10511, 7, 20],
            [2003, 10512, 22, 24],
            [2003, 10513, 32, 31],
            [2003, 10514, 16, 24],
            [2003, 10515, 17, 26],
            [2003, 10516, 16, 23],
            [2003, 10517, 22, 30],
            [2003, 10518, 17, 18],
            [2003, 10519, 22, 20],
            [2003, 10520, 11, 12],
            [2003, 10521, 18, 23],
            [2003, 10522, 18, 22],
            [2003, 10523, 18, 22],
            [2003, 10524, 24, 24],
            [2003, 10525, 17, 22],
            [2003, 10526, 18, 22],
            [2003, 10527, 16, 18],
            [2003, 10528, 22, 22],
            [2003, 10529, 21, 22],
            [2003, 10530, 18, 22],
            [2003, 10531, 16, 21],
            [2003, 10532, 22, 21],
            [2003, 10533, 32, 27],
            [2003, 10534, 15, 13],
            [2003, 10535, 31, 25],
            [2003, 10536, 17, 20],
            [2003, 10537, 22, 20],
            [2003, 10538, 29, 24],
            [2003, 10539, 17, 17],
            [2003, 10540, 31, 25],
            [2003, 10541, 38, 32],
            [2003, 10542, 41, 28],
            [2003, 10543, 7, 7],
            [2003, 10544, 12, 10],
            [2003, 10545, 7, 7],
            [2003, 10546, 8, 8],
            [2003, 10547, 8, 8],
            [2003, 10548, 11, 10],
            [2003, 10549, 8, 8],
            [2003, 10550, 14, 11],
            [2003, 10551, 8, 8],
            [2003, 10552, 7, 7],
            [2003, 10553, 18, 14],
            [2003, 10554, 17, 11],
            [2003, 10555, 11, 8],
            [2003, 10556, 20, 14],
            [2003, 10557, 14, 10],
            [2003, 10558, 27, 17],
            [2003, 10559, 19, 13],
            [2003, 10560, 19, 13],
            [2003, 10577, 18, 11],
            [2003, 10578, 38, 44],
            [2003, 10579, 47, 41],
            [2003, 10580, 64, 52],
            [2003, 10581, 79, 66],
            [2003, 10582, 62, 49],
            [2003, 10583, 57, 50],
            [2003, 10584, 63, 53],
            [2003, 10585, 50, 52],
            [2003, 10586, 68, 60],
            [2003, 10587, 61, 51],
            [2003, 10588, 44, 42],
            [2003, 10589, 58, 53],
            [2003, 10590, 75, 59],
            [2003, 10591, 78, 73],
            [2003, 10592, 64, 37],
            [2003, 10593, 54, 45],
            [2003, 10594, 65, 61],
            [2003, 10595, 41, 45],
            [2003, 10596, 46, 43],
            [2003, 10597, 55, 45],
            [2003, 10598, 50, 39],
            [2003, 10600, 42, 31],
            [2003, 10601, 58, 36],
            [2003, 10602, 29, 33],
            [2003, 10603, 42, 40],
            [2003, 10604, 42, 29],
            [2003, 10605, 19, 11],
            [2003, 10606, 16, 11],
            [2003, 10607, 25, 14],
            [2003, 10608, 14, 11],
            [2003, 10609, 14, 11],
            [2003, 10610, 23, 11],
            [2003, 10611, 23, 15],
            [2003, 10612, 21, 16],
            [2003, 10613, 48, 17],
            [2003, 10614, 41, 25],
            [2003, 10615, 44, 23],
            [2003, 10616, 39, 32],
            [2003, 10617, 51, 30],
            [2003, 10618, 55, 29],
            [2003, 10619, 41, 24],
            [2003, 10620, 30, 21],
            [2003, 10621, 41, 17],
            [2003, 10622, 36, 19],
            [2003, 10623, 41, 19],
            [2003, 10624, 41, 18],
            [2003, 10625, 35, 23],
            [2003, 10626, 51, 27],
            [2003, 10627, 47, 23],
            [2003, 10628, 53, 34],
            [2003, 10629, 51, 33],
            [2003, 10630, 31, 18],
            [2003, 10631, 47, 20],
            [2003, 10632, 36, 19],
            [2003, 10633, 51, 25],
            [2003, 10634, 50, 19],
            [2003, 10635, 52, 19],
            [2003, 10636, 41, 25],
            [2003, 10637, 40, 23],
            [2003, 10638, 25, 18],
            [2003, 10639, 52, 28],
            [2003, 10640, 48, 28],
            [2003, 10641, 47, 29],
            [2003, 10642, 51, 30],
            [2003, 10643, 41, 27],
            [2003, 10644, 48, 28],
            [2003, 10645, 36, 31],
            [2003, 10646, 49, 30],
            [2003, 10647, 49, 29],
            [2003, 10648, 42, 35],
            [2003, 10649, 45, 26],
            [2003, 10650, 49, 24],
            [2003, 10651, 47, 24],
            [2003, 10652, 39, 25],
            [2003, 10653, 52, 24],
            [2003, 10654, 39, 29],
            [2003, 10655, 48, 27],
            [2003, 10656, 49, 29],
            [2003, 10657, 39, 21],
            [2003, 10658, 46, 20],
            [2003, 10659, 23, 18],
            [2003, 10660, 54, 25],
            [2003, 10661, 80, 30],
            [2003, 10662, 49, 30],
            [2003, 10663, 46, 19],
            [2003, 10664, 51, 24],
            [2003, 10665, 53, 26],
            [2003, 10666, 55, 23],
            [2003, 10667, 51, 23],
            [2003, 10668, 47, 25],
            [2003, 10669, 22, 18],
            [2003, 10670, 48, 22],
            [2003, 10671, 49, 30],
            [2003, 10672, 54, 29],
            [2003, 10673, 36, 17],
            [2003, 10674, 41, 19],
            [2003, 10675, 41, 39],
            [2003, 10676, 41, 39],
            [2003, 10677, 36, 19],
            [2003, 10678, 41, 26],
            [2003, 10679, 59, 29],
            [2003, 10680, 26, 20],
            [2003, 10681, 44, 23],
            [2003, 10682, 41, 25],
            [2003, 10683, 39, 25],
            [2003, 10684, 29, 30],
            [2003, 10685, 85, 39],
            [2003, 10686, 47, 40],
            [2003, 10687, 41, 42],
            [2003, 10688, 61, 42],
            [2003, 10689, 61, 40],
            [2003, 10690, 62, 42],
            [2003, 10691, 64, 42],
            [2003, 10692, 64, 27],
            [2003, 10693, 87, 28],
            [2003, 10694, 65, 27],
            [2003, 10695, 52, 27],
            [2003, 10696, 52, 30],
            [2003, 10697, 36, 27],
            [2003, 10698, 41, 37],
            [2003, 10699, 48, 37],
            [2003, 10700, 23, 23],
            [2003, 10701, 77, 26],
            [2003, 10702, 78, 27],
            [2003, 10703, 79, 27],
            [2003, 10704, 52, 26],
            [2003, 10705, 60, 25],
            [2003, 10706, 53, 24],
            [2003, 10707, 43, 46],
            [2003, 10708, 48, 46],
            [2003, 10709, 51, 46],
            [2003, 10710, 73, 22],
            [2003, 10711, 49, 23],
            [2003, 10712, 54, 40],
            [2003, 10713, 54, 40],
            [2003, 10714, 47, 30],
            [2003, 10715, 79, 25],
            [2003, 10716, 52, 46],
            [2003, 10717, 49, 46],
            [2003, 10718, 47, 46],
            [2003, 10719, 64, 43],
            [2003, 10720, 65, 43],
            [2003, 10721, 30, 26],
            [2003, 10722, 64, 42],
            [2003, 10723, 51, 42],
            [2003, 10724, 54, 42],
            [2003, 10725, 51, 43],
            [2003, 10726, 38, 26],
            [2003, 10727, 50, 28],
            [2003, 10728, 53, 31],
            [2003, 10729, 49, 29],
            [2003, 10730, 52, 28],
            [2003, 10731, 39, 23],
            [2003, 10732, 52, 24],
            [2003, 10733, 53, 24],
            [2003, 10734, 52, 24],
            [2003, 10735, 53, 21],
            [2003, 10736, 52, 20],
            [2003, 10737, 88, 22],
            [2003, 10738, 54, 30],
            [2003, 10739, 30, 17],
            [2003, 10740, 49, 23],
            [2003, 10741, 43, 25],
            [2003, 10742, 49, 34],
            [2003, 10743, 42, 29],
            [2003, 10744, 41, 25],
            [2003, 10745, 48, 29],
            [2003, 10746, 48, 25],
            [2003, 10747, 30, 21],
            [2003, 10748, 47, 19],
            [2003, 10749, 47, 25],
            [2003, 10750, 49, 12],
            [2003, 10751, 48, 22],
            [2003, 10752, 49, 24],
            [2003, 10753, 52, 29],
            [2003, 10754, 46, 21],
            [2003, 10755, 21, 15],
            [2003, 10756, 83, 66],
            [2003, 10757, 23, 14],
            [2003, 10758, 30, 12],
            [2003, 10759, 55, 27],
            [2003, 10760, 57, 33],
            [2003, 10761, 47, 31],
            [2003, 10762, 48, 26],
            [2003, 10763, 41, 26],
            [2003, 10764, 30, 26],
            [2003, 10765, 36, 24],
            [2003, 10766, 50, 25],
            [2003, 10767, 52, 19],
            [2003, 10768, 47, 20],
            [2003, 10769, 50, 20],
            [2003, 10770, 50, 40],
            [2003, 10771, 52, 40],
            [2003, 10772, 36, 47],
            [2003, 10773, 49, 54],
            [2003, 10774, 40, 24],
            [2003, 10775, 47, 24],
            [2003, 10776, 42, 20],
            [2003, 10777, 33, 21],
            [2003, 10778, 82, 21],
            [2003, 10779, 41, 28],
            [2003, 10780, 47, 21],
            [2003, 10781, 42, 20],
            [2003, 10782, 41, 19],
            [2003, 10783, 60, 37],
            [2003, 10784, 51, 25],
            [2003, 10785, 53, 27],
            [2003, 10786, 40, 21],
            [2003, 10787, 44, 20],
            [2003, 10788, 48, 46],
            [2003, 10789, 44, 26],
            [2003, 10790, 53, 26],
            [2003, 10791, 54, 26],
            [2003, 10792, 30, 19],
            [2003, 10793, 50, 19],
            [2003, 10794, 54, 20],
            [2003, 10795, 55, 20],
            [2003, 10796, 56, 20],
            [2003, 10797, 49, 21],
            [2003, 10798, 34, 20],
            [2003, 10799, 25, 18],
            [2003, 10800, 49, 33],
            [2003, 10801, 48, 25],
            [2003, 10802, 41, 26],
            [2003, 10803, 36, 21],
            [2003, 10804, 60, 24],
            [2003, 10805, 64, 25],
            [2003, 10806, 39, 24],
            [2003, 10807, 48, 24],
            [2003, 10808, 33, 17],
            [2003, 10809, 31, 20],
            [2003, 10810, 40, 20],
            [2003, 10811, 41, 18],
            [2003, 10812, 128, 50],
            [2003, 10813, 49, 41],
            [2003, 10814, 40, 23],
            [2003, 10815, 49, 23],
            [2003, 10816, 52, 22],
            [2003, 10817, 49, 22],
            [2003, 10818, 52, 35],
            [2003, 10819, 51, 31],
            [2003, 10820, 52, 28],
            [2003, 10821, 46, 19],
            [2003, 10822, 49, 19],
            [2003, 10823, 44, 19],
            [2003, 10824, 39, 24],
            [2003, 10825, 40, 25],
            [2003, 10826, 44, 26],
            [2003, 10827, 41, 26],
            [2003, 10828, 35, 21],
            [2003, 10829, 51, 30],
            [2003, 10830, 48, 28],
            [2003, 10831, 50, 27],
            [2003, 10832, 47, 27],
            [2003, 10833, 47, 27],
            [2003, 10834, 48, 28],
            [2003, 10835, 49, 29],
            [2003, 10836, 47, 28],
            [2003, 10837, 55, 29],
            [2003, 10838, 49, 28],
            [2003, 10839, 40, 28],
            [2003, 10840, 30, 24],
            [2003, 10841, 75, 21],
            [2003, 10842, 36, 19],
            [2003, 10843, 49, 25],
            [2003, 10844, 37, 30],
            [2003, 10845, 33, 28],
            [2003, 10846, 39, 27],
            [2003, 10847, 38, 20],
            [2003, 10848, 49, 20],
            [2003, 10849, 49, 20],
            [2003, 10850, 43, 28],
            [2003, 10851, 38, 26],
            [2003, 10852, 41, 26],
            [2003, 10853, 53, 38],
            [2003, 10854, 50, 26],
            [2003, 10855, 53, 26],
            [2003, 10856, 52, 34],
            [2003, 10857, 52, 34],
            [2003, 10858, 48, 29],
            [2003, 10859, 53, 29],
            [2003, 10860, 64, 31],
            [2003, 10861, 60, 31],
            [2003, 10862, 47, 29],
            [2003, 10863, 27, 23],
            [2003, 10864, 71, 32],
            [2003, 10865, 48, 20],
            [2003, 10866, 38, 23],
            [2003, 10867, 49, 28],
            [2003, 10868, 48, 27],
            [2003, 10869, 54, 20],
            [2003, 10870, 52, 25],
            [2003, 10871, 53, 26],
            [2003, 10872, 51, 20],
            [2003, 10873, 62, 21],
            [2003, 10874, 54, 20],
            [2003, 10875, 50, 23],
            [2003, 10876, 62, 27],
            [2003, 10877, 75, 32],
            [2003, 10878, 52, 27],
            [2003, 10879, 53, 25],
            [2003, 10880, 55, 25],
            [2003, 10881, 40, 19],
            [2003, 10882, 62, 24],
            [2003, 10883, 75, 25],
            [2003, 10884, 85, 26],
            [2003, 10885, 40, 35],
            [2003, 10886, 51, 26],
            [2003, 10887, 41, 26],
            [2003, 10888, 65, 33],
            [2003, 10889, 50, 29],
            [2003, 10890, 43, 22],
            [2003, 10891, 30, 20],
            [2003, 10892, 38, 24],
            [2003, 10893, 54, 44],
            [2003, 10894, 51, 44],
            [2003, 10895, 76, 37],
            [2003, 10896, 49, 39],
            [2003, 10897, 53, 40],
            [2003, 10898, 52, 39],
            [2003, 10899, 45, 23],
            [2003, 10900, 42, 21],
            [2003, 10901, 44, 18],
            [2003, 10902, 47, 19],
            [2003, 10903, 47, 23],
            [2003, 10904, 49, 24],
            [2003, 10905, 40, 24],
            [2003, 10906, 53, 38],
            [2003, 10907, 53, 37],
            [2003, 10908, 48, 21],
            [2003, 10909, 74, 23],
            [2003, 10910, 49, 24],
            [2003, 10911, 64, 54],
            [2003, 10912, 63, 54],
            [2003, 10913, 42, 40],
            [2003, 10914, 82, 38],
            [2003, 10915, 55, 44],
            [2003, 10916, 59, 43],
            [2003, 10917, 66, 43],
            [2003, 10918, 37, 32],
            [2003, 10978, 49, 19],
            [2003, 10979, 45, 28],
            [2003, 10980, 47, 26],
            [2003, 11091, 9, 6],
            [2003, 11092, 12, 8],
            [2003, 11093, 11, 6],
            [2003, 11094, 15, 8],
            [2003, 11095, 8, 6],
            [2003, 11096, 23, 18],
            [2003, 11097, 10, 6],
            [2003, 11098, 9, 6],
            [2003, 11099, 41, 33],
            [2003, 11100, 9, 6],
            [2003, 11101, 11, 7],
            [2003, 11102, 10, 6],
            [2003, 11103, 15, 9],
            [2003, 11104, 50, 31],
            [2003, 11105, 31, 30],
            [2003, 11106, 27, 17],
            [2003, 11107, 18, 10],
            [2003, 11108, 9, 5],
            [2003, 11109, 21, 18],
            [2003, 11110, 17, 9],
            [2003, 11111, 7, 8],
            [2003, 11112, 28, 18],
            [2003, 11113, 24, 15],
            [2003, 11114, 37, 26],
            [2003, 11115, 8, 5],
            [2003, 11116, 8, 5],
            [2003, 11117, 9, 7],
            [2003, 11118, 15, 10],
            [2003, 11119, 36, 22],
            [2003, 11120, 29, 21],
            [2003, 11121, 10, 8],
            [2003, 11122, 10, 7],
            [2003, 11123, 14, 8],
            [2003, 11124, 9, 7],
            [2003, 11125, 28, 15],
            [2003, 11126, 13, 8],
            [2003, 11127, 7, 7],
            [2003, 11128, 12, 6],
            [2003, 11129, 7, 5],
            [2003, 11130, 15, 10],
            [2003, 11131, 7, 6],
            [2003, 11132, 19, 12],
            [2003, 11133, 11, 7],
            [2003, 11134, 7, 4],
            [2003, 11135, 49, 27],
            [2003, 11136, 10, 7],
            [2003, 11137, 7, 5],
            [2003, 11138, 20, 14],
            [2003, 11139, 12, 8],
            [2003, 11140, 11, 9],
            [2003, 11141, 10, 6],
            [2003, 11142, 9, 6],
            [2003, 11143, 8, 5],
            [2003, 11144, 10, 7],
            [2003, 11145, 27, 22],
            [2003, 11146, 8, 6],
            [2003, 11147, 5, 3],
            [2003, 11148, 31, 27],
            [2003, 11149, 15, 11],
            [2003, 11150, 23, 17],
            [2003, 11151, 14, 12],
            [2003, 11152, 14, 12],
            [2003, 11153, 14, 9],
            [2003, 11154, 26, 16],
            [2003, 11155, 17, 10],
            [2003, 11156, 11, 10],
            [2003, 11157, 12, 10],
            [2003, 11158, 12, 10],
            [2003, 11159, 13, 12],
            [2003, 11160, 14, 10],
            [2003, 11161, 13, 10],
            [2003, 11162, 12, 11],
            [2003, 11163, 12, 12],
            [2003, 11164, 17, 16],
            [2003, 11165, 12, 9],
            [2003, 11166, 47, 28],
            [2003, 11167, 83, 47],
            [2003, 11168, 23, 16],
            [2003, 11169, 10, 9],
            [2003, 11170, 12, 10],
            [2003, 11171, 14, 11],
            [2003, 11172, 9, 9],
            [2003, 11173, 14, 12],
            [2003, 11174, 8, 7],
            [2003, 11175, 7, 7],
            [2003, 11176, 5, 5],
            [2003, 11177, 18, 15],
            [2003, 11178, 8, 8],
            [2003, 11179, 11, 9],
            [2003, 11180, 10, 7],
            [2003, 11181, 15, 13],
            [2003, 11182, 12, 11],
            [2003, 11183, 12, 10],
            [2003, 11184, 108, 83],
            [2003, 11185, 108, 83],
            [2003, 11186, 108, 83],
            [2003, 11187, 108, 83],
            [2003, 11188, 108, 83],
            [2003, 11189, 74, 108],
            [2003, 11190, 93, 80],
            [2003, 11191, 93, 80],
            [2003, 11192, 93, 80],
            [2003, 11193, 93, 80],
            [2003, 11194, 50, 35],
            [2003, 11195, 21, 32],
            [2003, 11196, 94, 61],
            [2003, 11197, 116, 50],
            [2003, 11198, 40, 29],
            [2003, 11199, 60, 33],
            [2003, 11200, 58, 29],
            [2003, 11201, 10, 11],
            [2003, 11202, 58, 35],
            [2003, 11203, 13, 14],
            [2003, 11204, 86, 52],
            [2003, 11205, 123, 85],
            [2003, 11206, 68, 57],
            [2003, 11207, 11, 12],
            [2003, 11208, 30, 19],
            [2003, 11292, 14, 18],
            [2003, 11293, 10, 12],
            [2003, 11294, 12, 15],
            [2003, 11295, 12, 15],
            [2003, 11296, 83, 63],
            [2003, 11297, 100, 74],
            [2003, 11298, 26, 25],
            [2003, 11299, 40, 25],
            [2003, 11300, 21, 29],
            [2003, 11301, 58, 53],
            [2003, 11302, 32, 30],
            [2003, 11303, 24, 24],
            [2003, 11304, 32, 22],
            [2003, 11306, 15, 23],
            [2003, 11307, 18, 24],
            [2003, 11313, 19, 24],
            [2003, 11314, 37, 35],
            [2003, 11315, 39, 36],
            [2003, 11316, 29, 27],
            [2003, 11317, 40, 39],
            [2003, 11318, 20, 24],
            [2003, 11319, 24, 22],
            [2003, 11320, 23, 21],
            [2003, 11321, 37, 41],
            [2003, 11322, 90, 42],
            [2003, 11323, 29, 33],
            [2003, 11324, 30, 21],
            [2003, 11325, 34, 24],
            [2003, 11326, 32, 36],
            [2003, 11327, 33, 25],
            [2003, 11328, 32, 37],
            [2003, 11329, 27, 32],
            [2003, 11330, 31, 29],
            [2003, 11331, 39, 41],
            [2003, 11332, 23, 26],
            [2003, 11333, 46, 32],
            [2003, 11334, 52, 33],
            [2003, 11335, 33, 24],
            [2003, 11336, 15, 17],
            [2003, 11337, 28, 30],
            [2003, 11338, 37, 36],
            [2003, 11339, 42, 36],
            [2003, 11340, 39, 38],
            [2003, 11341, 56, 50],
            [2003, 11342, 45, 36],
            [2003, 11343, 40, 43],
            [2003, 11344, 38, 43],
            [2003, 11345, 32, 40],
            [2003, 11346, 45, 36],
            [2003, 11347, 38, 32],
            [2003, 11348, 56, 47],
            [2003, 11349, 22, 19],
            [2003, 11350, 47, 54],
            [2003, 11351, 35, 38],
            [2003, 11352, 27, 36],
            [2003, 11353, 46, 43],
            [2003, 11354, 31, 25],
            [2003, 11355, 41, 33],
            [2003, 11356, 26, 21],
            [2003, 11357, 30, 27],
            [2003, 11358, 19, 25],
            [2003, 11359, 62, 48],
            [2003, 11360, 40, 25],
            [2003, 11361, 58, 53],
            [2003, 11362, 32, 30],
            [2003, 11363, 10, 10],
            [2003, 11364, 12, 13],
            [2003, 11365, 29, 24],
            [2004, 7, 27, 26],
            [2004, 25, 13, 9],
            [2004, 48, 60, 40],
            [2004, 49, 28, 20],
            [2004, 51, 30, 26],
            [2004, 62, 18, 26],
            [2004, 65, 19, 17],
            [2004, 78, 21, 18],
            [2004, 82, 12, 17],
            [2004, 83, 28, 32],
            [2004, 99, 26, 26],
            [2004, 101, 50, 41],
            [2004, 119, 34, 24],
            [2004, 138, 44, 29],
            [2004, 163, 32, 30],
            [2004, 166, 29, 28],
            [2004, 190, 27, 26],
            [2004, 200, 34, 26],
            [2004, 204, 11, 21],
            [2004, 211, 19, 37],
            [2004, 216, 21, 18],
            [2004, 218, 42, 23],
            [2004, 220, 16, 17],
            [2004, 226, 19, 15],
            [2004, 231, 46, 39],
            [2004, 233, 17, 18],
            [2004, 234, 11, 14],
            [2004, 240, 45, 27],
            [2004, 243, 49, 28],
            [2004, 246, 37, 26],
            [2004, 272, 36, 15],
            [2004, 282, 37, 28],
            [2004, 286, 23, 24],
            [2004, 305, 22, 26],
            [2004, 308, 11, 31],
            [2004, 310, 18, 18],
            [2004, 312, 19, 18],
            [2004, 314, 17, 24],
            [2004, 324, 32, 28],
            [2004, 327, 36, 31],
            [2004, 329, 32, 23],
            [2004, 346, 45, 36],
            [2004, 355, 41, 27],
            [2004, 361, 27, 26],
            [2004, 378, 18, 19],
            [2004, 379, 14, 12],
            [2004, 389, 25, 27],
            [2004, 392, 18, 18],
            [2004, 399, 62, 30],
            [2004, 424, 19, 18],
            [2004, 425, 14, 20],
            [2004, 428, 26, 19],
            [2004, 430, 19, 22],
            [2004, 432, 60, 36],
            [2004, 436, 39, 32],
            [2004, 471, 18, 19],
            [2004, 479, 50, 40],
            [2004, 480, 50, 28],
            [2004, 487, 25, 23],
            [2004, 494, 16, 17],
            [2004, 497, 9, 14],
            [2004, 503, 72, 20],
            [2004, 504, 12, 10],
            [2004, 505, 39, 24],
            [2004, 519, 16, 24],
            [2004, 525, 19, 26],
            [2004, 536, 25, 18],
            [2004, 541, 100, 40],
            [2004, 545, 21, 25],
            [2004, 568, 18, 18],
            [2004, 569, 73, 27],
            [2004, 570, 24, 19],
            [2004, 577, 39, 22],
            [2004, 585, 47, 40],
            [2004, 590, 44, 51],
            [2004, 593, 33, 29],
            [2004, 597, 33, 14],
            [2004, 604, 41, 26],
            [2004, 608, 24, 18],
            [2004, 612, 29, 28],
            [2004, 618, 20, 18],
            [2004, 628, 30, 27],
            [2004, 631, 31, 22],
            [2004, 660, 50, 33],
            [2004, 662, 49, 41],
            [2004, 663, 57, 29],
            [2004, 669, 21, 17],
            [2004, 678, 18, 23],
            [2004, 686, 13, 19],
            [2004, 691, 23, 27],
            [2004, 694, 32, 25],
            [2004, 695, 60, 45],
            [2004, 700, 46, 35],
            [2004, 703, 11, 15],
            [2004, 716, 50, 45],
            [2004, 724, 18, 34],
            [2004, 734, 17, 31],
            [2004, 751, 29, 20],
            [2004, 754, 28, 27],
            [2004, 766, 77, 41],
            [2004, 769, 49, 31],
            [2004, 785, 45, 36],
            [2004, 790, 30, 23],
            [2004, 801, 17, 18],
            [2004, 803, 29, 26],
            [2004, 805, 28, 22],
            [2004, 820, 53, 33],
            [2004, 822, 15, 19],
            [2004, 826, 19, 18],
            [2004, 827, 10, 13],
            [2004, 835, 43, 25],
            [2004, 843, 31, 27],
            [2004, 845, 45, 35],
            [2004, 848, 23, 19],
            [2004, 865, 62, 26],
            [2004, 871, 34, 19],
            [2004, 878, 7, 6],
            [2004, 882, 38, 27],
            [2004, 894, 26, 12],
            [2004, 913, 18, 18],
            [2004, 915, 45, 32],
            [2004, 922, 32, 40],
            [2004, 926, 45, 19],
            [2004, 938, 11, 12],
            [2004, 940, 11, 13],
            [2004, 941, 30, 25],
            [2004, 949, 52, 30],
            [2004, 950, 14, 18],
            [2004, 964, 11, 15],
            [2004, 969, 43, 35],
            [2004, 971, 18, 16],
            [2004, 978, 37, 38],
            [2004, 979, 18, 18],
            [2004, 985, 69, 33],
            [2004, 993, 59, 31],
            [2004, 998, 40, 28],
            [2004, 1003, 8, 6],
            [2004, 1008, 35, 36],
            [2004, 1016, 11, 14],
            [2004, 1030, 9, 13],
            [2004, 1048, 36, 35],
            [2004, 1056, 19, 36],
            [2004, 1059, 35, 34],
            [2004, 1095, 18, 18],
            [2004, 1097, 30, 17],
            [2004, 1106, 71, 32],
            [2004, 1111, 40, 40],
            [2004, 1131, 46, 34],
            [2004, 1132, 11, 13],
            [2004, 1136, 34, 32],
            [2004, 1142, 22, 20],
            [2004, 1144, 24, 19],
            [2004, 1145, 27, 22],
            [2004, 1150, 32, 21],
            [2004, 1155, 25, 26],
            [2004, 1156, 25, 17],
            [2004, 1157, 36, 31],
            [2004, 1159, 78, 34],
            [2004, 1167, 21, 19],
            [2004, 1169, 26, 23],
            [2004, 1174, 27, 37],
            [2004, 1177, 26, 22],
            [2004, 1186, 15, 16],
            [2004, 1194, 82, 37],
            [2004, 1200, 17, 19],
            [2004, 1203, 11, 17],
            [2004, 1213, 21, 16],
            [2004, 1219, 26, 16],
            [2004, 1221, 18, 17],
            [2004, 1226, 18, 23],
            [2004, 1234, 12, 14],
            [2004, 1235, 23, 18],
            [2004, 1238, 14, 23],
            [2004, 1247, 46, 26],
            [2004, 1254, 46, 23],
            [2004, 1268, 34, 27],
            [2004, 1275, 28, 12],
            [2004, 1281, 14, 18],
            [2004, 1295, 38, 36],
            [2004, 1302, 43, 48],
            [2004, 1303, 69, 33],
            [2004, 1320, 35, 30],
            [2004, 1334, 73, 44],
            [2004, 1358, 51, 32],
            [2004, 1359, 32, 27],
            [2004, 1370, 13, 20],
            [2004, 1396, 11, 19],
            [2004, 1420, 53, 43],
            [2004, 1445, 67, 24],
            [2004, 1456, 25, 25],
            [2004, 1466, 31, 25],
            [2004, 1473, 13, 18],
            [2004, 1475, 56, 28],
            [2004, 1476, 48, 33],
            [2004, 1477, 28, 17],
            [2004, 1481, 38, 24],
            [2004, 1484, 40, 27],
            [2004, 1486, 13, 13],
            [2004, 1491, 11, 8],
            [2004, 1493, 25, 19],
            [2004, 1507, 33, 28],
            [2004, 1510, 16, 19],
            [2004, 1511, 27, 26],
            [2004, 1515, 20, 15],
            [2004, 1522, 24, 18],
            [2004, 1525, 33, 33],
            [2004, 1527, 31, 27],
            [2004, 1530, 69, 44],
            [2004, 1536, 15, 18],
            [2004, 1537, 61, 44],
            [2004, 1548, 34, 32],
            [2004, 1557, 29, 24],
            [2004, 1562, 41, 30],
            [2004, 1568, 29, 27],
            [2004, 1577, 25, 17],
            [2004, 1580, 39, 30],
            [2004, 1582, 29, 23],
            [2004, 1587, 17, 16],
            [2004, 1589, 46, 24],
            [2004, 1598, 11, 8],
            [2004, 1610, 25, 26],
            [2004, 1628, 30, 17],
            [2004, 1635, 17, 16],
            [2004, 1638, 41, 33],
            [2004, 1644, 101, 57],
            [2004, 1645, 48, 30],
            [2004, 1659, 24, 21],
            [2004, 1662, 13, 11],
            [2004, 1673, 73, 39],
            [2004, 1680, 115, 44],
            [2004, 1685, 33, 30],
            [2004, 1704, 14, 17],
            [2004, 1717, 47, 32],
            [2004, 1730, 17, 11],
            [2004, 1763, 22, 21],
            [2004, 1769, 46, 38],
            [2004, 1771, 18, 18],
            [2004, 1772, 10, 13],
            [2004, 1774, 22, 23],
            [2004, 1786, 18, 22],
            [2004, 1794, 29, 29],
            [2004, 1795, 12, 9],
            [2004, 1797, 50, 32],
            [2004, 1798, 35, 40],
            [2004, 1804, 29, 17],
            [2004, 1812, 14, 15],
            [2004, 1818, 18, 18],
            [2004, 1824, 26, 29],
            [2004, 1825, 18, 23],
            [2004, 1841, 37, 36],
            [2004, 1845, 36, 27],
            [2004, 1848, 46, 26],
            [2004, 1864, 104, 62],
            [2004, 1866, 51, 27],
            [2004, 1882, 16, 18],
            [2004, 1891, 31, 27],
            [2004, 1894, 32, 15],
            [2004, 1903, 70, 30],
            [2004, 1915, 37, 30],
            [2004, 1916, 19, 17],
            [2004, 1921, 14, 11],
            [2004, 1930, 10, 8],
            [2004, 1933, 11, 14],
            [2004, 1950, 19, 28],
            [2004, 1952, 168, 68],
            [2004, 1962, 12, 14],
            [2004, 1965, 62, 37],
            [2004, 1995, 44, 25],
            [2004, 2000, 30, 26],
            [2004, 2001, 31, 23],
            [2004, 2006, 21, 19],
            [2004, 2011, 12, 16],
            [2004, 2017, 44, 30],
            [2004, 2021, 25, 26],
            [2004, 2023, 11, 11],
            [2004, 2025, 58, 46],
            [2004, 2028, 45, 31],
            [2004, 2029, 35, 28],
            [2004, 2035, 51, 28],
            [2004, 2048, 14, 28],
            [2004, 2056, 23, 41],
            [2004, 2057, 58, 31],
            [2004, 2064, 55, 30],
            [2004, 2081, 29, 17],
            [2004, 2084, 61, 26],
            [2004, 2098, 13, 16],
            [2004, 2099, 30, 22],
            [2004, 2127, 15, 13],
            [2004, 2128, 28, 27],
            [2004, 2138, 24, 23],
            [2004, 2142, 9, 10],
            [2004, 2171, 24, 23],
            [2004, 2178, 12, 16],
            [2004, 2180, 34, 26],
            [2004, 2190, 25, 19],
            [2004, 2198, 19, 15],
            [2004, 2201, 27, 27],
            [2004, 2208, 72, 37],
            [2004, 2213, 39, 30],
            [2004, 2224, 33, 26],
            [2004, 2227, 17, 19],
            [2004, 2232, 27, 27],
            [2004, 2238, 30, 26],
            [2004, 2244, 21, 21],
            [2004, 2250, 38, 25],
            [2004, 2258, 26, 26],
            [2004, 2277, 26, 19],
            [2004, 2280, 13, 10],
            [2004, 2282, 17, 51],
            [2004, 2300, 50, 40],
            [2004, 2303, 28, 24],
            [2004, 2311, 34, 31],
            [2004, 2316, 46, 32],
            [2004, 2343, 36, 25],
            [2004, 2352, 36, 31],
            [2004, 2367, 39, 27],
            [2004, 2371, 48, 28],
            [2004, 2384, 25, 31],
            [2004, 2404, 26, 26],
            [2004, 2429, 12, 12],
            [2004, 2433, 41, 20],
            [2004, 2435, 14, 11],
            [2004, 2443, 47, 32],
            [2004, 2458, 28, 21],
            [2004, 2459, 25, 15],
            [2004, 2467, 11, 14],
            [2004, 2483, 41, 45],
            [2004, 2485, 12, 14],
            [2004, 2488, 26, 23],
            [2004, 2494, 31, 27],
            [2004, 2497, 30, 18],
            [2004, 2500, 23, 17],
            [2004, 2501, 52, 30],
            [2004, 2505, 38, 25],
            [2004, 2524, 10, 9],
            [2004, 2533, 10, 16],
            [2004, 2539, 78, 24],
            [2004, 2540, 16, 20],
            [2004, 2543, 16, 19],
            [2004, 2547, 15, 28],
            [2004, 2554, 10, 10],
            [2004, 2562, 91, 32],
            [2004, 2564, 27, 18],
            [2004, 2574, 66, 36],
            [2004, 2576, 68, 36],
            [2004, 2585, 42, 33],
            [2004, 2595, 36, 29],
            [2004, 2603, 54, 32],
            [2004, 2606, 18, 14],
            [2004, 2612, 36, 25],
            [2004, 2617, 32, 21],
            [2004, 2619, 11, 11],
            [2004, 2627, 49, 28],
            [2004, 2635, 12, 16],
            [2004, 2647, 28, 24],
            [2004, 2656, 19, 18],
            [2004, 2670, 36, 25],
            [2004, 2671, 41, 44],
            [2004, 2687, 40, 21],
            [2004, 2692, 48, 28],
            [2004, 2695, 12, 13],
            [2004, 2720, 29, 33],
            [2004, 2723, 34, 40],
            [2004, 2758, 30, 26],
            [2004, 2762, 52, 33],
            [2004, 2775, 47, 28],
            [2004, 2785, 12, 14],
            [2004, 2798, 12, 17],
            [2004, 2822, 23, 18],
            [2004, 2823, 22, 18],
            [2004, 2827, 12, 17],
            [2004, 2832, 16, 16],
            [2004, 2833, 37, 25],
            [2004, 2835, 25, 23],
            [2004, 2836, 25, 17],
            [2004, 2838, 31, 26],
            [2004, 2846, 25, 35],
            [2004, 2851, 19, 14],
            [2004, 2872, 18, 19],
            [2004, 2879, 21, 18],
            [2004, 2880, 34, 23],
            [2004, 2883, 35, 38],
            [2004, 2901, 44, 36],
            [2004, 2904, 57, 25],
            [2004, 2910, 18, 18],
            [2004, 2914, 39, 26],
            [2004, 2922, 13, 14],
            [2004, 2929, 43, 28],
            [2004, 2934, 19, 18],
            [2004, 2935, 50, 27],
            [2004, 2950, 33, 27],
            [2004, 2969, 20, 15],
            [2004, 2973, 32, 38],
            [2004, 2974, 32, 20],
            [2004, 2978, 27, 26],
            [2004, 2991, 34, 30],
            [2004, 3016, 34, 26],
            [2004, 3019, 39, 21],
            [2004, 3027, 16, 17],
            [2004, 3033, 47, 31],
            [2004, 3035, 19, 19],
            [2004, 3046, 50, 22],
            [2004, 3053, 66, 48],
            [2004, 3066, 45, 28],
            [2004, 3070, 37, 31],
            [2004, 3077, 48, 41],
            [2004, 3086, 100, 34],
            [2004, 3091, 13, 14],
            [2004, 3092, 48, 28],
            [2004, 3098, 33, 28],
            [2004, 3112, 49, 26],
            [2004, 3114, 54, 29],
            [2004, 3119, 11, 24],
            [2004, 3126, 40, 27],
            [2004, 3133, 38, 29],
            [2004, 3134, 32, 35],
            [2004, 3137, 28, 27],
            [2004, 3142, 28, 33],
            [2004, 3148, 32, 23],
            [2004, 3155, 23, 19],
            [2004, 3158, 15, 16],
            [2004, 3161, 18, 18],
            [2004, 3164, 47, 32],
            [2004, 3167, 19, 25],
            [2004, 3171, 31, 17],
            [2004, 3182, 134, 43],
            [2004, 3206, 47, 27],
            [2004, 3221, 38, 32],
            [2004, 3228, 42, 27],
            [2004, 3231, 18, 18],
            [2004, 3234, 40, 23],
            [2004, 3246, 81, 28],
            [2004, 3248, 16, 22],
            [2004, 3252, 42, 26],
            [2004, 3254, 22, 25],
            [2004, 3256, 25, 20],
            [2004, 3264, 25, 26],
            [2004, 3273, 60, 36],
            [2004, 3274, 19, 17],
            [2004, 3280, 30, 27],
            [2004, 3289, 90, 54],
            [2004, 3301, 36, 33],
            [2004, 3306, 19, 23],
            [2004, 3308, 52, 31],
            [2004, 3309, 35, 36],
            [2004, 3320, 41, 42],
            [2004, 3321, 50, 28],
            [2004, 3326, 18, 19],
            [2004, 3327, 38, 36],
            [2004, 3331, 30, 18],
            [2004, 3346, 33, 37],
            [2004, 3348, 47, 30],
            [2004, 3357, 12, 17],
            [2004, 3363, 51, 26],
            [2004, 3364, 11, 15],
            [2004, 3372, 45, 30],
            [2004, 3382, 30, 22],
            [2004, 3418, 55, 30],
            [2004, 3434, 7, 7],
            [2004, 3438, 46, 25],
            [2004, 3439, 26, 21],
            [2004, 3451, 37, 37],
            [2004, 3454, 11, 10],
            [2004, 3459, 22, 19],
            [2004, 3462, 48, 23],
            [2004, 3469, 24, 17],
            [2004, 3494, 11, 13],
            [2004, 3498, 15, 19],
            [2004, 3503, 50, 35],
            [2004, 3511, 18, 25],
            [2004, 3515, 13, 34],
            [2004, 3517, 45, 28],
            [2004, 3531, 24, 18],
            [2004, 3541, 23, 23],
            [2004, 3557, 10, 13],
            [2004, 3559, 38, 28],
            [2004, 3569, 47, 47],
            [2004, 3579, 18, 27],
            [2004, 3590, 21, 23],
            [2004, 3593, 51, 49],
            [2004, 3598, 16, 12],
            [2004, 3602, 18, 18],
            [2004, 3608, 37, 24],
            [2004, 3653, 20, 18],
            [2004, 3659, 37, 27],
            [2004, 3661, 26, 26],
            [2004, 3669, 11, 17],
            [2004, 3679, 17, 26],
            [2004, 3700, 19, 20],
            [2004, 3718, 45, 32],
            [2004, 3726, 10, 12],
            [2004, 3729, 111, 43],
            [2004, 3731, 48, 60],
            [2004, 3751, 34, 24],
            [2004, 3755, 30, 23],
            [2004, 3765, 20, 18],
            [2004, 3777, 25, 20],
            [2004, 3782, 58, 27],
            [2004, 3796, 26, 26],
            [2004, 3827, 44, 26],
            [2004, 3828, 17, 20],
            [2004, 3833, 63, 33],
            [2004, 3845, 47, 26],
            [2004, 3854, 29, 23],
            [2004, 3859, 11, 15],
            [2004, 3870, 48, 31],
            [2004, 3874, 36, 27],
            [2004, 3884, 49, 28],
            [2004, 3889, 58, 24],
            [2004, 3905, 25, 25],
            [2004, 3915, 24, 24],
            [2004, 3921, 24, 26],
            [2004, 3925, 48, 35],
            [2004, 3932, 21, 26],
            [2004, 3942, 28, 25],
            [2004, 3943, 25, 23],
            [2004, 3947, 36, 30],
            [2004, 3956, 40, 48],
            [2004, 3960, 56, 44],
            [2004, 3969, 70, 40],
            [2004, 3970, 44, 30],
            [2004, 3972, 142, 68],
            [2004, 3976, 17, 13],
            [2004, 3985, 23, 20],
            [2004, 3988, 22, 25],
            [2004, 3992, 66, 32],
            [2004, 3993, 10, 12],
            [2004, 4015, 48, 26],
            [2004, 4022, 44, 30],
            [2004, 4023, 27, 27],
            [2004, 4026, 26, 16],
            [2004, 4027, 65, 31],
            [2004, 4028, 22, 27],
            [2004, 4031, 16, 14],
            [2004, 4034, 56, 44],
            [2004, 4038, 65, 32],
            [2004, 4043, 17, 16],
            [2004, 4047, 39, 32],
            [2004, 4074, 17, 23],
            [2004, 4082, 60, 32],
            [2004, 4084, 11, 16],
            [2004, 4091, 37, 28],
            [2004, 4106, 41, 29],
            [2004, 4107, 61, 27],
            [2004, 4109, 17, 17],
            [2004, 4111, 16, 13],
            [2004, 4122, 46, 41],
            [2004, 4124, 33, 28],
            [2004, 4125, 12, 14],
            [2004, 4152, 87, 42],
            [2004, 4156, 16, 17],
            [2004, 4165, 32, 32],
            [2004, 4169, 26, 20],
            [2004, 4173, 11, 15],
            [2004, 4176, 10, 13],
            [2004, 4199, 73, 33],
            [2004, 4209, 36, 34],
            [2004, 4229, 23, 20],
            [2004, 4242, 27, 25],
            [2004, 4246, 11, 19],
            [2004, 4272, 41, 26],
            [2004, 4283, 25, 19],
            [2004, 4285, 25, 30],
            [2004, 4298, 34, 37],
            [2004, 4299, 31, 25],
            [2004, 4301, 47, 49],
            [2004, 4310, 28, 21],
            [2004, 4312, 44, 26],
            [2004, 4325, 53, 25],
            [2004, 4338, 25, 26],
            [2004, 4350, 19, 18],
            [2004, 4353, 23, 23],
            [2004, 4358, 12, 13],
            [2004, 4362, 72, 46],
            [2004, 4380, 15, 17],
            [2004, 4382, 88, 37],
            [2004, 4386, 13, 15],
            [2004, 4413, 11, 11],
            [2004, 4414, 14, 21],
            [2004, 4426, 10, 13],
            [2004, 4438, 43, 30],
            [2004, 4440, 39, 27],
            [2004, 4442, 13, 17],
            [2004, 4454, 18, 17],
            [2004, 4464, 43, 25],
            [2004, 4470, 23, 24],
            [2004, 4471, 18, 18],
            [2004, 4477, 26, 28],
            [2004, 4487, 20, 25],
            [2004, 4491, 42, 27],
            [2004, 4495, 25, 20],
            [2004, 4500, 18, 18],
            [2004, 4504, 53, 34],
            [2004, 4506, 17, 18],
            [2004, 4508, 25, 22],
            [2004, 4515, 50, 41],
            [2004, 4518, 43, 31],
            [2004, 4521, 42, 27],
            [2004, 4524, 27, 27],
            [2004, 4532, 26, 18],
            [2004, 4536, 19, 18],
            [2004, 4542, 28, 20],
            [2004, 4545, 42, 31],
            [2004, 4552, 14, 16],
            [2004, 4558, 26, 23],
            [2004, 4572, 26, 23],
            [2004, 4591, 31, 21],
            [2004, 4602, 20, 25],
            [2004, 4610, 58, 28],
            [2004, 4613, 33, 29],
            [2004, 4616, 21, 18],
            [2004, 4617, 110, 46],
            [2004, 4618, 24, 21],
            [2004, 4623, 14, 17],
            [2004, 4626, 29, 17],
            [2004, 4634, 27, 25],
            [2004, 4638, 93, 32],
            [2004, 4643, 20, 19],
            [2004, 4644, 13, 17],
            [2004, 4648, 36, 25],
            [2004, 4660, 58, 30],
            [2004, 4668, 52, 29],
            [2004, 4670, 49, 32],
            [2004, 4676, 13, 17],
            [2004, 4684, 20, 16],
            [2004, 4689, 36, 25],
            [2004, 4703, 10, 14],
            [2004, 4710, 8, 6],
            [2004, 4717, 18, 18],
            [2004, 4724, 25, 18],
            [2004, 4728, 22, 20],
            [2004, 4732, 58, 65],
            [2004, 4734, 14, 15],
            [2004, 4738, 34, 40],
            [2004, 4745, 20, 19],
            [2004, 4747, 49, 27],
            [2004, 4749, 38, 27],
            [2004, 4762, 39, 37],
            [2004, 4764, 22, 29],
            [2004, 4777, 20, 20],
            [2004, 4789, 45, 25],
            [2004, 4791, 20, 25],
            [2004, 4794, 21, 17],
            [2004, 4801, 10, 16],
            [2004, 4805, 15, 18],
            [2004, 4820, 44, 38],
            [2004, 4826, 16, 18],
            [2004, 4828, 63, 44],
            [2004, 4832, 12, 15],
            [2004, 4835, 22, 21],
            [2004, 4839, 29, 19],
            [2004, 4840, 47, 29],
            [2004, 4849, 18, 18],
            [2004, 4863, 39, 32],
            [2004, 4864, 18, 20],
            [2004, 4865, 28, 18],
            [2004, 4871, 15, 18],
            [2004, 4877, 22, 18],
            [2004, 4880, 17, 20],
            [2004, 4881, 29, 28],
            [2004, 4888, 41, 38],
            [2004, 4897, 15, 20],
            [2004, 4912, 10, 16],
            [2004, 4914, 28, 18],
            [2004, 4915, 18, 16],
            [2004, 4918, 20, 25],
            [2004, 4926, 47, 43],
            [2004, 4927, 16, 18],
            [2004, 4931, 17, 18],
            [2004, 4939, 22, 21],
            [2004, 4940, 36, 20],
            [2004, 4944, 13, 14],
            [2004, 4950, 52, 27],
            [2004, 4951, 30, 29],
            [2004, 4955, 37, 27],
            [2004, 4957, 29, 23],
            [2004, 4960, 88, 42],
            [2004, 4973, 26, 26],
            [2004, 4975, 26, 26],
            [2004, 4976, 11, 15],
            [2004, 4978, 54, 41],
            [2004, 4983, 18, 17],
            [2004, 4990, 37, 24],
            [2004, 4992, 23, 21],
            [2004, 4997, 24, 20],
            [2004, 4998, 70, 27],
            [2004, 5006, 76, 34],
            [2004, 5009, 18, 18],
            [2004, 5011, 50, 35],
            [2004, 5012, 36, 41],
            [2004, 5013, 16, 16],
            [2004, 5017, 26, 26],
            [2004, 5019, 42, 28],
            [2004, 5031, 10, 13],
            [2004, 5035, 27, 27],
            [2004, 5038, 11, 16],
            [2004, 5046, 45, 27],
            [2004, 5048, 29, 25],
            [2004, 5050, 16, 13],
            [2004, 5051, 11, 11],
            [2004, 5053, 27, 21],
            [2004, 5062, 26, 33],
            [2004, 5063, 19, 24],
            [2004, 5071, 25, 26],
            [2004, 5073, 54, 35],
            [2004, 5075, 21, 27],
            [2004, 5079, 16, 18],
            [2004, 5081, 36, 16],
            [2004, 5091, 74, 36],
            [2004, 5092, 11, 14],
            [2004, 5095, 14, 15],
            [2004, 5102, 19, 12],
            [2004, 5107, 90, 33],
            [2004, 5108, 19, 25],
            [2004, 5116, 32, 28],
            [2004, 5126, 26, 20],
            [2004, 5127, 17, 18],
            [2004, 5130, 50, 45],
            [2004, 5149, 19, 17],
            [2004, 5150, 49, 32],
            [2004, 5159, 64, 26],
            [2004, 5162, 21, 20],
            [2004, 5173, 35, 22],
            [2004, 5181, 17, 18],
            [2004, 5184, 30, 19],
            [2004, 5185, 26, 15],
            [2004, 5186, 12, 15],
            [2004, 5187, 12, 12],
            [2004, 5188, 11, 13],
            [2004, 5189, 17, 10],
            [2004, 5217, 44, 31],
            [2004, 5219, 17, 44],
            [2004, 5220, 14, 47],
            [2004, 5221, 11, 35],
            [2004, 5222, 15, 20],
            [2004, 5223, 11, 28],
            [2004, 5224, 15, 40],
            [2004, 5225, 15, 46],
            [2004, 5226, 12, 49],
            [2004, 5227, 28, 58],
            [2004, 5228, 19, 57],
            [2004, 5229, 11, 40],
            [2004, 5230, 15, 36],
            [2004, 5231, 12, 28],
            [2004, 5232, 18, 50],
            [2004, 5233, 23, 70],
            [2004, 5234, 10, 23],
            [2004, 5235, 35, 39],
            [2004, 5236, 15, 37],
            [2004, 5237, 23, 46],
            [2004, 5238, 15, 35],
            [2004, 5239, 22, 56],
            [2004, 5240, 18, 61],
            [2004, 5241, 26, 59],
            [2004, 5242, 18, 38],
            [2004, 5243, 25, 62],
            [2004, 5244, 19, 65],
            [2004, 5245, 24, 62],
            [2004, 5247, 29, 13],
            [2004, 5248, 30, 18],
            [2004, 5273, 24, 15],
            [2004, 5276, 25, 36],
            [2004, 5279, 18, 20],
            [2004, 5287, 12, 12],
            [2004, 5290, 19, 18],
            [2004, 5298, 11, 11],
            [2004, 5299, 16, 17],
            [2004, 5303, 28, 19],
            [2004, 5305, 22, 19],
            [2004, 5314, 18, 20],
            [2004, 5315, 17, 21],
            [2004, 5317, 30, 39],
            [2004, 5321, 20, 19],
            [2004, 5323, 13, 18],
            [2004, 5328, 16, 16],
            [2004, 5332, 17, 20],
            [2004, 5333, 11, 13],
            [2004, 5336, 13, 14],
            [2004, 5337, 15, 16],
            [2004, 5338, 23, 20],
            [2004, 5339, 19, 19],
            [2004, 5340, 22, 24],
            [2004, 5343, 13, 12],
            [2004, 5344, 33, 32],
            [2004, 5347, 17, 18],
            [2004, 5349, 19, 20],
            [2004, 5350, 17, 21],
            [2004, 5353, 15, 18],
            [2004, 5355, 17, 26],
            [2004, 5357, 20, 16],
            [2004, 5359, 16, 19],
            [2004, 5366, 23, 19],
            [2004, 5371, 26, 26],
            [2004, 5372, 19, 18],
            [2004, 5375, 15, 15],
            [2004, 5377, 14, 15],
            [2004, 5383, 20, 20],
            [2004, 5385, 24, 19],
            [2004, 5387, 14, 13],
            [2004, 5400, 14, 13],
            [2004, 5403, 19, 19],
            [2004, 5404, 19, 19],
            [2004, 5407, 17, 19],
            [2004, 5408, 16, 18],
            [2004, 5411, 18, 16],
            [2004, 5412, 18, 15],
            [2004, 5414, 11, 13],
            [2004, 5415, 29, 31],
            [2004, 5418, 22, 26],
            [2004, 5420, 15, 15],
            [2004, 5421, 14, 12],
            [2004, 5422, 20, 24],
            [2004, 5425, 16, 17],
            [2004, 5426, 16, 20],
            [2004, 5428, 16, 19],
            [2004, 5431, 21, 21],
            [2004, 5432, 20, 23],
            [2004, 5434, 13, 13],
            [2004, 5436, 16, 18],
            [2004, 5437, 23, 19],
            [2004, 5440, 25, 21],
            [2004, 5441, 22, 25],
            [2004, 5444, 21, 27],
            [2004, 5447, 17, 18],
            [2004, 5449, 20, 23],
            [2004, 5450, 21, 22],
            [2004, 5452, 19, 23],
            [2004, 5453, 24, 23],
            [2004, 5454, 12, 13],
            [2004, 5455, 19, 16],
            [2004, 5457, 13, 17],
            [2004, 5459, 19, 19],
            [2004, 5462, 18, 20],
            [2004, 5463, 12, 14],
            [2004, 5464, 16, 15],
            [2004, 5465, 19, 19],
            [2004, 5472, 17, 20],
            [2004, 5473, 15, 18],
            [2004, 5476, 14, 17],
            [2004, 5479, 18, 16],
            [2004, 5480, 26, 22],
            [2004, 5482, 15, 16],
            [2004, 5486, 18, 18],
            [2004, 5489, 23, 33],
            [2004, 5492, 21, 29],
            [2004, 5494, 20, 22],
            [2004, 5495, 21, 19],
            [2004, 5498, 29, 28],
            [2004, 5499, 23, 19],
            [2004, 5501, 21, 28],
            [2004, 5505, 15, 20],
            [2004, 5508, 19, 23],
            [2004, 5528, 16, 15],
            [2004, 5532, 19, 18],
            [2004, 5534, 14, 13],
            [2004, 5539, 15, 16],
            [2004, 5541, 22, 18],
            [2004, 5544, 18, 22],
            [2004, 5545, 15, 18],
            [2004, 5547, 24, 22],
            [2004, 5550, 16, 15],
            [2004, 5571, 19, 16],
            [2004, 5944, 7, 7],
            [2004, 5945, 8, 9],
            [2004, 5946, 6, 5],
            [2004, 5962, 68, 76],
            [2004, 5989, 221, 179],
            [2004, 5990, 221, 179],
            [2004, 5991, 221, 179],
            [2004, 5992, 221, 200],
            [2004, 5993, 221, 179],
            [2004, 5996, 45, 25],
            [2004, 6068, 45, 33],
            [2004, 6069, 48, 38],
            [2004, 6070, 48, 38],
            [2004, 6071, 29, 23],
            [2004, 6073, 30, 28],
            [2004, 6074, 35, 28],
            [2004, 6075, 48, 38],
            [2004, 6076, 35, 30],
            [2004, 6077, 30, 26],
            [2004, 6078, 35, 35],
            [2004, 6079, 37, 29],
            [2004, 6080, 35, 34],
            [2004, 6081, 24, 24],
            [2004, 6082, 35, 28],
            [2004, 6083, 32, 25],
            [2004, 6084, 43, 28],
            [2004, 6085, 38, 30],
            [2004, 6087, 83, 26],
            [2004, 6088, 34, 30],
            [2004, 6089, 30, 26],
            [2004, 6090, 48, 31],
            [2004, 6091, 29, 25],
            [2004, 6092, 32, 29],
            [2004, 6093, 35, 28],
            [2004, 6094, 35, 28],
            [2004, 6095, 24, 21],
            [2004, 6096, 32, 23],
            [2004, 6097, 37, 26],
            [2004, 6098, 32, 25],
            [2004, 6099, 43, 28],
            [2004, 6100, 35, 28],
            [2004, 6101, 35, 23],
            [2004, 6102, 24, 22],
            [2004, 6103, 32, 25],
            [2004, 6104, 38, 24],
            [2004, 6105, 43, 28],
            [2004, 6106, 27, 24],
            [2004, 6108, 35, 27],
            [2004, 6109, 21, 23],
            [2004, 6110, 32, 28],
            [2004, 6111, 15, 21],
            [2004, 6112, 29, 27],
            [2004, 6113, 23, 23],
            [2004, 6114, 23, 23],
            [2004, 6115, 23, 26],
            [2004, 6116, 31, 27],
            [2004, 6117, 26, 25],
            [2004, 6118, 31, 29],
            [2004, 6119, 29, 27],
            [2004, 6120, 21, 22],
            [2004, 6121, 28, 28],
            [2004, 6122, 29, 24],
            [2004, 6123, 23, 23],
            [2004, 6124, 31, 25],
            [2004, 6125, 26, 25],
            [2004, 6126, 28, 28],
            [2004, 6127, 28, 28],
            [2004, 6128, 24, 29],
            [2004, 6130, 29, 27],
            [2004, 6131, 32, 25],
            [2004, 6132, 35, 28],
            [2004, 6133, 32, 25],
            [2004, 6134, 32, 25],
            [2004, 6135, 70, 56],
            [2004, 6136, 61, 49],
            [2004, 6137, 18, 20],
            [2004, 6138, 26, 28],
            [2004, 6139, 30, 27],
            [2004, 6140, 21, 24],
            [2004, 6141, 30, 30],
            [2004, 6142, 24, 27],
            [2004, 6143, 26, 25],
            [2004, 6145, 31, 30],
            [2004, 6146, 15, 21],
            [2004, 6147, 21, 28],
            [2004, 6148, 21, 25],
            [2004, 6149, 28, 28],
            [2004, 6150, 16, 21],
            [2004, 6151, 21, 21],
            [2004, 6152, 19, 21],
            [2004, 6153, 20, 23],
            [2004, 6154, 28, 28],
            [2004, 6155, 21, 23],
            [2004, 6156, 24, 25],
            [2004, 6157, 33, 29],
            [2004, 6158, 24, 23],
            [2004, 6159, 32, 28],
            [2004, 6160, 21, 22],
            [2004, 6161, 16, 20],
            [2004, 6162, 18, 21],
            [2004, 6163, 43, 36],
            [2004, 6164, 30, 28],
            [2004, 6165, 26, 24],
            [2004, 6166, 40, 27],
            [2004, 6167, 43, 35],
            [2004, 6244, 60, 33],
            [2004, 6353, 40, 40],
            [2004, 6357, 40, 22],
            [2004, 6358, 91, 41],
            [2004, 6359, 20, 20],
            [2004, 6360, 74, 55],
            [2004, 6361, 74, 62],
            [2004, 6362, 50, 47],
            [2004, 6363, 50, 50],
            [2004, 6364, 74, 56],
            [2004, 6365, 86, 63],
            [2004, 6366, 86, 63],
            [2004, 6367, 46, 47],
            [2004, 6368, 74, 56],
            [2004, 6369, 53, 50],
            [2004, 6370, 73, 54],
            [2004, 6371, 74, 60],
            [2004, 6372, 86, 63],
            [2004, 6373, 86, 68],
            [2004, 6374, 74, 55],
            [2004, 6375, 82, 55],
            [2004, 6376, 53, 47],
            [2004, 6377, 81, 60],
            [2004, 6378, 50, 47],
            [2004, 6379, 53, 49],
            [2004, 6380, 53, 45],
            [2004, 6381, 53, 47],
            [2004, 6382, 74, 55],
            [2004, 6383, 53, 47],
            [2004, 6384, 74, 56],
            [2004, 6385, 74, 47],
            [2004, 6386, 74, 55],
            [2004, 6387, 73, 59],
            [2004, 6388, 74, 54],
            [2004, 6389, 86, 63],
            [2004, 6390, 74, 56],
            [2004, 6391, 48, 44],
            [2004, 6392, 74, 55],
            [2004, 6393, 81, 60],
            [2004, 6394, 86, 63],
            [2004, 6395, 74, 56],
            [2004, 6396, 86, 63],
            [2004, 6397, 74, 55],
            [2004, 6398, 92, 68],
            [2004, 6399, 86, 63],
            [2004, 6400, 70, 52],
            [2004, 6401, 53, 51],
            [2004, 6402, 86, 63],
            [2004, 6403, 92, 68],
            [2004, 6404, 86, 63],
            [2004, 6405, 86, 63],
            [2004, 6406, 74, 55],
            [2004, 6407, 74, 56],
            [2004, 6408, 74, 56],
            [2004, 6409, 74, 55],
            [2004, 6410, 74, 56],
            [2004, 6411, 68, 50],
            [2004, 6412, 74, 55],
            [2004, 6413, 92, 68],
            [2004, 6414, 82, 55],
            [2004, 6415, 74, 55],
            [2004, 6416, 86, 63],
            [2004, 6417, 86, 63],
            [2004, 6418, 92, 68],
            [2004, 6419, 86, 68],
            [2004, 6420, 92, 68],
            [2004, 6421, 74, 55],
            [2004, 6422, 74, 56],
            [2004, 6423, 27, 25],
            [2004, 6424, 53, 51],
            [2004, 6425, 53, 47],
            [2004, 6426, 74, 60],
            [2004, 6427, 92, 68],
            [2004, 6428, 82, 60],
            [2004, 6429, 92, 67],
            [2004, 6430, 50, 51],
            [2004, 6431, 74, 56],
            [2004, 6432, 74, 60],
            [2004, 6433, 44, 44],
            [2004, 6434, 74, 55],
            [2004, 6435, 51, 43],
            [2004, 6436, 82, 55],
            [2004, 6437, 86, 63],
            [2004, 6438, 74, 55],
            [2004, 6439, 74, 55],
            [2004, 6440, 82, 60],
            [2004, 6441, 69, 51],
            [2004, 6442, 48, 44],
            [2004, 6443, 74, 55],
            [2004, 6444, 60, 62],
            [2004, 6445, 74, 55],
            [2004, 6446, 86, 63],
            [2004, 6447, 47, 36],
            [2004, 6448, 74, 55],
            [2004, 6449, 86, 68],
            [2004, 6450, 82, 60],
            [2004, 6451, 86, 68],
            [2004, 6452, 82, 55],
            [2004, 6453, 74, 55],
            [2004, 6454, 74, 55],
            [2004, 6455, 74, 55],
            [2004, 6456, 74, 55],
            [2004, 6457, 31, 30],
            [2004, 6458, 22, 25],
            [2004, 6459, 92, 63],
            [2004, 6460, 82, 60],
            [2004, 6461, 74, 55],
            [2004, 6462, 73, 59],
            [2004, 6463, 74, 60],
            [2004, 6464, 92, 68],
            [2004, 6465, 86, 68],
            [2004, 6466, 73, 54],
            [2004, 6467, 80, 60],
            [2004, 6468, 86, 63],
            [2004, 6469, 74, 55],
            [2004, 6470, 74, 56],
            [2004, 6471, 74, 55],
            [2004, 6472, 86, 63],
            [2004, 6473, 86, 63],
            [2004, 6474, 74, 55],
            [2004, 6475, 74, 55],
            [2004, 6476, 74, 55],
            [2004, 6477, 101, 76],
            [2004, 6478, 74, 55],
            [2004, 6479, 74, 55],
            [2004, 6480, 74, 55],
            [2004, 6481, 86, 63],
            [2004, 6482, 86, 68],
            [2004, 6483, 74, 55],
            [2004, 6484, 53, 39],
            [2004, 6485, 69, 56],
            [2004, 6486, 86, 63],
            [2004, 6487, 74, 56],
            [2004, 6488, 74, 56],
            [2004, 6489, 74, 55],
            [2004, 6490, 74, 55],
            [2004, 6491, 74, 55],
            [2004, 6492, 26, 25],
            [2004, 6493, 74, 56],
            [2004, 6494, 26, 24],
            [2004, 6495, 69, 51],
            [2004, 6496, 74, 56],
            [2004, 6498, 92, 68],
            [2004, 6499, 82, 60],
            [2004, 6500, 53, 47],
            [2004, 6501, 74, 56],
            [2004, 6502, 46, 47],
            [2004, 6503, 74, 55],
            [2004, 6504, 74, 62],
            [2004, 6505, 74, 55],
            [2004, 6506, 74, 60],
            [2004, 6507, 86, 63],
            [2004, 6508, 86, 63],
            [2004, 6509, 74, 56],
            [2004, 6510, 92, 68],
            [2004, 6511, 74, 56],
            [2004, 6512, 74, 56],
            [2004, 6513, 20, 19],
            [2004, 6514, 72, 53],
            [2004, 6515, 74, 60],
            [2004, 6516, 53, 43],
            [2004, 6517, 29, 24],
            [2004, 6518, 74, 60],
            [2004, 6519, 81, 60],
            [2004, 6520, 92, 68],
            [2004, 6521, 42, 40],
            [2004, 6522, 74, 55],
            [2004, 6523, 92, 68],
            [2004, 6524, 82, 61],
            [2004, 6525, 74, 56],
            [2004, 6526, 86, 63],
            [2004, 6527, 74, 56],
            [2004, 6528, 74, 55],
            [2004, 6529, 81, 62],
            [2004, 6530, 70, 52],
            [2004, 6531, 86, 68],
            [2004, 6532, 74, 55],
            [2004, 6533, 74, 55],
            [2004, 6534, 74, 60],
            [2004, 6535, 86, 63],
            [2004, 6536, 29, 27],
            [2004, 6537, 86, 63],
            [2004, 6538, 86, 68],
            [2004, 6539, 74, 55],
            [2004, 6540, 86, 68],
            [2004, 6541, 86, 63],
            [2004, 6542, 86, 63],
            [2004, 6543, 86, 63],
            [2004, 6544, 86, 63],
            [2004, 6546, 86, 63],
            [2004, 6547, 92, 68],
            [2004, 6548, 86, 63],
            [2004, 6549, 86, 68],
            [2004, 6550, 86, 63],
            [2004, 6551, 86, 63],
            [2004, 6552, 86, 68],
            [2004, 6553, 86, 63],
            [2004, 6554, 86, 63],
            [2004, 6555, 86, 63],
            [2004, 6556, 86, 63],
            [2004, 6557, 86, 63],
            [2004, 6558, 74, 55],
            [2004, 6559, 86, 63],
            [2004, 6560, 74, 55],
            [2004, 6561, 86, 68],
            [2004, 6562, 86, 63],
            [2004, 6563, 86, 63],
            [2004, 6564, 86, 63],
            [2004, 6565, 81, 62],
            [2004, 6566, 74, 50],
            [2004, 6567, 86, 63],
            [2004, 6568, 74, 56],
            [2004, 6569, 74, 56],
            [2004, 6570, 86, 63],
            [2004, 6572, 86, 63],
            [2004, 6573, 74, 56],
            [2004, 6574, 74, 55],
            [2004, 6575, 73, 54],
            [2004, 6576, 74, 55],
            [2004, 6577, 74, 56],
            [2004, 6578, 74, 55],
            [2004, 6579, 86, 63],
            [2004, 6580, 74, 56],
            [2004, 6581, 80, 60],
            [2004, 6582, 74, 55],
            [2004, 6583, 81, 60],
            [2004, 6584, 101, 76],
            [2004, 6585, 74, 56],
            [2004, 6586, 74, 56],
            [2004, 6587, 74, 56],
            [2004, 6588, 74, 55],
            [2004, 6589, 74, 55],
            [2004, 6590, 101, 76],
            [2004, 6591, 86, 63],
            [2004, 6592, 86, 63],
            [2004, 6593, 86, 63],
            [2004, 6594, 86, 63],
            [2004, 6595, 74, 55],
            [2004, 6596, 74, 55],
            [2004, 6597, 86, 63],
            [2004, 6598, 86, 63],
            [2004, 6599, 82, 60],
            [2004, 6600, 74, 55],
            [2004, 6601, 86, 63],
            [2004, 6602, 74, 55],
            [2004, 6603, 50, 47],
            [2004, 6604, 86, 68],
            [2004, 6605, 74, 55],
            [2004, 6606, 74, 56],
            [2004, 6607, 81, 55],
            [2004, 6608, 74, 55],
            [2004, 6609, 74, 55],
            [2004, 6610, 74, 55],
            [2004, 6611, 50, 47],
            [2004, 6612, 74, 60],
            [2004, 6613, 74, 55],
            [2004, 6614, 29, 27],
            [2004, 6615, 74, 56],
            [2004, 6616, 74, 55],
            [2004, 6617, 30, 28],
            [2004, 6618, 74, 56],
            [2004, 6619, 86, 63],
            [2004, 6620, 86, 63],
            [2004, 6621, 74, 55],
            [2004, 6622, 74, 56],
            [2004, 6623, 82, 60],
            [2004, 6624, 92, 63],
            [2004, 6625, 86, 63],
            [2004, 6626, 92, 68],
            [2004, 6627, 74, 55],
            [2004, 6628, 86, 68],
            [2004, 6629, 50, 51],
            [2004, 6630, 53, 51],
            [2004, 6631, 40, 40],
            [2004, 6633, 27, 27],
            [2004, 6634, 32, 28],
            [2004, 6635, 38, 30],
            [2004, 6636, 52, 42],
            [2004, 6637, 43, 28],
            [2004, 6638, 48, 33],
            [2004, 6639, 38, 35],
            [2004, 6640, 25, 65],
            [2004, 6643, 50, 27],
            [2004, 6649, 43, 29],
            [2004, 6650, 43, 28],
            [2004, 6651, 30, 21],
            [2004, 6652, 39, 29],
            [2004, 6653, 40, 32],
            [2004, 6654, 29, 27],
            [2004, 6655, 29, 23],
            [2004, 6656, 31, 27],
            [2004, 6657, 38, 30],
            [2004, 6660, 32, 22],
            [2004, 6661, 26, 25],
            [2004, 6662, 35, 29],
            [2004, 6663, 29, 27],
            [2004, 6664, 34, 30],
            [2004, 6665, 28, 28],
            [2004, 6666, 28, 25],
            [2004, 6667, 29, 27],
            [2004, 6668, 29, 21],
            [2004, 6669, 37, 30],
            [2004, 6670, 30, 26],
            [2004, 6671, 39, 27],
            [2004, 6672, 32, 24],
            [2004, 6673, 35, 25],
            [2004, 6674, 31, 29],
            [2004, 6675, 30, 26],
            [2004, 6676, 40, 35],
            [2004, 6677, 28, 28],
            [2004, 6678, 30, 26],
            [2004, 6679, 61, 49],
            [2004, 6680, 27, 24],
            [2004, 6682, 26, 24],
            [2004, 6683, 28, 28],
            [2004, 6684, 27, 30],
            [2004, 6685, 23, 25],
            [2004, 6686, 21, 24],
            [2004, 6687, 23, 26],
            [2004, 6688, 21, 24],
            [2004, 6689, 23, 26],
            [2004, 6690, 21, 24],
            [2004, 6697, 33, 27],
            [2004, 6699, 25, 78],
            [2004, 6700, 80, 38],
            [2004, 6701, 75, 45],
            [2004, 6702, 35, 23],
            [2004, 6704, 90, 48],
            [2004, 6715, 51, 38],
            [2004, 6716, 30, 32],
            [2004, 6718, 31, 55],
            [2004, 6722, 35, 32],
            [2004, 6723, 85, 50],
            [2004, 6726, 45, 70],
            [2004, 6728, 55, 35],
            [2004, 6734, 70, 45],
            [2004, 6737, 31, 90],
            [2004, 6738, 75, 53],
            [2004, 6741, 17, 15],
            [2004, 6748, 26, 24],
            [2004, 6749, 27, 26],
            [2004, 6750, 39, 36],
            [2004, 6752, 21, 24],
            [2004, 6753, 33, 30],
            [2004, 6754, 32, 28],
            [2004, 6755, 38, 37],
            [2004, 6756, 33, 33],
            [2004, 6757, 29, 28],
            [2004, 6758, 33, 39],
            [2004, 6759, 21, 24],
            [2004, 6760, 38, 37],
            [2004, 6761, 39, 36],
            [2004, 6762, 33, 33],
            [2004, 6763, 24, 21],
            [2004, 6764, 31, 33],
            [2004, 6766, 48, 39],
            [2004, 6767, 32, 27],
            [2004, 6768, 31, 29],
            [2004, 6769, 38, 44],
            [2004, 6770, 34, 36],
            [2004, 6771, 34, 34],
            [2004, 6772, 27, 31],
            [2004, 6773, 42, 39],
            [2004, 6777, 44, 39],
            [2004, 6778, 28, 28],
            [2004, 6779, 34, 36],
            [2004, 6780, 35, 34],
            [2004, 6781, 40, 35],
            [2004, 6782, 61, 46],
            [2004, 6783, 44, 39],
            [2004, 6784, 33, 33],
            [2004, 6785, 34, 32],
            [2004, 6786, 34, 36],
            [2004, 6787, 31, 35],
            [2004, 6789, 39, 36],
            [2004, 6790, 35, 107],
            [2004, 6791, 95, 90],
            [2004, 6794, 21, 40],
            [2004, 6795, 46, 75],
            [2004, 6798, 35, 28],
            [2004, 6803, 31, 81],
            [2004, 6804, 50, 107],
            [2004, 6805, 80, 140],
            [2004, 6806, 30, 73],
            [2004, 6807, 35, 47],
            [2004, 6808, 21, 40],
            [2004, 6812, 176, 80],
            [2004, 6813, 31, 70],
            [2004, 6814, 134, 110],
            [2004, 6816, 90, 100],
            [2004, 6818, 18, 20],
            [2004, 6819, 34, 43],
            [2004, 6820, 33, 33],
            [2004, 6821, 35, 41],
            [2004, 6822, 45, 44],
            [2004, 6823, 32, 36],
            [2004, 6833, 75, 62],
            [2004, 6834, 160, 110],
            [2004, 6835, 310, 150],
            [2004, 6836, 40, 70],
            [2004, 6837, 21, 28],
            [2004, 6838, 150, 100],
            [2004, 6841, 29, 21],
            [2004, 6845, 31, 65],
            [2004, 6846, 38, 59],
            [2004, 6847, 40, 45],
            [2004, 6848, 40, 21],
            [2004, 6849, 78, 48],
            [2004, 6850, 45, 53],
            [2004, 6851, 21, 46],
            [2004, 6852, 90, 132],
            [2004, 6853, 31, 55],
            [2004, 6854, 160, 84],
            [2004, 6855, 40, 40],
            [2004, 6856, 30, 56],
            [2004, 6857, 35, 78],
            [2004, 6858, 50, 55],
            [2004, 6859, 63, 58],
            [2004, 6860, 25, 31],
            [2004, 6861, 30, 50],
            [2004, 6862, 35, 40],
            [2004, 6867, 12, 19],
            [2004, 6868, 12, 15],
            [2004, 6869, 13, 15],
            [2004, 6870, 14, 18],
            [2004, 6871, 14, 15],
            [2004, 6872, 12, 17],
            [2004, 6873, 18, 17],
            [2004, 6874, 15, 17],
            [2004, 6875, 15, 17],
            [2004, 6876, 15, 16],
            [2004, 6877, 16, 17],
            [2004, 6878, 14, 15],
            [2004, 6879, 14, 17],
            [2004, 6880, 18, 20],
            [2004, 6881, 15, 13],
            [2004, 6882, 15, 18],
            [2004, 6883, 14, 18],
            [2004, 6910, 60, 48],
            [2004, 6911, 65, 51],
            [2004, 6912, 20, 12],
            [2004, 6913, 58, 45],
            [2004, 6914, 12, 12],
            [2004, 6915, 39, 30],
            [2004, 6917, 28, 31],
            [2004, 6918, 30, 25],
            [2004, 6919, 35, 36],
            [2004, 6920, 21, 20],
            [2004, 6921, 47, 34],
            [2004, 6922, 12, 11],
            [2004, 6923, 51, 36],
            [2004, 6925, 41, 37],
            [2004, 6926, 57, 30],
            [2004, 6927, 65, 35],
            [2004, 6928, 19, 18],
            [2004, 6929, 54, 37],
            [2004, 6930, 30, 20],
            [2004, 6931, 39, 37],
            [2004, 6932, 19, 14],
            [2004, 6933, 28, 25],
            [2004, 6934, 18, 15],
            [2004, 6935, 45, 38],
            [2004, 6936, 22, 23],
            [2004, 6937, 47, 37],
            [2004, 6938, 18, 14],
            [2004, 6939, 48, 35],
            [2004, 6940, 12, 11],
            [2004, 6941, 28, 22],
            [2004, 6942, 20, 17],
            [2004, 6943, 75, 54],
            [2004, 6944, 11, 11],
            [2004, 6945, 50, 30],
            [2004, 6946, 56, 31],
            [2004, 6947, 65, 44],
            [2004, 6948, 12, 11],
            [2004, 6949, 47, 35],
            [2004, 6950, 13, 11],
            [2004, 6951, 50, 38],
            [2004, 6952, 52, 24],
            [2004, 6953, 59, 32],
            [2004, 6954, 27, 16],
            [2004, 6955, 47, 35],
            [2004, 6957, 66, 55],
            [2004, 6958, 13, 11],
            [2004, 6959, 47, 37],
            [2004, 6960, 15, 15],
            [2004, 6961, 45, 24],
            [2004, 6962, 13, 11],
            [2004, 6965, 9, 10],
            [2004, 6966, 21, 35],
            [2004, 6967, 18, 39],
            [2004, 6968, 37, 65],
            [2004, 6969, 18, 34],
            [2004, 6970, 23, 40],
            [2004, 7005, 14, 14],
            [2004, 7006, 32, 30],
            [2004, 7007, 57, 27],
            [2004, 7008, 56, 28],
            [2004, 7011, 10, 10],
            [2004, 7012, 22, 25],
            [2004, 7013, 21, 19],
            [2004, 7014, 14, 9],
            [2004, 7015, 8, 8],
            [2004, 7019, 11, 9],
            [2004, 7021, 12, 11],
            [2004, 7022, 25, 30],
            [2004, 7023, 16, 18],
            [2004, 7024, 26, 30],
            [2004, 7026, 26, 20],
            [2004, 7027, 17, 17],
            [2004, 7028, 39, 37],
            [2004, 7029, 37, 27],
            [2004, 7030, 52, 36],
            [2004, 7031, 15, 19],
            [2004, 7032, 30, 20],
            [2004, 7033, 25, 21],
            [2004, 7034, 32, 28],
            [2004, 7035, 11, 12],
            [2004, 7036, 30, 29],
            [2004, 7037, 26, 26],
            [2004, 7038, 32, 35],
            [2004, 7039, 22, 14],
            [2004, 7040, 28, 26],
            [2004, 7042, 54, 31],
            [2004, 7043, 19, 26],
            [2004, 7044, 27, 25],
            [2004, 7045, 33, 22],
            [2004, 7046, 51, 36],
            [2004, 7048, 27, 21],
            [2004, 7049, 49, 36],
            [2004, 7050, 17, 14],
            [2004, 7051, 54, 39],
            [2004, 7052, 15, 18],
            [2004, 7053, 49, 39],
            [2004, 7054, 17, 15],
            [2004, 7055, 35, 25],
            [2004, 7056, 13, 14],
            [2004, 7057, 58, 39],
            [2004, 7058, 27, 17],
            [2004, 7059, 54, 31],
            [2004, 7060, 27, 18],
            [2004, 7061, 49, 39],
            [2004, 7062, 16, 13],
            [2004, 7063, 50, 35],
            [2004, 7064, 27, 18],
            [2004, 7065, 41, 39],
            [2004, 7066, 12, 12],
            [2004, 7067, 50, 39],
            [2004, 7068, 71, 29],
            [2004, 7069, 77, 51],
            [2004, 7070, 34, 30],
            [2004, 7071, 56, 38],
            [2004, 7072, 10, 11],
            [2004, 7073, 28, 27],
            [2004, 7074, 17, 15],
            [2004, 7075, 56, 54],
            [2004, 7076, 28, 21],
            [2004, 7077, 38, 28],
            [2004, 7078, 11, 11],
            [2004, 7079, 35, 21],
            [2004, 7080, 40, 34],
            [2004, 7081, 67, 49],
            [2004, 7082, 20, 20],
            [2004, 7083, 48, 37],
            [2004, 7084, 52, 25],
            [2004, 7085, 60, 37],
            [2004, 7086, 12, 14],
            [2004, 7087, 42, 34],
            [2004, 7088, 54, 29],
            [2004, 7089, 62, 37],
            [2004, 7090, 18, 12],
            [2004, 7091, 54, 37],
            [2004, 7092, 55, 45],
            [2004, 7093, 67, 55],
            [2004, 7094, 48, 32],
            [2004, 7095, 55, 40],
            [2004, 7096, 27, 22],
            [2004, 7097, 38, 30],
            [2004, 7098, 26, 25],
            [2004, 7099, 51, 38],
            [2004, 7100, 15, 13],
            [2004, 7101, 19, 17],
            [2004, 7156, 17, 18],
            [2004, 7259, 83, 52],
            [2004, 7260, 106, 82],
            [2004, 7261, 84, 67],
            [2004, 7262, 70, 74],
            [2004, 7263, 96, 79],
            [2004, 7264, 84, 88],
            [2004, 7265, 88, 72],
            [2004, 7266, 112, 83],
            [2004, 7267, 84, 68],
            [2004, 7268, 111, 82],
            [2004, 7269, 111, 82],
            [2004, 7270, 80, 50],
            [2004, 7271, 66, 61],
            [2004, 7272, 107, 79],
            [2004, 7273, 86, 90],
            [2004, 7274, 105, 76],
            [2004, 7275, 91, 76],
            [2004, 7276, 59, 49],
            [2004, 7277, 86, 69],
            [2004, 7278, 71, 75],
            [2004, 7279, 92, 65],
            [2004, 7280, 113, 84],
            [2004, 7281, 83, 66],
            [2004, 7282, 69, 72],
            [2004, 7283, 13, 19],
            [2004, 7284, 11, 10],
            [2004, 7285, 12, 11],
            [2004, 7286, 15, 20],
            [2004, 7287, 13, 23],
            [2004, 7288, 28, 28],
            [2004, 7289, 26, 21],
            [2004, 7290, 45, 31],
            [2004, 7291, 34, 28],
            [2004, 7292, 33, 34],
            [2004, 7293, 24, 21],
            [2004, 7294, 21, 20],
            [2004, 7295, 13, 14],
            [2004, 7296, 23, 21],
            [2004, 7297, 25, 22],
            [2004, 7298, 15, 16],
            [2004, 7299, 16, 18],
            [2004, 7300, 18, 27],
            [2004, 7301, 13, 24],
            [2004, 7302, 39, 43],
            [2004, 7303, 75, 72],
            [2004, 7304, 30, 32],
            [2004, 7305, 39, 39],
            [2004, 7306, 30, 33],
            [2004, 7307, 47, 50],
            [2004, 7308, 38, 41],
            [2004, 7309, 31, 33],
            [2004, 7310, 79, 66],
            [2004, 7311, 66, 64],
            [2004, 7312, 37, 38],
            [2004, 7313, 99, 71],
            [2004, 7314, 80, 61],
            [2004, 7315, 75, 57],
            [2004, 7316, 81, 61],
            [2004, 7317, 82, 62],
            [2004, 7318, 80, 62],
            [2004, 7319, 104, 75],
            [2004, 7320, 78, 59],
            [2004, 7321, 101, 76],
            [2004, 7322, 80, 60],
            [2004, 7323, 94, 70],
            [2004, 7324, 99, 71],
            [2004, 7325, 83, 62],
            [2004, 7326, 81, 61],
            [2004, 7327, 96, 71],
            [2004, 7328, 25, 29],
            [2004, 7329, 47, 44],
            [2004, 7330, 29, 29],
            [2004, 7331, 29, 29],
            [2004, 7332, 24, 27],
            [2004, 7333, 50, 56],
            [2004, 7337, 15, 12],
            [2004, 7342, 13, 10],
            [2004, 7343, 15, 8],
            [2004, 7344, 11, 9],
            [2004, 7348, 15, 8],
            [2004, 7352, 12, 11],
            [2004, 7354, 26, 15],
            [2004, 7356, 14, 14],
            [2004, 7357, 24, 15],
            [2004, 7358, 14, 10],
            [2004, 7359, 24, 15],
            [2004, 7360, 17, 10],
            [2004, 7362, 17, 12],
            [2004, 7363, 12, 11],
            [2004, 7364, 15, 11],
            [2004, 7367, 15, 12],
            [2004, 7370, 11, 10],
            [2004, 7371, 13, 11],
            [2004, 7372, 13, 10],
            [2004, 7373, 13, 10],
            [2004, 7374, 11, 8],
            [2004, 7375, 12, 8],
            [2004, 7376, 7, 8],
            [2004, 7377, 11, 8],
            [2004, 7378, 20, 18],
            [2004, 7379, 30, 23],
            [2004, 7396, 28, 27],
            [2004, 7397, 45, 37],
            [2004, 7398, 28, 29],
            [2004, 7399, 23, 26],
            [2004, 7400, 45, 41],
            [2004, 7401, 23, 26],
            [2004, 7402, 53, 60],
            [2004, 7403, 19, 22],
            [2004, 7404, 56, 43],
            [2004, 7405, 27, 28],
            [2004, 7406, 43, 46],
            [2004, 7407, 29, 28],
            [2004, 7408, 45, 49],
            [2004, 7410, 22, 38],
            [2004, 7411, 53, 49],
            [2004, 7413, 11, 14],
            [2004, 7414, 21, 35],
            [2004, 7415, 11, 16],
            [2004, 7416, 27, 33],
            [2004, 7417, 23, 20],
            [2004, 7420, 29, 32],
            [2004, 7421, 27, 29],
            [2004, 7423, 57, 64],
            [2004, 7433, 80, 58],
            [2004, 7434, 100, 100],
            [2004, 7435, 43, 80],
            [2004, 7436, 60, 82],
            [2004, 7437, 19, 18],
            [2004, 7438, 38, 31],
            [2004, 7441, 23, 15],
            [2004, 7442, 43, 21],
            [2004, 7443, 80, 115],
            [2004, 7444, 70, 115],
            [2004, 7445, 35, 78],
            [2004, 7446, 46, 85],
            [2004, 7447, 20, 19],
            [2004, 7448, 39, 33],
            [2004, 7449, 20, 20],
            [2004, 7450, 21, 21],
            [2004, 7451, 14, 15],
            [2004, 7452, 23, 17],
            [2004, 7453, 52, 29],
            [2004, 7454, 16, 17],
            [2004, 7455, 24, 22],
            [2004, 7456, 73, 53],
            [2004, 7457, 57, 51],
            [2004, 7458, 38, 35],
            [2004, 7459, 57, 51],
            [2004, 7460, 57, 56],
            [2004, 7461, 38, 34],
            [2004, 7462, 43, 39],
            [2004, 7463, 48, 45],
            [2004, 7464, 62, 45],
            [2004, 7465, 53, 39],
            [2004, 7466, 48, 35],
            [2004, 7467, 57, 51],
            [2004, 7468, 43, 39],
            [2004, 7469, 55, 42],
            [2004, 7470, 68, 49],
            [2004, 7471, 81, 59],
            [2004, 7472, 30, 61],
            [2004, 7473, 38, 39],
            [2004, 7474, 57, 51],
            [2004, 7475, 57, 51],
            [2004, 7476, 45, 41],
            [2004, 7477, 41, 37],
            [2004, 7478, 43, 40],
            [2004, 7479, 43, 39],
            [2004, 7480, 57, 45],
            [2004, 7481, 38, 40],
            [2004, 7482, 48, 35],
            [2004, 7483, 57, 51],
            [2004, 7484, 45, 45],
            [2004, 7485, 83, 61],
            [2004, 7486, 62, 45],
            [2004, 7487, 45, 41],
            [2004, 7488, 53, 39],
            [2004, 7489, 65, 42],
            [2004, 7490, 43, 39],
            [2004, 7491, 53, 40],
            [2004, 7492, 63, 46],
            [2004, 7493, 48, 43],
            [2004, 7494, 48, 43],
            [2004, 7495, 57, 51],
            [2004, 7496, 83, 61],
            [2004, 7497, 53, 39],
            [2004, 7498, 38, 40],
            [2004, 7499, 43, 34],
            [2004, 7500, 51, 45],
            [2004, 7501, 62, 45],
            [2004, 7502, 53, 39],
            [2004, 7503, 58, 43],
            [2004, 7504, 56, 40],
            [2004, 7505, 48, 43],
            [2004, 7506, 62, 45],
            [2004, 7507, 46, 41],
            [2004, 7508, 53, 40],
            [2004, 7509, 57, 51],
            [2004, 7510, 57, 51],
            [2004, 7511, 62, 45],
            [2004, 7512, 57, 51],
            [2004, 7513, 53, 39],
            [2004, 7514, 100, 75],
            [2004, 7515, 58, 42],
            [2004, 7516, 57, 51],
            [2004, 7517, 83, 61],
            [2004, 7518, 62, 45],
            [2004, 7519, 48, 43],
            [2004, 7520, 48, 44],
            [2004, 7521, 38, 39],
            [2004, 7522, 68, 49],
            [2004, 7523, 48, 45],
            [2004, 7524, 71, 64],
            [2004, 7525, 57, 51],
            [2004, 7526, 55, 40],
            [2004, 7527, 38, 39],
            [2004, 7528, 73, 53],
            [2004, 7529, 83, 75],
            [2004, 7530, 68, 49],
            [2004, 7531, 45, 45],
            [2004, 7532, 57, 51],
            [2004, 7533, 73, 53],
            [2004, 7534, 83, 75],
            [2004, 7535, 48, 44],
            [2004, 7536, 68, 49],
            [2004, 7537, 60, 44],
            [2004, 7538, 73, 53],
            [2004, 7539, 48, 45],
            [2004, 7540, 73, 53],
            [2004, 7541, 58, 42],
            [2004, 7542, 73, 53],
            [2004, 7543, 57, 42],
            [2004, 7544, 60, 44],
            [2004, 7545, 45, 41],
            [2004, 7546, 53, 39],
            [2004, 7547, 53, 39],
            [2004, 7548, 51, 45],
            [2004, 7549, 57, 51],
            [2004, 7550, 43, 39],
            [2004, 7551, 43, 39],
            [2004, 7552, 43, 39],
            [2004, 7553, 48, 44],
            [2004, 7554, 78, 66],
            [2004, 7555, 73, 56],
            [2004, 7556, 57, 51],
            [2004, 7557, 83, 61],
            [2004, 7558, 38, 34],
            [2004, 7559, 53, 39],
            [2004, 7560, 43, 39],
            [2004, 7561, 83, 61],
            [2004, 7562, 83, 61],
            [2004, 7563, 68, 49],
            [2004, 7564, 57, 42],
            [2004, 7565, 48, 45],
            [2004, 7566, 48, 43],
            [2004, 7567, 57, 51],
            [2004, 7568, 48, 44],
            [2004, 7569, 48, 44],
            [2004, 7570, 48, 43],
            [2004, 7571, 48, 43],
            [2004, 7572, 83, 61],
            [2004, 7573, 57, 45],
            [2004, 7574, 48, 43],
            [2004, 7575, 62, 45],
            [2004, 7576, 62, 45],
            [2004, 7577, 68, 49],
            [2004, 7578, 48, 45],
            [2004, 7579, 68, 49],
            [2004, 7580, 68, 49],
            [2004, 7581, 58, 43],
            [2004, 7582, 58, 48],
            [2004, 7583, 57, 51],
            [2004, 7584, 45, 41],
            [2004, 7585, 46, 42],
            [2004, 7586, 83, 61],
            [2004, 7587, 51, 45],
            [2004, 7588, 48, 45],
            [2004, 7589, 83, 61],
            [2004, 7590, 57, 51],
            [2004, 7591, 53, 40],
            [2004, 7592, 68, 49],
            [2004, 7593, 60, 44],
            [2004, 7594, 48, 43],
            [2004, 7595, 48, 45],
            [2004, 7596, 43, 39],
            [2004, 7597, 48, 45],
            [2004, 7598, 62, 45],
            [2004, 7599, 57, 51],
            [2004, 7600, 57, 51],
            [2004, 7601, 43, 39],
            [2004, 7602, 41, 37],
            [2004, 7603, 57, 51],
            [2004, 7604, 57, 51],
            [2004, 7605, 57, 51],
            [2004, 7606, 57, 45],
            [2004, 7607, 68, 49],
            [2004, 7608, 43, 39],
            [2004, 7609, 57, 51],
            [2004, 7610, 43, 40],
            [2004, 7611, 41, 51],
            [2004, 7612, 57, 49],
            [2004, 7613, 48, 45],
            [2004, 7614, 53, 43],
            [2004, 7615, 68, 49],
            [2004, 7616, 58, 42],
            [2004, 7617, 53, 40],
            [2004, 7618, 58, 42],
            [2004, 7619, 57, 51],
            [2004, 7620, 51, 45],
            [2004, 7621, 57, 51],
            [2004, 7622, 68, 49],
            [2004, 7623, 48, 43],
            [2004, 7624, 73, 53],
            [2004, 7625, 43, 40],
            [2004, 7626, 58, 42],
            [2004, 7627, 46, 41],
            [2004, 7628, 68, 49],
            [2004, 7629, 43, 40],
            [2004, 7630, 45, 41],
            [2004, 7631, 54, 48],
            [2004, 7632, 57, 42],
            [2004, 7633, 43, 40],
            [2004, 7634, 15, 22],
            [2004, 7635, 14, 19],
            [2004, 7636, 18, 23],
            [2004, 7637, 28, 27],
            [2004, 7638, 24, 20],
            [2004, 7639, 11, 13],
            [2004, 7640, 10, 11],
            [2004, 7641, 14, 17],
            [2004, 7642, 30, 32],
            [2004, 7643, 18, 18],
            [2004, 7644, 28, 36],
            [2004, 7645, 18, 21],
            [2004, 7646, 25, 24],
            [2004, 7647, 31, 22],
            [2004, 7648, 11, 11],
            [2004, 7649, 11, 12],
            [2004, 7650, 17, 18],
            [2004, 7651, 13, 12],
            [2004, 7652, 14, 12],
            [2004, 7653, 41, 31],
            [2004, 7654, 12, 13],
            [2004, 7655, 14, 14],
            [2004, 7656, 13, 13],
            [2004, 7657, 23, 24],
            [2004, 7658, 21, 25],
            [2004, 7659, 13, 17],
            [2004, 7661, 10, 10],
            [2004, 7662, 17, 14],
            [2004, 7663, 17, 19],
            [2004, 7664, 21, 27],
            [2004, 7665, 29, 36],
            [2004, 7666, 13, 14],
            [2004, 7667, 14, 16],
            [2004, 7668, 13, 12],
            [2004, 7669, 11, 8],
            [2004, 7672, 9, 9],
            [2004, 7673, 8, 7],
            [2004, 7674, 17, 16],
            [2004, 7676, 6, 7],
            [2004, 7677, 5, 6],
            [2004, 7678, 10, 8],
            [2004, 7679, 11, 9],
            [2004, 7680, 37, 20],
            [2004, 7681, 5, 3],
            [2004, 7682, 16, 13],
            [2004, 7683, 3, 3],
            [2004, 7684, 15, 14],
            [2004, 7685, 12, 11],
            [2004, 7686, 21, 19],
            [2004, 7687, 5, 4],
            [2004, 7688, 15, 14],
            [2004, 7690, 7, 8],
            [2004, 7691, 24, 24],
            [2004, 7692, 10, 8],
            [2004, 7693, 9, 9],
            [2004, 7694, 9, 9],
            [2004, 7695, 28, 20],
            [2004, 7696, 3, 3],
            [2004, 7697, 16, 12],
            [2004, 7698, 9, 8],
            [2004, 7699, 12, 14],
            [2004, 7700, 14, 10],
            [2004, 7701, 9, 8],
            [2004, 7702, 22, 13],
            [2004, 7703, 12, 13],
            [2004, 7705, 23, 13],
            [2004, 7706, 11, 10],
            [2004, 7707, 12, 10],
            [2004, 7708, 9, 7],
            [2004, 7709, 12, 14],
            [2004, 7710, 6, 5],
            [2004, 7711, 15, 11],
            [2004, 7713, 28, 12],
            [2004, 7714, 10, 9],
            [2004, 7715, 29, 33],
            [2004, 7716, 27, 28],
            [2004, 7717, 49, 54],
            [2004, 7718, 29, 29],
            [2004, 7719, 24, 27],
            [2004, 7720, 54, 62],
            [2004, 7721, 30, 29],
            [2004, 7722, 35, 30],
            [2004, 7723, 22, 25],
            [2004, 7724, 46, 49],
            [2004, 7725, 17, 21],
            [2004, 7726, 27, 30],
            [2004, 7727, 32, 32],
            [2004, 7728, 48, 44],
            [2004, 7729, 31, 30],
            [2004, 7730, 21, 24],
            [2004, 7731, 48, 52],
            [2004, 7732, 26, 30],
            [2004, 7733, 45, 50],
            [2004, 7734, 41, 34],
            [2004, 7735, 61, 57],
            [2004, 7736, 23, 26],
            [2004, 7737, 42, 38],
            [2004, 7738, 22, 25],
            [2004, 7739, 35, 40],
            [2004, 7740, 23, 26],
            [2004, 7741, 42, 46],
            [2004, 7742, 44, 43],
            [2004, 7743, 29, 28],
            [2004, 7744, 47, 51],
            [2004, 7745, 49, 39],
            [2004, 7746, 30, 29],
            [2004, 7747, 36, 42],
            [2004, 7748, 47, 44],
            [2004, 7749, 31, 32],
            [2004, 7750, 47, 52],
            [2004, 7751, 41, 34],
            [2004, 7752, 60, 55],
            [2004, 7753, 44, 41],
            [2004, 7754, 31, 32],
            [2004, 7755, 24, 26],
            [2004, 7756, 61, 42],
            [2004, 7757, 36, 103],
            [2004, 7758, 65, 110],
            [2004, 7759, 31, 29],
            [2004, 7760, 65, 48],
            [2004, 7761, 50, 61],
            [2004, 7762, 118, 90],
            [2004, 7763, 14, 19],
            [2004, 7764, 13, 15],
            [2004, 7765, 15, 21],
            [2004, 7766, 10, 18],
            [2004, 7767, 24, 29],
            [2004, 7768, 10, 19],
            [2004, 7769, 34, 34],
            [2004, 7770, 46, 36],
            [2004, 7771, 14, 16],
            [2004, 7772, 14, 17],
            [2004, 7773, 22, 24],
            [2004, 7774, 12, 21],
            [2004, 7775, 36, 36],
            [2004, 7776, 14, 29],
            [2004, 7777, 21, 33],
            [2004, 7778, 9, 12],
            [2004, 7779, 15, 20],
            [2004, 7780, 17, 18],
            [2004, 7781, 23, 27],
            [2004, 7782, 27, 25],
            [2004, 7783, 28, 23],
            [2004, 7784, 13, 27],
            [2004, 7785, 22, 36],
            [2004, 7786, 14, 16],
            [2004, 7787, 23, 27],
            [2004, 7788, 18, 20],
            [2004, 7789, 20, 26],
            [2004, 7790, 19, 25],
            [2004, 7791, 37, 36],
            [2004, 7792, 16, 21],
            [2004, 7793, 33, 32],
            [2004, 7795, 171, 98],
            [2004, 7796, 237, 75],
            [2004, 7797, 256, 85],
            [2004, 7798, 164, 32],
            [2004, 7799, 175, 76],
            [2004, 7800, 100, 37],
            [2004, 7801, 213, 78],
            [2004, 7802, 40, 29],
            [2004, 7803, 394, 126],
            [2004, 7804, 182, 91],
            [2004, 7805, 158, 55],
            [2004, 7806, 160, 89],
            [2004, 7807, 106, 29],
            [2004, 7808, 180, 42],
            [2004, 7809, 120, 77],
            [2004, 7810, 234, 119],
            [2004, 7811, 586, 120],
            [2004, 7812, 39, 31],
            [2004, 7813, 90, 33],
            [2004, 7815, 88, 34],
            [2004, 7816, 325, 112],
            [2004, 7817, 56, 41],
            [2004, 7818, 86, 81],
            [2004, 7819, 43, 72],
            [2004, 7820, 96, 43],
            [2004, 7821, 213, 71],
            [2004, 7822, 142, 73],
            [2004, 7823, 47, 39],
            [2004, 7824, 208, 73],
            [2004, 7825, 170, 75],
            [2004, 7826, 120, 91],
            [2004, 7827, 173, 66],
            [2004, 7828, 173, 118],
            [2004, 7829, 103, 37],
            [2004, 7830, 147, 60],
            [2004, 7831, 165, 37],
            [2004, 7832, 187, 94],
            [2004, 7833, 63, 30],
            [2004, 7834, 175, 90],
            [2004, 7835, 128, 33],
            [2004, 7836, 177, 86],
            [2004, 7837, 42, 32],
            [2004, 7838, 183, 80],
            [2004, 7839, 122, 98],
            [2004, 7840, 222, 110],
            [2004, 7841, 175, 72],
            [2004, 7842, 40, 35],
            [2004, 7843, 40, 31],
            [2004, 7844, 196, 65],
            [2004, 7845, 53, 51],
            [2004, 7846, 219, 112],
            [2004, 7847, 391, 112],
            [2004, 7848, 285, 106],
            [2004, 7849, 285, 160],
            [2004, 7850, 103, 93],
            [2004, 7851, 190, 90],
            [2004, 7852, 101, 48],
            [2004, 7853, 92, 62],
            [2004, 7854, 31, 27],
            [2004, 7855, 32, 28],
            [2004, 7856, 197, 112],
            [2004, 7857, 41, 31],
            [2004, 7858, 40, 32],
            [2004, 7859, 186, 74],
            [2004, 7860, 124, 79],
            [2004, 7861, 35, 27],
            [2004, 7862, 322, 52],
            [2004, 7863, 443, 103],
            [2004, 7864, 39, 34],
            [2004, 7865, 46, 37],
            [2004, 7866, 160, 76],
            [2004, 7867, 55, 32],
            [2004, 7868, 42, 31],
            [2004, 7869, 160, 79],
            [2004, 7870, 42, 31],
            [2004, 7871, 64, 35],
            [2004, 7872, 180, 135],
            [2004, 7873, 222, 119],
            [2004, 7874, 42, 32],
            [2004, 7875, 242, 100],
            [2004, 7876, 180, 112],
            [2004, 7877, 120, 74],
            [2004, 7878, 189, 40],
            [2004, 7879, 190, 103],
            [2004, 7880, 97, 72],
            [2004, 7881, 120, 66],
            [2004, 7882, 51, 40],
            [2004, 7883, 120, 93],
            [2004, 7884, 67, 64],
            [2004, 7885, 39, 34],
            [2004, 7886, 80, 35],
            [2004, 7887, 42, 32],
            [2004, 7888, 140, 51],
            [2004, 7889, 258, 120],
            [2004, 7890, 170, 111],
            [2004, 7891, 75, 28],
            [2004, 7892, 64, 33],
            [2004, 7893, 41, 31],
            [2004, 7894, 140, 97],
            [2004, 7895, 80, 37],
            [2004, 7896, 264, 90],
            [2004, 7897, 216, 62],
            [2004, 7898, 120, 59],
            [2004, 7899, 453, 113],
            [2004, 7900, 243, 93],
            [2004, 7901, 120, 29],
            [2004, 7902, 161, 88],
            [2004, 7903, 218, 110],
            [2004, 7904, 120, 31],
            [2004, 7905, 140, 71],
            [2004, 7906, 146, 111],
            [2004, 7907, 172, 42],
            [2004, 7908, 170, 40],
            [2004, 7909, 120, 50],
            [2004, 7910, 124, 58],
            [2004, 7911, 180, 29],
            [2004, 7912, 359, 156],
            [2004, 7913, 198, 61],
            [2004, 7914, 120, 68],
            [2004, 7915, 54, 40],
            [2004, 7916, 150, 42],
            [2004, 7917, 59, 43],
            [2004, 7918, 71, 30],
            [2004, 7919, 120, 32],
            [2004, 7920, 91, 43],
            [2004, 7921, 60, 31],
            [2004, 7922, 120, 35],
            [2004, 7923, 133, 31],
            [2004, 7924, 41, 31],
            [2004, 7925, 41, 31],
            [2004, 7926, 52, 42],
            [2004, 7927, 140, 57],
            [2004, 7928, 120, 53],
            [2004, 7929, 186, 96],
            [2004, 7930, 272, 57],
            [2004, 7931, 59, 32],
            [2004, 7932, 42, 32],
            [2004, 7933, 120, 75],
            [2004, 7934, 176, 113],
            [2004, 7935, 197, 90],
            [2004, 7936, 179, 32],
            [2004, 7937, 75, 31],
            [2004, 7938, 40, 31],
            [2004, 7939, 316, 112],
            [2004, 7940, 167, 86],
            [2004, 7941, 273, 107],
            [2004, 7942, 176, 111],
            [2004, 7943, 43, 33],
            [2004, 7944, 120, 43],
            [2004, 7945, 216, 53],
            [2004, 7946, 124, 91],
            [2004, 7947, 101, 40],
            [2004, 7948, 120, 30],
            [2004, 7949, 199, 111],
            [2004, 7950, 66, 49],
            [2004, 7951, 169, 73],
            [2004, 7952, 125, 90],
            [2004, 7953, 33, 30],
            [2004, 7954, 120, 32],
            [2004, 7955, 200, 60],
            [2004, 7956, 340, 120],
            [2004, 7957, 49, 41],
            [2004, 7958, 173, 53],
            [2004, 7959, 188, 65],
            [2004, 7960, 120, 32],
            [2004, 7961, 165, 165],
            [2004, 7962, 309, 112],
            [2004, 7963, 32, 27],
            [2004, 7964, 160, 112],
            [2004, 7965, 179, 38],
            [2004, 7966, 142, 93],
            [2004, 7967, 182, 31],
            [2004, 7968, 396, 128],
            [2004, 7969, 336, 176],
            [2004, 7970, 162, 83],
            [2004, 7971, 32, 29],
            [2004, 7972, 77, 30],
            [2004, 7974, 33, 30],
            [2004, 7975, 302, 120],
            [2004, 7976, 320, 43],
            [2004, 7977, 222, 131],
            [2004, 7978, 172, 40],
            [2004, 7979, 128, 74],
            [2004, 7980, 265, 80],
            [2004, 7981, 169, 41],
            [2004, 7982, 83, 33],
            [2004, 7983, 120, 31],
            [2004, 7984, 180, 112],
            [2004, 7985, 91, 59],
            [2004, 7986, 41, 31],
            [2004, 7987, 106, 35],
            [2004, 7988, 54, 39],
            [2004, 7989, 720, 98],
            [2004, 7990, 83, 28],
            [2004, 7992, 120, 75],
            [2004, 7993, 185, 103],
            [2004, 7994, 120, 52],
            [2004, 7995, 434, 161],
            [2004, 7996, 136, 34],
            [2004, 7997, 252, 116],
            [2004, 7998, 120, 32],
            [2004, 7999, 138, 100],
            [2004, 8000, 120, 29],
            [2004, 8001, 198, 99],
            [2004, 8002, 167, 93],
            [2004, 8003, 120, 29],
            [2004, 8004, 189, 175],
            [2004, 8005, 18, 21],
            [2004, 8006, 14, 17],
            [2004, 8007, 24, 28],
            [2004, 8008, 21, 24],
            [2004, 8009, 15, 15],
            [2004, 8010, 13, 15],
            [2004, 8011, 15, 17],
            [2004, 8012, 11, 14],
            [2004, 8013, 7, 6],
            [2004, 8014, 8, 9],
            [2004, 8015, 8, 8],
            [2004, 8016, 6, 5],
            [2004, 8017, 12, 12],
            [2004, 8018, 7, 6],
            [2004, 8019, 14, 13],
            [2004, 8020, 12, 12],
            [2004, 8021, 6, 5],
            [2004, 8022, 21, 25],
            [2004, 8023, 15, 16],
            [2004, 8024, 19, 18],
            [2004, 8025, 16, 19],
            [2004, 8026, 17, 18],
            [2004, 8027, 13, 11],
            [2004, 8028, 13, 13],
            [2004, 8029, 21, 20],
            [2004, 8030, 16, 15],
            [2004, 8031, 12, 11],
            [2004, 8032, 17, 21],
            [2004, 8033, 21, 22],
            [2004, 8034, 21, 26],
            [2004, 8035, 18, 18],
            [2004, 8036, 16, 19],
            [2004, 8037, 19, 21],
            [2004, 8038, 29, 28],
            [2004, 8039, 30, 57],
            [2004, 8040, 20, 57],
            [2004, 8041, 7, 13],
            [2004, 8042, 7, 9],
            [2004, 8043, 10, 14],
            [2004, 8044, 10, 15],
            [2004, 8045, 5, 3],
            [2004, 8046, 5, 3],
            [2004, 8047, 5, 5],
            [2004, 8048, 14, 19],
            [2004, 8049, 11, 15],
            [2004, 8050, 9, 10],
            [2004, 8051, 20, 21],
            [2004, 8052, 32, 43],
            [2004, 8053, 21, 35],
            [2004, 8054, 18, 30],
            [2004, 8055, 29, 42],
            [2004, 8056, 41, 45],
            [2004, 8057, 19, 29],
            [2004, 8058, 18, 25],
            [2004, 8059, 23, 25],
            [2004, 8060, 25, 29],
            [2004, 8061, 50, 55],
            [2004, 8062, 52, 68],
            [2004, 8063, 10, 9],
            [2004, 8064, 14, 18],
            [2004, 8065, 14, 11],
            [2004, 8068, 11, 10],
            [2004, 8069, 13, 24],
            [2004, 8071, 38, 20],
            [2004, 8073, 46, 25],
            [2004, 8074, 12, 12],
            [2004, 8075, 26, 15],
            [2004, 8076, 52, 34],
            [2004, 8086, 14, 40],
            [2004, 8087, 15, 28],
            [2004, 8088, 17, 35],
            [2004, 8089, 20, 42],
            [2004, 8090, 19, 29],
            [2004, 8091, 21, 57],
            [2004, 8092, 18, 44],
            [2004, 8093, 21, 57],
            [2004, 8094, 14, 57],
            [2004, 8095, 20, 26],
            [2004, 8096, 22, 35],
            [2004, 8097, 20, 30],
            [2004, 8098, 8, 23],
            [2004, 8099, 29, 29],
            [2004, 8100, 28, 27],
            [2004, 8101, 29, 29],
            [2004, 8102, 23, 25],
            [2004, 8103, 29, 29],
            [2004, 8104, 28, 28],
            [2004, 8105, 43, 36],
            [2004, 8106, 32, 32],
            [2004, 8107, 24, 27],
            [2004, 8108, 42, 39],
            [2004, 8109, 31, 30],
            [2004, 8110, 23, 26],
            [2004, 8111, 39, 36],
            [2004, 8112, 28, 28],
            [2004, 8113, 43, 36],
            [2004, 8114, 23, 26],
            [2004, 8115, 55, 63],
            [2004, 8116, 32, 31],
            [2004, 8117, 43, 55],
            [2004, 8118, 24, 28],
            [2004, 8119, 30, 29],
            [2004, 8120, 40, 37],
            [2004, 8121, 24, 26],
            [2004, 8122, 29, 29],
            [2004, 8123, 44, 37],
            [2004, 8124, 30, 31],
            [2004, 8125, 44, 37],
            [2004, 8126, 24, 25],
            [2004, 8127, 31, 32],
            [2004, 8128, 67, 63],
            [2004, 8129, 29, 29],
            [2004, 8130, 44, 37],
            [2004, 8131, 22, 25],
            [2004, 8132, 42, 39],
            [2004, 8133, 24, 27],
            [2004, 8134, 44, 41],
            [2004, 8135, 44, 36],
            [2004, 8136, 19, 22],
            [2004, 8137, 29, 30],
            [2004, 8138, 32, 32],
            [2004, 8139, 51, 55],
            [2004, 8140, 32, 37],
            [2004, 8141, 28, 27],
            [2004, 8142, 29, 29],
            [2004, 8143, 53, 60],
            [2004, 8144, 24, 27],
            [2004, 8145, 23, 25],
            [2004, 8146, 40, 43],
            [2004, 8147, 28, 27],
            [2004, 8148, 31, 30],
            [2004, 8149, 25, 28],
            [2004, 8150, 58, 68],
            [2004, 8151, 22, 25],
            [2004, 8152, 49, 56],
            [2004, 8153, 29, 30],
            [2004, 8154, 28, 27],
            [2004, 8155, 38, 32],
            [2004, 8156, 61, 73],
            [2004, 8157, 32, 31],
            [2004, 8158, 29, 29],
            [2004, 8159, 25, 26],
            [2004, 8160, 29, 28],
            [2004, 8161, 44, 37],
            [2004, 8162, 46, 38],
            [2004, 8163, 44, 34],
            [2004, 8164, 27, 28],
            [2004, 8165, 31, 31],
            [2004, 8166, 61, 47],
            [2004, 8167, 44, 37],
            [2004, 8168, 29, 30],
            [2004, 8169, 43, 35],
            [2004, 8170, 30, 30],
            [2004, 8171, 29, 30],
            [2004, 8172, 62, 46],
            [2004, 8173, 29, 29],
            [2004, 8174, 30, 29],
            [2004, 8175, 24, 26],
            [2004, 8176, 23, 26],
            [2004, 8177, 25, 29],
            [2004, 8178, 31, 32],
            [2004, 8179, 40, 36],
            [2004, 8180, 28, 28],
            [2004, 8181, 59, 46],
            [2004, 8182, 44, 37],
            [2004, 8183, 32, 32],
            [2004, 8184, 28, 27],
            [2004, 8185, 28, 28],
            [2004, 8186, 31, 31],
            [2004, 8187, 25, 28],
            [2004, 8188, 18, 21],
            [2004, 8189, 41, 38],
            [2004, 8190, 23, 25],
            [2004, 8191, 42, 42],
            [2004, 8192, 32, 31],
            [2004, 8193, 59, 44],
            [2004, 8194, 28, 27],
            [2004, 8195, 29, 29],
            [2004, 8196, 25, 28],
            [2004, 8197, 32, 32],
            [2004, 8198, 25, 28],
            [2004, 8199, 49, 53],
            [2004, 8200, 23, 27],
            [2004, 8201, 63, 48],
            [2004, 8202, 38, 37],
            [2004, 8203, 54, 36],
            [2004, 8204, 43, 36],
            [2004, 8205, 20, 23],
            [2004, 8206, 48, 46],
            [2004, 8207, 29, 28],
            [2004, 8208, 23, 26],
            [2004, 8209, 62, 48],
            [2004, 8210, 31, 31],
            [2004, 8211, 53, 60],
            [2004, 8212, 23, 25],
            [2004, 8213, 31, 30],
            [2004, 8214, 50, 55],
            [2004, 8215, 30, 29],
            [2004, 8216, 29, 29],
            [2004, 8217, 31, 31],
            [2004, 8218, 16, 21],
            [2004, 8219, 47, 45],
            [2004, 8220, 22, 25],
            [2004, 8221, 41, 38],
            [2004, 8222, 20, 24],
            [2004, 8223, 23, 26],
            [2004, 8224, 39, 41],
            [2004, 8225, 31, 36],
            [2004, 8226, 52, 58],
            [2004, 8227, 29, 29],
            [2004, 8228, 20, 23],
            [2004, 8229, 28, 27],
            [2004, 8230, 31, 30],
            [2004, 8231, 19, 22],
            [2004, 8232, 50, 48],
            [2004, 8233, 29, 29],
            [2004, 8234, 21, 23],
            [2004, 8235, 49, 54],
            [2004, 8236, 23, 26],
            [2004, 8237, 47, 44],
            [2004, 8238, 28, 28],
            [2004, 8239, 69, 53],
            [2004, 8240, 30, 29],
            [2004, 8241, 25, 28],
            [2004, 8242, 44, 41],
            [2004, 8245, 31, 30],
            [2004, 8246, 32, 32],
            [2004, 8247, 44, 36],
            [2004, 8248, 20, 23],
            [2004, 8249, 42, 39],
            [2004, 8250, 27, 28],
            [2004, 8251, 30, 29],
            [2004, 8252, 40, 37],
            [2004, 8253, 42, 34],
            [2004, 8254, 33, 37],
            [2004, 8255, 28, 28],
            [2004, 8256, 25, 27],
            [2004, 8257, 49, 55],
            [2004, 8258, 29, 28],
            [2004, 8259, 28, 28],
            [2004, 8260, 31, 32],
            [2004, 8261, 48, 52],
            [2004, 8262, 46, 47],
            [2004, 8263, 54, 41],
            [2004, 8264, 27, 31],
            [2004, 8265, 46, 61],
            [2004, 8267, 42, 35],
            [2004, 8268, 30, 29],
            [2004, 8269, 29, 29],
            [2004, 8270, 18, 22],
            [2004, 8271, 24, 28],
            [2004, 8272, 41, 37],
            [2004, 8273, 29, 29],
            [2004, 8274, 28, 28],
            [2004, 8275, 26, 29],
            [2004, 8276, 28, 28],
            [2004, 8277, 29, 22],
            [2004, 8278, 44, 37],
            [2004, 8279, 29, 29],
            [2004, 8280, 32, 32],
            [2004, 8281, 29, 28],
            [2004, 8282, 32, 32],
            [2004, 8283, 31, 30],
            [2004, 8284, 30, 29],
            [2004, 8285, 32, 32],
            [2004, 8286, 32, 32],
            [2004, 8287, 31, 31],
            [2004, 8288, 24, 28],
            [2004, 8289, 42, 39],
            [2004, 8290, 32, 32],
            [2004, 8291, 32, 32],
            [2004, 8292, 31, 30],
            [2004, 8293, 28, 28],
            [2004, 8294, 29, 28],
            [2004, 8295, 44, 36],
            [2004, 8296, 43, 31],
            [2004, 8297, 30, 30],
            [2004, 8298, 28, 46],
            [2004, 8299, 19, 22],
            [2004, 8300, 62, 47],
            [2004, 8301, 31, 31],
            [2004, 8302, 29, 28],
            [2004, 8303, 44, 37],
            [2004, 8304, 28, 28],
            [2004, 8305, 41, 34],
            [2004, 8306, 25, 28],
            [2004, 8307, 18, 21],
            [2004, 8308, 29, 28],
            [2004, 8309, 15, 19],
            [2004, 8310, 42, 38],
            [2004, 8311, 13, 13],
            [2004, 8312, 12, 12],
            [2004, 8313, 12, 11],
            [2004, 8314, 12, 12],
            [2004, 8315, 12, 12],
            [2004, 8316, 11, 11],
            [2004, 8317, 35, 35],
            [2004, 8318, 51, 39],
            [2004, 8319, 18, 18],
            [2004, 8320, 44, 37],
            [2004, 8321, 32, 26],
            [2004, 8322, 31, 31],
            [2004, 8323, 25, 28],
            [2004, 8324, 56, 41],
            [2004, 8325, 49, 40],
            [2004, 8326, 43, 36],
            [2004, 8327, 41, 34],
            [2004, 8328, 46, 38],
            [2004, 8329, 29, 28],
            [2004, 8330, 46, 38],
            [2004, 8331, 41, 34],
            [2004, 8332, 44, 36],
            [2004, 8336, 20, 17],
            [2004, 8337, 12, 15],
            [2004, 8338, 12, 12],
            [2004, 8339, 33, 33],
            [2004, 8340, 15, 17],
            [2004, 8341, 23, 26],
            [2004, 8342, 15, 15],
            [2004, 8343, 17, 17],
            [2004, 8344, 14, 13],
            [2004, 8345, 20, 15],
            [2004, 8346, 18, 22],
            [2004, 8347, 15, 17],
            [2004, 8348, 20, 23],
            [2004, 8349, 15, 16],
            [2004, 8350, 17, 17],
            [2004, 8351, 14, 11],
            [2004, 8352, 18, 23],
            [2004, 8353, 13, 16],
            [2004, 8354, 21, 24],
            [2004, 8355, 14, 14],
            [2004, 8356, 23, 26],
            [2004, 8357, 14, 14],
            [2004, 8358, 22, 17],
            [2004, 8359, 30, 34],
            [2004, 8360, 27, 31],
            [2004, 8361, 14, 13],
            [2004, 8362, 17, 22],
            [2004, 8363, 21, 26],
            [2004, 8364, 25, 22],
            [2004, 8365, 12, 14],
            [2004, 8366, 20, 18],
            [2004, 8367, 16, 16],
            [2004, 8368, 17, 22],
            [2004, 8369, 18, 22],
            [2004, 8370, 18, 18],
            [2004, 8371, 19, 18],
            [2004, 8372, 21, 18],
            [2004, 8373, 21, 24],
            [2004, 8374, 20, 25],
            [2004, 8375, 14, 13],
            [2004, 8376, 24, 24],
            [2004, 8377, 19, 15],
            [2004, 8378, 20, 17],
            [2004, 8379, 24, 22],
            [2004, 8380, 24, 25],
            [2004, 8381, 24, 27],
            [2004, 8382, 18, 19],
            [2004, 8383, 22, 25],
            [2004, 8384, 20, 26],
            [2004, 8385, 18, 22],
            [2004, 8386, 13, 15],
            [2004, 8387, 21, 21],
            [2004, 8388, 17, 17],
            [2004, 8389, 16, 18],
            [2004, 8390, 13, 14],
            [2004, 8391, 16, 18],
            [2004, 8392, 18, 20],
            [2004, 8393, 29, 37],
            [2004, 8394, 22, 18],
            [2004, 8395, 18, 19],
            [2004, 8396, 47, 39],
            [2004, 8397, 55, 41],
            [2004, 8398, 40, 29],
            [2004, 8399, 51, 33],
            [2004, 8400, 43, 40],
            [2004, 8401, 51, 31],
            [2004, 8402, 41, 31],
            [2004, 8403, 45, 30],
            [2004, 8404, 39, 34],
            [2004, 8405, 45, 30],
            [2004, 8406, 40, 32],
            [2004, 8407, 47, 42],
            [2004, 8408, 38, 38],
            [2004, 8409, 34, 28],
            [2004, 8410, 40, 33],
            [2004, 8411, 74, 52],
            [2004, 8412, 42, 39],
            [2004, 8413, 50, 38],
            [2004, 8414, 57, 31],
            [2004, 8415, 61, 42],
            [2004, 8416, 31, 29],
            [2004, 8417, 50, 34],
            [2004, 8418, 26, 27],
            [2004, 8419, 52, 37],
            [2004, 8420, 44, 34],
            [2004, 8421, 53, 40],
            [2004, 8422, 33, 33],
            [2004, 8423, 50, 45],
            [2004, 8424, 52, 51],
            [2004, 8425, 39, 45],
            [2004, 8426, 35, 30],
            [2004, 8427, 38, 32],
            [2004, 8428, 41, 33],
            [2004, 8429, 33, 30],
            [2004, 8430, 50, 45],
            [2004, 8431, 51, 39],
            [2004, 8432, 51, 45],
            [2004, 8433, 48, 43],
            [2004, 8434, 52, 34],
            [2004, 8435, 70, 38],
            [2004, 8436, 55, 41],
            [2004, 8438, 36, 30],
            [2004, 8439, 39, 35],
            [2004, 8440, 58, 38],
            [2004, 8441, 54, 36],
            [2004, 8442, 37, 34],
            [2004, 8443, 47, 40],
            [2004, 8444, 50, 45],
            [2004, 8445, 27, 24],
            [2004, 8446, 35, 29],
            [2004, 8447, 46, 37],
            [2004, 8448, 38, 33],
            [2004, 8449, 56, 27],
            [2004, 8450, 52, 37],
            [2004, 8451, 21, 27],
            [2004, 8452, 27, 36],
            [2004, 8453, 20, 24],
            [2004, 8454, 22, 27],
            [2004, 8455, 23, 27],
            [2004, 8456, 23, 27],
            [2004, 8457, 50, 45],
            [2004, 8458, 38, 30],
            [2004, 8459, 47, 33],
            [2004, 8460, 41, 36],
            [2004, 8461, 53, 33],
            [2004, 8462, 52, 36],
            [2004, 8463, 50, 42],
            [2004, 8464, 55, 40],
            [2004, 8465, 34, 25],
            [2004, 8466, 32, 37],
            [2004, 8467, 36, 31],
            [2004, 8468, 42, 37],
            [2004, 8469, 39, 32],
            [2004, 8470, 55, 42],
            [2004, 8471, 35, 38],
            [2004, 8472, 54, 29],
            [2004, 8473, 45, 40],
            [2004, 8474, 38, 35],
            [2004, 8475, 48, 37],
            [2004, 8476, 49, 38],
            [2004, 8477, 49, 38],
            [2004, 8478, 30, 30],
            [2004, 8479, 39, 34],
            [2004, 8480, 54, 42],
            [2004, 8481, 46, 37],
            [2004, 8482, 42, 33],
            [2004, 8483, 41, 33],
            [2004, 8484, 47, 35],
            [2004, 8485, 50, 41],
            [2004, 8486, 33, 27],
            [2004, 8487, 46, 33],
            [2004, 8488, 36, 30],
            [2004, 8489, 33, 47],
            [2004, 8490, 47, 37],
            [2004, 8491, 39, 37],
            [2004, 8492, 41, 31],
            [2004, 8493, 47, 32],
            [2004, 8494, 33, 27],
            [2004, 8495, 51, 51],
            [2004, 8496, 26, 33],
            [2004, 8497, 44, 43],
            [2004, 8498, 32, 33],
            [2004, 8499, 40, 32],
            [2004, 8500, 51, 36],
            [2004, 8501, 50, 55],
            [2004, 8502, 53, 35],
            [2004, 8503, 51, 39],
            [2004, 8504, 40, 37],
            [2004, 8505, 52, 40],
            [2004, 8506, 55, 41],
            [2004, 8507, 54, 42],
            [2004, 8508, 34, 32],
            [2004, 8509, 38, 33],
            [2004, 8510, 53, 39],
            [2004, 8511, 46, 35],
            [2004, 8512, 50, 45],
            [2004, 8513, 44, 40],
            [2004, 8514, 49, 45],
            [2004, 8515, 41, 38],
            [2004, 8516, 90, 54],
            [2004, 8517, 52, 23],
            [2004, 8518, 58, 51],
            [2004, 8519, 38, 32],
            [2004, 8520, 41, 32],
            [2004, 8521, 37, 32],
            [2004, 8522, 39, 35],
            [2004, 8523, 38, 33],
            [2004, 8524, 36, 31],
            [2004, 8525, 47, 33],
            [2004, 8526, 49, 38],
            [2004, 8527, 47, 45],
            [2004, 8528, 48, 40],
            [2004, 8529, 58, 40],
            [2004, 8530, 35, 31],
            [2004, 8531, 56, 49],
            [2004, 8532, 48, 44],
            [2004, 8533, 55, 49],
            [2004, 8534, 41, 39],
            [2004, 8535, 54, 52],
            [2004, 8536, 18, 30],
            [2004, 8537, 38, 27],
            [2004, 8538, 38, 26],
            [2004, 8539, 35, 30],
            [2004, 8540, 28, 36],
            [2004, 8541, 35, 44],
            [2004, 8542, 29, 38],
            [2004, 8543, 19, 36],
            [2004, 8544, 27, 50],
            [2004, 8546, 25, 37],
            [2004, 8547, 30, 50],
            [2004, 8548, 15, 18],
            [2004, 8549, 23, 29],
            [2004, 8550, 20, 27],
            [2004, 8551, 32, 28],
            [2004, 8552, 29, 35],
            [2004, 8553, 40, 51],
            [2004, 8554, 21, 20],
            [2004, 8555, 34, 33],
            [2004, 8556, 38, 50],
            [2004, 8557, 50, 49],
            [2004, 8558, 27, 30],
            [2004, 8559, 34, 31],
            [2004, 8560, 28, 33],
            [2004, 8561, 23, 28],
            [2004, 8562, 32, 32],
            [2004, 8563, 39, 41],
            [2004, 8564, 67, 55],
            [2004, 8565, 10, 12],
            [2004, 8566, 22, 14],
            [2004, 8567, 22, 21],
            [2004, 8568, 16, 16],
            [2004, 8569, 19, 15],
            [2004, 8570, 10, 10],
            [2004, 8571, 14, 11],
            [2004, 8572, 12, 12],
            [2004, 8573, 13, 11],
            [2004, 8574, 15, 13],
            [2004, 8575, 10, 10],
            [2004, 8576, 32, 19],
            [2004, 8577, 14, 16],
            [2004, 8578, 24, 21],
            [2004, 8579, 14, 20],
            [2004, 8580, 18, 17],
            [2004, 8581, 14, 15],
            [2004, 8582, 20, 18],
            [2004, 8583, 20, 18],
            [2004, 8584, 16, 14],
            [2004, 8585, 11, 11],
            [2004, 8586, 30, 18],
            [2004, 8587, 10, 8],
            [2004, 8588, 31, 15],
            [2004, 8589, 14, 12],
            [2004, 8590, 20, 14],
            [2004, 8591, 19, 14],
            [2004, 8592, 26, 25],
            [2004, 8593, 23, 20],
            [2004, 8594, 36, 23],
            [2004, 8595, 14, 13],
            [2004, 8596, 17, 14],
            [2004, 8597, 18, 21],
            [2004, 8598, 27, 21],
            [2004, 8599, 14, 12],
            [2004, 8600, 20, 14],
            [2004, 8601, 25, 18],
            [2004, 8602, 25, 18],
            [2004, 8603, 24, 14],
            [2004, 8604, 39, 21],
            [2004, 8605, 22, 21],
            [2004, 8606, 37, 23],
            [2004, 8607, 17, 22],
            [2004, 8608, 26, 25],
            [2004, 8609, 25, 18],
            [2004, 8610, 22, 22],
            [2004, 8611, 23, 17],
            [2004, 8612, 33, 22],
            [2004, 8613, 14, 11],
            [2004, 8614, 26, 19],
            [2004, 8615, 11, 11],
            [2004, 8616, 26, 20],
            [2004, 8617, 27, 14],
            [2004, 8618, 18, 12],
            [2004, 8619, 30, 25],
            [2004, 8622, 45, 23],
            [2004, 8623, 45, 25],
            [2004, 8624, 17, 19],
            [2004, 8625, 37, 23],
            [2004, 8626, 21, 16],
            [2004, 8627, 32, 18],
            [2004, 8628, 27, 22],
            [2004, 8629, 26, 22],
            [2004, 8630, 19, 15],
            [2004, 8631, 26, 19],
            [2004, 8632, 20, 15],
            [2004, 8633, 22, 17],
            [2004, 8634, 14, 14],
            [2004, 8635, 24, 14],
            [2004, 8636, 10, 9],
            [2004, 8637, 21, 14],
            [2004, 8638, 14, 11],
            [2004, 8639, 18, 13],
            [2004, 8640, 21, 17],
            [2004, 8641, 37, 20],
            [2004, 8642, 24, 19],
            [2004, 8643, 24, 24],
            [2004, 8644, 39, 22],
            [2004, 8645, 20, 18],
            [2004, 8646, 23, 18],
            [2004, 8647, 19, 14],
            [2004, 8648, 18, 14],
            [2004, 8649, 21, 19],
            [2004, 8650, 27, 16],
            [2004, 8651, 29, 19],
            [2004, 8652, 35, 26],
            [2004, 8653, 26, 22],
            [2004, 8654, 49, 23],
            [2004, 8655, 20, 19],
            [2004, 8656, 20, 18],
            [2004, 8657, 9, 12],
            [2004, 8658, 19, 16],
            [2004, 8659, 28, 22],
            [2004, 8660, 13, 11],
            [2004, 8661, 17, 13],
            [2004, 8662, 20, 12],
            [2004, 8663, 21, 14],
            [2004, 8664, 25, 17],
            [2004, 8665, 35, 26],
            [2004, 8666, 16, 15],
            [2004, 8667, 18, 17],
            [2004, 8668, 16, 20],
            [2004, 8669, 31, 29],
            [2004, 8670, 17, 18],
            [2004, 8671, 25, 26],
            [2004, 8672, 14, 17],
            [2004, 8673, 25, 23],
            [2004, 8674, 23, 16],
            [2004, 8675, 46, 21],
            [2004, 8676, 32, 23],
            [2004, 8677, 37, 24],
            [2004, 8678, 32, 18],
            [2004, 8679, 34, 17],
            [2004, 8680, 23, 17],
            [2004, 8681, 31, 20],
            [2004, 8682, 32, 19],
            [2004, 8683, 27, 13],
            [2004, 8684, 25, 19],
            [2004, 8685, 19, 17],
            [2004, 8686, 28, 17],
            [2004, 8687, 20, 15],
            [2004, 8688, 32, 22],
            [2004, 8689, 28, 20],
            [2004, 8690, 33, 20],
            [2004, 8691, 22, 21],
            [2004, 8692, 36, 24],
            [2004, 8693, 31, 12],
            [2004, 8694, 31, 20],
            [2004, 8695, 13, 14],
            [2004, 8696, 20, 18],
            [2004, 8697, 18, 14],
            [2004, 8698, 34, 16],
            [2004, 8699, 27, 15],
            [2004, 8700, 30, 15],
            [2004, 8701, 21, 13],
            [2004, 8702, 24, 17],
            [2004, 8703, 23, 19],
            [2004, 8704, 28, 22],
            [2004, 8705, 25, 16],
            [2004, 8706, 31, 18],
            [2004, 8707, 18, 19],
            [2004, 8708, 25, 21],
            [2004, 8709, 33, 18],
            [2004, 8710, 27, 18],
            [2004, 8711, 10, 9],
            [2004, 8712, 20, 18],
            [2004, 8713, 28, 19],
            [2004, 8714, 6, 5],
            [2004, 8715, 7, 6],
            [2004, 8716, 6, 6],
            [2004, 8717, 11, 11],
            [2004, 8718, 8, 7],
            [2004, 8719, 24, 24],
            [2004, 8720, 25, 27],
            [2004, 8721, 26, 28],
            [2004, 8722, 24, 23],
            [2004, 8723, 26, 25],
            [2004, 8724, 24, 24],
            [2004, 8725, 26, 22],
            [2004, 8726, 25, 23],
            [2004, 8727, 22, 22],
            [2004, 8728, 21, 21],
            [2004, 8729, 23, 21],
            [2004, 8730, 21, 21],
            [2004, 8731, 21, 21],
            [2004, 8732, 25, 22],
            [2004, 8733, 26, 22],
            [2004, 8734, 26, 22],
            [2004, 8735, 21, 22],
            [2004, 8736, 21, 21],
            [2004, 8737, 21, 21],
            [2004, 8738, 21, 21],
            [2004, 8739, 21, 21],
            [2004, 8740, 21, 21],
            [2004, 8741, 24, 21],
            [2004, 8742, 23, 22],
            [2004, 8743, 22, 22],
            [2004, 8744, 23, 22],
            [2004, 8745, 24, 22],
            [2004, 8746, 27, 24],
            [2004, 8747, 27, 23],
            [2004, 8748, 28, 23],
            [2004, 8749, 23, 22],
            [2004, 8750, 22, 23],
            [2004, 8751, 22, 25],
            [2004, 8752, 21, 21],
            [2004, 8753, 21, 21],
            [2004, 8754, 21, 21],
            [2004, 8755, 21, 21],
            [2004, 8756, 27, 22],
            [2004, 8757, 21, 21],
            [2004, 8758, 21, 21],
            [2004, 8759, 22, 21],
            [2004, 8760, 29, 30],
            [2004, 8761, 22, 21],
            [2004, 8762, 27, 22],
            [2004, 8763, 21, 21],
            [2004, 8764, 29, 24],
            [2004, 8765, 25, 21],
            [2004, 8766, 26, 22],
            [2004, 8767, 28, 24],
            [2004, 8768, 29, 23],
            [2004, 8769, 27, 23],
            [2004, 8770, 28, 24],
            [2004, 8771, 28, 26],
            [2004, 8772, 30, 25],
            [2004, 8773, 21, 21],
            [2004, 8774, 21, 21],
            [2004, 8775, 21, 21],
            [2004, 8776, 21, 21],
            [2004, 8777, 22, 22],
            [2004, 8778, 29, 25],
            [2004, 8779, 10, 11],
            [2004, 8780, 13, 9],
            [2004, 8781, 16, 13],
            [2004, 8782, 14, 10],
            [2004, 8783, 10, 8],
            [2004, 8784, 12, 9],
            [2004, 8785, 7, 7],
            [2004, 8786, 9, 10],
            [2004, 8787, 11, 10],
            [2004, 8788, 12, 10],
            [2004, 8790, 10, 8],
            [2004, 8791, 6, 6],
            [2004, 8792, 12, 10],
            [2004, 8793, 8, 8],
            [2004, 8794, 8, 7],
            [2004, 8795, 9, 7],
            [2004, 8796, 13, 9],
            [2004, 8797, 15, 9],
            [2004, 8798, 9, 8],
            [2004, 8799, 15, 13],
            [2004, 8800, 10, 8],
            [2004, 8801, 10, 9],
            [2004, 8802, 8, 7],
            [2004, 8803, 8, 8],
            [2004, 8804, 7, 8],
            [2004, 8805, 9, 8],
            [2004, 8806, 9, 10],
            [2004, 8807, 13, 12],
            [2004, 8808, 9, 8],
            [2004, 8809, 6, 8],
            [2004, 8810, 10, 10],
            [2004, 8811, 7, 9],
            [2004, 8812, 11, 9],
            [2004, 8814, 6, 7],
            [2004, 8815, 9, 9],
            [2004, 8816, 12, 7],
            [2004, 8817, 17, 10],
            [2004, 8818, 41, 34],
            [2004, 8819, 35, 33],
            [2004, 8820, 50, 41],
            [2004, 8821, 39, 27],
            [2004, 8822, 48, 39],
            [2004, 8823, 31, 25],
            [2004, 8824, 22, 18],
            [2004, 8825, 34, 29],
            [2004, 8826, 22, 21],
            [2004, 8827, 37, 29],
            [2004, 8828, 37, 28],
            [2004, 8829, 41, 32],
            [2004, 8830, 27, 28],
            [2004, 8831, 33, 25],
            [2004, 8832, 19, 11],
            [2004, 8833, 30, 24],
            [2004, 8834, 35, 30],
            [2004, 8835, 29, 19],
            [2004, 8836, 45, 36],
            [2004, 8837, 30, 21],
            [2004, 8838, 38, 32],
            [2004, 8839, 24, 13],
            [2004, 8840, 34, 24],
            [2004, 8841, 23, 13],
            [2004, 8842, 15, 18],
            [2004, 8843, 19, 12],
            [2004, 8844, 27, 22],
            [2004, 8845, 14, 17],
            [2004, 8846, 33, 26],
            [2004, 8847, 18, 19],
            [2004, 8848, 42, 34],
            [2004, 8849, 27, 21],
            [2004, 8850, 37, 31],
            [2004, 8851, 22, 22],
            [2004, 8852, 32, 25],
            [2004, 8853, 14, 17],
            [2004, 8854, 32, 27],
            [2004, 8855, 20, 14],
            [2004, 8856, 30, 25],
            [2004, 8857, 23, 13],
            [2004, 8858, 27, 14],
            [2004, 8859, 40, 35],
            [2004, 8860, 27, 12],
            [2004, 8861, 33, 28],
            [2004, 8862, 24, 21],
            [2004, 8863, 37, 32],
            [2004, 8864, 21, 21],
            [2004, 8865, 31, 25],
            [2004, 8866, 22, 21],
            [2004, 8867, 45, 38],
            [2004, 8868, 37, 31],
            [2004, 8869, 48, 39],
            [2004, 8870, 44, 35],
            [2004, 8871, 32, 27],
            [2004, 8872, 35, 30],
            [2004, 8873, 26, 22],
            [2004, 8874, 30, 25],
            [2004, 8875, 34, 28],
            [2004, 8876, 18, 18],
            [2004, 8877, 41, 33],
            [2004, 8878, 27, 24],
            [2004, 8879, 18, 11],
            [2004, 8880, 30, 25],
            [2004, 8881, 48, 39],
            [2004, 8882, 28, 24],
            [2004, 8883, 47, 37],
            [2004, 8884, 17, 15],
            [2004, 8885, 52, 35],
            [2004, 8886, 33, 25],
            [2004, 8887, 19, 11],
            [2004, 8888, 37, 33],
            [2004, 8889, 44, 35],
            [2004, 8890, 13, 16],
            [2004, 8891, 32, 28],
            [2004, 8892, 14, 11],
            [2004, 8893, 34, 30],
            [2004, 8894, 19, 18],
            [2004, 8895, 15, 11],
            [2004, 8896, 24, 20],
            [2004, 8897, 15, 10],
            [2004, 8898, 19, 18],
            [2004, 8899, 45, 39],
            [2004, 8900, 33, 28],
            [2004, 8901, 39, 29],
            [2004, 8902, 32, 27],
            [2004, 8903, 25, 21],
            [2004, 8904, 33, 28],
            [2004, 8905, 23, 19],
            [2004, 8906, 30, 24],
            [2004, 8907, 19, 19],
            [2004, 8908, 28, 24],
            [2004, 8909, 21, 18],
            [2004, 8910, 21, 12],
            [2004, 8911, 23, 13],
            [2004, 8912, 41, 36],
            [2004, 8913, 26, 23],
            [2004, 8914, 39, 33],
            [2004, 8915, 27, 23],
            [2004, 8916, 42, 34],
            [2004, 8917, 32, 22],
            [2004, 8918, 43, 35],
            [2004, 8919, 30, 26],
            [2004, 8920, 32, 27],
            [2004, 8921, 33, 31],
            [2004, 8922, 30, 24],
            [2004, 8923, 24, 20],
            [2004, 8924, 14, 13],
            [2004, 8925, 11, 10],
            [2004, 8926, 14, 12],
            [2004, 8927, 15, 15],
            [2004, 8928, 13, 12],
            [2004, 8929, 10, 10],
            [2004, 8930, 9, 10],
            [2004, 8931, 13, 14],
            [2004, 8932, 16, 18],
            [2004, 8933, 23, 23],
            [2004, 8934, 26, 25],
            [2004, 8935, 41, 34],
            [2004, 8936, 25, 19],
            [2004, 8937, 33, 28],
            [2004, 8938, 24, 19],
            [2004, 8939, 31, 24],
            [2004, 8940, 18, 16],
            [2004, 8941, 30, 24],
            [2004, 8942, 18, 16],
            [2004, 8943, 26, 19],
            [2004, 8944, 31, 25],
            [2004, 8945, 22, 19],
            [2004, 8946, 31, 25],
            [2004, 8947, 22, 18],
            [2004, 8948, 30, 25],
            [2004, 8949, 25, 20],
            [2004, 8950, 22, 19],
            [2004, 8951, 30, 25],
            [2004, 8952, 23, 19],
            [2004, 8953, 38, 32],
            [2004, 8954, 24, 17],
            [2004, 8955, 39, 34],
            [2004, 8956, 26, 23],
            [2004, 8957, 26, 18],
            [2004, 8958, 47, 39],
            [2004, 8959, 27, 19],
            [2004, 8960, 44, 36],
            [2004, 8961, 27, 19],
            [2004, 8962, 39, 34],
            [2004, 8963, 30, 26],
            [2004, 8964, 19, 12],
            [2004, 8965, 41, 34],
            [2004, 8966, 36, 28],
            [2004, 8967, 39, 30],
            [2004, 8968, 30, 25],
            [2004, 8969, 18, 13],
            [2004, 8970, 40, 34],
            [2004, 8971, 34, 30],
            [2004, 8972, 17, 13],
            [2004, 8973, 39, 31],
            [2004, 8974, 13, 19],
            [2004, 8975, 45, 36],
            [2004, 8976, 48, 39],
            [2004, 8977, 26, 21],
            [2004, 8978, 14, 11],
            [2004, 8979, 37, 32],
            [2004, 8980, 30, 25],
            [2004, 8981, 29, 23],
            [2004, 8983, 34, 28],
            [2004, 8984, 28, 20],
            [2004, 8985, 33, 28],
            [2004, 8986, 25, 20],
            [2004, 8987, 27, 25],
            [2004, 8988, 18, 26],
            [2004, 8989, 34, 28],
            [2004, 8990, 23, 20],
            [2004, 8991, 32, 27],
            [2004, 8992, 18, 18],
            [2004, 8993, 33, 30],
            [2004, 8994, 41, 35],
            [2004, 8995, 35, 27],
            [2004, 8996, 45, 37],
            [2004, 8997, 22, 21],
            [2004, 8998, 27, 20],
            [2004, 8999, 19, 11],
            [2004, 9000, 47, 39],
            [2004, 9001, 41, 28],
            [2004, 9002, 39, 30],
            [2004, 9003, 23, 21],
            [2004, 9004, 44, 37],
            [2004, 9005, 20, 18],
            [2004, 9006, 34, 27],
            [2004, 9007, 27, 19],
            [2004, 9008, 37, 24],
            [2004, 9009, 32, 24],
            [2004, 9010, 25, 20],
            [2004, 9011, 19, 11],
            [2004, 9012, 27, 25],
            [2004, 9013, 20, 24],
            [2004, 9014, 36, 28],
            [2004, 9015, 19, 14],
            [2004, 9016, 19, 14],
            [2004, 9017, 39, 30],
            [2004, 9018, 26, 26],
            [2004, 9019, 30, 29],
            [2004, 9020, 18, 18],
            [2004, 9021, 34, 29],
            [2004, 9022, 32, 24],
            [2004, 9023, 31, 25],
            [2004, 9024, 36, 29],
            [2004, 9025, 30, 25],
            [2004, 9026, 34, 18],
            [2004, 9027, 27, 17],
            [2004, 9028, 39, 30],
            [2004, 9030, 40, 30],
            [2004, 9031, 32, 26],
            [2004, 9032, 41, 30],
            [2004, 9033, 30, 26],
            [2004, 9034, 46, 37],
            [2004, 9035, 39, 33],
            [2004, 9036, 36, 31],
            [2004, 9037, 16, 14],
            [2004, 9038, 27, 26],
            [2004, 9039, 15, 20],
            [2004, 9040, 34, 28],
            [2004, 9041, 23, 19],
            [2004, 9042, 39, 29],
            [2004, 9043, 33, 28],
            [2004, 9044, 24, 14],
            [2004, 9045, 33, 25],
            [2004, 9046, 28, 20],
            [2004, 9047, 33, 27],
            [2004, 9048, 30, 21],
            [2004, 9049, 53, 35],
            [2004, 9050, 28, 20],
            [2004, 9051, 41, 33],
            [2004, 9052, 44, 26],
            [2004, 9053, 31, 31],
            [2004, 9054, 35, 27],
            [2004, 9055, 45, 21],
            [2004, 9056, 48, 25],
            [2004, 9057, 41, 29],
            [2004, 9058, 25, 19],
            [2004, 9059, 47, 32],
            [2004, 9060, 40, 28],
            [2004, 9061, 65, 52],
            [2004, 9062, 21, 21],
            [2004, 9063, 33, 24],
            [2004, 9064, 16, 18],
            [2004, 9065, 22, 21],
            [2004, 9066, 16, 17],
            [2004, 9067, 30, 22],
            [2004, 9068, 26, 18],
            [2004, 9069, 33, 37],
            [2004, 9070, 17, 17],
            [2004, 9071, 25, 31],
            [2004, 9072, 13, 16],
            [2004, 9073, 14, 16],
            [2004, 9074, 29, 27],
            [2004, 9075, 20, 23],
            [2004, 9076, 23, 25],
            [2004, 9077, 34, 22],
            [2004, 9078, 26, 16],
            [2004, 9079, 36, 31],
            [2004, 9080, 21, 18],
            [2004, 9081, 27, 22],
            [2004, 9082, 44, 30],
            [2004, 9083, 30, 24],
            [2004, 9084, 37, 27],
            [2004, 9085, 19, 19],
            [2004, 9086, 36, 28],
            [2004, 9087, 41, 27],
            [2004, 9088, 29, 17],
            [2004, 9089, 17, 14],
            [2004, 9090, 23, 18],
            [2004, 9091, 23, 15],
            [2004, 9092, 39, 25],
            [2004, 9093, 20, 19],
            [2004, 9094, 45, 38],
            [2004, 9095, 14, 12],
            [2004, 9096, 26, 30],
            [2004, 9097, 29, 21],
            [2004, 9098, 36, 23],
            [2004, 9099, 19, 13],
            [2004, 9100, 33, 22],
            [2004, 9101, 15, 17],
            [2004, 9102, 37, 28],
            [2004, 9103, 24, 24],
            [2004, 9104, 36, 28],
            [2004, 9105, 21, 14],
            [2004, 9106, 28, 15],
            [2004, 9107, 33, 25],
            [2004, 9108, 34, 25],
            [2004, 9109, 33, 26],
            [2004, 9110, 37, 28],
            [2004, 9111, 25, 13],
            [2004, 9112, 43, 35],
            [2004, 9113, 32, 27],
            [2004, 9114, 48, 25],
            [2004, 9115, 14, 14],
            [2004, 9116, 22, 15],
            [2004, 9117, 29, 12],
            [2004, 9118, 43, 29],
            [2004, 9119, 17, 12],
            [2004, 9120, 27, 21],
            [2004, 9121, 30, 25],
            [2004, 9122, 37, 32],
            [2004, 9123, 26, 18],
            [2004, 9124, 38, 30],
            [2004, 9125, 16, 23],
            [2004, 9126, 40, 34],
            [2004, 9127, 28, 25],
            [2004, 9128, 34, 28],
            [2004, 9129, 37, 31],
            [2004, 9130, 49, 40],
            [2004, 9131, 25, 25],
            [2004, 9132, 39, 34],
            [2004, 9133, 26, 18],
            [2004, 9134, 34, 26],
            [2004, 9135, 44, 31],
            [2004, 9136, 40, 28],
            [2004, 9137, 16, 11],
            [2004, 9138, 19, 15],
            [2004, 9139, 27, 24],
            [2004, 9140, 39, 34],
            [2004, 9141, 25, 23],
            [2004, 9142, 45, 40],
            [2004, 9143, 20, 20],
            [2004, 9144, 23, 26],
            [2004, 9145, 32, 26],
            [2004, 9146, 40, 32],
            [2004, 9149, 18, 16],
            [2004, 9150, 19, 20],
            [2004, 9151, 16, 16],
            [2004, 9152, 21, 22],
            [2004, 9153, 12, 15],
            [2004, 9154, 14, 14],
            [2004, 9155, 20, 21],
            [2004, 9156, 23, 21],
            [2004, 9157, 23, 25],
            [2004, 9158, 11, 14],
            [2004, 9159, 19, 23],
            [2004, 9160, 14, 14],
            [2004, 9161, 17, 18],
            [2004, 9162, 22, 23],
            [2004, 9163, 25, 21],
            [2004, 9164, 18, 17],
            [2004, 9165, 16, 27],
            [2004, 9166, 19, 21],
            [2004, 9167, 17, 17],
            [2004, 9168, 23, 25],
            [2004, 9169, 20, 19],
            [2004, 9170, 24, 26],
            [2004, 9171, 17, 16],
            [2004, 9172, 18, 20],
            [2004, 9173, 19, 24],
            [2004, 9174, 17, 16],
            [2004, 9175, 18, 18],
            [2004, 9176, 10, 10],
            [2004, 9177, 18, 17],
            [2004, 9178, 19, 25],
            [2004, 9179, 20, 24],
            [2004, 9180, 12, 14],
            [2004, 9181, 17, 16],
            [2004, 9182, 21, 25],
            [2004, 9183, 19, 18],
            [2004, 9184, 22, 22],
            [2004, 9185, 20, 19],
            [2004, 9186, 14, 16],
            [2004, 9187, 20, 19],
            [2004, 9188, 23, 23],
            [2004, 9189, 22, 21],
            [2004, 9190, 14, 16],
            [2004, 9191, 19, 17],
            [2004, 9192, 17, 19],
            [2004, 9193, 18, 16],
            [2004, 9194, 26, 28],
            [2004, 9195, 28, 32],
            [2004, 9196, 29, 22],
            [2004, 9198, 29, 22],
            [2004, 9199, 27, 22],
            [2004, 9200, 27, 22],
            [2004, 9201, 32, 31],
            [2004, 9202, 32, 31],
            [2004, 9203, 10, 12],
            [2004, 9204, 9, 10],
            [2004, 9209, 25, 23],
            [2004, 9211, 33, 33],
            [2004, 9214, 39, 37],
            [2004, 9218, 23, 20],
            [2004, 9226, 38, 28],
            [2004, 9227, 42, 35],
            [2004, 9228, 40, 45],
            [2004, 9229, 35, 36],
            [2004, 9230, 34, 28],
            [2004, 9232, 35, 31],
            [2004, 9233, 31, 33],
            [2004, 9234, 31, 33],
            [2004, 9235, 31, 33],
            [2004, 9237, 30, 20],
            [2004, 9238, 33, 36],
            [2004, 9242, 35, 36],
            [2004, 9244, 39, 37],
            [2004, 9245, 24, 27],
            [2004, 9248, 32, 26],
            [2004, 9254, 87, 85],
            [2004, 9255, 43, 31],
            [2004, 9257, 60, 52],
            [2004, 9258, 34, 45],
            [2004, 9259, 48, 48],
            [2004, 9260, 41, 34],
            [2004, 9261, 62, 74],
            [2004, 9263, 44, 47],
            [2004, 9264, 37, 39],
            [2004, 9265, 41, 44],
            [2004, 9266, 68, 73],
            [2004, 9267, 59, 57],
            [2004, 9268, 52, 51],
            [2004, 9269, 76, 76],
            [2004, 9270, 68, 73],
            [2004, 9271, 71, 77],
            [2004, 9272, 77, 85],
            [2004, 9273, 73, 80],
            [2004, 9274, 82, 75],
            [2004, 9275, 48, 46],
            [2004, 9276, 79, 73],
            [2004, 9277, 65, 54],
            [2004, 9278, 72, 75],
            [2004, 9279, 69, 63],
            [2004, 9280, 50, 49],
            [2004, 9281, 76, 64],
            [2004, 9282, 83, 74],
            [2004, 9283, 72, 72],
            [2004, 9284, 100, 105],
            [2004, 9285, 62, 67],
            [2004, 9286, 90, 98],
            [2004, 9287, 95, 95],
            [2004, 9288, 52, 41],
            [2004, 9289, 85, 93],
            [2004, 9290, 59, 66],
            [2004, 9291, 83, 83],
            [2004, 9292, 82, 81],
            [2004, 9293, 59, 42],
            [2004, 9294, 51, 50],
            [2004, 9295, 69, 63],
            [2004, 9296, 52, 39],
            [2004, 9297, 77, 53],
            [2004, 9298, 67, 76],
            [2004, 9299, 81, 86],
            [2004, 9300, 86, 88],
            [2004, 9301, 70, 77],
            [2004, 9302, 95, 96],
            [2004, 9303, 71, 81],
            [2004, 9304, 59, 73],
            [2004, 9305, 74, 86],
            [2004, 9306, 97, 111],
            [2004, 9307, 40, 53],
            [2004, 9308, 51, 64],
            [2004, 9309, 46, 55],
            [2004, 9310, 57, 60],
            [2004, 9311, 54, 61],
            [2004, 9312, 57, 60],
            [2004, 9313, 53, 59],
            [2004, 9314, 71, 80],
            [2004, 9315, 35, 34],
            [2004, 9316, 37, 25],
            [2004, 9317, 12, 14],
            [2004, 9318, 14, 16],
            [2004, 9319, 33, 37],
            [2004, 9320, 47, 44],
            [2004, 9327, 12, 14],
            [2004, 9328, 19, 22],
            [2004, 9329, 27, 29],
            [2004, 9330, 36, 38],
            [2004, 9331, 22, 24],
            [2004, 9332, 26, 29],
            [2004, 9333, 11, 14],
            [2004, 9334, 11, 13],
            [2004, 9335, 22, 23],
            [2004, 9336, 20, 22],
            [2004, 9337, 16, 19],
            [2004, 9338, 10, 13],
            [2004, 9339, 16, 18],
            [2004, 9340, 35, 38],
            [2004, 9341, 17, 23],
            [2004, 9342, 28, 28],
            [2004, 9343, 8, 9],
            [2004, 9344, 16, 16],
            [2004, 9345, 17, 21],
            [2004, 9346, 12, 13],
            [2004, 9347, 10, 12],
            [2004, 9348, 23, 21],
            [2004, 9349, 16, 19],
            [2004, 9350, 35, 40],
            [2004, 9351, 28, 26],
            [2004, 9352, 34, 36],
            [2004, 9353, 15, 20],
            [2004, 9354, 25, 30],
            [2004, 9355, 17, 15],
            [2004, 9356, 32, 30],
            [2004, 9357, 15, 18],
            [2004, 9358, 22, 25],
            [2004, 9359, 16, 24],
            [2004, 9360, 26, 29],
            [2004, 9361, 20, 18],
            [2004, 9362, 31, 29],
            [2004, 9363, 20, 22],
            [2004, 9364, 34, 26],
            [2004, 9365, 16, 21],
            [2004, 9366, 45, 50],
            [2004, 9367, 19, 21],
            [2004, 9368, 61, 65],
            [2004, 9369, 28, 35],
            [2004, 9370, 15, 16],
            [2004, 9371, 22, 26],
            [2004, 9372, 45, 30],
            [2004, 9373, 18, 18],
            [2004, 9374, 32, 31],
            [2004, 9375, 19, 23],
            [2004, 9376, 45, 45],
            [2004, 9377, 12, 13],
            [2004, 9378, 18, 22],
            [2004, 9379, 27, 32],
            [2004, 9380, 24, 27],
            [2004, 9381, 55, 51],
            [2004, 9382, 25, 30],
            [2004, 9383, 45, 30],
            [2004, 9384, 16, 17],
            [2004, 9385, 17, 18],
            [2004, 9386, 16, 17],
            [2004, 9387, 14, 14],
            [2004, 9388, 13, 14],
            [2004, 9389, 16, 15],
            [2004, 9390, 17, 21],
            [2004, 9391, 21, 24],
            [2004, 9392, 19, 21],
            [2004, 9393, 21, 21],
            [2004, 9394, 14, 15],
            [2004, 9395, 18, 18],
            [2004, 9396, 20, 24],
            [2004, 9397, 34, 38],
            [2004, 9398, 33, 38],
            [2004, 9399, 45, 50],
            [2004, 9400, 20, 24],
            [2004, 9401, 70, 64],
            [2004, 9402, 38, 29],
            [2004, 9403, 102, 75],
            [2004, 9406, 120, 82],
            [2004, 9411, 98, 71],
            [2004, 9416, 50, 60],
            [2004, 9417, 103, 76],
            [2004, 9420, 100, 73],
            [2004, 9423, 88, 65],
            [2004, 9428, 98, 74],
            [2004, 9431, 100, 73],
            [2004, 9436, 100, 73],
            [2004, 9443, 101, 74],
            [2004, 9444, 98, 71],
            [2004, 9451, 120, 76],
            [2004, 9452, 100, 80],
            [2004, 9453, 82, 63],
            [2004, 9456, 100, 73],
            [2004, 9457, 88, 90],
            [2004, 9458, 100, 74],
            [2004, 9465, 57, 53],
            [2004, 9470, 99, 72],
            [2004, 9473, 43, 65],
            [2004, 9474, 120, 90],
            [2004, 9477, 34, 42],
            [2004, 9478, 52, 65],
            [2004, 9487, 25, 43],
            [2004, 9488, 42, 65],
            [2004, 9491, 39, 59],
            [2004, 9492, 64, 71],
            [2004, 9497, 41, 28],
            [2004, 9498, 118, 43],
            [2004, 9509, 88, 82],
            [2004, 9519, 21, 25],
            [2004, 9520, 89, 53],
            [2004, 9525, 21, 20],
            [2004, 9526, 44, 50],
            [2004, 9529, 32, 31],
            [2004, 9530, 62, 65],
            [2004, 9531, 37, 47],
            [2004, 9532, 78, 75],
            [2004, 9539, 51, 48],
            [2004, 9540, 70, 76],
            [2004, 9541, 38, 35],
            [2004, 9542, 61, 56],
            [2004, 9543, 32, 39],
            [2004, 9544, 54, 61],
            [2004, 9547, 34, 41],
            [2004, 9548, 58, 67],
            [2004, 9549, 31, 31],
            [2004, 9550, 60, 53],
            [2004, 9551, 32, 45],
            [2004, 9552, 78, 75],
            [2004, 9553, 39, 43],
            [2004, 9554, 57, 65],
            [2004, 9555, 55, 90],
            [2004, 9556, 81, 90],
            [2004, 9557, 42, 47],
            [2004, 9558, 91, 76],
            [2004, 9561, 38, 54],
            [2004, 9562, 61, 84],
            [2004, 9581, 44, 53],
            [2004, 9582, 51, 67],
            [2004, 9593, 32, 45],
            [2004, 9594, 52, 79],
            [2004, 9595, 36, 46],
            [2004, 9596, 61, 70],
            [2004, 9597, 25, 24],
            [2004, 9598, 75, 90],
            [2004, 9609, 31, 31],
            [2004, 9610, 47, 53],
            [2004, 9611, 45, 45],
            [2004, 9612, 57, 60],
            [2004, 9613, 60, 90],
            [2004, 9614, 86, 90],
            [2004, 9617, 17, 15],
            [2004, 9618, 58, 53],
            [2004, 9619, 21, 20],
            [2004, 9620, 21, 20],
            [2004, 9633, 48, 57],
            [2004, 9634, 86, 74],
            [2004, 9639, 18, 24],
            [2004, 9640, 66, 53],
            [2004, 9641, 49, 38],
            [2004, 9642, 120, 65],
            [2004, 9643, 26, 42],
            [2004, 9644, 52, 67],
            [2004, 9651, 90, 60],
            [2004, 9652, 90, 60],
            [2004, 9653, 50, 45],
            [2004, 9654, 65, 39],
            [2004, 9661, 80, 47],
            [2004, 9662, 100, 44],
            [2004, 9663, 70, 45],
            [2004, 9664, 70, 45],
            [2004, 9665, 48, 40],
            [2004, 9666, 60, 40],
            [2004, 9667, 21, 18],
            [2004, 9668, 38, 32],
            [2004, 9670, 100, 55],
            [2004, 9673, 40, 24],
            [2004, 9674, 45, 24],
            [2004, 9675, 35, 37],
            [2004, 9676, 57, 46],
            [2004, 9677, 20, 21],
            [2004, 9678, 35, 25],
            [2004, 9681, 50, 37],
            [2004, 9682, 60, 37],
            [2004, 9687, 19, 28],
            [2004, 9689, 23, 21],
            [2004, 9690, 40, 33],
            [2004, 9691, 60, 38],
            [2004, 9692, 40, 31],
            [2004, 9693, 40, 33],
            [2004, 9694, 40, 35],
            [2004, 9695, 39, 38],
            [2004, 9696, 43, 35],
            [2004, 9699, 31, 35],
            [2004, 9700, 80, 45],
            [2004, 9701, 32, 27],
            [2004, 9702, 100, 45],
            [2004, 9704, 90, 43],
            [2004, 9705, 35, 40],
            [2004, 9706, 100, 60],
            [2004, 9709, 21, 17],
            [2004, 9710, 25, 18],
            [2004, 9711, 25, 30],
            [2004, 9712, 25, 30],
            [2004, 9713, 31, 31],
            [2004, 9714, 35, 49],
            [2004, 9715, 70, 55],
            [2004, 9716, 25, 25],
            [2004, 9717, 35, 35],
            [2004, 9718, 31, 29],
            [2004, 9720, 55, 46],
            [2004, 9721, 65, 39],
            [2004, 9722, 39, 43],
            [2004, 9723, 55, 40],
            [2004, 9724, 68, 58],
            [2004, 9725, 75, 52],
            [2004, 9726, 25, 28],
            [2004, 9727, 47, 31],
            [2004, 9728, 25, 25],
            [2004, 9729, 21, 23],
            [2004, 9730, 42, 50],
            [2004, 9731, 68, 55],
            [2004, 9735, 46, 48],
            [2004, 9736, 50, 55],
            [2004, 9737, 35, 21],
            [2004, 9738, 38, 46],
            [2004, 9739, 46, 42],
            [2004, 9740, 90, 90],
            [2004, 9741, 95, 78],
            [2004, 9742, 53, 46],
            [2004, 9743, 35, 31],
            [2004, 9744, 95, 60],
            [2004, 9745, 40, 23],
            [2004, 9746, 46, 28],
            [2004, 9747, 40, 55],
            [2004, 9748, 40, 45],
            [2004, 9751, 42, 47],
            [2004, 9752, 39, 57],
            [2004, 9755, 38, 36],
            [2004, 9756, 35, 33],
            [2004, 9757, 21, 18],
            [2004, 9758, 25, 18],
            [2004, 9759, 20, 14],
            [2004, 9760, 34, 22],
            [2004, 9761, 35, 23],
            [2004, 9762, 33, 17],
            [2004, 9763, 21, 15],
            [2004, 9764, 23, 14],
            [2004, 9765, 32, 24],
            [2004, 9766, 35, 18],
            [2004, 9767, 34, 39],
            [2004, 9768, 28, 21],
            [2004, 9769, 23, 16],
            [2004, 9770, 39, 33],
            [2004, 9771, 43, 21],
            [2004, 9772, 28, 15],
            [2004, 9773, 33, 25],
            [2004, 9774, 21, 17],
            [2004, 9775, 23, 17],
            [2004, 9776, 26, 14],
            [2004, 9777, 34, 22],
            [2004, 9778, 35, 25],
            [2004, 9779, 33, 24],
            [2004, 9780, 34, 26],
            [2004, 9781, 27, 16],
            [2004, 9782, 35, 25],
            [2004, 9783, 30, 19],
            [2004, 9784, 30, 23],
            [2004, 9785, 26, 22],
            [2004, 9786, 20, 15],
            [2004, 9787, 33, 23],
            [2004, 9788, 20, 16],
            [2004, 9789, 35, 19],
            [2004, 9790, 34, 22],
            [2004, 9791, 36, 26],
            [2004, 9792, 34, 29],
            [2004, 9793, 16, 12],
            [2004, 9794, 13, 13],
            [2004, 9795, 12, 12],
            [2004, 9796, 17, 15],
            [2004, 9797, 14, 12],
            [2004, 9798, 14, 13],
            [2004, 9799, 35, 30],
            [2004, 9800, 20, 19],
            [2004, 9801, 18, 15],
            [2004, 9802, 18, 15],
            [2004, 9803, 11, 9],
            [2004, 9804, 17, 14],
            [2004, 9805, 29, 23],
            [2004, 9806, 19, 16],
            [2004, 9807, 28, 19],
            [2004, 9808, 58, 38],
            [2004, 9809, 34, 17],
            [2004, 9811, 35, 23],
            [2004, 9812, 54, 36],
            [2004, 9813, 49, 24],
            [2004, 9814, 20, 13],
            [2004, 9815, 38, 23],
            [2004, 9816, 29, 16],
            [2004, 9817, 22, 13],
            [2004, 9818, 49, 19],
            [2004, 9819, 42, 30],
            [2004, 9820, 52, 33],
            [2004, 9821, 42, 25],
            [2004, 9822, 22, 19],
            [2004, 9823, 26, 19],
            [2004, 9824, 28, 23],
            [2004, 9825, 19, 16],
            [2004, 9826, 40, 31],
            [2004, 9827, 38, 25],
            [2004, 9828, 46, 32],
            [2004, 9829, 33, 24],
            [2004, 9830, 28, 23],
            [2004, 9831, 34, 23],
            [2004, 9832, 31, 21],
            [2004, 9833, 30, 22],
            [2004, 9834, 53, 35],
            [2004, 9835, 33, 28],
            [2004, 9836, 39, 28],
            [2004, 9837, 28, 20],
            [2004, 9838, 44, 33],
            [2004, 9839, 18, 16],
            [2004, 9840, 36, 27],
            [2004, 9841, 63, 39],
            [2004, 9842, 32, 20],
            [2004, 9843, 28, 20],
            [2004, 9844, 33, 22],
            [2004, 9845, 29, 24],
            [2004, 9846, 26, 18],
            [2004, 9847, 15, 13],
            [2004, 9848, 26, 17],
            [2004, 9849, 24, 16],
            [2004, 9850, 25, 14],
            [2004, 9851, 24, 13],
            [2004, 9852, 19, 12],
            [2004, 9853, 23, 17],
            [2004, 9854, 14, 12],
            [2004, 9855, 26, 23],
            [2004, 9856, 15, 16],
            [2004, 9857, 16, 13],
            [2004, 9858, 37, 25],
            [2004, 9859, 48, 31],
            [2004, 9860, 42, 31],
            [2004, 9861, 53, 45],
            [2004, 9862, 25, 26],
            [2004, 9863, 39, 28],
            [2004, 9864, 48, 23],
            [2004, 9865, 34, 22],
            [2004, 9866, 47, 22],
            [2004, 9867, 20, 16],
            [2004, 9868, 40, 28],
            [2004, 9869, 36, 23],
            [2004, 9870, 35, 37],
            [2004, 9871, 39, 25],
            [2004, 9872, 23, 21],
            [2004, 9873, 31, 29],
            [2004, 9874, 35, 20],
            [2004, 9875, 31, 23],
            [2004, 9876, 24, 21],
            [2004, 9877, 33, 26],
            [2004, 9878, 34, 23],
            [2004, 9879, 35, 22],
            [2004, 9880, 36, 28],
            [2004, 9881, 41, 24],
            [2004, 9882, 32, 27],
            [2004, 9883, 30, 20],
            [2004, 9884, 31, 19],
            [2004, 9885, 35, 21],
            [2004, 9886, 38, 21],
            [2004, 9887, 35, 25],
            [2004, 9888, 44, 33],
            [2004, 9889, 39, 26],
            [2004, 9890, 35, 26],
            [2004, 9891, 30, 21],
            [2004, 9892, 28, 22],
            [2004, 9893, 25, 18],
            [2004, 9894, 44, 30],
            [2004, 9895, 26, 16],
            [2004, 9896, 11, 14],
            [2004, 9897, 32, 22],
            [2004, 9898, 35, 26],
            [2004, 9899, 22, 18],
            [2004, 9900, 48, 40],
            [2004, 9901, 43, 31],
            [2004, 9902, 58, 43],
            [2004, 9903, 57, 48],
            [2004, 9904, 52, 38],
            [2004, 9905, 34, 28],
            [2004, 9906, 39, 24],
            [2004, 9907, 30, 26],
            [2004, 9908, 52, 35],
            [2004, 9909, 16, 14],
            [2004, 9910, 43, 37],
            [2004, 9911, 58, 36],
            [2004, 9912, 41, 27],
            [2004, 9913, 23, 20],
            [2004, 9914, 31, 23],
            [2004, 9915, 29, 25],
            [2004, 9916, 30, 27],
            [2004, 9917, 24, 22],
            [2004, 9918, 61, 26],
            [2004, 9919, 61, 50],
            [2004, 9920, 62, 45],
            [2004, 9921, 25, 20],
            [2004, 9922, 26, 16],
            [2004, 9923, 29, 21],
            [2004, 9924, 35, 22],
            [2004, 9925, 44, 39],
            [2004, 9926, 35, 37],
            [2004, 9927, 29, 21],
            [2004, 9928, 47, 27],
            [2004, 9929, 36, 33],
            [2004, 9930, 36, 24],
            [2004, 9931, 46, 30],
            [2004, 9932, 48, 26],
            [2004, 9933, 44, 33],
            [2004, 9934, 39, 24],
            [2004, 9935, 34, 22],
            [2004, 9936, 35, 26],
            [2004, 9937, 26, 24],
            [2004, 9938, 16, 15],
            [2004, 9939, 41, 22],
            [2004, 9940, 33, 28],
            [2004, 9941, 36, 21],
            [2004, 9942, 20, 16],
            [2004, 9943, 71, 46],
            [2004, 9944, 38, 24],
            [2004, 9945, 55, 28],
            [2004, 9946, 34, 19],
            [2004, 9947, 46, 26],
            [2004, 9948, 69, 38],
            [2004, 9949, 68, 43],
            [2004, 9950, 47, 37],
            [2004, 9951, 33, 22],
            [2004, 9952, 44, 24],
            [2004, 9953, 23, 19],
            [2004, 9954, 54, 36],
            [2004, 9955, 22, 19],
            [2004, 9956, 46, 24],
            [2004, 9957, 63, 34],
            [2004, 9958, 26, 22],
            [2004, 9959, 69, 38],
            [2004, 9960, 39, 22],
            [2004, 9961, 27, 24],
            [2004, 9962, 32, 22],
            [2004, 9963, 56, 35],
            [2004, 9964, 32, 28],
            [2004, 9965, 30, 15],
            [2004, 9966, 46, 26],
            [2004, 9967, 56, 30],
            [2004, 9968, 35, 32],
            [2004, 9969, 30, 19],
            [2004, 9970, 49, 26],
            [2004, 9971, 26, 21],
            [2004, 9972, 71, 35],
            [2004, 9973, 38, 31],
            [2004, 9974, 31, 16],
            [2004, 9975, 67, 32],
            [2004, 9976, 75, 37],
            [2004, 9977, 32, 19],
            [2004, 9978, 38, 20],
            [2004, 9979, 62, 33],
            [2004, 9980, 37, 21],
            [2004, 9981, 24, 16],
            [2004, 9982, 17, 13],
            [2004, 9983, 58, 29],
            [2004, 9984, 33, 23],
            [2004, 9985, 36, 23],
            [2004, 9986, 36, 24],
            [2004, 9987, 38, 31],
            [2004, 9988, 33, 23],
            [2004, 9989, 30, 25],
            [2004, 9990, 35, 22],
            [2004, 9991, 36, 28],
            [2004, 9992, 41, 31],
            [2004, 9993, 29, 31],
            [2004, 9994, 24, 22],
            [2004, 9995, 38, 30],
            [2004, 9996, 29, 25],
            [2004, 9997, 16, 20],
            [2004, 9998, 17, 15],
            [2004, 9999, 25, 27],
            [2004, 10000, 23, 17],
            [2004, 10001, 19, 16],
            [2004, 10002, 17, 14],
            [2004, 10003, 36, 24],
            [2004, 10004, 21, 17],
            [2004, 10005, 21, 17],
            [2004, 10006, 16, 13],
            [2004, 10007, 32, 34],
            [2004, 10008, 47, 44],
            [2004, 10009, 43, 28],
            [2004, 10010, 48, 28],
            [2004, 10011, 41, 26],
            [2004, 10012, 49, 23],
            [2004, 10013, 30, 24],
            [2004, 10014, 36, 32],
            [2004, 10015, 29, 26],
            [2004, 10016, 33, 32],
            [2004, 10017, 39, 30],
            [2004, 10018, 38, 32],
            [2004, 10019, 38, 29],
            [2004, 10020, 47, 38],
            [2004, 10021, 53, 37],
            [2004, 10022, 53, 40],
            [2004, 10023, 49, 36],
            [2004, 10024, 72, 48],
            [2004, 10025, 63, 48],
            [2004, 10026, 57, 41],
            [2004, 10027, 48, 37],
            [2004, 10030, 47, 37],
            [2004, 10031, 72, 60],
            [2004, 10032, 63, 46],
            [2004, 10033, 40, 29],
            [2004, 10034, 48, 31],
            [2004, 10035, 66, 37],
            [2004, 10036, 72, 34],
            [2004, 10037, 67, 38],
            [2004, 10038, 29, 19],
            [2004, 10039, 20, 20],
            [2004, 10040, 27, 19],
            [2004, 10041, 27, 16],
            [2004, 10042, 50, 33],
            [2004, 10043, 51, 27],
            [2004, 10044, 58, 27],
            [2004, 10045, 34, 21],
            [2004, 10046, 47, 31],
            [2004, 10047, 44, 24],
            [2004, 10048, 41, 26],
            [2004, 10049, 31, 22],
            [2004, 10050, 40, 28],
            [2004, 10051, 50, 34],
            [2004, 10052, 50, 41],
            [2004, 10053, 53, 39],
            [2004, 10054, 46, 39],
            [2004, 10055, 51, 42],
            [2004, 10056, 45, 42],
            [2004, 10057, 53, 43],
            [2004, 10058, 30, 32],
            [2004, 10059, 55, 31],
            [2004, 10060, 45, 30],
            [2004, 10061, 51, 45],
            [2004, 10063, 20, 20],
            [2004, 10064, 34, 27],
            [2004, 10065, 31, 34],
            [2004, 10066, 35, 30],
            [2004, 10067, 48, 37],
            [2004, 10068, 58, 42],
            [2004, 10069, 49, 38],
            [2004, 10070, 38, 23],
            [2004, 10071, 46, 33],
            [2004, 10072, 51, 21],
            [2004, 10073, 49, 25],
            [2004, 10074, 47, 25],
            [2004, 10075, 53, 31],
            [2004, 10076, 52, 31],
            [2004, 10077, 48, 31],
            [2004, 10078, 61, 37],
            [2004, 10079, 38, 28],
            [2004, 10080, 37, 31],
            [2004, 10081, 57, 38],
            [2004, 10082, 38, 40],
            [2004, 10083, 37, 33],
            [2004, 10084, 39, 28],
            [2004, 10085, 38, 21],
            [2004, 10086, 41, 25],
            [2004, 10087, 38, 18],
            [2004, 10088, 50, 33],
            [2004, 10089, 51, 34],
            [2004, 10090, 40, 31],
            [2004, 10091, 51, 25],
            [2004, 10092, 52, 27],
            [2004, 10093, 37, 31],
            [2004, 10094, 64, 41],
            [2004, 10095, 57, 38],
            [2004, 10096, 47, 30],
            [2004, 10097, 42, 29],
            [2004, 10098, 47, 32],
            [2004, 10099, 59, 41],
            [2004, 10101, 58, 45],
            [2004, 10102, 49, 36],
            [2004, 10103, 51, 45],
            [2004, 10104, 19, 18],
            [2004, 10105, 28, 20],
            [2004, 10106, 28, 25],
            [2004, 10107, 49, 43],
            [2004, 10108, 54, 46],
            [2004, 10109, 100, 64],
            [2004, 10110, 46, 38],
            [2004, 10111, 63, 47],
            [2004, 10112, 63, 49],
            [2004, 10113, 92, 74],
            [2004, 10114, 56, 36],
            [2004, 10115, 37, 27],
            [2004, 10116, 41, 33],
            [2004, 10117, 40, 35],
            [2004, 10118, 43, 43],
            [2004, 10119, 24, 15],
            [2004, 10120, 29, 19],
            [2004, 10121, 56, 46],
            [2004, 10122, 55, 45],
            [2004, 10123, 72, 59],
            [2004, 10124, 61, 56],
            [2004, 10125, 57, 34],
            [2004, 10126, 51, 32],
            [2004, 10127, 50, 30],
            [2004, 10128, 51, 36],
            [2004, 10129, 77, 50],
            [2004, 10130, 72, 49],
            [2004, 10131, 39, 31],
            [2004, 10132, 40, 31],
            [2004, 10133, 51, 29],
            [2004, 10134, 80, 56],
            [2004, 10135, 78, 61],
            [2004, 10136, 45, 25],
            [2004, 10137, 56, 38],
            [2004, 10138, 46, 27],
            [2004, 10139, 47, 29],
            [2004, 10141, 43, 29],
            [2004, 10142, 47, 29],
            [2004, 10144, 57, 29],
            [2004, 10145, 39, 36],
            [2004, 10146, 43, 38],
            [2004, 10148, 40, 24],
            [2004, 10149, 42, 42],
            [2004, 10150, 25, 28],
            [2004, 10151, 41, 36],
            [2004, 10152, 52, 40],
            [2004, 10153, 58, 44],
            [2004, 10154, 22, 23],
            [2004, 10155, 50, 47],
            [2004, 10156, 33, 28],
            [2004, 10157, 53, 39],
            [2004, 10158, 31, 32],
            [2004, 10159, 42, 32],
            [2004, 10160, 44, 28],
            [2004, 10161, 60, 36],
            [2004, 10162, 48, 25],
            [2004, 10163, 68, 35],
            [2004, 10164, 47, 25],
            [2004, 10165, 53, 29],
            [2004, 10166, 40, 24],
            [2004, 10167, 46, 34],
            [2004, 10168, 48, 37],
            [2004, 10169, 50, 36],
            [2004, 10170, 28, 31],
            [2004, 10171, 43, 35],
            [2004, 10172, 34, 28],
            [2004, 10173, 42, 34],
            [2004, 10174, 42, 27],
            [2004, 10175, 48, 33],
            [2004, 10176, 18, 19],
            [2004, 10177, 16, 18],
            [2004, 10178, 19, 19],
            [2004, 10179, 17, 19],
            [2004, 10180, 36, 28],
            [2004, 10181, 22, 15],
            [2004, 10182, 34, 34],
            [2004, 10183, 40, 24],
            [2004, 10184, 37, 17],
            [2004, 10185, 16, 14],
            [2004, 10186, 15, 12],
            [2004, 10187, 20, 17],
            [2004, 10188, 21, 14],
            [2004, 10189, 47, 28],
            [2004, 10190, 19, 14],
            [2004, 10191, 39, 24],
            [2004, 10192, 30, 20],
            [2004, 10193, 18, 17],
            [2004, 10194, 15, 11],
            [2004, 10195, 14, 12],
            [2004, 10196, 38, 28],
            [2004, 10197, 37, 26],
            [2004, 10198, 28, 29],
            [2004, 10199, 27, 29],
            [2004, 10200, 27, 30],
            [2004, 10201, 26, 27],
            [2004, 10202, 61, 50],
            [2004, 10203, 52, 37],
            [2004, 10204, 53, 37],
            [2004, 10205, 42, 31],
            [2004, 10206, 39, 27],
            [2004, 10207, 37, 26],
            [2004, 10208, 39, 29],
            [2004, 10209, 37, 27],
            [2004, 10210, 43, 34],
            [2004, 10211, 41, 32],
            [2004, 10212, 44, 29],
            [2004, 10213, 44, 28],
            [2004, 10214, 39, 33],
            [2004, 10215, 37, 32],
            [2004, 10216, 45, 32],
            [2004, 10217, 48, 34],
            [2004, 10218, 41, 33],
            [2004, 10219, 40, 33],
            [2004, 10220, 38, 31],
            [2004, 10221, 41, 28],
            [2004, 10222, 39, 30],
            [2004, 10223, 48, 39],
            [2004, 10224, 57, 46],
            [2004, 10225, 50, 45],
            [2004, 10226, 30, 28],
            [2004, 10227, 31, 28],
            [2004, 10228, 29, 26],
            [2004, 10234, 42, 33],
            [2004, 10235, 34, 29],
            [2004, 10236, 34, 30],
            [2004, 10237, 25, 24],
            [2004, 10238, 33, 30],
            [2004, 10239, 47, 39],
            [2004, 10240, 28, 26],
            [2004, 10241, 23, 28],
            [2004, 10242, 29, 25],
            [2004, 10243, 33, 27],
            [2004, 10244, 33, 34],
            [2004, 10245, 17, 22],
            [2004, 10246, 31, 27],
            [2004, 10247, 20, 22],
            [2004, 10248, 33, 24],
            [2004, 10249, 20, 24],
            [2004, 10250, 32, 29],
            [2004, 10251, 31, 26],
            [2004, 10252, 32, 29],
            [2004, 10253, 32, 31],
            [2004, 10255, 31, 29],
            [2004, 10256, 38, 34],
            [2004, 10257, 30, 26],
            [2004, 10258, 34, 31],
            [2004, 10259, 16, 23],
            [2004, 10260, 33, 30],
            [2004, 10261, 35, 27],
            [2004, 10263, 19, 22],
            [2004, 10264, 34, 29],
            [2004, 10267, 23, 22],
            [2004, 10268, 33, 26],
            [2004, 10269, 22, 23],
            [2004, 10270, 29, 29],
            [2004, 10271, 34, 27],
            [2004, 10272, 27, 25],
            [2004, 10276, 27, 26],
            [2004, 10277, 35, 31],
            [2004, 10278, 21, 25],
            [2004, 10279, 32, 29],
            [2004, 10280, 20, 26],
            [2004, 10281, 32, 33],
            [2004, 10283, 21, 23],
            [2004, 10284, 27, 27],
            [2004, 10285, 20, 21],
            [2004, 10286, 27, 24],
            [2004, 10287, 27, 24],
            [2004, 10288, 28, 22],
            [2004, 10289, 32, 27],
            [2004, 10290, 29, 25],
            [2004, 10291, 29, 26],
            [2004, 10292, 22, 24],
            [2004, 10293, 29, 29],
            [2004, 10294, 16, 22],
            [2004, 10295, 21, 25],
            [2004, 10296, 29, 28],
            [2004, 10297, 21, 23],
            [2004, 10298, 28, 27],
            [2004, 10299, 21, 23],
            [2004, 10300, 29, 26],
            [2004, 10301, 29, 29],
            [2004, 10302, 21, 24],
            [2004, 10303, 32, 31],
            [2004, 10304, 21, 25],
            [2004, 10305, 30, 29],
            [2004, 10306, 25, 28],
            [2004, 10307, 25, 27],
            [2004, 10309, 27, 25],
            [2004, 10310, 21, 25],
            [2004, 10311, 31, 30],
            [2004, 10312, 25, 24],
            [2004, 10313, 35, 27],
            [2004, 10314, 34, 28],
            [2004, 10315, 31, 24],
            [2004, 10317, 23, 23],
            [2004, 10318, 38, 30],
            [2004, 10319, 23, 27],
            [2004, 10320, 46, 30],
            [2004, 10321, 24, 23],
            [2004, 10322, 32, 32],
            [2004, 10323, 22, 27],
            [2004, 10326, 42, 33],
            [2004, 10327, 22, 24],
            [2004, 10329, 27, 23],
            [2004, 10330, 25, 27],
            [2004, 10332, 19, 22],
            [2004, 10333, 30, 29],
            [2004, 10334, 31, 29],
            [2004, 10335, 30, 31],
            [2004, 10337, 22, 22],
            [2004, 10338, 35, 29],
            [2004, 10339, 24, 25],
            [2004, 10340, 37, 29],
            [2004, 10341, 20, 21],
            [2004, 10342, 30, 25],
            [2004, 10343, 26, 24],
            [2004, 10344, 25, 28],
            [2004, 10347, 20, 27],
            [2004, 10354, 19, 21],
            [2004, 10355, 32, 28],
            [2004, 10356, 23, 25],
            [2004, 10357, 31, 31],
            [2004, 10358, 30, 26],
            [2004, 10360, 19, 22],
            [2004, 10361, 33, 27],
            [2004, 10362, 30, 29],
            [2004, 10363, 42, 30],
            [2004, 10364, 50, 30],
            [2004, 10366, 33, 30],
            [2004, 10367, 40, 28],
            [2004, 10368, 48, 33],
            [2004, 10369, 40, 29],
            [2004, 10370, 51, 35],
            [2004, 10371, 29, 34],
            [2004, 10372, 19, 22],
            [2004, 10374, 21, 24],
            [2004, 10376, 20, 21],
            [2004, 10377, 25, 25],
            [2004, 10378, 27, 27],
            [2004, 10380, 24, 25],
            [2004, 10381, 42, 32],
            [2004, 10382, 25, 26],
            [2004, 10383, 50, 32],
            [2004, 10384, 29, 28],
            [2004, 10385, 52, 33],
            [2004, 10388, 17, 24],
            [2004, 10390, 23, 26],
            [2004, 10391, 28, 24],
            [2004, 10392, 27, 27],
            [2004, 10394, 20, 21],
            [2004, 10395, 30, 27],
            [2004, 10396, 21, 23],
            [2004, 10398, 21, 25],
            [2004, 10399, 31, 28],
            [2004, 10400, 22, 24],
            [2004, 10402, 20, 26],
            [2004, 10403, 35, 34],
            [2004, 10404, 24, 27],
            [2004, 10408, 20, 26],
            [2004, 10409, 31, 33],
            [2004, 10410, 22, 27],
            [2004, 10411, 34, 31],
            [2004, 10412, 32, 21],
            [2004, 10413, 57, 36],
            [2004, 10417, 33, 33],
            [2004, 10418, 20, 22],
            [2004, 10419, 28, 28],
            [2004, 10420, 33, 33],
            [2004, 10422, 26, 28],
            [2004, 10424, 36, 30],
            [2004, 10425, 20, 24],
            [2004, 10426, 30, 30],
            [2004, 10427, 25, 24],
            [2004, 10428, 27, 29],
            [2004, 10431, 21, 25],
            [2004, 10432, 33, 29],
            [2004, 10433, 19, 22],
            [2004, 10434, 33, 28],
            [2004, 10435, 31, 26],
            [2004, 10436, 24, 23],
            [2004, 10437, 29, 23],
            [2004, 10438, 22, 24],
            [2004, 10439, 31, 32],
            [2004, 10440, 20, 25],
            [2004, 10441, 30, 27],
            [2004, 10442, 25, 26],
            [2004, 10443, 20, 21],
            [2004, 10444, 32, 24],
            [2004, 10445, 35, 29],
            [2004, 10447, 19, 20],
            [2004, 10448, 31, 27],
            [2004, 10450, 19, 23],
            [2004, 10453, 44, 26],
            [2004, 10454, 38, 25],
            [2004, 10455, 44, 29],
            [2004, 10456, 19, 22],
            [2004, 10458, 20, 22],
            [2004, 10459, 27, 24],
            [2004, 10461, 21, 26],
            [2004, 10463, 17, 21],
            [2004, 10464, 26, 27],
            [2004, 10467, 20, 26],
            [2004, 10469, 23, 23],
            [2004, 10471, 22, 21],
            [2004, 10474, 13, 11],
            [2004, 10475, 13, 11],
            [2004, 10476, 15, 16],
            [2004, 10477, 17, 17],
            [2004, 10478, 23, 28],
            [2004, 10479, 32, 24],
            [2004, 10480, 19, 20],
            [2004, 10482, 20, 23],
            [2004, 10483, 26, 28],
            [2004, 10484, 20, 23],
            [2004, 10485, 25, 29],
            [2004, 10486, 20, 23],
            [2004, 10487, 25, 30],
            [2004, 10490, 16, 25],
            [2004, 10491, 9, 21],
            [2004, 10492, 8, 13],
            [2004, 10493, 34, 33],
            [2004, 10494, 11, 37],
            [2004, 10495, 11, 27],
            [2004, 10496, 9, 18],
            [2004, 10497, 28, 50],
            [2004, 10498, 9, 24],
            [2004, 10499, 9, 53],
            [2004, 10500, 11, 54],
            [2004, 10501, 11, 54],
            [2004, 10502, 32, 73],
            [2004, 10503, 11, 56],
            [2004, 10504, 14, 75],
            [2004, 10505, 33, 51],
            [2004, 10506, 15, 34],
            [2004, 10507, 9, 21],
            [2004, 10508, 26, 56],
            [2004, 10509, 28, 38],
            [2004, 10510, 14, 39],
            [2004, 10511, 7, 19],
            [2004, 10512, 19, 21],
            [2004, 10513, 29, 28],
            [2004, 10514, 15, 22],
            [2004, 10515, 15, 23],
            [2004, 10516, 14, 20],
            [2004, 10517, 19, 25],
            [2004, 10518, 14, 14],
            [2004, 10519, 19, 16],
            [2004, 10520, 9, 9],
            [2004, 10521, 16, 20],
            [2004, 10522, 16, 19],
            [2004, 10523, 16, 19],
            [2004, 10524, 22, 21],
            [2004, 10525, 15, 19],
            [2004, 10526, 16, 20],
            [2004, 10527, 13, 14],
            [2004, 10528, 19, 19],
            [2004, 10529, 19, 19],
            [2004, 10530, 16, 19],
            [2004, 10531, 14, 17],
            [2004, 10532, 22, 21],
            [2004, 10533, 32, 27],
            [2004, 10534, 20, 13],
            [2004, 10535, 31, 25],
            [2004, 10536, 16, 19],
            [2004, 10537, 22, 20],
            [2004, 10538, 29, 24],
            [2004, 10539, 17, 17],
            [2004, 10540, 31, 25],
            [2004, 10541, 38, 32],
            [2004, 10542, 40, 28],
            [2004, 10543, 7, 7],
            [2004, 10544, 11, 9],
            [2004, 10545, 7, 7],
            [2004, 10546, 10, 8],
            [2004, 10547, 8, 8],
            [2004, 10548, 12, 9],
            [2004, 10549, 8, 8],
            [2004, 10550, 9, 11],
            [2004, 10551, 9, 8],
            [2004, 10552, 7, 7],
            [2004, 10553, 24, 16],
            [2004, 10554, 19, 13],
            [2004, 10555, 11, 8],
            [2004, 10556, 20, 13],
            [2004, 10557, 10, 10],
            [2004, 10558, 30, 20],
            [2004, 10559, 14, 9],
            [2004, 10560, 20, 13],
            [2004, 10577, 22, 13],
            [2004, 10578, 33, 37],
            [2004, 10579, 60, 40],
            [2004, 10580, 75, 42],
            [2004, 10581, 63, 53],
            [2004, 10582, 52, 39],
            [2004, 10583, 49, 42],
            [2004, 10584, 49, 42],
            [2004, 10585, 40, 41],
            [2004, 10586, 52, 47],
            [2004, 10587, 47, 40],
            [2004, 10588, 41, 38],
            [2004, 10589, 46, 42],
            [2004, 10590, 60, 47],
            [2004, 10591, 68, 63],
            [2004, 10592, 53, 31],
            [2004, 10593, 48, 39],
            [2004, 10594, 53, 49],
            [2004, 10595, 39, 41],
            [2004, 10596, 40, 37],
            [2004, 10597, 46, 38],
            [2004, 10598, 41, 31],
            [2004, 10602, 26, 29],
            [2004, 10603, 38, 35],
            [2004, 10604, 34, 24],
            [2004, 10605, 17, 12],
            [2004, 10606, 15, 10],
            [2004, 10607, 20, 15],
            [2004, 10608, 14, 10],
            [2004, 10609, 14, 10],
            [2004, 10610, 21, 11],
            [2004, 10611, 21, 14],
            [2004, 10612, 19, 14],
            [2004, 10613, 46, 32],
            [2004, 10614, 47, 24],
            [2004, 10615, 42, 30],
            [2004, 10616, 42, 31],
            [2004, 10617, 48, 35],
            [2004, 10618, 52, 28],
            [2004, 10619, 39, 23],
            [2004, 10620, 28, 19],
            [2004, 10621, 46, 28],
            [2004, 10622, 34, 18],
            [2004, 10623, 39, 25],
            [2004, 10624, 48, 24],
            [2004, 10625, 30, 20],
            [2004, 10626, 48, 26],
            [2004, 10627, 45, 30],
            [2004, 10628, 50, 31],
            [2004, 10629, 48, 31],
            [2004, 10630, 48, 28],
            [2004, 10631, 48, 25],
            [2004, 10632, 34, 21],
            [2004, 10633, 54, 43],
            [2004, 10634, 47, 32],
            [2004, 10635, 49, 35],
            [2004, 10636, 39, 28],
            [2004, 10637, 58, 32],
            [2004, 10638, 23, 16],
            [2004, 10639, 49, 34],
            [2004, 10640, 46, 27],
            [2004, 10641, 45, 28],
            [2004, 10642, 54, 32],
            [2004, 10643, 39, 25],
            [2004, 10644, 62, 36],
            [2004, 10645, 34, 28],
            [2004, 10646, 47, 29],
            [2004, 10647, 47, 28],
            [2004, 10648, 40, 32],
            [2004, 10649, 43, 25],
            [2004, 10650, 47, 33],
            [2004, 10651, 45, 32],
            [2004, 10652, 40, 24],
            [2004, 10653, 49, 30],
            [2004, 10654, 40, 28],
            [2004, 10655, 46, 32],
            [2004, 10656, 47, 28],
            [2004, 10657, 37, 28],
            [2004, 10658, 50, 28],
            [2004, 10659, 20, 17],
            [2004, 10660, 51, 36],
            [2004, 10661, 76, 29],
            [2004, 10662, 47, 29],
            [2004, 10663, 44, 28],
            [2004, 10664, 48, 32],
            [2004, 10665, 50, 32],
            [2004, 10666, 80, 36],
            [2004, 10667, 65, 32],
            [2004, 10668, 45, 32],
            [2004, 10669, 20, 16],
            [2004, 10670, 46, 28],
            [2004, 10671, 52, 29],
            [2004, 10672, 51, 27],
            [2004, 10673, 34, 22],
            [2004, 10674, 39, 22],
            [2004, 10675, 50, 37],
            [2004, 10676, 39, 35],
            [2004, 10677, 38, 21],
            [2004, 10678, 39, 25],
            [2004, 10679, 56, 28],
            [2004, 10680, 35, 28],
            [2004, 10681, 42, 32],
            [2004, 10682, 39, 24],
            [2004, 10683, 37, 24],
            [2004, 10684, 26, 19],
            [2004, 10685, 80, 37],
            [2004, 10686, 45, 38],
            [2004, 10687, 39, 38],
            [2004, 10688, 58, 39],
            [2004, 10689, 58, 38],
            [2004, 10690, 59, 40],
            [2004, 10691, 61, 40],
            [2004, 10692, 61, 37],
            [2004, 10693, 82, 37],
            [2004, 10694, 60, 33],
            [2004, 10695, 62, 32],
            [2004, 10696, 49, 29],
            [2004, 10697, 32, 24],
            [2004, 10698, 39, 32],
            [2004, 10699, 46, 34],
            [2004, 10700, 20, 15],
            [2004, 10701, 50, 30],
            [2004, 10702, 74, 26],
            [2004, 10703, 75, 26],
            [2004, 10704, 49, 25],
            [2004, 10705, 57, 24],
            [2004, 10706, 50, 36],
            [2004, 10707, 41, 42],
            [2004, 10708, 55, 44],
            [2004, 10709, 48, 43],
            [2004, 10710, 69, 32],
            [2004, 10711, 47, 32],
            [2004, 10712, 51, 37],
            [2004, 10713, 64, 38],
            [2004, 10714, 45, 28],
            [2004, 10715, 60, 32],
            [2004, 10716, 49, 40],
            [2004, 10717, 47, 40],
            [2004, 10718, 45, 40],
            [2004, 10719, 61, 36],
            [2004, 10720, 62, 40],
            [2004, 10721, 28, 21],
            [2004, 10722, 61, 39],
            [2004, 10723, 48, 38],
            [2004, 10724, 51, 39],
            [2004, 10725, 48, 38],
            [2004, 10726, 36, 24],
            [2004, 10727, 47, 27],
            [2004, 10728, 50, 28],
            [2004, 10729, 58, 36],
            [2004, 10730, 65, 34],
            [2004, 10731, 37, 32],
            [2004, 10732, 60, 38],
            [2004, 10733, 50, 32],
            [2004, 10734, 49, 32],
            [2004, 10735, 50, 26],
            [2004, 10736, 49, 32],
            [2004, 10737, 83, 45],
            [2004, 10738, 51, 29],
            [2004, 10739, 28, 15],
            [2004, 10740, 47, 32],
            [2004, 10741, 50, 38],
            [2004, 10742, 47, 31],
            [2004, 10743, 40, 27],
            [2004, 10744, 39, 24],
            [2004, 10745, 46, 28],
            [2004, 10746, 46, 24],
            [2004, 10747, 28, 16],
            [2004, 10748, 42, 26],
            [2004, 10749, 45, 30],
            [2004, 10750, 47, 32],
            [2004, 10751, 46, 32],
            [2004, 10752, 47, 32],
            [2004, 10753, 56, 36],
            [2004, 10754, 44, 26],
            [2004, 10755, 20, 15],
            [2004, 10756, 79, 45],
            [2004, 10757, 20, 14],
            [2004, 10758, 29, 18],
            [2004, 10759, 52, 26],
            [2004, 10760, 54, 31],
            [2004, 10761, 45, 29],
            [2004, 10762, 46, 36],
            [2004, 10763, 39, 25],
            [2004, 10764, 28, 21],
            [2004, 10765, 34, 23],
            [2004, 10766, 60, 34],
            [2004, 10767, 49, 32],
            [2004, 10768, 45, 30],
            [2004, 10769, 47, 28],
            [2004, 10770, 47, 34],
            [2004, 10771, 49, 37],
            [2004, 10772, 37, 42],
            [2004, 10773, 47, 46],
            [2004, 10774, 38, 23],
            [2004, 10775, 45, 23],
            [2004, 10776, 40, 22],
            [2004, 10777, 32, 20],
            [2004, 10778, 78, 36],
            [2004, 10779, 38, 27],
            [2004, 10780, 45, 28],
            [2004, 10781, 40, 28],
            [2004, 10782, 48, 30],
            [2004, 10783, 57, 34],
            [2004, 10784, 48, 30],
            [2004, 10785, 50, 26],
            [2004, 10786, 44, 32],
            [2004, 10787, 50, 28],
            [2004, 10788, 46, 34],
            [2004, 10789, 42, 25],
            [2004, 10790, 50, 25],
            [2004, 10791, 51, 25],
            [2004, 10792, 35, 28],
            [2004, 10793, 47, 28],
            [2004, 10794, 51, 32],
            [2004, 10795, 52, 32],
            [2004, 10796, 53, 32],
            [2004, 10797, 46, 30],
            [2004, 10798, 38, 28],
            [2004, 10799, 23, 16],
            [2004, 10800, 47, 31],
            [2004, 10801, 62, 36],
            [2004, 10802, 49, 25],
            [2004, 10803, 34, 20],
            [2004, 10804, 60, 32],
            [2004, 10805, 73, 33],
            [2004, 10806, 41, 32],
            [2004, 10807, 46, 23],
            [2004, 10808, 36, 20],
            [2004, 10809, 30, 26],
            [2004, 10810, 47, 30],
            [2004, 10811, 50, 28],
            [2004, 10812, 128, 50],
            [2004, 10814, 38, 28],
            [2004, 10815, 47, 30],
            [2004, 10816, 49, 32],
            [2004, 10817, 47, 30],
            [2004, 10818, 49, 32],
            [2004, 10819, 48, 30],
            [2004, 10820, 49, 27],
            [2004, 10821, 44, 28],
            [2004, 10822, 47, 30],
            [2004, 10823, 50, 28],
            [2004, 10824, 37, 26],
            [2004, 10825, 38, 32],
            [2004, 10826, 42, 25],
            [2004, 10827, 39, 30],
            [2004, 10828, 33, 26],
            [2004, 10829, 50, 32],
            [2004, 10830, 46, 27],
            [2004, 10831, 47, 32],
            [2004, 10832, 45, 26],
            [2004, 10833, 45, 26],
            [2004, 10834, 46, 27],
            [2004, 10835, 47, 28],
            [2004, 10836, 45, 27],
            [2004, 10837, 52, 28],
            [2004, 10838, 47, 27],
            [2004, 10839, 38, 26],
            [2004, 10840, 28, 20],
            [2004, 10841, 60, 30],
            [2004, 10842, 34, 30],
            [2004, 10843, 47, 30],
            [2004, 10844, 34, 26],
            [2004, 10845, 32, 24],
            [2004, 10846, 36, 26],
            [2004, 10847, 40, 28],
            [2004, 10848, 47, 32],
            [2004, 10849, 47, 32],
            [2004, 10850, 41, 27],
            [2004, 10851, 48, 30],
            [2004, 10852, 45, 28],
            [2004, 10853, 58, 40],
            [2004, 10854, 47, 32],
            [2004, 10855, 50, 27],
            [2004, 10856, 49, 31],
            [2004, 10857, 49, 32],
            [2004, 10858, 46, 28],
            [2004, 10859, 50, 28],
            [2004, 10860, 61, 30],
            [2004, 10861, 57, 30],
            [2004, 10862, 51, 28],
            [2004, 10863, 25, 19],
            [2004, 10864, 67, 31],
            [2004, 10865, 46, 32],
            [2004, 10866, 36, 22],
            [2004, 10867, 47, 26],
            [2004, 10868, 46, 26],
            [2004, 10869, 70, 32],
            [2004, 10870, 61, 36],
            [2004, 10871, 50, 25],
            [2004, 10872, 70, 30],
            [2004, 10873, 59, 32],
            [2004, 10874, 58, 32],
            [2004, 10875, 50, 32],
            [2004, 10876, 59, 26],
            [2004, 10877, 71, 30],
            [2004, 10878, 49, 26],
            [2004, 10879, 50, 32],
            [2004, 10880, 52, 32],
            [2004, 10881, 40, 26],
            [2004, 10882, 59, 32],
            [2004, 10883, 71, 36],
            [2004, 10884, 80, 36],
            [2004, 10885, 50, 33],
            [2004, 10886, 48, 24],
            [2004, 10887, 39, 28],
            [2004, 10888, 62, 32],
            [2004, 10889, 47, 28],
            [2004, 10890, 41, 25],
            [2004, 10891, 29, 21],
            [2004, 10892, 34, 21],
            [2004, 10893, 51, 41],
            [2004, 10894, 48, 40],
            [2004, 10895, 72, 35],
            [2004, 10896, 47, 36],
            [2004, 10897, 50, 37],
            [2004, 10898, 45, 37],
            [2004, 10899, 58, 30],
            [2004, 10900, 47, 30],
            [2004, 10901, 42, 30],
            [2004, 10902, 45, 23],
            [2004, 10903, 50, 32],
            [2004, 10904, 52, 32],
            [2004, 10905, 38, 23],
            [2004, 10906, 50, 35],
            [2004, 10907, 50, 35],
            [2004, 10908, 46, 28],
            [2004, 10909, 60, 38],
            [2004, 10910, 47, 32],
            [2004, 10911, 61, 32],
            [2004, 10912, 60, 45],
            [2004, 10913, 40, 36],
            [2004, 10914, 78, 36],
            [2004, 10915, 52, 41],
            [2004, 10916, 56, 41],
            [2004, 10917, 63, 40],
            [2004, 10918, 35, 30],
            [2004, 10978, 47, 32],
            [2004, 10979, 43, 27],
            [2004, 10980, 45, 25],
            [2004, 11091, 8, 5],
            [2004, 11092, 10, 8],
            [2004, 11093, 12, 7],
            [2004, 11094, 16, 12],
            [2004, 11095, 10, 7],
            [2004, 11096, 19, 12],
            [2004, 11097, 10, 8],
            [2004, 11098, 9, 7],
            [2004, 11099, 32, 18],
            [2004, 11100, 14, 11],
            [2004, 11101, 11, 9],
            [2004, 11102, 12, 9],
            [2004, 11103, 15, 10],
            [2004, 11104, 48, 22],
            [2004, 11105, 34, 22],
            [2004, 11106, 29, 15],
            [2004, 11107, 17, 10],
            [2004, 11108, 9, 6],
            [2004, 11109, 16, 12],
            [2004, 11110, 16, 9],
            [2004, 11111, 13, 7],
            [2004, 11112, 23, 14],
            [2004, 11113, 28, 17],
            [2004, 11114, 53, 33],
            [2004, 11115, 7, 6],
            [2004, 11116, 8, 6],
            [2004, 11117, 8, 5],
            [2004, 11118, 15, 9],
            [2004, 11119, 48, 25],
            [2004, 11120, 28, 16],
            [2004, 11121, 9, 6],
            [2004, 11122, 12, 8],
            [2004, 11123, 21, 12],
            [2004, 11124, 9, 8],
            [2004, 11125, 27, 15],
            [2004, 11126, 13, 11],
            [2004, 11127, 7, 7],
            [2004, 11128, 13, 7],
            [2004, 11129, 7, 6],
            [2004, 11130, 15, 10],
            [2004, 11131, 7, 6],
            [2004, 11132, 24, 14],
            [2004, 11133, 11, 8],
            [2004, 11134, 6, 4],
            [2004, 11135, 66, 26],
            [2004, 11136, 10, 8],
            [2004, 11137, 6, 5],
            [2004, 11138, 19, 11],
            [2004, 11139, 10, 6],
            [2004, 11140, 10, 9],
            [2004, 11141, 8, 6],
            [2004, 11142, 9, 7],
            [2004, 11143, 7, 6],
            [2004, 11144, 9, 8],
            [2004, 11145, 31, 19],
            [2004, 11146, 7, 6],
            [2004, 11147, 5, 3],
            [2004, 11148, 43, 22],
            [2004, 11149, 18, 11],
            [2004, 11150, 18, 16],
            [2004, 11151, 23, 16],
            [2004, 11152, 16, 11],
            [2004, 11153, 15, 9],
            [2004, 11154, 25, 18],
            [2004, 11155, 19, 10],
            [2004, 11156, 11, 10],
            [2004, 11157, 14, 10],
            [2004, 11158, 15, 10],
            [2004, 11159, 20, 10],
            [2004, 11160, 30, 15],
            [2004, 11161, 12, 10],
            [2004, 11162, 18, 12],
            [2004, 11163, 15, 12],
            [2004, 11164, 17, 16],
            [2004, 11165, 17, 12],
            [2004, 11166, 45, 27],
            [2004, 11167, 75, 43],
            [2004, 11168, 28, 20],
            [2004, 11169, 8, 8],
            [2004, 11170, 10, 9],
            [2004, 11171, 12, 10],
            [2004, 11172, 10, 9],
            [2004, 11173, 12, 11],
            [2004, 11174, 6, 6],
            [2004, 11175, 6, 6],
            [2004, 11176, 6, 6],
            [2004, 11177, 21, 18],
            [2004, 11178, 7, 7],
            [2004, 11179, 14, 12],
            [2004, 11180, 13, 10],
            [2004, 11181, 16, 13],
            [2004, 11182, 14, 11],
            [2004, 11183, 14, 13],
            [2004, 11184, 102, 79],
            [2004, 11185, 102, 79],
            [2004, 11186, 102, 79],
            [2004, 11187, 102, 79],
            [2004, 11188, 102, 79],
            [2004, 11189, 78, 90],
            [2004, 11195, 19, 18],
            [2004, 11197, 97, 45],
            [2004, 11199, 52, 28],
            [2004, 11201, 10, 10],
            [2004, 11202, 51, 32],
            [2004, 11203, 13, 14],
            [2004, 11204, 77, 50],
            [2004, 11205, 108, 74],
            [2004, 11206, 61, 54],
            [2004, 11207, 9, 9],
            [2004, 11209, 221, 200],
            [2004, 11210, 780, 95],
            [2004, 11211, 102, 103],
            [2004, 11212, 780, 103],
            [2004, 11213, 780, 95],
            [2004, 11214, 780, 95],
            [2004, 11215, 102, 103],
            [2004, 11216, 780, 103],
            [2004, 11217, 102, 103],
            [2004, 11218, 780, 103],
            [2004, 11219, 102, 103],
            [2004, 11220, 780, 95],
            [2004, 11221, 102, 103],
            [2004, 11222, 102, 103],
            [2004, 11223, 102, 97],
            [2004, 11224, 102, 103],
            [2004, 11225, 780, 103],
            [2004, 11226, 780, 103],
            [2004, 11228, 102, 103],
            [2004, 11229, 102, 103],
            [2004, 11230, 102, 103],
            [2004, 11231, 102, 103],
            [2004, 11232, 102, 103],
            [2004, 11233, 102, 103],
            [2004, 11234, 102, 97],
            [2004, 11235, 102, 103],
            [2004, 11236, 102, 103],
            [2004, 11237, 780, 103],
            [2004, 11238, 780, 103],
            [2004, 11239, 102, 103],
            [2004, 11240, 102, 103],
            [2004, 11241, 102, 103],
            [2004, 11242, 102, 103],
            [2004, 11243, 780, 95],
            [2004, 11245, 102, 103],
            [2004, 11246, 221, 179],
            [2004, 11247, 221, 179],
            [2004, 11248, 102, 103],
            [2004, 11249, 102, 103],
            [2004, 11250, 102, 103],
            [2004, 11251, 102, 103],
            [2004, 11252, 102, 103],
            [2004, 11253, 102, 103],
            [2004, 11254, 102, 97],
            [2004, 11255, 102, 103],
            [2004, 11256, 102, 103],
            [2004, 11257, 780, 103],
            [2004, 11258, 780, 103],
            [2004, 11259, 780, 95],
            [2004, 11260, 780, 103],
            [2004, 11262, 102, 103],
            [2004, 11263, 102, 103],
            [2004, 11264, 102, 103],
            [2004, 11265, 102, 103],
            [2004, 11266, 102, 103],
            [2004, 11267, 102, 103],
            [2004, 11268, 102, 103],
            [2004, 11269, 102, 103],
            [2004, 11270, 221, 179],
            [2004, 11271, 780, 103],
            [2004, 11272, 780, 103],
            [2004, 11274, 102, 103],
            [2004, 11275, 102, 97],
            [2004, 11276, 102, 103],
            [2004, 11277, 102, 103],
            [2004, 11278, 102, 103],
            [2004, 11279, 221, 179],
            [2004, 11280, 780, 103],
            [2004, 11281, 780, 103],
            [2004, 11283, 102, 97],
            [2004, 11284, 102, 103],
            [2004, 11285, 102, 97],
            [2004, 11286, 102, 103],
            [2004, 11287, 102, 97],
            [2004, 11288, 102, 103],
            [2004, 11289, 102, 103],
            [2004, 11290, 780, 103],
            [2004, 11291, 780, 103],
            [2004, 11292, 14, 18],
            [2004, 11293, 10, 12],
            [2004, 11294, 12, 15],
            [2004, 11295, 12, 15],
            [2004, 11296, 31, 55],
            [2004, 11297, 92, 68],
            [2004, 11298, 23, 20],
            [2004, 11300, 41, 44],
            [2004, 11303, 19, 17],
            [2004, 11304, 30, 20],
            [2004, 11305, 60, 49],
            [2004, 11306, 14, 20],
            [2004, 11307, 16, 20],
            [2004, 11308, 18, 30],
            [2004, 11309, 27, 24],
            [2004, 11310, 21, 21],
            [2004, 11311, 21, 22],
            [2004, 11312, 24, 20],
            [2004, 11313, 18, 21],
            [2004, 11314, 35, 36],
            [2004, 11315, 33, 30],
            [2004, 11316, 30, 33],
            [2004, 11317, 33, 33],
            [2004, 11318, 19, 22],
            [2004, 11319, 21, 19],
            [2004, 11320, 20, 18],
            [2004, 11321, 48, 33],
            [2004, 11322, 62, 32],
            [2004, 11323, 25, 27],
            [2004, 11324, 30, 21],
            [2004, 11325, 37, 22],
            [2004, 11326, 26, 28],
            [2004, 11327, 31, 23],
            [2004, 11328, 28, 32],
            [2004, 11329, 23, 28],
            [2004, 11330, 35, 36],
            [2004, 11331, 32, 34],
            [2004, 11332, 20, 18],
            [2004, 11333, 38, 28],
            [2004, 11334, 45, 29],
            [2004, 11335, 29, 22],
            [2004, 11336, 13, 14],
            [2004, 11337, 25, 27],
            [2004, 11338, 26, 28],
            [2004, 11339, 34, 28],
            [2004, 11340, 33, 33],
            [2004, 11341, 38, 31],
            [2004, 11342, 33, 33],
            [2004, 11343, 34, 37],
            [2004, 11344, 33, 36],
            [2004, 11345, 27, 32],
            [2004, 11346, 42, 31],
            [2004, 11347, 33, 28],
            [2004, 11348, 46, 39],
            [2004, 11349, 21, 18],
            [2004, 11350, 33, 33],
            [2004, 11351, 30, 33],
            [2004, 11352, 30, 33],
            [2004, 11353, 39, 37],
            [2004, 11354, 29, 23],
            [2004, 11355, 34, 28],
            [2004, 11356, 32, 26],
            [2004, 11357, 27, 24],
            [2004, 11358, 25, 27],
            [2004, 11359, 41, 44],
            [2004, 11360, 40, 26],
            [2004, 11361, 46, 39],
            [2004, 11362, 29, 27],
            [2004, 11363, 9, 10],
            [2004, 11364, 11, 12],
            [2004, 11365, 36, 23],
            [2004, 11366, 21, 21],
            [2004, 11367, 45, 44],
            [2004, 11368, 21, 23],
            [2004, 11369, 53, 55],
            [2004, 11370, 22, 26],
            [2004, 11371, 31, 31],
            [2004, 11372, 32, 34],
            [2004, 11373, 55, 35],
            [2004, 11374, 40, 40],
            [2004, 11375, 60, 46],
            [2004, 11376, 21, 21],
            [2004, 11377, 48, 43],
            [2004, 11378, 28, 29],
            [2004, 11384, 52, 52],
            [2004, 11385, 68, 68],
            [2004, 11386, 66, 68],
            [2004, 11387, 99, 75],
            [2004, 11388, 69, 62],
            [2004, 11389, 53, 45],
            [2004, 11390, 58, 56],
            [2004, 11391, 49, 40],
            [2004, 11392, 99, 75],
            [2004, 11393, 70, 65],
            [2004, 11394, 97, 68],
            [2004, 11395, 99, 75],
            [2004, 11396, 97, 90],
            [2004, 11397, 97, 83],
            [2004, 11398, 64, 67],
            [2004, 11399, 95, 90],
            [2004, 11400, 99, 75],
            [2004, 11401, 87, 36],
            [2004, 11402, 61, 68],
            [2004, 11403, 58, 67],
            [2004, 11404, 106, 79],
            [2004, 11405, 78, 75],
            [2004, 11406, 87, 71],
            [2004, 11407, 41, 41],
            [2004, 11408, 89, 62],
            [2004, 11409, 57, 50],
            [2004, 11410, 88, 69],
            [2004, 11411, 60, 55],
            [2004, 11412, 94, 90],
            [2004, 11413, 90, 78],
            [2004, 11414, 64, 90],
            [2004, 11415, 98, 75],
            [2004, 11416, 38, 37],
            [2004, 11417, 59, 59],
            [2004, 11418, 60, 65],
            [2004, 11419, 57, 60],
            [2004, 11420, 87, 74],
            [2004, 11421, 99, 73],
            [2004, 11422, 74, 84],
            [2004, 11423, 60, 82],
            [2004, 11424, 58, 48],
            [2004, 11425, 22, 18],
            [2004, 11426, 9, 7],
            [2004, 11427, 8, 8],
            [2004, 11428, 53, 26],
            [2004, 11429, 15, 12],
            [2004, 11430, 9, 10],
            [2004, 11431, 12, 10],
            [2004, 11432, 8, 8],
            [2004, 11433, 10, 12],
            [2004, 11434, 10, 9],
            [2004, 11435, 7, 8],
            [2004, 11436, 20, 20],
            [2004, 11437, 12, 11],
            [2004, 11438, 10, 9],
            [2004, 11439, 11, 9],
            [2004, 11440, 16, 14],
            [2004, 11441, 46, 28],
            [2004, 11442, 9, 8],
            [2004, 11443, 11, 11],
            [2004, 11444, 14, 9],
            [2004, 11445, 8, 8],
            [2004, 11446, 11, 9],
            [2004, 11447, 17, 14],
            [2004, 11448, 12, 10],
            [2004, 11449, 12, 8],
            [2004, 11450, 12, 10],
            [2004, 11451, 9, 7],
            [2004, 11452, 10, 9],
            [2004, 11453, 30, 19],
            [2004, 11454, 13, 11],
            [2004, 11455, 8, 8],
            [2004, 11456, 8, 8],
            [2004, 11457, 9, 9],
            [2004, 11458, 6, 7],
            [2004, 11459, 6, 6],
            [2004, 11460, 7, 6],
            [2004, 11461, 9, 8],
            [2004, 11462, 7, 7],
            [2004, 11463, 10, 9],
            [2004, 11464, 9, 7],
            [2004, 11465, 18, 14],
            [2004, 11466, 14, 9],
            [2004, 11467, 15, 11],
            [2004, 11468, 38, 25],
            [2004, 11469, 16, 12],
            [2004, 11470, 21, 16],
            [2004, 11471, 15, 14],
            [2004, 11472, 28, 17],
            [2004, 11473, 10, 9],
            [2004, 11474, 8, 9],
            [2004, 11475, 9, 9],
            [2004, 11476, 12, 9],
            [2004, 11477, 24, 19],
            [2004, 11478, 30, 19],
            [2004, 11479, 11, 9],
            [2004, 11480, 21, 17],
            [2004, 11481, 15, 14],
            [2004, 11482, 17, 14],
            [2004, 11483, 19, 15],
            [2004, 11484, 21, 15],
            [2004, 11485, 25, 18],
            [2004, 11486, 23, 15],
            [2004, 11487, 17, 14],
            [2004, 11488, 24, 18],
            [2004, 11489, 13, 11],
            [2004, 11490, 14, 13],
            [2004, 11491, 11, 9],
            [2004, 11492, 8, 7],
            [2004, 11493, 8, 8],
            [2004, 11494, 6, 7],
            [2004, 11495, 6, 6],
            [2004, 11496, 7, 8],
            [2004, 11497, 9, 8],
            [2004, 11498, 9, 8],
            [2004, 11499, 9, 9],
            [2004, 11500, 22, 20],
            [2004, 11501, 8, 8],
            [2004, 11502, 12, 10],
            [2004, 11503, 7, 8],
            [2004, 11504, 9, 9],
            [2004, 11505, 14, 11],
            [2004, 11506, 10, 10],
            [2004, 11507, 11, 12],
            [2004, 11508, 7, 8],
            [2004, 11509, 27, 16],
            [2004, 11510, 11, 9],
            [2004, 11511, 12, 9],
            [2004, 11512, 19, 12],
            [2004, 11513, 13, 11],
            [2004, 11514, 9, 9],
            [2004, 11515, 9, 9],
            [2004, 11516, 14, 11],
            [2004, 11517, 21, 18],
            [2004, 11518, 10, 15],
            [2004, 11519, 22, 15],
            [2004, 11520, 33, 20],
            [2004, 11521, 8, 6],
            [2004, 11522, 10, 10],
            [2004, 11523, 11, 9],
            [2004, 11524, 8, 7],
            [2004, 11525, 11, 8],
            [2004, 11526, 16, 11],
            [2004, 11527, 10, 10],
            [2004, 11528, 8, 7],
            [2004, 11529, 79, 81],
            [2004, 11530, 82, 90],
            [2004, 11531, 79, 52],
            [2004, 11532, 68, 90],
            [2004, 11533, 41, 37],
            [2004, 11534, 95, 90],
            [2004, 11535, 101, 85],
            [2004, 11536, 38, 63],
            [2004, 11537, 106, 65],
            [2004, 11538, 94, 70],
            [2004, 11539, 87, 69],
            [2004, 11540, 58, 44],
            [2004, 11541, 100, 73],
            [2004, 11542, 100, 76],
            [2004, 11543, 101, 68],
            [2004, 11544, 45, 61],
            [2004, 11545, 54, 90],
            [2004, 11546, 120, 76],
            [2004, 11547, 100, 76],
            [2004, 11548, 120, 76],
            [2004, 11549, 57, 46],
            [2004, 11550, 101, 75],
            [2004, 11551, 71, 58],
            [2004, 11552, 100, 90],
            [2004, 11553, 110, 90],
            [2004, 11554, 34, 65],
            [2004, 11555, 63, 70],
            [2004, 11556, 112, 74],
            [2004, 11557, 98, 75],
            [2004, 11558, 59, 90],
            [2004, 11559, 101, 75],
            [2004, 11560, 43, 67],
            [2004, 11561, 120, 90],
            [2004, 11562, 98, 75],
            [2004, 11563, 119, 90],
            [2004, 11564, 88, 90],
            [2004, 11565, 120, 72],
            [2004, 11566, 73, 90],
            [2004, 11567, 101, 75],
            [2004, 11568, 97, 68],
            [2004, 11569, 98, 89],
            [2004, 11570, 98, 75],
            [2004, 11571, 10, 11],
            [2004, 11572, 17, 14],
            [2004, 11573, 120, 90],
            [2004, 11574, 12, 12],
            [2004, 11575, 31, 30],
            [2004, 11576, 14, 14],
            [2004, 11577, 14, 14],
            [2004, 11578, 19, 19],
            [2004, 11579, 18, 25],
            [2004, 11580, 11, 13],
            [2004, 11581, 14, 17],
            [2004, 11582, 18, 20],
            [2004, 11583, 38, 29],
            [2004, 11585, 30, 17],
            [2004, 11586, 54, 26],
            [2004, 11587, 14, 13],
            [2004, 11588, 41, 36],
            [2004, 11589, 49, 29],
            [2004, 11590, 44, 28],
            [2004, 11591, 32, 22],
            [2004, 11592, 71, 39],
            [2004, 11593, 57, 24],
            [2004, 11594, 97, 51],
            [2004, 11595, 46, 27],
            [2004, 11596, 30, 29],
            [2004, 11597, 85, 46],
            [2004, 11598, 29, 14],
            [2004, 11599, 34, 24],
            [2004, 11600, 27, 24],
            [2004, 11601, 55, 38],
            [2004, 11602, 60, 35],
            [2004, 11603, 68, 32],
            [2004, 11604, 16, 17],
            [2004, 11605, 24, 18],
            [2004, 11606, 40, 32],
            [2004, 11607, 36, 27],
            [2004, 11608, 38, 33],
            [2004, 11609, 41, 22],
            [2004, 11610, 30, 36],
            [2004, 11611, 35, 24],
            [2004, 11612, 45, 27],
            [2004, 11613, 38, 25],
            [2004, 11614, 28, 25],
            [2004, 11615, 28, 18],
            [2004, 11616, 26, 22],
            [2004, 11617, 34, 23],
            [2004, 11618, 37, 35],
            [2004, 11619, 26, 21],
            [2004, 11620, 24, 21],
            [2004, 11621, 36, 24],
            [2004, 11622, 25, 39],
            [2004, 11623, 28, 22],
            [2004, 11624, 39, 26],
            [2004, 11625, 28, 27],
            [2004, 11626, 22, 25],
            [2004, 11627, 37, 21],
            [2004, 11628, 32, 27],
            [2004, 11629, 35, 37],
            [2004, 11630, 58, 27],
            [2004, 11631, 57, 42],
            [2004, 11632, 33, 28],
            [2004, 11633, 22, 22],
            [2004, 11634, 37, 33],
            [2004, 11635, 26, 21],
            [2004, 11636, 29, 23],
            [2004, 11637, 35, 26],
            [2004, 11638, 40, 26],
            [2004, 11639, 26, 26],
            [2004, 11640, 58, 38],
            [2004, 11641, 31, 26],
            [2004, 11642, 22, 20],
            [2004, 11643, 39, 26],
            [2004, 11644, 31, 20],
            [2004, 11645, 38, 28],
            [2004, 11646, 20, 19],
            [2004, 11647, 29, 24],
            [2004, 11648, 20, 21],
            [2004, 11649, 23, 20],
            [2004, 11650, 18, 19],
            [2004, 11651, 29, 29],
            [2004, 11652, 32, 23],
            [2004, 11653, 48, 28],
            [2004, 11654, 44, 25],
            [2004, 11655, 45, 30],
            [2004, 11656, 48, 26],
            [2004, 11657, 65, 39],
            [2004, 11658, 31, 23],
            [2004, 11659, 57, 42],
            [2004, 11660, 33, 31],
            [2004, 11661, 30, 22],
            [2004, 11662, 48, 26],
            [2004, 11663, 34, 22],
            [2004, 11664, 26, 27],
            [2004, 11665, 63, 26],
            [2004, 11666, 47, 26],
            [2004, 11667, 59, 36],
            [2004, 11668, 36, 25],
            [2004, 11669, 35, 23],
            [2004, 11670, 42, 29],
            [2004, 11671, 43, 27],
            [2004, 11672, 38, 30],
            [2004, 11673, 49, 30],
            [2004, 11674, 39, 32],
            [2004, 11675, 50, 44],
            [2004, 11676, 45, 30],
            [2004, 11677, 68, 48],
            [2004, 11678, 56, 35],
            [2004, 11679, 46, 25],
            [2004, 11680, 45, 27],
            [2004, 11681, 36, 27],
            [2004, 11682, 65, 32],
            [2004, 11683, 25, 20],
            [2004, 11684, 37, 31],
            [2004, 11685, 25, 22],
            [2004, 11686, 46, 25],
            [2004, 11687, 20, 20],
            [2004, 11688, 62, 41],
            [2004, 11689, 40, 24],
            [2004, 11690, 26, 21],
            [2004, 11691, 32, 25],
            [2004, 11692, 38, 28],
            [2004, 11693, 20, 20],
            [2004, 11694, 19, 19],
            [2004, 11695, 22, 21],
            [2004, 11696, 25, 24],
            [2004, 11697, 24, 24],
            [2004, 11698, 19, 19],
            [2004, 11699, 43, 34],
            [2004, 11700, 32, 32],
            [2004, 11701, 35, 32],
            [2004, 11702, 39, 26],
            [2004, 11703, 19, 17],
            [2004, 11704, 21, 22],
            [2004, 11705, 50, 28],
            [2004, 11706, 149, 65],
            [2004, 11707, 29, 23],
            [2004, 11708, 28, 20],
            [2004, 11709, 59, 28],
            [2004, 11710, 80, 39],
            [2004, 11712, 49, 39],
            [2004, 11713, 86, 40],
            [2004, 11714, 46, 11],
            [2004, 11745, 33, 30],
            [2004, 11746, 31, 19],
            [2005, 25, 12, 9],
            [2005, 48, 53, 36],
            [2005, 49, 27, 20],
            [2005, 51, 30, 26],
            [2005, 62, 18, 25],
            [2005, 65, 19, 16],
            [2005, 78, 20, 18],
            [2005, 82, 15, 16],
            [2005, 83, 28, 31],
            [2005, 99, 26, 25],
            [2005, 101, 46, 37],
            [2005, 119, 33, 23],
            [2005, 138, 40, 28],
            [2005, 163, 32, 30],
            [2005, 166, 27, 26],
            [2005, 190, 26, 25],
            [2005, 200, 33, 25],
            [2005, 204, 15, 27],
            [2005, 211, 21, 36],
            [2005, 216, 21, 18],
            [2005, 218, 37, 22],
            [2005, 220, 15, 16],
            [2005, 226, 18, 14],
            [2005, 231, 45, 35],
            [2005, 233, 17, 18],
            [2005, 234, 12, 12],
            [2005, 240, 63, 37],
            [2005, 243, 42, 26],
            [2005, 246, 34, 25],
            [2005, 272, 33, 15],
            [2005, 282, 37, 27],
            [2005, 286, 18, 21],
            [2005, 305, 20, 24],
            [2005, 308, 11, 27],
            [2005, 310, 17, 17],
            [2005, 312, 19, 18],
            [2005, 314, 17, 23],
            [2005, 324, 32, 28],
            [2005, 327, 36, 31],
            [2005, 329, 32, 23],
            [2005, 346, 44, 35],
            [2005, 355, 38, 27],
            [2005, 361, 26, 25],
            [2005, 378, 17, 19],
            [2005, 379, 14, 12],
            [2005, 389, 25, 26],
            [2005, 392, 17, 17],
            [2005, 399, 54, 29],
            [2005, 424, 19, 18],
            [2005, 425, 14, 18],
            [2005, 428, 24, 18],
            [2005, 430, 19, 21],
            [2005, 432, 47, 28],
            [2005, 436, 42, 35],
            [2005, 471, 18, 19],
            [2005, 479, 47, 37],
            [2005, 480, 50, 28],
            [2005, 487, 24, 22],
            [2005, 497, 9, 14],
            [2005, 503, 98, 28],
            [2005, 504, 12, 10],
            [2005, 505, 35, 24],
            [2005, 519, 16, 22],
            [2005, 536, 25, 18],
            [2005, 541, 91, 36],
            [2005, 545, 20, 23],
            [2005, 568, 17, 17],
            [2005, 569, 64, 25],
            [2005, 570, 24, 19],
            [2005, 577, 37, 21],
            [2005, 585, 46, 36],
            [2005, 590, 44, 49],
            [2005, 593, 43, 35],
            [2005, 597, 32, 14],
            [2005, 604, 99, 53],
            [2005, 608, 23, 18],
            [2005, 612, 28, 27],
            [2005, 618, 20, 17],
            [2005, 628, 29, 26],
            [2005, 631, 26, 22],
            [2005, 660, 44, 31],
            [2005, 662, 48, 40],
            [2005, 663, 55, 28],
            [2005, 669, 26, 18],
            [2005, 678, 17, 21],
            [2005, 686, 17, 18],
            [2005, 691, 23, 26],
            [2005, 694, 31, 24],
            [2005, 695, 54, 41],
            [2005, 700, 44, 34],
            [2005, 703, 15, 15],
            [2005, 716, 46, 40],
            [2005, 724, 18, 26],
            [2005, 734, 20, 25],
            [2005, 751, 27, 20],
            [2005, 754, 27, 25],
            [2005, 766, 77, 41],
            [2005, 769, 48, 30],
            [2005, 801, 17, 18],
            [2005, 803, 28, 25],
            [2005, 805, 24, 20],
            [2005, 820, 51, 29],
            [2005, 822, 15, 19],
            [2005, 826, 18, 17],
            [2005, 827, 11, 13],
            [2005, 835, 39, 25],
            [2005, 843, 30, 27],
            [2005, 845, 41, 33],
            [2005, 848, 23, 19],
            [2005, 865, 72, 28],
            [2005, 871, 33, 19],
            [2005, 878, 7, 6],
            [2005, 882, 37, 27],
            [2005, 894, 25, 12],
            [2005, 913, 17, 17],
            [2005, 915, 42, 31],
            [2005, 922, 29, 35],
            [2005, 926, 41, 19],
            [2005, 938, 11, 12],
            [2005, 940, 11, 13],
            [2005, 941, 34, 36],
            [2005, 949, 47, 29],
            [2005, 950, 14, 17],
            [2005, 964, 11, 15],
            [2005, 969, 42, 34],
            [2005, 971, 17, 15],
            [2005, 979, 17, 17],
            [2005, 985, 61, 30],
            [2005, 998, 38, 28],
            [2005, 1003, 8, 6],
            [2005, 1008, 34, 35],
            [2005, 1016, 11, 13],
            [2005, 1030, 9, 13],
            [2005, 1048, 35, 34],
            [2005, 1056, 21, 33],
            [2005, 1059, 47, 46],
            [2005, 1095, 17, 17],
            [2005, 1097, 28, 17],
            [2005, 1106, 61, 31],
            [2005, 1111, 39, 39],
            [2005, 1131, 40, 31],
            [2005, 1132, 11, 12],
            [2005, 1136, 33, 31],
            [2005, 1142, 22, 20],
            [2005, 1144, 24, 18],
            [2005, 1145, 26, 21],
            [2005, 1150, 29, 21],
            [2005, 1155, 24, 25],
            [2005, 1156, 24, 17],
            [2005, 1157, 35, 31],
            [2005, 1159, 76, 28],
            [2005, 1167, 20, 19],
            [2005, 1169, 25, 23],
            [2005, 1174, 26, 34],
            [2005, 1186, 15, 15],
            [2005, 1194, 72, 35],
            [2005, 1200, 17, 19],
            [2005, 1203, 11, 17],
            [2005, 1213, 20, 16],
            [2005, 1219, 25, 16],
            [2005, 1221, 17, 16],
            [2005, 1226, 28, 23],
            [2005, 1234, 14, 15],
            [2005, 1235, 23, 18],
            [2005, 1238, 14, 22],
            [2005, 1247, 40, 25],
            [2005, 1254, 45, 23],
            [2005, 1268, 31, 25],
            [2005, 1275, 27, 17],
            [2005, 1281, 13, 16],
            [2005, 1295, 37, 35],
            [2005, 1302, 43, 48],
            [2005, 1303, 60, 32],
            [2005, 1320, 35, 30],
            [2005, 1334, 62, 38],
            [2005, 1359, 31, 26],
            [2005, 1370, 13, 20],
            [2005, 1396, 13, 16],
            [2005, 1420, 51, 42],
            [2005, 1445, 65, 24],
            [2005, 1456, 24, 23],
            [2005, 1466, 28, 24],
            [2005, 1473, 13, 17],
            [2005, 1475, 44, 22],
            [2005, 1476, 37, 31],
            [2005, 1477, 24, 17],
            [2005, 1481, 35, 23],
            [2005, 1484, 37, 26],
            [2005, 1486, 13, 13],
            [2005, 1491, 11, 8],
            [2005, 1493, 24, 19],
            [2005, 1507, 33, 28],
            [2005, 1510, 16, 18],
            [2005, 1511, 26, 25],
            [2005, 1515, 19, 15],
            [2005, 1522, 19, 18],
            [2005, 1525, 33, 32],
            [2005, 1527, 31, 26],
            [2005, 1530, 67, 43],
            [2005, 1536, 15, 18],
            [2005, 1537, 52, 38],
            [2005, 1548, 32, 29],
            [2005, 1557, 39, 27],
            [2005, 1562, 38, 29],
            [2005, 1568, 28, 26],
            [2005, 1577, 24, 17],
            [2005, 1580, 37, 30],
            [2005, 1582, 27, 22],
            [2005, 1587, 14, 15],
            [2005, 1589, 43, 24],
            [2005, 1598, 11, 8],
            [2005, 1610, 24, 25],
            [2005, 1628, 29, 17],
            [2005, 1635, 17, 16],
            [2005, 1638, 41, 30],
            [2005, 1644, 87, 49],
            [2005, 1645, 48, 30],
            [2005, 1659, 24, 21],
            [2005, 1673, 63, 34],
            [2005, 1680, 98, 38],
            [2005, 1685, 32, 29],
            [2005, 1704, 17, 15],
            [2005, 1717, 46, 32],
            [2005, 1730, 14, 11],
            [2005, 1763, 21, 21],
            [2005, 1769, 45, 37],
            [2005, 1771, 18, 18],
            [2005, 1772, 10, 13],
            [2005, 1774, 21, 22],
            [2005, 1794, 28, 25],
            [2005, 1795, 12, 9],
            [2005, 1797, 47, 30],
            [2005, 1798, 35, 37],
            [2005, 1804, 25, 17],
            [2005, 1812, 14, 15],
            [2005, 1818, 17, 17],
            [2005, 1824, 63, 35],
            [2005, 1825, 18, 22],
            [2005, 1841, 35, 34],
            [2005, 1845, 33, 26],
            [2005, 1848, 40, 26],
            [2005, 1864, 101, 60],
            [2005, 1866, 44, 26],
            [2005, 1882, 16, 17],
            [2005, 1891, 30, 22],
            [2005, 1894, 29, 15],
            [2005, 1903, 61, 29],
            [2005, 1916, 19, 17],
            [2005, 1921, 13, 11],
            [2005, 1930, 10, 8],
            [2005, 1933, 11, 14],
            [2005, 1952, 144, 57],
            [2005, 1962, 12, 14],
            [2005, 1965, 60, 36],
            [2005, 1995, 37, 25],
            [2005, 2000, 28, 25],
            [2005, 2006, 20, 18],
            [2005, 2011, 19, 18],
            [2005, 2017, 40, 30],
            [2005, 2021, 25, 26],
            [2005, 2023, 11, 11],
            [2005, 2025, 50, 41],
            [2005, 2029, 34, 27],
            [2005, 2035, 45, 28],
            [2005, 2048, 15, 28],
            [2005, 2056, 22, 40],
            [2005, 2057, 49, 27],
            [2005, 2064, 50, 27],
            [2005, 2081, 28, 17],
            [2005, 2084, 54, 25],
            [2005, 2098, 13, 16],
            [2005, 2099, 29, 22],
            [2005, 2127, 15, 13],
            [2005, 2128, 27, 26],
            [2005, 2138, 21, 22],
            [2005, 2142, 9, 10],
            [2005, 2171, 23, 22],
            [2005, 2178, 15, 14],
            [2005, 2180, 31, 25],
            [2005, 2190, 25, 19],
            [2005, 2198, 18, 15],
            [2005, 2201, 27, 27],
            [2005, 2208, 66, 35],
            [2005, 2213, 38, 29],
            [2005, 2224, 31, 26],
            [2005, 2227, 16, 18],
            [2005, 2232, 25, 25],
            [2005, 2238, 30, 25],
            [2005, 2244, 21, 21],
            [2005, 2250, 37, 25],
            [2005, 2258, 25, 25],
            [2005, 2277, 25, 18],
            [2005, 2280, 13, 10],
            [2005, 2282, 17, 45],
            [2005, 2300, 47, 37],
            [2005, 2303, 24, 24],
            [2005, 2311, 31, 29],
            [2005, 2316, 44, 32],
            [2005, 2343, 36, 25],
            [2005, 2352, 36, 30],
            [2005, 2367, 36, 26],
            [2005, 2371, 46, 28],
            [2005, 2384, 24, 28],
            [2005, 2404, 26, 25],
            [2005, 2429, 15, 16],
            [2005, 2433, 41, 20],
            [2005, 2435, 14, 16],
            [2005, 2443, 44, 30],
            [2005, 2458, 28, 21],
            [2005, 2459, 21, 14],
            [2005, 2467, 14, 14],
            [2005, 2483, 40, 44],
            [2005, 2485, 18, 14],
            [2005, 2488, 24, 22],
            [2005, 2494, 29, 26],
            [2005, 2497, 29, 18],
            [2005, 2500, 23, 17],
            [2005, 2501, 48, 30],
            [2005, 2505, 38, 25],
            [2005, 2524, 10, 9],
            [2005, 2533, 10, 16],
            [2005, 2539, 76, 23],
            [2005, 2540, 16, 19],
            [2005, 2547, 15, 28],
            [2005, 2554, 11, 20],
            [2005, 2562, 78, 30],
            [2005, 2564, 21, 18],
            [2005, 2574, 57, 33],
            [2005, 2576, 60, 33],
            [2005, 2585, 41, 28],
            [2005, 2595, 35, 29],
            [2005, 2603, 49, 31],
            [2005, 2606, 18, 14],
            [2005, 2612, 31, 22],
            [2005, 2617, 30, 21],
            [2005, 2619, 11, 11],
            [2005, 2627, 43, 26],
            [2005, 2635, 14, 15],
            [2005, 2647, 27, 23],
            [2005, 2656, 19, 18],
            [2005, 2670, 35, 24],
            [2005, 2671, 40, 40],
            [2005, 2687, 35, 21],
            [2005, 2692, 39, 26],
            [2005, 2695, 17, 13],
            [2005, 2720, 28, 31],
            [2005, 2723, 34, 37],
            [2005, 2758, 30, 26],
            [2005, 2762, 45, 29],
            [2005, 2775, 46, 28],
            [2005, 2785, 12, 13],
            [2005, 2798, 16, 17],
            [2005, 2822, 23, 18],
            [2005, 2823, 21, 17],
            [2005, 2827, 12, 16],
            [2005, 2832, 16, 16],
            [2005, 2835, 24, 22],
            [2005, 2836, 24, 17],
            [2005, 2838, 29, 24],
            [2005, 2851, 19, 14],
            [2005, 2872, 17, 18],
            [2005, 2879, 21, 18],
            [2005, 2880, 32, 23],
            [2005, 2883, 34, 37],
            [2005, 2910, 18, 18],
            [2005, 2914, 39, 26],
            [2005, 2922, 13, 14],
            [2005, 2929, 40, 27],
            [2005, 2934, 18, 17],
            [2005, 2935, 44, 26],
            [2005, 2950, 32, 26],
            [2005, 2969, 20, 15],
            [2005, 2974, 30, 20],
            [2005, 2978, 27, 26],
            [2005, 2991, 34, 28],
            [2005, 3016, 32, 25],
            [2005, 3019, 39, 21],
            [2005, 3027, 16, 17],
            [2005, 3033, 59, 44],
            [2005, 3035, 18, 18],
            [2005, 3046, 49, 22],
            [2005, 3053, 59, 41],
            [2005, 3066, 43, 28],
            [2005, 3070, 36, 29],
            [2005, 3077, 43, 35],
            [2005, 3086, 86, 29],
            [2005, 3091, 12, 13],
            [2005, 3092, 44, 28],
            [2005, 3098, 29, 24],
            [2005, 3112, 43, 25],
            [2005, 3114, 42, 29],
            [2005, 3119, 11, 22],
            [2005, 3126, 36, 26],
            [2005, 3133, 32, 28],
            [2005, 3134, 31, 33],
            [2005, 3137, 26, 26],
            [2005, 3142, 26, 31],
            [2005, 3148, 29, 22],
            [2005, 3155, 22, 19],
            [2005, 3158, 18, 21],
            [2005, 3161, 17, 17],
            [2005, 3164, 44, 31],
            [2005, 3167, 18, 23],
            [2005, 3171, 30, 17],
            [2005, 3182, 115, 39],
            [2005, 3206, 41, 26],
            [2005, 3221, 38, 31],
            [2005, 3228, 39, 26],
            [2005, 3231, 17, 17],
            [2005, 3234, 36, 22],
            [2005, 3246, 70, 26],
            [2005, 3252, 41, 26],
            [2005, 3254, 21, 25],
            [2005, 3256, 24, 19],
            [2005, 3264, 23, 23],
            [2005, 3273, 54, 33],
            [2005, 3274, 21, 19],
            [2005, 3280, 29, 26],
            [2005, 3301, 35, 28],
            [2005, 3306, 18, 21],
            [2005, 3308, 49, 30],
            [2005, 3309, 34, 35],
            [2005, 3321, 43, 26],
            [2005, 3326, 18, 19],
            [2005, 3327, 37, 28],
            [2005, 3331, 28, 18],
            [2005, 3346, 26, 29],
            [2005, 3348, 44, 29],
            [2005, 3357, 12, 17],
            [2005, 3363, 45, 25],
            [2005, 3364, 11, 14],
            [2005, 3372, 43, 29],
            [2005, 3382, 28, 21],
            [2005, 3418, 49, 28],
            [2005, 3434, 7, 7],
            [2005, 3438, 45, 25],
            [2005, 3439, 25, 21],
            [2005, 3451, 60, 42],
            [2005, 3454, 11, 10],
            [2005, 3459, 24, 19],
            [2005, 3462, 44, 23],
            [2005, 3469, 24, 17],
            [2005, 3494, 11, 12],
            [2005, 3503, 91, 44],
            [2005, 3511, 18, 25],
            [2005, 3515, 13, 34],
            [2005, 3517, 41, 28],
            [2005, 3531, 22, 17],
            [2005, 3541, 18, 23],
            [2005, 3557, 10, 13],
            [2005, 3559, 36, 28],
            [2005, 3569, 47, 47],
            [2005, 3579, 18, 27],
            [2005, 3590, 18, 22],
            [2005, 3593, 49, 49],
            [2005, 3598, 16, 12],
            [2005, 3602, 18, 18],
            [2005, 3608, 36, 24],
            [2005, 3653, 20, 18],
            [2005, 3659, 37, 27],
            [2005, 3661, 25, 25],
            [2005, 3669, 14, 19],
            [2005, 3679, 16, 24],
            [2005, 3700, 17, 19],
            [2005, 3718, 44, 32],
            [2005, 3726, 13, 12],
            [2005, 3729, 98, 41],
            [2005, 3751, 29, 19],
            [2005, 3755, 29, 23],
            [2005, 3765, 18, 16],
            [2005, 3777, 24, 20],
            [2005, 3782, 53, 27],
            [2005, 3796, 26, 25],
            [2005, 3827, 40, 25],
            [2005, 3828, 17, 20],
            [2005, 3833, 59, 30],
            [2005, 3845, 41, 25],
            [2005, 3854, 25, 23],
            [2005, 3859, 11, 15],
            [2005, 3870, 41, 30],
            [2005, 3874, 35, 26],
            [2005, 3884, 46, 27],
            [2005, 3889, 52, 24],
            [2005, 3905, 24, 24],
            [2005, 3915, 24, 24],
            [2005, 3921, 24, 26],
            [2005, 3925, 47, 30],
            [2005, 3932, 21, 25],
            [2005, 3942, 27, 25],
            [2005, 3943, 23, 23],
            [2005, 3947, 33, 27],
            [2005, 3956, 39, 47],
            [2005, 3960, 48, 39],
            [2005, 3969, 59, 36],
            [2005, 3970, 40, 29],
            [2005, 3972, 138, 66],
            [2005, 3976, 17, 17],
            [2005, 3985, 22, 20],
            [2005, 3992, 57, 30],
            [2005, 3993, 15, 15],
            [2005, 4015, 45, 26],
            [2005, 4022, 43, 29],
            [2005, 4023, 26, 26],
            [2005, 4026, 25, 16],
            [2005, 4027, 56, 30],
            [2005, 4028, 21, 20],
            [2005, 4031, 15, 14],
            [2005, 4034, 48, 38],
            [2005, 4038, 56, 30],
            [2005, 4043, 17, 16],
            [2005, 4074, 17, 23],
            [2005, 4082, 52, 30],
            [2005, 4084, 11, 16],
            [2005, 4091, 34, 28],
            [2005, 4106, 35, 22],
            [2005, 4107, 55, 27],
            [2005, 4109, 17, 17],
            [2005, 4111, 16, 13],
            [2005, 4124, 31, 27],
            [2005, 4125, 15, 16],
            [2005, 4152, 72, 38],
            [2005, 4156, 16, 17],
            [2005, 4165, 32, 31],
            [2005, 4169, 25, 20],
            [2005, 4173, 15, 17],
            [2005, 4176, 10, 12],
            [2005, 4199, 63, 31],
            [2005, 4209, 36, 34],
            [2005, 4229, 23, 20],
            [2005, 4242, 26, 25],
            [2005, 4246, 11, 18],
            [2005, 4272, 39, 26],
            [2005, 4283, 25, 19],
            [2005, 4285, 24, 29],
            [2005, 4299, 31, 22],
            [2005, 4301, 46, 48],
            [2005, 4310, 28, 21],
            [2005, 4312, 40, 26],
            [2005, 4325, 47, 24],
            [2005, 4338, 25, 25],
            [2005, 4350, 18, 17],
            [2005, 4353, 23, 22],
            [2005, 4358, 12, 13],
            [2005, 4362, 62, 41],
            [2005, 4380, 17, 19],
            [2005, 4382, 85, 29],
            [2005, 4386, 18, 20],
            [2005, 4413, 11, 11],
            [2005, 4414, 16, 23],
            [2005, 4426, 15, 15],
            [2005, 4440, 37, 27],
            [2005, 4442, 16, 20],
            [2005, 4454, 17, 16],
            [2005, 4464, 38, 24],
            [2005, 4470, 23, 23],
            [2005, 4471, 17, 17],
            [2005, 4477, 26, 28],
            [2005, 4487, 19, 24],
            [2005, 4491, 40, 27],
            [2005, 4495, 24, 20],
            [2005, 4500, 17, 17],
            [2005, 4504, 47, 32],
            [2005, 4506, 16, 17],
            [2005, 4515, 43, 32],
            [2005, 4518, 40, 28],
            [2005, 4521, 39, 26],
            [2005, 4524, 26, 26],
            [2005, 4532, 25, 18],
            [2005, 4536, 19, 18],
            [2005, 4545, 40, 30],
            [2005, 4552, 14, 16],
            [2005, 4572, 26, 23],
            [2005, 4591, 30, 21],
            [2005, 4602, 20, 23],
            [2005, 4610, 53, 28],
            [2005, 4616, 21, 18],
            [2005, 4617, 91, 41],
            [2005, 4618, 23, 20],
            [2005, 4623, 17, 19],
            [2005, 4626, 28, 17],
            [2005, 4634, 26, 24],
            [2005, 4638, 80, 29],
            [2005, 4643, 20, 19],
            [2005, 4644, 13, 17],
            [2005, 4648, 34, 24],
            [2005, 4660, 52, 29],
            [2005, 4668, 45, 28],
            [2005, 4670, 46, 30],
            [2005, 4676, 13, 16],
            [2005, 4684, 20, 16],
            [2005, 4689, 36, 25],
            [2005, 4703, 10, 13],
            [2005, 4710, 8, 6],
            [2005, 4717, 17, 17],
            [2005, 4724, 24, 18],
            [2005, 4728, 22, 20],
            [2005, 4732, 54, 62],
            [2005, 4734, 14, 15],
            [2005, 4738, 33, 35],
            [2005, 4745, 20, 19],
            [2005, 4747, 45, 26],
            [2005, 4749, 36, 27],
            [2005, 4762, 38, 35],
            [2005, 4764, 21, 26],
            [2005, 4777, 20, 20],
            [2005, 4789, 44, 25],
            [2005, 4791, 20, 25],
            [2005, 4794, 21, 17],
            [2005, 4801, 14, 18],
            [2005, 4805, 12, 17],
            [2005, 4820, 42, 35],
            [2005, 4826, 16, 18],
            [2005, 4828, 61, 44],
            [2005, 4832, 17, 20],
            [2005, 4835, 22, 21],
            [2005, 4839, 28, 18],
            [2005, 4840, 46, 28],
            [2005, 4849, 17, 17],
            [2005, 4863, 38, 31],
            [2005, 4864, 18, 20],
            [2005, 4865, 27, 18],
            [2005, 4871, 14, 17],
            [2005, 4877, 22, 18],
            [2005, 4880, 17, 20],
            [2005, 4881, 29, 27],
            [2005, 4888, 40, 32],
            [2005, 4897, 14, 18],
            [2005, 4912, 10, 15],
            [2005, 4914, 25, 18],
            [2005, 4915, 18, 16],
            [2005, 4918, 20, 23],
            [2005, 4926, 47, 43],
            [2005, 4927, 16, 18],
            [2005, 4931, 16, 17],
            [2005, 4939, 21, 20],
            [2005, 4940, 34, 20],
            [2005, 4944, 15, 14],
            [2005, 4950, 44, 26],
            [2005, 4951, 29, 29],
            [2005, 4955, 34, 26],
            [2005, 4957, 23, 18],
            [2005, 4960, 75, 38],
            [2005, 4973, 30, 30],
            [2005, 4975, 25, 25],
            [2005, 4976, 11, 13],
            [2005, 4978, 52, 39],
            [2005, 4983, 17, 16],
            [2005, 4990, 31, 19],
            [2005, 4992, 22, 20],
            [2005, 4997, 22, 20],
            [2005, 4998, 62, 26],
            [2005, 5006, 74, 34],
            [2005, 5009, 18, 18],
            [2005, 5011, 43, 32],
            [2005, 5012, 34, 37],
            [2005, 5013, 16, 16],
            [2005, 5017, 25, 25],
            [2005, 5019, 57, 38],
            [2005, 5031, 10, 12],
            [2005, 5035, 26, 26],
            [2005, 5038, 14, 16],
            [2005, 5046, 39, 26],
            [2005, 5048, 29, 25],
            [2005, 5050, 22, 18],
            [2005, 5051, 12, 15],
            [2005, 5053, 26, 21],
            [2005, 5062, 36, 21],
            [2005, 5063, 20, 25],
            [2005, 5071, 24, 25],
            [2005, 5073, 52, 34],
            [2005, 5075, 21, 26],
            [2005, 5079, 16, 17],
            [2005, 5081, 34, 16],
            [2005, 5091, 72, 31],
            [2005, 5092, 11, 14],
            [2005, 5095, 14, 15],
            [2005, 5107, 87, 28],
            [2005, 5108, 19, 24],
            [2005, 5116, 30, 27],
            [2005, 5126, 20, 20],
            [2005, 5127, 16, 17],
            [2005, 5130, 47, 41],
            [2005, 5149, 19, 17],
            [2005, 5150, 44, 30],
            [2005, 5159, 55, 24],
            [2005, 5162, 21, 20],
            [2005, 5173, 33, 21],
            [2005, 5181, 17, 18],
            [2005, 5184, 29, 18],
            [2005, 5185, 25, 14],
            [2005, 5186, 14, 15],
            [2005, 5187, 14, 16],
            [2005, 5188, 16, 19],
            [2005, 5189, 16, 10],
            [2005, 5217, 43, 31],
            [2005, 5219, 17, 39],
            [2005, 5220, 15, 42],
            [2005, 5221, 11, 30],
            [2005, 5222, 16, 20],
            [2005, 5223, 11, 26],
            [2005, 5224, 16, 37],
            [2005, 5225, 15, 40],
            [2005, 5226, 12, 42],
            [2005, 5227, 27, 50],
            [2005, 5228, 19, 49],
            [2005, 5229, 11, 36],
            [2005, 5230, 15, 32],
            [2005, 5231, 12, 28],
            [2005, 5232, 18, 44],
            [2005, 5233, 23, 59],
            [2005, 5234, 10, 21],
            [2005, 5235, 34, 35],
            [2005, 5236, 15, 33],
            [2005, 5237, 23, 42],
            [2005, 5238, 15, 30],
            [2005, 5239, 22, 52],
            [2005, 5240, 19, 55],
            [2005, 5241, 25, 51],
            [2005, 5242, 18, 34],
            [2005, 5243, 24, 53],
            [2005, 5244, 20, 55],
            [2005, 5245, 24, 53],
            [2005, 5247, 29, 13],
            [2005, 5248, 30, 18],
            [2005, 5273, 23, 15],
            [2005, 5276, 24, 33],
            [2005, 5279, 23, 22],
            [2005, 5287, 12, 12],
            [2005, 5290, 22, 18],
            [2005, 5298, 14, 14],
            [2005, 5299, 22, 17],
            [2005, 5303, 28, 19],
            [2005, 5305, 21, 16],
            [2005, 5314, 18, 20],
            [2005, 5315, 22, 22],
            [2005, 5317, 28, 36],
            [2005, 5321, 23, 25],
            [2005, 5323, 21, 21],
            [2005, 5328, 16, 15],
            [2005, 5332, 17, 21],
            [2005, 5333, 15, 16],
            [2005, 5336, 16, 14],
            [2005, 5337, 15, 14],
            [2005, 5338, 26, 23],
            [2005, 5339, 21, 25],
            [2005, 5340, 23, 23],
            [2005, 5343, 13, 11],
            [2005, 5344, 32, 30],
            [2005, 5347, 17, 18],
            [2005, 5349, 22, 22],
            [2005, 5350, 21, 22],
            [2005, 5353, 23, 21],
            [2005, 5355, 16, 19],
            [2005, 5357, 21, 21],
            [2005, 5359, 16, 21],
            [2005, 5366, 22, 19],
            [2005, 5371, 28, 28],
            [2005, 5372, 21, 18],
            [2005, 5375, 14, 14],
            [2005, 5377, 22, 21],
            [2005, 5383, 22, 28],
            [2005, 5385, 23, 22],
            [2005, 5387, 15, 13],
            [2005, 5400, 14, 13],
            [2005, 5403, 26, 23],
            [2005, 5404, 19, 19],
            [2005, 5407, 17, 19],
            [2005, 5408, 21, 21],
            [2005, 5411, 21, 15],
            [2005, 5412, 21, 21],
            [2005, 5414, 13, 13],
            [2005, 5415, 23, 21],
            [2005, 5418, 21, 25],
            [2005, 5420, 15, 14],
            [2005, 5421, 21, 15],
            [2005, 5422, 29, 24],
            [2005, 5425, 16, 17],
            [2005, 5426, 16, 19],
            [2005, 5428, 19, 23],
            [2005, 5431, 20, 18],
            [2005, 5432, 21, 23],
            [2005, 5434, 10, 11],
            [2005, 5436, 18, 17],
            [2005, 5437, 23, 19],
            [2005, 5440, 26, 23],
            [2005, 5441, 21, 24],
            [2005, 5444, 22, 28],
            [2005, 5447, 18, 18],
            [2005, 5449, 21, 26],
            [2005, 5450, 21, 22],
            [2005, 5452, 21, 22],
            [2005, 5453, 23, 24],
            [2005, 5454, 14, 14],
            [2005, 5455, 19, 16],
            [2005, 5457, 14, 21],
            [2005, 5459, 15, 15],
            [2005, 5462, 18, 21],
            [2005, 5463, 13, 14],
            [2005, 5464, 17, 18],
            [2005, 5465, 23, 19],
            [2005, 5472, 24, 22],
            [2005, 5473, 21, 19],
            [2005, 5476, 15, 17],
            [2005, 5479, 16, 16],
            [2005, 5480, 25, 22],
            [2005, 5482, 18, 16],
            [2005, 5486, 18, 18],
            [2005, 5489, 23, 31],
            [2005, 5492, 24, 27],
            [2005, 5494, 21, 22],
            [2005, 5495, 21, 18],
            [2005, 5498, 31, 31],
            [2005, 5499, 18, 21],
            [2005, 5501, 25, 32],
            [2005, 5505, 21, 21],
            [2005, 5508, 23, 23],
            [2005, 5528, 13, 12],
            [2005, 5532, 23, 19],
            [2005, 5534, 18, 14],
            [2005, 5539, 22, 17],
            [2005, 5541, 21, 18],
            [2005, 5544, 21, 21],
            [2005, 5545, 21, 21],
            [2005, 5547, 31, 28],
            [2005, 5550, 17, 17],
            [2005, 5571, 24, 21],
            [2005, 5944, 7, 7],
            [2005, 5945, 8, 9],
            [2005, 5946, 6, 5],
            [2005, 5962, 68, 76],
            [2005, 5989, 221, 171],
            [2005, 5990, 221, 171],
            [2005, 5991, 221, 171],
            [2005, 5992, 221, 179],
            [2005, 5993, 221, 171],
            [2005, 5996, 42, 25],
            [2005, 6068, 40, 28],
            [2005, 6069, 42, 32],
            [2005, 6070, 42, 32],
            [2005, 6071, 27, 21],
            [2005, 6073, 27, 25],
            [2005, 6074, 32, 24],
            [2005, 6075, 42, 32],
            [2005, 6076, 31, 26],
            [2005, 6077, 27, 23],
            [2005, 6078, 31, 30],
            [2005, 6079, 34, 25],
            [2005, 6080, 31, 29],
            [2005, 6081, 22, 22],
            [2005, 6082, 32, 24],
            [2005, 6083, 30, 22],
            [2005, 6084, 38, 24],
            [2005, 6085, 34, 26],
            [2005, 6087, 74, 23],
            [2005, 6088, 30, 26],
            [2005, 6089, 27, 23],
            [2005, 6090, 42, 27],
            [2005, 6091, 27, 22],
            [2005, 6092, 30, 25],
            [2005, 6093, 32, 24],
            [2005, 6094, 32, 24],
            [2005, 6095, 22, 19],
            [2005, 6096, 30, 21],
            [2005, 6097, 34, 23],
            [2005, 6098, 30, 22],
            [2005, 6099, 38, 24],
            [2005, 6100, 32, 24],
            [2005, 6101, 32, 21],
            [2005, 6102, 22, 20],
            [2005, 6103, 30, 22],
            [2005, 6104, 34, 22],
            [2005, 6105, 38, 24],
            [2005, 6106, 25, 21],
            [2005, 6108, 32, 23],
            [2005, 6109, 20, 21],
            [2005, 6110, 30, 24],
            [2005, 6111, 14, 19],
            [2005, 6112, 26, 24],
            [2005, 6113, 21, 21],
            [2005, 6114, 21, 21],
            [2005, 6115, 21, 23],
            [2005, 6116, 28, 24],
            [2005, 6117, 23, 23],
            [2005, 6118, 28, 26],
            [2005, 6119, 26, 24],
            [2005, 6120, 19, 20],
            [2005, 6121, 25, 25],
            [2005, 6122, 26, 22],
            [2005, 6123, 21, 21],
            [2005, 6124, 27, 23],
            [2005, 6125, 23, 23],
            [2005, 6126, 25, 25],
            [2005, 6127, 25, 25],
            [2005, 6128, 21, 25],
            [2005, 6130, 26, 24],
            [2005, 6131, 30, 22],
            [2005, 6132, 32, 24],
            [2005, 6133, 30, 22],
            [2005, 6134, 30, 22],
            [2005, 6135, 59, 44],
            [2005, 6136, 52, 40],
            [2005, 6137, 16, 19],
            [2005, 6138, 24, 25],
            [2005, 6139, 27, 24],
            [2005, 6140, 20, 22],
            [2005, 6141, 27, 26],
            [2005, 6142, 21, 23],
            [2005, 6143, 23, 23],
            [2005, 6145, 27, 27],
            [2005, 6146, 14, 19],
            [2005, 6147, 18, 24],
            [2005, 6148, 18, 22],
            [2005, 6149, 25, 25],
            [2005, 6150, 15, 19],
            [2005, 6151, 19, 19],
            [2005, 6152, 17, 19],
            [2005, 6153, 17, 20],
            [2005, 6154, 25, 25],
            [2005, 6155, 20, 21],
            [2005, 6156, 22, 22],
            [2005, 6157, 29, 26],
            [2005, 6158, 22, 21],
            [2005, 6159, 29, 25],
            [2005, 6160, 19, 20],
            [2005, 6161, 15, 19],
            [2005, 6162, 16, 19],
            [2005, 6163, 37, 31],
            [2005, 6164, 27, 25],
            [2005, 6165, 24, 22],
            [2005, 6166, 34, 24],
            [2005, 6167, 37, 30],
            [2005, 6244, 54, 31],
            [2005, 6353, 39, 39],
            [2005, 6357, 39, 22],
            [2005, 6358, 82, 40],
            [2005, 6360, 120, 65],
            [2005, 6361, 126, 60],
            [2005, 6371, 136, 123],
            [2005, 6374, 123, 150],
            [2005, 6375, 212, 72],
            [2005, 6380, 81, 44],
            [2005, 6382, 79, 51],
            [2005, 6385, 110, 100],
            [2005, 6388, 180, 95],
            [2005, 6391, 64, 41],
            [2005, 6393, 200, 180],
            [2005, 6395, 94, 47],
            [2005, 6400, 105, 68],
            [2005, 6405, 166, 50],
            [2005, 6408, 350, 100],
            [2005, 6411, 60, 47],
            [2005, 6412, 89, 104],
            [2005, 6413, 118, 89],
            [2005, 6414, 144, 63],
            [2005, 6416, 150, 70],
            [2005, 6421, 64, 57],
            [2005, 6422, 85, 70],
            [2005, 6425, 84, 44],
            [2005, 6426, 90, 78],
            [2005, 6430, 49, 67],
            [2005, 6431, 64, 69],
            [2005, 6432, 127, 114],
            [2005, 6433, 40, 36],
            [2005, 6436, 167, 62],
            [2005, 6438, 76, 65],
            [2005, 6441, 49, 51],
            [2005, 6442, 47, 32],
            [2005, 6448, 71, 50],
            [2005, 6450, 172, 139],
            [2005, 6452, 200, 100],
            [2005, 6462, 120, 94],
            [2005, 6463, 100, 100],
            [2005, 6467, 220, 216],
            [2005, 6469, 75, 98],
            [2005, 6471, 60, 48],
            [2005, 6474, 140, 75],
            [2005, 6476, 78, 49],
            [2005, 6477, 225, 108],
            [2005, 6478, 143, 48],
            [2005, 6483, 96, 70],
            [2005, 6486, 214, 82],
            [2005, 6489, 110, 50],
            [2005, 6492, 26, 30],
            [2005, 6494, 29, 25],
            [2005, 6495, 60, 48],
            [2005, 6496, 71, 50],
            [2005, 6499, 146, 115],
            [2005, 6502, 39, 45],
            [2005, 6512, 60, 50],
            [2005, 6514, 171, 110],
            [2005, 6515, 150, 75],
            [2005, 6516, 110, 150],
            [2005, 6518, 87, 92],
            [2005, 6519, 200, 200],
            [2005, 6521, 56, 35],
            [2005, 6524, 145, 130],
            [2005, 6527, 51, 50],
            [2005, 6529, 116, 127],
            [2005, 6530, 55, 45],
            [2005, 6532, 58, 48],
            [2005, 6534, 62, 65],
            [2005, 6565, 150, 105],
            [2005, 6566, 58, 44],
            [2005, 6568, 64, 50],
            [2005, 6570, 140, 80],
            [2005, 6576, 51, 50],
            [2005, 6581, 200, 119],
            [2005, 6584, 120, 50],
            [2005, 6585, 56, 53],
            [2005, 6587, 115, 80],
            [2005, 6589, 170, 60],
            [2005, 6590, 219, 92],
            [2005, 6602, 104, 47],
            [2005, 6607, 129, 54],
            [2005, 6609, 82, 57],
            [2005, 6612, 96, 80],
            [2005, 6614, 32, 32],
            [2005, 6615, 76, 56],
            [2005, 6616, 85, 111],
            [2005, 6621, 126, 50],
            [2005, 6623, 120, 90],
            [2005, 6630, 81, 100],
            [2005, 6631, 34, 33],
            [2005, 6633, 25, 24],
            [2005, 6634, 29, 25],
            [2005, 6635, 34, 26],
            [2005, 6636, 45, 34],
            [2005, 6637, 38, 24],
            [2005, 6638, 42, 28],
            [2005, 6639, 34, 30],
            [2005, 6640, 25, 59],
            [2005, 6643, 43, 25],
            [2005, 6649, 38, 25],
            [2005, 6650, 38, 24],
            [2005, 6651, 27, 19],
            [2005, 6652, 33, 26],
            [2005, 6653, 36, 27],
            [2005, 6654, 26, 24],
            [2005, 6655, 27, 21],
            [2005, 6656, 28, 24],
            [2005, 6657, 34, 26],
            [2005, 6660, 29, 20],
            [2005, 6661, 23, 23],
            [2005, 6662, 31, 26],
            [2005, 6663, 26, 24],
            [2005, 6664, 30, 26],
            [2005, 6665, 25, 25],
            [2005, 6666, 25, 23],
            [2005, 6667, 26, 24],
            [2005, 6668, 26, 20],
            [2005, 6669, 34, 25],
            [2005, 6670, 27, 23],
            [2005, 6671, 33, 24],
            [2005, 6672, 29, 21],
            [2005, 6673, 32, 22],
            [2005, 6674, 28, 26],
            [2005, 6675, 27, 23],
            [2005, 6676, 34, 30],
            [2005, 6677, 25, 25],
            [2005, 6678, 27, 23],
            [2005, 6679, 52, 40],
            [2005, 6680, 25, 21],
            [2005, 6682, 24, 22],
            [2005, 6683, 25, 25],
            [2005, 6684, 25, 26],
            [2005, 6685, 21, 23],
            [2005, 6686, 19, 21],
            [2005, 6687, 21, 23],
            [2005, 6688, 19, 21],
            [2005, 6689, 21, 23],
            [2005, 6690, 19, 21],
            [2005, 6697, 33, 27],
            [2005, 6699, 25, 76],
            [2005, 6700, 78, 37],
            [2005, 6701, 68, 41],
            [2005, 6702, 35, 23],
            [2005, 6704, 82, 44],
            [2005, 6715, 45, 35],
            [2005, 6716, 30, 31],
            [2005, 6718, 31, 53],
            [2005, 6722, 35, 31],
            [2005, 6723, 81, 48],
            [2005, 6726, 45, 65],
            [2005, 6728, 53, 34],
            [2005, 6734, 59, 40],
            [2005, 6737, 31, 87],
            [2005, 6738, 70, 48],
            [2005, 6741, 14, 15],
            [2005, 6748, 24, 22],
            [2005, 6749, 23, 23],
            [2005, 6750, 33, 31],
            [2005, 6752, 19, 21],
            [2005, 6753, 29, 27],
            [2005, 6754, 29, 25],
            [2005, 6755, 32, 32],
            [2005, 6756, 29, 29],
            [2005, 6757, 25, 24],
            [2005, 6758, 29, 33],
            [2005, 6759, 19, 21],
            [2005, 6760, 32, 32],
            [2005, 6761, 33, 31],
            [2005, 6762, 29, 29],
            [2005, 6763, 22, 19],
            [2005, 6764, 27, 29],
            [2005, 6766, 42, 32],
            [2005, 6767, 30, 24],
            [2005, 6768, 28, 26],
            [2005, 6769, 32, 37],
            [2005, 6770, 30, 31],
            [2005, 6771, 30, 29],
            [2005, 6772, 23, 26],
            [2005, 6773, 35, 33],
            [2005, 6777, 38, 32],
            [2005, 6778, 25, 25],
            [2005, 6779, 30, 31],
            [2005, 6780, 31, 29],
            [2005, 6781, 34, 30],
            [2005, 6782, 52, 37],
            [2005, 6783, 38, 33],
            [2005, 6784, 29, 29],
            [2005, 6785, 30, 28],
            [2005, 6786, 30, 31],
            [2005, 6787, 28, 30],
            [2005, 6789, 33, 31],
            [2005, 6790, 35, 104],
            [2005, 6791, 92, 87],
            [2005, 6794, 21, 40],
            [2005, 6795, 44, 68],
            [2005, 6798, 35, 28],
            [2005, 6803, 31, 79],
            [2005, 6804, 50, 104],
            [2005, 6805, 78, 136],
            [2005, 6806, 30, 68],
            [2005, 6807, 35, 46],
            [2005, 6808, 21, 40],
            [2005, 6812, 171, 78],
            [2005, 6813, 31, 65],
            [2005, 6814, 130, 107],
            [2005, 6816, 86, 95],
            [2005, 6818, 18, 20],
            [2005, 6819, 34, 43],
            [2005, 6820, 33, 33],
            [2005, 6821, 35, 41],
            [2005, 6822, 45, 44],
            [2005, 6823, 32, 36],
            [2005, 6833, 68, 55],
            [2005, 6834, 155, 107],
            [2005, 6835, 295, 143],
            [2005, 6836, 40, 65],
            [2005, 6837, 21, 28],
            [2005, 6838, 143, 95],
            [2005, 6841, 26, 20],
            [2005, 6845, 31, 63],
            [2005, 6846, 38, 58],
            [2005, 6847, 40, 45],
            [2005, 6848, 40, 21],
            [2005, 6849, 74, 46],
            [2005, 6850, 45, 51],
            [2005, 6851, 21, 46],
            [2005, 6852, 87, 128],
            [2005, 6853, 31, 54],
            [2005, 6854, 155, 81],
            [2005, 6855, 40, 40],
            [2005, 6856, 30, 55],
            [2005, 6857, 35, 76],
            [2005, 6858, 50, 54],
            [2005, 6859, 60, 52],
            [2005, 6860, 25, 31],
            [2005, 6861, 30, 50],
            [2005, 6862, 35, 40],
            [2005, 6867, 14, 20],
            [2005, 6868, 15, 15],
            [2005, 6869, 15, 15],
            [2005, 6870, 15, 17],
            [2005, 6871, 16, 17],
            [2005, 6872, 15, 17],
            [2005, 6873, 20, 16],
            [2005, 6874, 11, 16],
            [2005, 6875, 14, 17],
            [2005, 6876, 11, 15],
            [2005, 6877, 19, 25],
            [2005, 6878, 14, 16],
            [2005, 6879, 16, 20],
            [2005, 6880, 19, 19],
            [2005, 6881, 11, 13],
            [2005, 6882, 15, 17],
            [2005, 6883, 19, 21],
            [2005, 6910, 58, 46],
            [2005, 6911, 62, 49],
            [2005, 6912, 19, 11],
            [2005, 6913, 55, 43],
            [2005, 6914, 12, 12],
            [2005, 6915, 37, 28],
            [2005, 6917, 27, 30],
            [2005, 6918, 29, 24],
            [2005, 6919, 34, 35],
            [2005, 6920, 21, 20],
            [2005, 6921, 45, 32],
            [2005, 6922, 12, 11],
            [2005, 6923, 48, 34],
            [2005, 6925, 39, 35],
            [2005, 6926, 54, 29],
            [2005, 6927, 63, 33],
            [2005, 6928, 18, 17],
            [2005, 6929, 52, 35],
            [2005, 6930, 25, 18],
            [2005, 6931, 37, 35],
            [2005, 6932, 18, 14],
            [2005, 6933, 27, 24],
            [2005, 6934, 17, 15],
            [2005, 6935, 43, 36],
            [2005, 6936, 21, 22],
            [2005, 6937, 45, 35],
            [2005, 6938, 17, 14],
            [2005, 6939, 46, 33],
            [2005, 6940, 12, 11],
            [2005, 6941, 27, 21],
            [2005, 6942, 19, 17],
            [2005, 6943, 71, 51],
            [2005, 6944, 11, 11],
            [2005, 6945, 43, 30],
            [2005, 6946, 54, 30],
            [2005, 6947, 63, 42],
            [2005, 6948, 12, 11],
            [2005, 6949, 45, 33],
            [2005, 6950, 13, 11],
            [2005, 6951, 47, 36],
            [2005, 6952, 49, 23],
            [2005, 6953, 56, 27],
            [2005, 6954, 26, 16],
            [2005, 6955, 45, 33],
            [2005, 6957, 63, 52],
            [2005, 6958, 13, 11],
            [2005, 6959, 45, 35],
            [2005, 6960, 15, 15],
            [2005, 6961, 43, 23],
            [2005, 6962, 13, 11],
            [2005, 6965, 9, 10],
            [2005, 6966, 21, 34],
            [2005, 6967, 17, 37],
            [2005, 6968, 35, 60],
            [2005, 6969, 19, 34],
            [2005, 6970, 22, 36],
            [2005, 7005, 14, 14],
            [2005, 7006, 30, 29],
            [2005, 7007, 53, 26],
            [2005, 7008, 52, 26],
            [2005, 7011, 10, 10],
            [2005, 7012, 21, 24],
            [2005, 7013, 21, 18],
            [2005, 7014, 14, 9],
            [2005, 7015, 8, 8],
            [2005, 7019, 11, 9],
            [2005, 7021, 12, 11],
            [2005, 7022, 25, 29],
            [2005, 7023, 16, 18],
            [2005, 7024, 25, 29],
            [2005, 7026, 25, 19],
            [2005, 7027, 16, 16],
            [2005, 7028, 37, 35],
            [2005, 7029, 35, 26],
            [2005, 7030, 49, 34],
            [2005, 7031, 15, 19],
            [2005, 7032, 29, 19],
            [2005, 7033, 24, 20],
            [2005, 7034, 31, 27],
            [2005, 7035, 11, 12],
            [2005, 7036, 29, 28],
            [2005, 7037, 25, 25],
            [2005, 7038, 31, 33],
            [2005, 7039, 21, 14],
            [2005, 7040, 27, 25],
            [2005, 7042, 52, 29],
            [2005, 7043, 19, 25],
            [2005, 7044, 27, 24],
            [2005, 7045, 32, 21],
            [2005, 7046, 48, 34],
            [2005, 7048, 26, 20],
            [2005, 7049, 47, 34],
            [2005, 7050, 16, 14],
            [2005, 7051, 51, 37],
            [2005, 7052, 15, 18],
            [2005, 7053, 47, 37],
            [2005, 7054, 16, 15],
            [2005, 7055, 33, 24],
            [2005, 7056, 13, 14],
            [2005, 7057, 55, 37],
            [2005, 7058, 26, 16],
            [2005, 7059, 51, 29],
            [2005, 7060, 26, 17],
            [2005, 7061, 47, 37],
            [2005, 7062, 16, 13],
            [2005, 7063, 42, 26],
            [2005, 7064, 26, 18],
            [2005, 7065, 39, 39],
            [2005, 7066, 12, 12],
            [2005, 7067, 47, 38],
            [2005, 7068, 66, 27],
            [2005, 7069, 74, 49],
            [2005, 7070, 33, 30],
            [2005, 7071, 55, 36],
            [2005, 7072, 10, 11],
            [2005, 7073, 27, 26],
            [2005, 7074, 15, 14],
            [2005, 7075, 56, 51],
            [2005, 7076, 26, 20],
            [2005, 7077, 36, 27],
            [2005, 7078, 11, 11],
            [2005, 7079, 31, 20],
            [2005, 7080, 38, 32],
            [2005, 7081, 65, 47],
            [2005, 7082, 20, 18],
            [2005, 7083, 46, 35],
            [2005, 7084, 50, 24],
            [2005, 7085, 57, 35],
            [2005, 7086, 12, 14],
            [2005, 7087, 40, 32],
            [2005, 7088, 51, 28],
            [2005, 7089, 59, 35],
            [2005, 7090, 17, 12],
            [2005, 7091, 52, 35],
            [2005, 7092, 46, 33],
            [2005, 7093, 65, 53],
            [2005, 7094, 44, 31],
            [2005, 7095, 53, 38],
            [2005, 7096, 25, 21],
            [2005, 7097, 38, 30],
            [2005, 7098, 24, 24],
            [2005, 7099, 49, 36],
            [2005, 7100, 15, 13],
            [2005, 7101, 19, 17],
            [2005, 7156, 17, 18],
            [2005, 7259, 83, 52],
            [2005, 7260, 106, 82],
            [2005, 7261, 84, 67],
            [2005, 7262, 70, 74],
            [2005, 7263, 96, 79],
            [2005, 7264, 84, 88],
            [2005, 7265, 88, 72],
            [2005, 7266, 112, 83],
            [2005, 7267, 84, 68],
            [2005, 7268, 111, 82],
            [2005, 7269, 111, 82],
            [2005, 7270, 80, 50],
            [2005, 7271, 66, 61],
            [2005, 7272, 107, 79],
            [2005, 7273, 86, 90],
            [2005, 7274, 105, 76],
            [2005, 7275, 91, 76],
            [2005, 7276, 59, 49],
            [2005, 7277, 86, 69],
            [2005, 7278, 71, 75],
            [2005, 7279, 92, 65],
            [2005, 7280, 113, 84],
            [2005, 7281, 83, 66],
            [2005, 7282, 69, 72],
            [2005, 7283, 13, 19],
            [2005, 7284, 11, 10],
            [2005, 7285, 12, 11],
            [2005, 7286, 15, 20],
            [2005, 7287, 13, 23],
            [2005, 7288, 28, 28],
            [2005, 7289, 26, 21],
            [2005, 7290, 45, 31],
            [2005, 7291, 34, 28],
            [2005, 7292, 33, 34],
            [2005, 7293, 24, 21],
            [2005, 7294, 21, 20],
            [2005, 7295, 13, 14],
            [2005, 7296, 23, 20],
            [2005, 7297, 25, 22],
            [2005, 7298, 15, 16],
            [2005, 7299, 16, 18],
            [2005, 7300, 18, 26],
            [2005, 7301, 13, 23],
            [2005, 7302, 39, 43],
            [2005, 7303, 75, 72],
            [2005, 7304, 30, 32],
            [2005, 7305, 39, 39],
            [2005, 7306, 30, 33],
            [2005, 7307, 47, 50],
            [2005, 7308, 38, 41],
            [2005, 7309, 31, 33],
            [2005, 7310, 79, 66],
            [2005, 7311, 66, 64],
            [2005, 7312, 37, 38],
            [2005, 7313, 99, 71],
            [2005, 7314, 80, 61],
            [2005, 7315, 75, 57],
            [2005, 7316, 81, 61],
            [2005, 7317, 82, 62],
            [2005, 7318, 80, 62],
            [2005, 7319, 104, 75],
            [2005, 7320, 78, 59],
            [2005, 7321, 101, 76],
            [2005, 7322, 80, 60],
            [2005, 7323, 94, 70],
            [2005, 7324, 99, 71],
            [2005, 7325, 83, 62],
            [2005, 7326, 81, 61],
            [2005, 7327, 96, 71],
            [2005, 7328, 25, 29],
            [2005, 7329, 47, 44],
            [2005, 7330, 29, 29],
            [2005, 7331, 29, 29],
            [2005, 7332, 24, 27],
            [2005, 7333, 50, 56],
            [2005, 7337, 15, 12],
            [2005, 7342, 13, 10],
            [2005, 7343, 15, 8],
            [2005, 7344, 11, 9],
            [2005, 7348, 15, 8],
            [2005, 7352, 12, 11],
            [2005, 7354, 26, 15],
            [2005, 7356, 14, 13],
            [2005, 7357, 24, 15],
            [2005, 7358, 14, 10],
            [2005, 7359, 24, 15],
            [2005, 7360, 16, 10],
            [2005, 7362, 17, 12],
            [2005, 7363, 12, 11],
            [2005, 7364, 14, 11],
            [2005, 7367, 15, 12],
            [2005, 7370, 11, 10],
            [2005, 7371, 13, 11],
            [2005, 7372, 13, 10],
            [2005, 7373, 13, 10],
            [2005, 7374, 11, 8],
            [2005, 7375, 12, 8],
            [2005, 7376, 7, 8],
            [2005, 7377, 11, 8],
            [2005, 7378, 20, 18],
            [2005, 7379, 30, 23],
            [2005, 7396, 28, 27],
            [2005, 7397, 45, 37],
            [2005, 7398, 28, 29],
            [2005, 7399, 23, 26],
            [2005, 7400, 45, 41],
            [2005, 7401, 23, 26],
            [2005, 7402, 53, 60],
            [2005, 7403, 19, 22],
            [2005, 7404, 56, 43],
            [2005, 7405, 27, 28],
            [2005, 7406, 43, 46],
            [2005, 7407, 29, 28],
            [2005, 7408, 45, 49],
            [2005, 7410, 20, 32],
            [2005, 7411, 51, 48],
            [2005, 7413, 11, 14],
            [2005, 7414, 20, 30],
            [2005, 7415, 11, 15],
            [2005, 7416, 26, 32],
            [2005, 7417, 21, 19],
            [2005, 7420, 28, 31],
            [2005, 7421, 26, 28],
            [2005, 7423, 55, 62],
            [2005, 7433, 78, 56],
            [2005, 7434, 95, 95],
            [2005, 7435, 42, 78],
            [2005, 7436, 58, 80],
            [2005, 7437, 19, 18],
            [2005, 7438, 38, 31],
            [2005, 7441, 23, 15],
            [2005, 7442, 42, 21],
            [2005, 7443, 78, 112],
            [2005, 7444, 68, 112],
            [2005, 7445, 35, 76],
            [2005, 7446, 46, 82],
            [2005, 7447, 20, 19],
            [2005, 7448, 38, 32],
            [2005, 7449, 23, 23],
            [2005, 7450, 21, 21],
            [2005, 7451, 14, 14],
            [2005, 7452, 24, 21],
            [2005, 7453, 74, 48],
            [2005, 7454, 21, 16],
            [2005, 7455, 24, 22],
            [2005, 7456, 66, 48],
            [2005, 7457, 53, 46],
            [2005, 7458, 34, 32],
            [2005, 7459, 53, 46],
            [2005, 7460, 53, 50],
            [2005, 7461, 34, 30],
            [2005, 7462, 39, 34],
            [2005, 7463, 42, 39],
            [2005, 7464, 57, 42],
            [2005, 7465, 46, 34],
            [2005, 7466, 43, 31],
            [2005, 7467, 53, 46],
            [2005, 7468, 38, 34],
            [2005, 7469, 48, 37],
            [2005, 7470, 62, 45],
            [2005, 7471, 72, 52],
            [2005, 7472, 27, 54],
            [2005, 7473, 34, 34],
            [2005, 7474, 53, 46],
            [2005, 7475, 53, 46],
            [2005, 7476, 40, 35],
            [2005, 7477, 37, 32],
            [2005, 7478, 38, 35],
            [2005, 7479, 38, 34],
            [2005, 7480, 53, 41],
            [2005, 7481, 34, 35],
            [2005, 7482, 43, 31],
            [2005, 7483, 53, 46],
            [2005, 7484, 43, 42],
            [2005, 7485, 74, 54],
            [2005, 7486, 53, 39],
            [2005, 7487, 40, 35],
            [2005, 7488, 46, 34],
            [2005, 7489, 59, 39],
            [2005, 7490, 39, 34],
            [2005, 7491, 46, 35],
            [2005, 7492, 53, 39],
            [2005, 7493, 42, 37],
            [2005, 7494, 42, 37],
            [2005, 7495, 53, 46],
            [2005, 7496, 74, 54],
            [2005, 7497, 46, 34],
            [2005, 7498, 34, 35],
            [2005, 7499, 38, 30],
            [2005, 7500, 48, 42],
            [2005, 7501, 57, 42],
            [2005, 7502, 46, 34],
            [2005, 7503, 49, 38],
            [2005, 7504, 48, 35],
            [2005, 7505, 42, 37],
            [2005, 7506, 57, 42],
            [2005, 7507, 41, 36],
            [2005, 7508, 46, 35],
            [2005, 7509, 53, 46],
            [2005, 7510, 53, 46],
            [2005, 7511, 57, 42],
            [2005, 7512, 53, 46],
            [2005, 7513, 46, 34],
            [2005, 7514, 94, 71],
            [2005, 7515, 50, 36],
            [2005, 7516, 53, 46],
            [2005, 7517, 74, 54],
            [2005, 7518, 57, 42],
            [2005, 7519, 42, 37],
            [2005, 7520, 43, 38],
            [2005, 7521, 35, 34],
            [2005, 7522, 62, 45],
            [2005, 7523, 42, 39],
            [2005, 7524, 59, 52],
            [2005, 7525, 53, 46],
            [2005, 7526, 48, 35],
            [2005, 7527, 35, 34],
            [2005, 7528, 66, 48],
            [2005, 7529, 74, 64],
            [2005, 7530, 62, 45],
            [2005, 7531, 43, 42],
            [2005, 7532, 53, 46],
            [2005, 7533, 66, 48],
            [2005, 7534, 74, 64],
            [2005, 7535, 43, 38],
            [2005, 7536, 62, 45],
            [2005, 7537, 51, 38],
            [2005, 7538, 66, 48],
            [2005, 7539, 42, 39],
            [2005, 7540, 66, 48],
            [2005, 7541, 50, 36],
            [2005, 7542, 66, 48],
            [2005, 7543, 49, 36],
            [2005, 7544, 51, 38],
            [2005, 7545, 40, 35],
            [2005, 7546, 46, 34],
            [2005, 7547, 46, 34],
            [2005, 7548, 48, 42],
            [2005, 7549, 53, 46],
            [2005, 7550, 38, 34],
            [2005, 7551, 39, 34],
            [2005, 7552, 39, 34],
            [2005, 7553, 43, 38],
            [2005, 7554, 70, 57],
            [2005, 7555, 66, 50],
            [2005, 7556, 53, 46],
            [2005, 7557, 74, 54],
            [2005, 7558, 35, 31],
            [2005, 7559, 46, 34],
            [2005, 7560, 39, 34],
            [2005, 7561, 74, 54],
            [2005, 7562, 74, 54],
            [2005, 7563, 62, 45],
            [2005, 7564, 49, 36],
            [2005, 7565, 42, 39],
            [2005, 7566, 42, 37],
            [2005, 7567, 53, 46],
            [2005, 7568, 43, 38],
            [2005, 7569, 43, 38],
            [2005, 7570, 42, 37],
            [2005, 7571, 42, 37],
            [2005, 7572, 74, 54],
            [2005, 7573, 53, 42],
            [2005, 7574, 42, 37],
            [2005, 7575, 57, 42],
            [2005, 7576, 57, 42],
            [2005, 7577, 62, 45],
            [2005, 7578, 42, 39],
            [2005, 7579, 62, 45],
            [2005, 7580, 62, 45],
            [2005, 7581, 49, 38],
            [2005, 7582, 50, 41],
            [2005, 7583, 53, 46],
            [2005, 7584, 40, 35],
            [2005, 7585, 40, 37],
            [2005, 7586, 74, 54],
            [2005, 7587, 48, 42],
            [2005, 7588, 42, 39],
            [2005, 7589, 74, 54],
            [2005, 7590, 53, 46],
            [2005, 7591, 46, 35],
            [2005, 7592, 62, 45],
            [2005, 7593, 51, 38],
            [2005, 7594, 42, 37],
            [2005, 7595, 42, 39],
            [2005, 7596, 38, 34],
            [2005, 7597, 42, 39],
            [2005, 7598, 57, 42],
            [2005, 7599, 53, 46],
            [2005, 7600, 53, 46],
            [2005, 7601, 39, 34],
            [2005, 7602, 37, 32],
            [2005, 7603, 53, 46],
            [2005, 7604, 53, 46],
            [2005, 7605, 53, 46],
            [2005, 7606, 53, 42],
            [2005, 7607, 62, 45],
            [2005, 7608, 39, 34],
            [2005, 7609, 53, 46],
            [2005, 7610, 38, 36],
            [2005, 7611, 40, 46],
            [2005, 7612, 53, 45],
            [2005, 7613, 42, 39],
            [2005, 7614, 46, 37],
            [2005, 7615, 62, 45],
            [2005, 7616, 50, 36],
            [2005, 7617, 46, 36],
            [2005, 7618, 50, 36],
            [2005, 7619, 53, 46],
            [2005, 7620, 48, 42],
            [2005, 7621, 53, 46],
            [2005, 7622, 62, 45],
            [2005, 7623, 42, 37],
            [2005, 7624, 66, 48],
            [2005, 7625, 38, 35],
            [2005, 7626, 50, 36],
            [2005, 7627, 41, 36],
            [2005, 7628, 62, 45],
            [2005, 7629, 38, 35],
            [2005, 7630, 40, 35],
            [2005, 7631, 50, 44],
            [2005, 7632, 49, 36],
            [2005, 7633, 38, 35],
            [2005, 7634, 13, 20],
            [2005, 7635, 13, 17],
            [2005, 7636, 16, 21],
            [2005, 7637, 28, 26],
            [2005, 7638, 54, 35],
            [2005, 7639, 11, 13],
            [2005, 7640, 10, 10],
            [2005, 7641, 15, 17],
            [2005, 7642, 31, 31],
            [2005, 7643, 21, 18],
            [2005, 7644, 26, 33],
            [2005, 7645, 18, 19],
            [2005, 7646, 24, 23],
            [2005, 7647, 34, 23],
            [2005, 7648, 11, 11],
            [2005, 7649, 11, 11],
            [2005, 7650, 17, 15],
            [2005, 7651, 12, 12],
            [2005, 7652, 14, 14],
            [2005, 7653, 37, 29],
            [2005, 7654, 11, 11],
            [2005, 7655, 14, 14],
            [2005, 7656, 14, 14],
            [2005, 7657, 23, 27],
            [2005, 7658, 23, 27],
            [2005, 7659, 14, 18],
            [2005, 7661, 10, 10],
            [2005, 7662, 17, 14],
            [2005, 7663, 16, 18],
            [2005, 7664, 21, 27],
            [2005, 7665, 27, 33],
            [2005, 7666, 13, 12],
            [2005, 7667, 17, 15],
            [2005, 7668, 13, 12],
            [2005, 7669, 11, 8],
            [2005, 7672, 9, 9],
            [2005, 7673, 8, 7],
            [2005, 7674, 17, 16],
            [2005, 7676, 6, 7],
            [2005, 7677, 5, 6],
            [2005, 7678, 10, 8],
            [2005, 7679, 11, 9],
            [2005, 7680, 34, 19],
            [2005, 7681, 5, 3],
            [2005, 7682, 16, 13],
            [2005, 7683, 3, 3],
            [2005, 7684, 14, 13],
            [2005, 7685, 12, 11],
            [2005, 7686, 20, 18],
            [2005, 7687, 5, 4],
            [2005, 7688, 14, 14],
            [2005, 7690, 7, 8],
            [2005, 7691, 24, 23],
            [2005, 7692, 10, 8],
            [2005, 7693, 9, 9],
            [2005, 7694, 9, 9],
            [2005, 7695, 25, 19],
            [2005, 7696, 3, 3],
            [2005, 7697, 16, 12],
            [2005, 7698, 9, 8],
            [2005, 7699, 12, 14],
            [2005, 7700, 14, 10],
            [2005, 7701, 9, 8],
            [2005, 7702, 22, 13],
            [2005, 7703, 12, 13],
            [2005, 7705, 23, 13],
            [2005, 7706, 11, 10],
            [2005, 7707, 12, 10],
            [2005, 7708, 9, 7],
            [2005, 7709, 12, 13],
            [2005, 7710, 6, 5],
            [2005, 7711, 15, 11],
            [2005, 7713, 27, 12],
            [2005, 7714, 10, 9],
            [2005, 7715, 29, 33],
            [2005, 7716, 27, 28],
            [2005, 7717, 49, 54],
            [2005, 7718, 29, 29],
            [2005, 7719, 24, 27],
            [2005, 7720, 54, 62],
            [2005, 7721, 30, 29],
            [2005, 7722, 35, 30],
            [2005, 7723, 22, 25],
            [2005, 7724, 46, 49],
            [2005, 7725, 17, 21],
            [2005, 7726, 27, 30],
            [2005, 7727, 32, 32],
            [2005, 7728, 48, 44],
            [2005, 7729, 31, 30],
            [2005, 7730, 21, 24],
            [2005, 7731, 48, 52],
            [2005, 7732, 26, 30],
            [2005, 7733, 45, 50],
            [2005, 7734, 41, 34],
            [2005, 7735, 61, 57],
            [2005, 7736, 23, 26],
            [2005, 7737, 42, 38],
            [2005, 7738, 22, 25],
            [2005, 7739, 35, 40],
            [2005, 7740, 23, 26],
            [2005, 7741, 42, 46],
            [2005, 7742, 44, 43],
            [2005, 7743, 29, 28],
            [2005, 7744, 47, 51],
            [2005, 7745, 49, 39],
            [2005, 7746, 30, 29],
            [2005, 7747, 36, 42],
            [2005, 7748, 47, 44],
            [2005, 7749, 31, 32],
            [2005, 7750, 47, 52],
            [2005, 7751, 41, 34],
            [2005, 7752, 60, 55],
            [2005, 7753, 44, 41],
            [2005, 7754, 31, 32],
            [2005, 7755, 24, 26],
            [2005, 7756, 61, 42],
            [2005, 7757, 36, 100],
            [2005, 7758, 65, 107],
            [2005, 7759, 30, 28],
            [2005, 7760, 60, 44],
            [2005, 7761, 49, 59],
            [2005, 7762, 114, 87],
            [2005, 7763, 13, 17],
            [2005, 7764, 11, 12],
            [2005, 7765, 14, 19],
            [2005, 7766, 9, 16],
            [2005, 7767, 24, 28],
            [2005, 7768, 10, 18],
            [2005, 7769, 31, 31],
            [2005, 7770, 14, 16],
            [2005, 7771, 40, 32],
            [2005, 7772, 14, 16],
            [2005, 7773, 22, 24],
            [2005, 7774, 12, 20],
            [2005, 7775, 34, 33],
            [2005, 7776, 14, 26],
            [2005, 7777, 23, 31],
            [2005, 7778, 9, 12],
            [2005, 7779, 15, 19],
            [2005, 7780, 17, 18],
            [2005, 7781, 24, 27],
            [2005, 7782, 26, 24],
            [2005, 7783, 27, 23],
            [2005, 7784, 15, 27],
            [2005, 7785, 32, 36],
            [2005, 7786, 14, 16],
            [2005, 7787, 23, 27],
            [2005, 7788, 18, 20],
            [2005, 7789, 20, 25],
            [2005, 7790, 19, 25],
            [2005, 7791, 37, 36],
            [2005, 7792, 16, 23],
            [2005, 7793, 33, 32],
            [2005, 7795, 120, 85],
            [2005, 7796, 120, 74],
            [2005, 7797, 120, 83],
            [2005, 7798, 120, 32],
            [2005, 7799, 120, 75],
            [2005, 7800, 94, 37],
            [2005, 7801, 120, 72],
            [2005, 7802, 40, 29],
            [2005, 7803, 120, 90],
            [2005, 7804, 120, 88],
            [2005, 7805, 120, 52],
            [2005, 7806, 120, 86],
            [2005, 7807, 100, 29],
            [2005, 7808, 120, 42],
            [2005, 7809, 111, 75],
            [2005, 7810, 120, 90],
            [2005, 7811, 120, 90],
            [2005, 7812, 39, 31],
            [2005, 7813, 87, 33],
            [2005, 7815, 86, 34],
            [2005, 7816, 120, 90],
            [2005, 7817, 56, 41],
            [2005, 7818, 83, 79],
            [2005, 7819, 43, 65],
            [2005, 7820, 91, 43],
            [2005, 7821, 120, 69],
            [2005, 7822, 120, 70],
            [2005, 7823, 47, 39],
            [2005, 7824, 120, 70],
            [2005, 7825, 120, 73],
            [2005, 7826, 111, 87],
            [2005, 7827, 120, 64],
            [2005, 7828, 120, 90],
            [2005, 7829, 97, 37],
            [2005, 7830, 120, 59],
            [2005, 7831, 120, 37],
            [2005, 7832, 120, 90],
            [2005, 7833, 61, 30],
            [2005, 7834, 120, 87],
            [2005, 7835, 117, 33],
            [2005, 7836, 120, 83],
            [2005, 7837, 42, 32],
            [2005, 7838, 120, 78],
            [2005, 7839, 112, 90],
            [2005, 7840, 120, 90],
            [2005, 7841, 120, 70],
            [2005, 7842, 40, 35],
            [2005, 7843, 40, 31],
            [2005, 7844, 120, 63],
            [2005, 7845, 51, 48],
            [2005, 7846, 120, 90],
            [2005, 7847, 120, 90],
            [2005, 7848, 120, 90],
            [2005, 7849, 120, 90],
            [2005, 7850, 97, 90],
            [2005, 7851, 120, 87],
            [2005, 7852, 96, 46],
            [2005, 7853, 88, 60],
            [2005, 7854, 31, 27],
            [2005, 7855, 32, 28],
            [2005, 7856, 120, 90],
            [2005, 7857, 41, 31],
            [2005, 7858, 40, 32],
            [2005, 7859, 120, 72],
            [2005, 7860, 114, 77],
            [2005, 7861, 35, 27],
            [2005, 7862, 120, 52],
            [2005, 7863, 120, 90],
            [2005, 7864, 39, 34],
            [2005, 7865, 46, 37],
            [2005, 7866, 120, 75],
            [2005, 7867, 53, 32],
            [2005, 7868, 42, 31],
            [2005, 7869, 120, 70],
            [2005, 7870, 42, 31],
            [2005, 7871, 59, 35],
            [2005, 7872, 120, 90],
            [2005, 7873, 120, 90],
            [2005, 7874, 42, 32],
            [2005, 7875, 120, 90],
            [2005, 7876, 120, 90],
            [2005, 7877, 111, 71],
            [2005, 7878, 120, 40],
            [2005, 7879, 120, 90],
            [2005, 7880, 92, 71],
            [2005, 7881, 111, 64],
            [2005, 7882, 49, 39],
            [2005, 7883, 111, 89],
            [2005, 7884, 67, 62],
            [2005, 7885, 39, 34],
            [2005, 7886, 73, 35],
            [2005, 7887, 42, 32],
            [2005, 7888, 120, 49],
            [2005, 7889, 120, 90],
            [2005, 7890, 120, 90],
            [2005, 7891, 74, 28],
            [2005, 7892, 64, 33],
            [2005, 7893, 41, 31],
            [2005, 7894, 120, 90],
            [2005, 7895, 80, 37],
            [2005, 7896, 120, 87],
            [2005, 7897, 120, 60],
            [2005, 7898, 111, 56],
            [2005, 7899, 120, 90],
            [2005, 7900, 120, 89],
            [2005, 7901, 111, 29],
            [2005, 7902, 120, 85],
            [2005, 7903, 120, 90],
            [2005, 7904, 111, 31],
            [2005, 7905, 120, 69],
            [2005, 7906, 120, 90],
            [2005, 7907, 120, 42],
            [2005, 7908, 120, 40],
            [2005, 7909, 111, 48],
            [2005, 7910, 114, 56],
            [2005, 7911, 120, 29],
            [2005, 7912, 120, 90],
            [2005, 7913, 120, 58],
            [2005, 7914, 111, 65],
            [2005, 7915, 54, 40],
            [2005, 7916, 120, 42],
            [2005, 7917, 59, 43],
            [2005, 7918, 70, 30],
            [2005, 7919, 111, 32],
            [2005, 7920, 87, 43],
            [2005, 7921, 59, 31],
            [2005, 7922, 111, 35],
            [2005, 7923, 120, 31],
            [2005, 7924, 41, 31],
            [2005, 7925, 41, 31],
            [2005, 7926, 52, 42],
            [2005, 7927, 120, 52],
            [2005, 7928, 111, 51],
            [2005, 7929, 120, 90],
            [2005, 7930, 120, 52],
            [2005, 7931, 58, 32],
            [2005, 7932, 42, 32],
            [2005, 7933, 103, 67],
            [2005, 7934, 120, 90],
            [2005, 7935, 120, 87],
            [2005, 7936, 120, 32],
            [2005, 7937, 72, 31],
            [2005, 7938, 40, 31],
            [2005, 7939, 120, 90],
            [2005, 7940, 120, 83],
            [2005, 7941, 120, 90],
            [2005, 7942, 120, 90],
            [2005, 7943, 43, 33],
            [2005, 7944, 111, 40],
            [2005, 7945, 120, 49],
            [2005, 7946, 114, 87],
            [2005, 7947, 95, 40],
            [2005, 7948, 111, 30],
            [2005, 7949, 120, 90],
            [2005, 7950, 66, 49],
            [2005, 7951, 120, 65],
            [2005, 7952, 115, 87],
            [2005, 7953, 33, 30],
            [2005, 7954, 103, 32],
            [2005, 7955, 120, 58],
            [2005, 7956, 120, 90],
            [2005, 7957, 49, 41],
            [2005, 7958, 120, 49],
            [2005, 7959, 120, 63],
            [2005, 7960, 103, 32],
            [2005, 7961, 120, 90],
            [2005, 7962, 120, 90],
            [2005, 7963, 32, 27],
            [2005, 7964, 120, 90],
            [2005, 7965, 120, 38],
            [2005, 7966, 120, 90],
            [2005, 7967, 120, 31],
            [2005, 7968, 120, 90],
            [2005, 7969, 120, 90],
            [2005, 7970, 120, 81],
            [2005, 7971, 32, 29],
            [2005, 7972, 70, 30],
            [2005, 7974, 33, 30],
            [2005, 7975, 120, 90],
            [2005, 7976, 120, 43],
            [2005, 7977, 120, 90],
            [2005, 7978, 120, 40],
            [2005, 7979, 117, 71],
            [2005, 7980, 120, 78],
            [2005, 7981, 120, 41],
            [2005, 7982, 80, 33],
            [2005, 7983, 111, 31],
            [2005, 7984, 120, 42],
            [2005, 7985, 87, 57],
            [2005, 7986, 41, 31],
            [2005, 7987, 99, 35],
            [2005, 7988, 54, 39],
            [2005, 7989, 120, 94],
            [2005, 7990, 80, 28],
            [2005, 7992, 111, 73],
            [2005, 7993, 120, 90],
            [2005, 7994, 111, 50],
            [2005, 7995, 120, 90],
            [2005, 7996, 120, 34],
            [2005, 7997, 120, 90],
            [2005, 7998, 103, 32],
            [2005, 7999, 120, 90],
            [2005, 8000, 111, 29],
            [2005, 8001, 120, 90],
            [2005, 8002, 120, 90],
            [2005, 8003, 111, 29],
            [2005, 8004, 120, 90],
            [2005, 8005, 21, 21],
            [2005, 8006, 13, 16],
            [2005, 8007, 24, 27],
            [2005, 8008, 22, 23],
            [2005, 8009, 15, 15],
            [2005, 8010, 13, 15],
            [2005, 8011, 21, 21],
            [2005, 8012, 12, 13],
            [2005, 8013, 7, 6],
            [2005, 8014, 9, 9],
            [2005, 8015, 10, 8],
            [2005, 8016, 6, 5],
            [2005, 8017, 11, 11],
            [2005, 8018, 7, 6],
            [2005, 8019, 14, 14],
            [2005, 8020, 11, 11],
            [2005, 8021, 6, 5],
            [2005, 8022, 21, 24],
            [2005, 8023, 15, 15],
            [2005, 8024, 22, 18],
            [2005, 8025, 16, 19],
            [2005, 8026, 17, 18],
            [2005, 8027, 14, 11],
            [2005, 8028, 13, 13],
            [2005, 8029, 20, 18],
            [2005, 8030, 21, 16],
            [2005, 8031, 12, 11],
            [2005, 8032, 18, 23],
            [2005, 8033, 17, 17],
            [2005, 8034, 21, 25],
            [2005, 8035, 19, 25],
            [2005, 8036, 16, 17],
            [2005, 8037, 22, 23],
            [2005, 8038, 29, 28],
            [2005, 8039, 28, 49],
            [2005, 8040, 20, 49],
            [2005, 8041, 7, 13],
            [2005, 8042, 7, 9],
            [2005, 8043, 10, 14],
            [2005, 8044, 10, 15],
            [2005, 8045, 5, 3],
            [2005, 8046, 5, 3],
            [2005, 8047, 5, 5],
            [2005, 8048, 14, 19],
            [2005, 8049, 11, 15],
            [2005, 8050, 9, 10],
            [2005, 8051, 19, 20],
            [2005, 8052, 31, 42],
            [2005, 8053, 21, 35],
            [2005, 8054, 17, 29],
            [2005, 8055, 29, 42],
            [2005, 8056, 41, 45],
            [2005, 8057, 19, 29],
            [2005, 8058, 17, 24],
            [2005, 8059, 23, 25],
            [2005, 8060, 25, 29],
            [2005, 8061, 50, 55],
            [2005, 8062, 52, 68],
            [2005, 8063, 10, 9],
            [2005, 8064, 13, 17],
            [2005, 8065, 13, 11],
            [2005, 8068, 11, 10],
            [2005, 8069, 13, 21],
            [2005, 8071, 34, 20],
            [2005, 8073, 43, 23],
            [2005, 8074, 12, 12],
            [2005, 8075, 22, 14],
            [2005, 8076, 46, 31],
            [2005, 8086, 14, 36],
            [2005, 8087, 15, 27],
            [2005, 8088, 17, 32],
            [2005, 8089, 20, 38],
            [2005, 8090, 19, 28],
            [2005, 8091, 21, 50],
            [2005, 8092, 18, 39],
            [2005, 8093, 21, 49],
            [2005, 8094, 14, 49],
            [2005, 8095, 20, 25],
            [2005, 8096, 21, 32],
            [2005, 8097, 20, 28],
            [2005, 8098, 11, 30],
            [2005, 8099, 29, 29],
            [2005, 8100, 28, 27],
            [2005, 8101, 29, 29],
            [2005, 8102, 23, 25],
            [2005, 8103, 29, 29],
            [2005, 8104, 28, 28],
            [2005, 8105, 43, 36],
            [2005, 8106, 32, 32],
            [2005, 8107, 24, 27],
            [2005, 8108, 42, 39],
            [2005, 8109, 31, 30],
            [2005, 8110, 23, 26],
            [2005, 8111, 39, 36],
            [2005, 8112, 28, 28],
            [2005, 8113, 43, 36],
            [2005, 8114, 23, 26],
            [2005, 8115, 55, 63],
            [2005, 8116, 32, 31],
            [2005, 8117, 43, 55],
            [2005, 8118, 24, 28],
            [2005, 8119, 30, 29],
            [2005, 8120, 40, 37],
            [2005, 8121, 24, 26],
            [2005, 8122, 29, 29],
            [2005, 8123, 44, 37],
            [2005, 8124, 30, 31],
            [2005, 8125, 44, 37],
            [2005, 8126, 24, 25],
            [2005, 8127, 31, 32],
            [2005, 8128, 67, 63],
            [2005, 8129, 29, 29],
            [2005, 8130, 44, 37],
            [2005, 8131, 22, 25],
            [2005, 8132, 42, 39],
            [2005, 8133, 24, 27],
            [2005, 8134, 44, 41],
            [2005, 8135, 44, 36],
            [2005, 8136, 19, 22],
            [2005, 8137, 29, 30],
            [2005, 8138, 32, 32],
            [2005, 8139, 51, 55],
            [2005, 8140, 32, 37],
            [2005, 8141, 28, 27],
            [2005, 8142, 29, 29],
            [2005, 8143, 53, 60],
            [2005, 8144, 24, 27],
            [2005, 8145, 23, 25],
            [2005, 8146, 40, 43],
            [2005, 8147, 28, 27],
            [2005, 8148, 31, 30],
            [2005, 8149, 25, 28],
            [2005, 8150, 58, 68],
            [2005, 8151, 22, 25],
            [2005, 8152, 49, 56],
            [2005, 8153, 29, 30],
            [2005, 8154, 28, 27],
            [2005, 8155, 38, 32],
            [2005, 8156, 61, 73],
            [2005, 8157, 32, 31],
            [2005, 8158, 29, 29],
            [2005, 8159, 25, 26],
            [2005, 8160, 29, 28],
            [2005, 8161, 44, 37],
            [2005, 8162, 46, 38],
            [2005, 8163, 44, 34],
            [2005, 8164, 27, 28],
            [2005, 8165, 31, 31],
            [2005, 8166, 61, 47],
            [2005, 8167, 44, 37],
            [2005, 8168, 29, 30],
            [2005, 8169, 43, 35],
            [2005, 8170, 30, 30],
            [2005, 8171, 29, 30],
            [2005, 8172, 62, 46],
            [2005, 8173, 29, 29],
            [2005, 8174, 30, 29],
            [2005, 8175, 24, 26],
            [2005, 8176, 23, 26],
            [2005, 8177, 25, 29],
            [2005, 8178, 31, 32],
            [2005, 8179, 40, 36],
            [2005, 8180, 28, 28],
            [2005, 8181, 59, 46],
            [2005, 8182, 44, 37],
            [2005, 8183, 32, 32],
            [2005, 8184, 28, 27],
            [2005, 8185, 28, 28],
            [2005, 8186, 31, 31],
            [2005, 8187, 25, 28],
            [2005, 8188, 18, 21],
            [2005, 8189, 41, 38],
            [2005, 8190, 23, 25],
            [2005, 8191, 42, 42],
            [2005, 8192, 32, 31],
            [2005, 8193, 59, 44],
            [2005, 8194, 28, 27],
            [2005, 8195, 29, 29],
            [2005, 8196, 25, 28],
            [2005, 8197, 32, 32],
            [2005, 8198, 25, 28],
            [2005, 8199, 49, 53],
            [2005, 8200, 23, 27],
            [2005, 8201, 63, 48],
            [2005, 8202, 38, 37],
            [2005, 8203, 54, 36],
            [2005, 8204, 43, 36],
            [2005, 8205, 20, 23],
            [2005, 8206, 48, 46],
            [2005, 8207, 29, 28],
            [2005, 8208, 23, 26],
            [2005, 8209, 62, 48],
            [2005, 8210, 31, 31],
            [2005, 8211, 53, 60],
            [2005, 8212, 23, 25],
            [2005, 8213, 31, 30],
            [2005, 8214, 50, 55],
            [2005, 8215, 30, 29],
            [2005, 8216, 29, 29],
            [2005, 8217, 31, 31],
            [2005, 8218, 16, 21],
            [2005, 8219, 47, 45],
            [2005, 8220, 22, 25],
            [2005, 8221, 41, 38],
            [2005, 8222, 20, 24],
            [2005, 8223, 23, 26],
            [2005, 8224, 39, 41],
            [2005, 8225, 31, 36],
            [2005, 8226, 52, 58],
            [2005, 8227, 29, 29],
            [2005, 8228, 20, 23],
            [2005, 8229, 28, 27],
            [2005, 8230, 31, 30],
            [2005, 8231, 19, 22],
            [2005, 8232, 50, 48],
            [2005, 8233, 29, 29],
            [2005, 8234, 21, 23],
            [2005, 8235, 49, 54],
            [2005, 8236, 23, 26],
            [2005, 8237, 47, 44],
            [2005, 8238, 28, 28],
            [2005, 8239, 69, 53],
            [2005, 8240, 30, 29],
            [2005, 8241, 25, 28],
            [2005, 8242, 44, 41],
            [2005, 8245, 31, 30],
            [2005, 8246, 32, 32],
            [2005, 8247, 44, 36],
            [2005, 8248, 20, 23],
            [2005, 8249, 42, 39],
            [2005, 8250, 27, 28],
            [2005, 8251, 30, 29],
            [2005, 8252, 40, 37],
            [2005, 8253, 42, 34],
            [2005, 8254, 33, 37],
            [2005, 8255, 28, 28],
            [2005, 8256, 25, 27],
            [2005, 8257, 49, 55],
            [2005, 8258, 29, 28],
            [2005, 8259, 28, 28],
            [2005, 8260, 31, 32],
            [2005, 8261, 48, 52],
            [2005, 8262, 46, 47],
            [2005, 8263, 54, 41],
            [2005, 8264, 27, 31],
            [2005, 8265, 46, 61],
            [2005, 8267, 42, 35],
            [2005, 8268, 30, 29],
            [2005, 8269, 29, 29],
            [2005, 8270, 18, 22],
            [2005, 8271, 24, 28],
            [2005, 8272, 41, 37],
            [2005, 8273, 29, 29],
            [2005, 8274, 28, 28],
            [2005, 8275, 26, 29],
            [2005, 8276, 28, 28],
            [2005, 8277, 29, 22],
            [2005, 8278, 44, 37],
            [2005, 8279, 29, 29],
            [2005, 8280, 32, 32],
            [2005, 8281, 29, 28],
            [2005, 8282, 32, 32],
            [2005, 8283, 31, 30],
            [2005, 8284, 30, 29],
            [2005, 8285, 32, 32],
            [2005, 8286, 32, 32],
            [2005, 8287, 31, 31],
            [2005, 8288, 24, 28],
            [2005, 8289, 42, 39],
            [2005, 8290, 32, 32],
            [2005, 8291, 32, 32],
            [2005, 8292, 31, 30],
            [2005, 8293, 28, 28],
            [2005, 8294, 29, 28],
            [2005, 8295, 44, 36],
            [2005, 8296, 43, 31],
            [2005, 8297, 30, 30],
            [2005, 8298, 29, 41],
            [2005, 8299, 19, 22],
            [2005, 8300, 62, 47],
            [2005, 8301, 31, 31],
            [2005, 8302, 29, 28],
            [2005, 8303, 44, 37],
            [2005, 8304, 28, 28],
            [2005, 8305, 41, 34],
            [2005, 8306, 25, 28],
            [2005, 8307, 18, 21],
            [2005, 8308, 29, 28],
            [2005, 8309, 15, 19],
            [2005, 8310, 42, 38],
            [2005, 8311, 13, 13],
            [2005, 8312, 12, 12],
            [2005, 8313, 12, 11],
            [2005, 8314, 12, 12],
            [2005, 8315, 12, 12],
            [2005, 8316, 11, 11],
            [2005, 8317, 35, 35],
            [2005, 8318, 51, 39],
            [2005, 8319, 18, 18],
            [2005, 8320, 44, 37],
            [2005, 8321, 32, 26],
            [2005, 8322, 31, 31],
            [2005, 8323, 25, 28],
            [2005, 8324, 56, 41],
            [2005, 8325, 49, 40],
            [2005, 8326, 43, 36],
            [2005, 8327, 41, 34],
            [2005, 8328, 46, 38],
            [2005, 8329, 29, 28],
            [2005, 8330, 46, 38],
            [2005, 8331, 41, 34],
            [2005, 8332, 44, 36],
            [2005, 8336, 20, 16],
            [2005, 8337, 12, 14],
            [2005, 8338, 12, 12],
            [2005, 8339, 32, 35],
            [2005, 8340, 15, 17],
            [2005, 8341, 23, 25],
            [2005, 8342, 15, 15],
            [2005, 8343, 15, 14],
            [2005, 8344, 15, 14],
            [2005, 8345, 21, 22],
            [2005, 8346, 18, 21],
            [2005, 8347, 15, 17],
            [2005, 8348, 21, 21],
            [2005, 8349, 22, 18],
            [2005, 8350, 18, 22],
            [2005, 8351, 14, 11],
            [2005, 8352, 22, 27],
            [2005, 8353, 11, 12],
            [2005, 8354, 24, 27],
            [2005, 8355, 14, 14],
            [2005, 8356, 26, 25],
            [2005, 8357, 21, 14],
            [2005, 8358, 22, 18],
            [2005, 8359, 31, 34],
            [2005, 8360, 27, 29],
            [2005, 8361, 13, 13],
            [2005, 8362, 22, 22],
            [2005, 8363, 28, 30],
            [2005, 8364, 24, 22],
            [2005, 8365, 23, 21],
            [2005, 8366, 22, 21],
            [2005, 8367, 18, 16],
            [2005, 8368, 17, 23],
            [2005, 8369, 18, 21],
            [2005, 8370, 22, 18],
            [2005, 8371, 19, 16],
            [2005, 8372, 20, 18],
            [2005, 8373, 23, 26],
            [2005, 8374, 18, 22],
            [2005, 8375, 16, 21],
            [2005, 8376, 23, 23],
            [2005, 8377, 21, 17],
            [2005, 8378, 22, 17],
            [2005, 8379, 22, 22],
            [2005, 8380, 27, 23],
            [2005, 8381, 21, 21],
            [2005, 8382, 16, 19],
            [2005, 8383, 23, 24],
            [2005, 8384, 21, 27],
            [2005, 8385, 18, 22],
            [2005, 8386, 15, 15],
            [2005, 8387, 22, 21],
            [2005, 8388, 22, 18],
            [2005, 8389, 16, 18],
            [2005, 8390, 13, 14],
            [2005, 8391, 21, 18],
            [2005, 8392, 21, 20],
            [2005, 8393, 27, 34],
            [2005, 8394, 23, 22],
            [2005, 8395, 18, 19],
            [2005, 8396, 47, 39],
            [2005, 8397, 55, 41],
            [2005, 8398, 40, 29],
            [2005, 8399, 51, 33],
            [2005, 8400, 43, 40],
            [2005, 8401, 51, 31],
            [2005, 8402, 41, 31],
            [2005, 8403, 45, 30],
            [2005, 8404, 39, 34],
            [2005, 8405, 45, 30],
            [2005, 8406, 40, 32],
            [2005, 8407, 47, 42],
            [2005, 8408, 38, 38],
            [2005, 8409, 34, 28],
            [2005, 8410, 40, 33],
            [2005, 8411, 74, 52],
            [2005, 8412, 42, 39],
            [2005, 8413, 50, 38],
            [2005, 8414, 57, 31],
            [2005, 8415, 61, 42],
            [2005, 8416, 31, 29],
            [2005, 8417, 50, 34],
            [2005, 8418, 26, 27],
            [2005, 8419, 52, 37],
            [2005, 8420, 44, 34],
            [2005, 8421, 53, 40],
            [2005, 8422, 33, 33],
            [2005, 8423, 50, 45],
            [2005, 8424, 52, 51],
            [2005, 8425, 39, 45],
            [2005, 8426, 35, 30],
            [2005, 8427, 38, 32],
            [2005, 8428, 41, 33],
            [2005, 8429, 33, 30],
            [2005, 8430, 50, 45],
            [2005, 8431, 51, 39],
            [2005, 8432, 51, 45],
            [2005, 8433, 48, 43],
            [2005, 8434, 52, 34],
            [2005, 8435, 70, 38],
            [2005, 8436, 55, 41],
            [2005, 8438, 36, 30],
            [2005, 8439, 39, 35],
            [2005, 8440, 58, 38],
            [2005, 8441, 54, 36],
            [2005, 8442, 37, 34],
            [2005, 8443, 47, 40],
            [2005, 8444, 50, 45],
            [2005, 8445, 27, 24],
            [2005, 8446, 35, 29],
            [2005, 8447, 46, 37],
            [2005, 8448, 38, 33],
            [2005, 8449, 56, 27],
            [2005, 8450, 52, 37],
            [2005, 8451, 21, 27],
            [2005, 8452, 27, 36],
            [2005, 8453, 20, 24],
            [2005, 8454, 22, 27],
            [2005, 8455, 23, 27],
            [2005, 8456, 23, 27],
            [2005, 8457, 50, 45],
            [2005, 8458, 38, 30],
            [2005, 8459, 47, 33],
            [2005, 8460, 41, 36],
            [2005, 8461, 53, 33],
            [2005, 8462, 52, 36],
            [2005, 8463, 50, 42],
            [2005, 8464, 55, 40],
            [2005, 8465, 34, 25],
            [2005, 8466, 32, 37],
            [2005, 8467, 36, 31],
            [2005, 8468, 42, 37],
            [2005, 8469, 39, 32],
            [2005, 8470, 55, 42],
            [2005, 8471, 35, 38],
            [2005, 8472, 54, 29],
            [2005, 8473, 45, 40],
            [2005, 8474, 38, 35],
            [2005, 8475, 48, 37],
            [2005, 8476, 49, 38],
            [2005, 8477, 49, 38],
            [2005, 8478, 30, 30],
            [2005, 8479, 39, 34],
            [2005, 8480, 54, 42],
            [2005, 8481, 46, 37],
            [2005, 8482, 42, 33],
            [2005, 8483, 41, 33],
            [2005, 8484, 47, 35],
            [2005, 8485, 50, 41],
            [2005, 8486, 33, 27],
            [2005, 8487, 46, 33],
            [2005, 8488, 36, 30],
            [2005, 8489, 33, 47],
            [2005, 8490, 47, 37],
            [2005, 8491, 39, 37],
            [2005, 8492, 41, 31],
            [2005, 8493, 47, 32],
            [2005, 8494, 33, 27],
            [2005, 8495, 51, 51],
            [2005, 8496, 26, 33],
            [2005, 8497, 44, 43],
            [2005, 8498, 32, 33],
            [2005, 8499, 40, 32],
            [2005, 8500, 51, 36],
            [2005, 8501, 50, 55],
            [2005, 8502, 53, 35],
            [2005, 8503, 51, 39],
            [2005, 8504, 40, 37],
            [2005, 8505, 52, 40],
            [2005, 8506, 55, 41],
            [2005, 8507, 54, 42],
            [2005, 8508, 34, 32],
            [2005, 8509, 38, 33],
            [2005, 8510, 53, 39],
            [2005, 8511, 46, 35],
            [2005, 8512, 50, 45],
            [2005, 8513, 44, 40],
            [2005, 8514, 49, 45],
            [2005, 8515, 41, 38],
            [2005, 8516, 90, 54],
            [2005, 8517, 52, 23],
            [2005, 8518, 58, 51],
            [2005, 8519, 38, 32],
            [2005, 8520, 41, 32],
            [2005, 8521, 37, 32],
            [2005, 8522, 39, 35],
            [2005, 8523, 38, 33],
            [2005, 8524, 36, 31],
            [2005, 8525, 47, 33],
            [2005, 8526, 49, 38],
            [2005, 8527, 47, 45],
            [2005, 8528, 48, 40],
            [2005, 8529, 58, 40],
            [2005, 8530, 35, 31],
            [2005, 8531, 56, 49],
            [2005, 8532, 48, 44],
            [2005, 8533, 55, 49],
            [2005, 8534, 41, 39],
            [2005, 8535, 54, 52],
            [2005, 8536, 18, 30],
            [2005, 8537, 38, 27],
            [2005, 8538, 38, 26],
            [2005, 8539, 35, 30],
            [2005, 8540, 28, 36],
            [2005, 8541, 35, 44],
            [2005, 8542, 29, 38],
            [2005, 8543, 19, 36],
            [2005, 8544, 27, 50],
            [2005, 8546, 25, 37],
            [2005, 8547, 30, 50],
            [2005, 8548, 15, 18],
            [2005, 8549, 23, 29],
            [2005, 8550, 20, 27],
            [2005, 8551, 32, 28],
            [2005, 8552, 29, 35],
            [2005, 8553, 40, 51],
            [2005, 8554, 21, 20],
            [2005, 8555, 34, 33],
            [2005, 8556, 38, 50],
            [2005, 8557, 50, 49],
            [2005, 8558, 27, 30],
            [2005, 8559, 34, 31],
            [2005, 8560, 28, 33],
            [2005, 8561, 23, 28],
            [2005, 8562, 32, 32],
            [2005, 8563, 39, 41],
            [2005, 8564, 67, 55],
            [2005, 8565, 10, 12],
            [2005, 8566, 22, 14],
            [2005, 8567, 21, 20],
            [2005, 8568, 15, 15],
            [2005, 8569, 19, 15],
            [2005, 8570, 10, 10],
            [2005, 8571, 14, 11],
            [2005, 8572, 12, 12],
            [2005, 8573, 13, 11],
            [2005, 8574, 15, 13],
            [2005, 8575, 10, 10],
            [2005, 8576, 29, 19],
            [2005, 8577, 14, 16],
            [2005, 8578, 23, 21],
            [2005, 8579, 14, 19],
            [2005, 8580, 18, 17],
            [2005, 8581, 14, 14],
            [2005, 8582, 17, 16],
            [2005, 8583, 20, 18],
            [2005, 8584, 15, 14],
            [2005, 8719, 24, 24],
            [2005, 8720, 25, 26],
            [2005, 8721, 26, 27],
            [2005, 8722, 24, 23],
            [2005, 8723, 26, 24],
            [2005, 8724, 24, 24],
            [2005, 8725, 26, 21],
            [2005, 8726, 25, 23],
            [2005, 8727, 22, 22],
            [2005, 8728, 19, 21],
            [2005, 8729, 23, 21],
            [2005, 8730, 21, 20],
            [2005, 8731, 21, 20],
            [2005, 8732, 25, 22],
            [2005, 8733, 26, 22],
            [2005, 8734, 26, 22],
            [2005, 8735, 21, 22],
            [2005, 8736, 21, 21],
            [2005, 8737, 20, 20],
            [2005, 8738, 21, 21],
            [2005, 8739, 21, 21],
            [2005, 8740, 21, 21],
            [2005, 8741, 24, 21],
            [2005, 8742, 23, 21],
            [2005, 8743, 22, 22],
            [2005, 8744, 23, 22],
            [2005, 8745, 24, 22],
            [2005, 8746, 27, 24],
            [2005, 8747, 27, 23],
            [2005, 8748, 28, 23],
            [2005, 8749, 23, 22],
            [2005, 8750, 22, 23],
            [2005, 8751, 22, 24],
            [2005, 8752, 21, 21],
            [2005, 8753, 19, 20],
            [2005, 8754, 21, 21],
            [2005, 8755, 20, 21],
            [2005, 8756, 27, 22],
            [2005, 8757, 19, 20],
            [2005, 8758, 21, 21],
            [2005, 8759, 22, 21],
            [2005, 8760, 29, 30],
            [2005, 8761, 22, 21],
            [2005, 8762, 27, 22],
            [2005, 8763, 19, 19],
            [2005, 8764, 29, 23],
            [2005, 8765, 25, 21],
            [2005, 8766, 26, 22],
            [2005, 8767, 28, 24],
            [2005, 8768, 28, 23],
            [2005, 8769, 27, 23],
            [2005, 8770, 28, 24],
            [2005, 8771, 28, 25],
            [2005, 8772, 29, 24],
            [2005, 8773, 21, 20],
            [2005, 8774, 21, 21],
            [2005, 8775, 21, 21],
            [2005, 8776, 21, 21],
            [2005, 8777, 22, 22],
            [2005, 8778, 29, 24],
            [2005, 8779, 10, 11],
            [2005, 8780, 12, 9],
            [2005, 8781, 16, 13],
            [2005, 8782, 14, 10],
            [2005, 8783, 10, 8],
            [2005, 8784, 12, 9],
            [2005, 8785, 7, 7],
            [2005, 8786, 9, 10],
            [2005, 8787, 11, 10],
            [2005, 8788, 12, 10],
            [2005, 8790, 10, 8],
            [2005, 8791, 6, 6],
            [2005, 8792, 12, 10],
            [2005, 8793, 8, 8],
            [2005, 8794, 8, 7],
            [2005, 8795, 9, 7],
            [2005, 8796, 13, 9],
            [2005, 8797, 15, 9],
            [2005, 8798, 9, 8],
            [2005, 8799, 15, 13],
            [2005, 8800, 10, 8],
            [2005, 8801, 10, 9],
            [2005, 8802, 8, 7],
            [2005, 8803, 8, 8],
            [2005, 8804, 7, 8],
            [2005, 8805, 9, 8],
            [2005, 8806, 9, 10],
            [2005, 8807, 12, 12],
            [2005, 8808, 9, 8],
            [2005, 8809, 6, 8],
            [2005, 8810, 10, 10],
            [2005, 8811, 7, 9],
            [2005, 8812, 11, 9],
            [2005, 8814, 6, 7],
            [2005, 8815, 9, 9],
            [2005, 8816, 12, 7],
            [2005, 8817, 16, 10],
            [2005, 8818, 40, 33],
            [2005, 8819, 35, 32],
            [2005, 8820, 47, 38],
            [2005, 8821, 39, 27],
            [2005, 8822, 45, 37],
            [2005, 8823, 31, 25],
            [2005, 8824, 22, 18],
            [2005, 8825, 34, 28],
            [2005, 8826, 22, 21],
            [2005, 8827, 37, 28],
            [2005, 8828, 37, 28],
            [2005, 8829, 40, 32],
            [2005, 8830, 27, 28],
            [2005, 8831, 33, 25],
            [2005, 8832, 19, 11],
            [2005, 8833, 30, 24],
            [2005, 8834, 35, 30],
            [2005, 8835, 28, 19],
            [2005, 8836, 43, 35],
            [2005, 8837, 30, 21],
            [2005, 8838, 38, 31],
            [2005, 8839, 24, 13],
            [2005, 8840, 34, 24],
            [2005, 8841, 23, 13],
            [2005, 8842, 15, 18],
            [2005, 8843, 19, 12],
            [2005, 8844, 27, 22],
            [2005, 8845, 14, 17],
            [2005, 8846, 33, 26],
            [2005, 8847, 18, 19],
            [2005, 8848, 41, 33],
            [2005, 8849, 27, 21],
            [2005, 8850, 36, 30],
            [2005, 8851, 22, 22],
            [2005, 8852, 32, 25],
            [2005, 8853, 14, 17],
            [2005, 8854, 32, 27],
            [2005, 8855, 20, 14],
            [2005, 8856, 30, 25],
            [2005, 8857, 23, 13],
            [2005, 8858, 27, 14],
            [2005, 8859, 40, 34],
            [2005, 8860, 27, 12],
            [2005, 8861, 33, 28],
            [2005, 8862, 24, 21],
            [2005, 8863, 36, 31],
            [2005, 8864, 21, 21],
            [2005, 8865, 31, 25],
            [2005, 8866, 22, 21],
            [2005, 8867, 43, 36],
            [2005, 8868, 37, 31],
            [2005, 8869, 45, 37],
            [2005, 8870, 43, 34],
            [2005, 8871, 32, 27],
            [2005, 8872, 35, 30],
            [2005, 8873, 26, 22],
            [2005, 8874, 30, 25],
            [2005, 8875, 33, 28],
            [2005, 8876, 18, 18],
            [2005, 8877, 40, 31],
            [2005, 8878, 26, 23],
            [2005, 8879, 18, 11],
            [2005, 8880, 30, 25],
            [2005, 8881, 45, 37],
            [2005, 8882, 28, 24],
            [2005, 8883, 45, 35],
            [2005, 8884, 17, 15],
            [2005, 8885, 48, 34],
            [2005, 8886, 33, 25],
            [2005, 8887, 19, 11],
            [2005, 8888, 37, 32],
            [2005, 8889, 43, 34],
            [2005, 8890, 13, 16],
            [2005, 8891, 32, 28],
            [2005, 8892, 14, 11],
            [2005, 8893, 33, 29],
            [2005, 8894, 19, 18],
            [2005, 8895, 15, 11],
            [2005, 8896, 24, 20],
            [2005, 8897, 15, 10],
            [2005, 8898, 19, 18],
            [2005, 8899, 43, 37],
            [2005, 8900, 33, 28],
            [2005, 8901, 38, 29],
            [2005, 8902, 31, 26],
            [2005, 8903, 25, 21],
            [2005, 8904, 33, 28],
            [2005, 8905, 23, 19],
            [2005, 8906, 30, 24],
            [2005, 8907, 19, 19],
            [2005, 8908, 28, 24],
            [2005, 8909, 21, 18],
            [2005, 8910, 21, 12],
            [2005, 8911, 23, 13],
            [2005, 8912, 40, 35],
            [2005, 8913, 26, 23],
            [2005, 8914, 39, 31],
            [2005, 8915, 27, 23],
            [2005, 8916, 41, 33],
            [2005, 8917, 32, 22],
            [2005, 8918, 42, 34],
            [2005, 8919, 30, 26],
            [2005, 8920, 32, 27],
            [2005, 8921, 33, 30],
            [2005, 8922, 30, 24],
            [2005, 8923, 24, 20],
            [2005, 8924, 14, 13],
            [2005, 8925, 11, 10],
            [2005, 8926, 14, 12],
            [2005, 8927, 15, 15],
            [2005, 8928, 13, 12],
            [2005, 8929, 10, 10],
            [2005, 8930, 9, 10],
            [2005, 8931, 13, 14],
            [2005, 8932, 16, 18],
            [2005, 8933, 23, 23],
            [2005, 8934, 26, 24],
            [2005, 8935, 38, 32],
            [2005, 8936, 25, 19],
            [2005, 8937, 33, 28],
            [2005, 8938, 24, 19],
            [2005, 8939, 31, 24],
            [2005, 8940, 18, 16],
            [2005, 8941, 30, 24],
            [2005, 8942, 18, 16],
            [2005, 8943, 26, 19],
            [2005, 8944, 31, 25],
            [2005, 8945, 22, 19],
            [2005, 8946, 31, 25],
            [2005, 8947, 22, 18],
            [2005, 8948, 30, 25],
            [2005, 8949, 25, 20],
            [2005, 8950, 22, 19],
            [2005, 8951, 29, 25],
            [2005, 8952, 23, 19],
            [2005, 8953, 35, 29],
            [2005, 8954, 24, 17],
            [2005, 8955, 39, 33],
            [2005, 8956, 26, 23],
            [2005, 8957, 26, 18],
            [2005, 8958, 45, 37],
            [2005, 8959, 27, 19],
            [2005, 8960, 43, 35],
            [2005, 8961, 27, 19],
            [2005, 8962, 37, 33],
            [2005, 8963, 30, 26],
            [2005, 8964, 19, 12],
            [2005, 8965, 40, 33],
            [2005, 8966, 36, 28],
            [2005, 8967, 39, 30],
            [2005, 8968, 30, 25],
            [2005, 8969, 18, 13],
            [2005, 8970, 40, 33],
            [2005, 8971, 32, 28],
            [2005, 8972, 17, 13],
            [2005, 8973, 38, 30],
            [2005, 8974, 13, 18],
            [2005, 8975, 43, 35],
            [2005, 8976, 45, 37],
            [2005, 8977, 26, 21],
            [2005, 8978, 14, 11],
            [2005, 8979, 37, 32],
            [2005, 8980, 30, 25],
            [2005, 8981, 29, 23],
            [2005, 8983, 34, 28],
            [2005, 8984, 28, 20],
            [2005, 8985, 33, 28],
            [2005, 8986, 25, 20],
            [2005, 8987, 27, 25],
            [2005, 8988, 18, 26],
            [2005, 8989, 34, 28],
            [2005, 8990, 23, 20],
            [2005, 8991, 32, 27],
            [2005, 8992, 18, 18],
            [2005, 8993, 33, 30],
            [2005, 8994, 40, 33],
            [2005, 8995, 35, 27],
            [2005, 8996, 43, 34],
            [2005, 8997, 22, 21],
            [2005, 8998, 27, 20],
            [2005, 8999, 19, 11],
            [2005, 9000, 45, 37],
            [2005, 9001, 40, 28],
            [2005, 9002, 38, 30],
            [2005, 9003, 23, 21],
            [2005, 9004, 43, 34],
            [2005, 9005, 20, 18],
            [2005, 9006, 34, 27],
            [2005, 9007, 27, 19],
            [2005, 9008, 37, 24],
            [2005, 9009, 32, 24],
            [2005, 9010, 25, 20],
            [2005, 9011, 19, 11],
            [2005, 9012, 27, 25],
            [2005, 9013, 20, 23],
            [2005, 9014, 36, 28],
            [2005, 9015, 19, 14],
            [2005, 9016, 19, 14],
            [2005, 9017, 39, 30],
            [2005, 9018, 26, 26],
            [2005, 9019, 30, 28],
            [2005, 9020, 18, 18],
            [2005, 9021, 34, 29],
            [2005, 9022, 30, 23],
            [2005, 9023, 31, 25],
            [2005, 9024, 36, 29],
            [2005, 9025, 30, 25],
            [2005, 9026, 33, 18],
            [2005, 9027, 27, 17],
            [2005, 9028, 38, 30],
            [2005, 9030, 39, 30],
            [2005, 9031, 32, 26],
            [2005, 9032, 41, 29],
            [2005, 9033, 30, 26],
            [2005, 9034, 44, 34],
            [2005, 9035, 38, 32],
            [2005, 9036, 36, 30],
            [2005, 9037, 16, 14],
            [2005, 9038, 27, 25],
            [2005, 9039, 15, 19],
            [2005, 9040, 34, 28],
            [2005, 9041, 23, 19],
            [2005, 9042, 38, 29],
            [2005, 9043, 33, 28],
            [2005, 9044, 23, 14],
            [2005, 9045, 33, 25],
            [2005, 9046, 27, 20],
            [2005, 9047, 33, 27],
            [2005, 9048, 30, 21],
            [2005, 9049, 49, 34],
            [2005, 9050, 28, 20],
            [2005, 9051, 40, 31],
            [2005, 9052, 43, 26],
            [2005, 9053, 31, 31],
            [2005, 9054, 35, 27],
            [2005, 9055, 43, 21],
            [2005, 9056, 45, 25],
            [2005, 9057, 40, 29],
            [2005, 9058, 25, 19],
            [2005, 9059, 45, 32],
            [2005, 9060, 40, 28],
            [2005, 9061, 57, 45],
            [2005, 9062, 21, 21],
            [2005, 9063, 33, 24],
            [2005, 9064, 16, 18],
            [2005, 9065, 22, 21],
            [2005, 9066, 16, 17],
            [2005, 9067, 30, 22],
            [2005, 9068, 26, 18],
            [2005, 9069, 33, 35],
            [2005, 9070, 17, 17],
            [2005, 9071, 25, 30],
            [2005, 9072, 13, 16],
            [2005, 9073, 14, 16],
            [2005, 9074, 29, 27],
            [2005, 9075, 20, 22],
            [2005, 9076, 23, 25],
            [2005, 9077, 34, 22],
            [2005, 9078, 26, 16],
            [2005, 9079, 35, 30],
            [2005, 9080, 21, 18],
            [2005, 9081, 27, 22],
            [2005, 9082, 43, 30],
            [2005, 9083, 30, 24],
            [2005, 9084, 37, 27],
            [2005, 9085, 19, 19],
            [2005, 9086, 36, 28],
            [2005, 9087, 40, 27],
            [2005, 9088, 28, 17],
            [2005, 9089, 17, 14],
            [2005, 9090, 23, 18],
            [2005, 9091, 23, 15],
            [2005, 9092, 39, 25],
            [2005, 9093, 20, 19],
            [2005, 9094, 43, 36],
            [2005, 9095, 14, 12],
            [2005, 9096, 26, 30],
            [2005, 9097, 29, 21],
            [2005, 9098, 36, 23],
            [2005, 9099, 19, 13],
            [2005, 9100, 33, 22],
            [2005, 9101, 15, 17],
            [2005, 9102, 37, 28],
            [2005, 9103, 24, 23],
            [2005, 9104, 36, 28],
            [2005, 9105, 21, 14],
            [2005, 9106, 28, 15],
            [2005, 9107, 33, 25],
            [2005, 9108, 34, 25],
            [2005, 9109, 33, 26],
            [2005, 9110, 36, 28],
            [2005, 9111, 25, 13],
            [2005, 9112, 42, 34],
            [2005, 9113, 32, 27],
            [2005, 9114, 45, 25],
            [2005, 9115, 14, 14],
            [2005, 9116, 22, 15],
            [2005, 9117, 29, 12],
            [2005, 9118, 38, 28],
            [2005, 9119, 17, 12],
            [2005, 9120, 26, 21],
            [2005, 9121, 30, 25],
            [2005, 9122, 37, 31],
            [2005, 9123, 26, 18],
            [2005, 9124, 38, 30],
            [2005, 9125, 16, 23],
            [2005, 9126, 39, 33],
            [2005, 9127, 28, 25],
            [2005, 9128, 34, 28],
            [2005, 9129, 36, 30],
            [2005, 9130, 46, 36],
            [2005, 9131, 25, 25],
            [2005, 9132, 36, 32],
            [2005, 9133, 26, 18],
            [2005, 9134, 32, 26],
            [2005, 9135, 43, 30],
            [2005, 9136, 37, 28],
            [2005, 9137, 16, 11],
            [2005, 9138, 19, 15],
            [2005, 9139, 27, 24],
            [2005, 9140, 36, 32],
            [2005, 9141, 25, 23],
            [2005, 9142, 42, 37],
            [2005, 9143, 20, 20],
            [2005, 9144, 23, 26],
            [2005, 9145, 32, 26],
            [2005, 9146, 40, 32],
            [2005, 9149, 21, 16],
            [2005, 9150, 21, 21],
            [2005, 9151, 21, 21],
            [2005, 9152, 23, 23],
            [2005, 9153, 12, 14],
            [2005, 9154, 14, 14],
            [2005, 9155, 21, 21],
            [2005, 9156, 23, 23],
            [2005, 9157, 22, 24],
            [2005, 9158, 13, 14],
            [2005, 9159, 22, 23],
            [2005, 9160, 16, 14],
            [2005, 9161, 17, 18],
            [2005, 9162, 23, 23],
            [2005, 9163, 21, 21],
            [2005, 9164, 21, 17],
            [2005, 9165, 21, 23],
            [2005, 9166, 18, 19],
            [2005, 9167, 16, 16],
            [2005, 9168, 23, 23],
            [2005, 9169, 23, 22],
            [2005, 9170, 23, 26],
            [2005, 9171, 23, 22],
            [2005, 9172, 21, 18],
            [2005, 9173, 19, 22],
            [2005, 9174, 16, 17],
            [2005, 9175, 17, 16],
            [2005, 9176, 11, 14],
            [2005, 9177, 21, 17],
            [2005, 9178, 16, 20],
            [2005, 9179, 22, 23],
            [2005, 9180, 15, 15],
            [2005, 9181, 23, 22],
            [2005, 9182, 21, 21],
            [2005, 9183, 22, 23],
            [2005, 9184, 23, 22],
            [2005, 9185, 21, 19],
            [2005, 9186, 13, 15],
            [2005, 9187, 23, 22],
            [2005, 9188, 22, 21],
            [2005, 9189, 22, 22],
            [2005, 9190, 15, 15],
            [2005, 9191, 19, 18],
            [2005, 9192, 17, 19],
            [2005, 9193, 22, 23],
            [2005, 9194, 26, 28],
            [2005, 9195, 28, 31],
            [2005, 9196, 29, 22],
            [2005, 9198, 28, 22],
            [2005, 9199, 26, 22],
            [2005, 9200, 26, 22],
            [2005, 9201, 32, 28],
            [2005, 9202, 32, 30],
            [2005, 9203, 10, 12],
            [2005, 9204, 9, 10],
            [2005, 9209, 25, 23],
            [2005, 9211, 33, 32],
            [2005, 9214, 38, 35],
            [2005, 9218, 23, 20],
            [2005, 9226, 38, 27],
            [2005, 9227, 41, 34],
            [2005, 9228, 38, 41],
            [2005, 9229, 34, 35],
            [2005, 9230, 33, 28],
            [2005, 9232, 34, 30],
            [2005, 9233, 30, 32],
            [2005, 9234, 30, 32],
            [2005, 9235, 30, 32],
            [2005, 9237, 29, 20],
            [2005, 9238, 33, 33],
            [2005, 9242, 34, 33],
            [2005, 9244, 38, 35],
            [2005, 9245, 24, 26],
            [2005, 9248, 32, 26],
            [2005, 9254, 87, 85],
            [2005, 9255, 43, 31],
            [2005, 9257, 60, 52],
            [2005, 9258, 34, 45],
            [2005, 9259, 48, 48],
            [2005, 9260, 41, 34],
            [2005, 9261, 62, 74],
            [2005, 9263, 44, 47],
            [2005, 9264, 37, 39],
            [2005, 9265, 41, 44],
            [2005, 9266, 68, 73],
            [2005, 9267, 59, 57],
            [2005, 9268, 52, 51],
            [2005, 9269, 76, 76],
            [2005, 9270, 68, 73],
            [2005, 9271, 71, 77],
            [2005, 9272, 77, 85],
            [2005, 9273, 73, 80],
            [2005, 9274, 82, 75],
            [2005, 9275, 48, 46],
            [2005, 9276, 79, 73],
            [2005, 9277, 65, 54],
            [2005, 9278, 72, 75],
            [2005, 9279, 69, 63],
            [2005, 9280, 50, 49],
            [2005, 9281, 76, 64],
            [2005, 9282, 83, 74],
            [2005, 9283, 72, 72],
            [2005, 9284, 100, 105],
            [2005, 9285, 62, 67],
            [2005, 9286, 90, 98],
            [2005, 9287, 95, 95],
            [2005, 9288, 52, 41],
            [2005, 9289, 85, 93],
            [2005, 9290, 59, 66],
            [2005, 9291, 83, 83],
            [2005, 9292, 82, 81],
            [2005, 9293, 59, 42],
            [2005, 9294, 51, 50],
            [2005, 9295, 69, 63],
            [2005, 9296, 52, 39],
            [2005, 9297, 77, 53],
            [2005, 9298, 67, 76],
            [2005, 9299, 81, 86],
            [2005, 9300, 86, 88],
            [2005, 9301, 70, 77],
            [2005, 9302, 95, 96],
            [2005, 9303, 71, 81],
            [2005, 9304, 59, 73],
            [2005, 9305, 74, 86],
            [2005, 9306, 97, 111],
            [2005, 9307, 40, 53],
            [2005, 9308, 51, 64],
            [2005, 9309, 46, 55],
            [2005, 9310, 57, 60],
            [2005, 9311, 54, 61],
            [2005, 9312, 57, 60],
            [2005, 9313, 53, 59],
            [2005, 9314, 71, 80],
            [2005, 9315, 33, 32],
            [2005, 9316, 37, 25],
            [2005, 9317, 12, 14],
            [2005, 9318, 13, 15],
            [2005, 9319, 31, 35],
            [2005, 9320, 43, 40],
            [2005, 9327, 12, 14],
            [2005, 9328, 19, 21],
            [2005, 9329, 27, 29],
            [2005, 9330, 35, 36],
            [2005, 9331, 22, 23],
            [2005, 9332, 24, 27],
            [2005, 9333, 11, 14],
            [2005, 9334, 11, 13],
            [2005, 9335, 22, 23],
            [2005, 9336, 20, 21],
            [2005, 9337, 15, 17],
            [2005, 9338, 10, 13],
            [2005, 9339, 16, 18],
            [2005, 9340, 35, 35],
            [2005, 9341, 17, 22],
            [2005, 9342, 26, 26],
            [2005, 9343, 8, 9],
            [2005, 9344, 16, 16],
            [2005, 9345, 17, 20],
            [2005, 9346, 12, 13],
            [2005, 9347, 10, 12],
            [2005, 9348, 22, 21],
            [2005, 9349, 16, 19],
            [2005, 9350, 34, 37],
            [2005, 9351, 28, 25],
            [2005, 9352, 33, 33],
            [2005, 9353, 15, 19],
            [2005, 9354, 24, 27],
            [2005, 9355, 17, 15],
            [2005, 9356, 30, 28],
            [2005, 9357, 15, 18],
            [2005, 9358, 21, 23],
            [2005, 9359, 16, 22],
            [2005, 9360, 24, 27],
            [2005, 9361, 20, 18],
            [2005, 9362, 28, 27],
            [2005, 9363, 20, 21],
            [2005, 9364, 32, 24],
            [2005, 9365, 16, 20],
            [2005, 9366, 43, 44],
            [2005, 9367, 19, 21],
            [2005, 9368, 54, 54],
            [2005, 9369, 27, 31],
            [2005, 9370, 15, 16],
            [2005, 9371, 22, 25],
            [2005, 9372, 43, 30],
            [2005, 9373, 18, 18],
            [2005, 9374, 30, 29],
            [2005, 9375, 18, 21],
            [2005, 9376, 43, 41],
            [2005, 9377, 12, 13],
            [2005, 9378, 18, 21],
            [2005, 9379, 25, 30],
            [2005, 9380, 22, 25],
            [2005, 9381, 50, 45],
            [2005, 9382, 23, 28],
            [2005, 9383, 43, 30],
            [2005, 9384, 16, 16],
            [2005, 9385, 16, 17],
            [2005, 9386, 15, 16],
            [2005, 9387, 14, 14],
            [2005, 9388, 13, 14],
            [2005, 9389, 16, 15],
            [2005, 9390, 17, 19],
            [2005, 9391, 21, 23],
            [2005, 9392, 18, 19],
            [2005, 9393, 21, 20],
            [2005, 9394, 13, 14],
            [2005, 9395, 18, 18],
            [2005, 9396, 18, 22],
            [2005, 9397, 34, 35],
            [2005, 9398, 31, 36],
            [2005, 9399, 42, 43],
            [2005, 9400, 20, 23],
            [2005, 9401, 68, 64],
            [2005, 9402, 36, 27],
            [2005, 9403, 97, 72],
            [2005, 9406, 102, 78],
            [2005, 9411, 94, 69],
            [2005, 9416, 50, 60],
            [2005, 9417, 98, 73],
            [2005, 9420, 96, 71],
            [2005, 9423, 81, 65],
            [2005, 9428, 94, 72],
            [2005, 9431, 96, 71],
            [2005, 9436, 89, 71],
            [2005, 9443, 96, 72],
            [2005, 9444, 94, 69],
            [2005, 9451, 102, 73],
            [2005, 9452, 96, 76],
            [2005, 9453, 82, 63],
            [2005, 9456, 89, 71],
            [2005, 9457, 82, 81],
            [2005, 9458, 96, 72],
            [2005, 9465, 51, 44],
            [2005, 9470, 95, 70],
            [2005, 9473, 42, 54],
            [2005, 9474, 102, 83],
            [2005, 9477, 33, 39],
            [2005, 9478, 49, 53],
            [2005, 9487, 25, 36],
            [2005, 9488, 42, 53],
            [2005, 9491, 38, 48],
            [2005, 9492, 56, 55],
            [2005, 9497, 40, 27],
            [2005, 9498, 101, 43],
            [2005, 9509, 81, 78],
            [2005, 9519, 21, 25],
            [2005, 9520, 81, 53],
            [2005, 9525, 21, 20],
            [2005, 9526, 43, 43],
            [2005, 9529, 32, 30],
            [2005, 9530, 54, 51],
            [2005, 9531, 37, 40],
            [2005, 9532, 74, 73],
            [2005, 9539, 47, 41],
            [2005, 9540, 68, 73],
            [2005, 9541, 36, 34],
            [2005, 9542, 54, 47],
            [2005, 9543, 32, 37],
            [2005, 9544, 49, 49],
            [2005, 9547, 33, 38],
            [2005, 9548, 52, 52],
            [2005, 9549, 30, 30],
            [2005, 9550, 53, 44],
            [2005, 9551, 32, 39],
            [2005, 9552, 74, 73],
            [2005, 9553, 38, 38],
            [2005, 9554, 51, 51],
            [2005, 9555, 50, 65],
            [2005, 9556, 76, 83],
            [2005, 9557, 41, 40],
            [2005, 9558, 83, 73],
            [2005, 9561, 38, 47],
            [2005, 9562, 61, 79],
            [2005, 9581, 43, 46],
            [2005, 9582, 48, 54],
            [2005, 9593, 32, 39],
            [2005, 9594, 52, 75],
            [2005, 9595, 35, 40],
            [2005, 9596, 53, 56],
            [2005, 9597, 25, 24],
            [2005, 9598, 64, 68],
            [2005, 9609, 31, 31],
            [2005, 9610, 45, 45],
            [2005, 9611, 43, 39],
            [2005, 9612, 51, 48],
            [2005, 9613, 53, 65],
            [2005, 9614, 79, 83],
            [2005, 9617, 17, 15],
            [2005, 9618, 51, 45],
            [2005, 9619, 21, 20],
            [2005, 9620, 21, 20],
            [2005, 9633, 45, 48],
            [2005, 9634, 79, 72],
            [2005, 9639, 18, 22],
            [2005, 9640, 65, 53],
            [2005, 9641, 46, 34],
            [2005, 9642, 102, 65],
            [2005, 9643, 26, 36],
            [2005, 9644, 49, 54],
            [2005, 9651, 87, 58],
            [2005, 9652, 87, 58],
            [2005, 9653, 49, 44],
            [2005, 9654, 57, 35],
            [2005, 9661, 76, 45],
            [2005, 9662, 95, 42],
            [2005, 9663, 68, 44],
            [2005, 9664, 68, 44],
            [2005, 9665, 43, 36],
            [2005, 9666, 52, 36],
            [2005, 9667, 21, 18],
            [2005, 9668, 35, 30],
            [2005, 9670, 87, 49],
            [2005, 9673, 37, 24],
            [2005, 9674, 45, 24],
            [2005, 9675, 30, 32],
            [2005, 9676, 51, 41],
            [2005, 9677, 20, 21],
            [2005, 9678, 35, 25],
            [2005, 9681, 45, 35],
            [2005, 9682, 56, 35],
            [2005, 9687, 18, 25],
            [2005, 9689, 23, 21],
            [2005, 9690, 39, 32],
            [2005, 9691, 49, 33],
            [2005, 9692, 39, 31],
            [2005, 9693, 37, 31],
            [2005, 9694, 40, 34],
            [2005, 9695, 36, 35],
            [2005, 9696, 42, 33],
            [2005, 9699, 27, 30],
            [2005, 9700, 75, 42],
            [2005, 9701, 29, 25],
            [2005, 9702, 84, 40],
            [2005, 9704, 77, 39],
            [2005, 9705, 34, 39],
            [2005, 9706, 83, 51],
            [2005, 9709, 21, 17],
            [2005, 9710, 25, 18],
            [2005, 9711, 25, 30],
            [2005, 9712, 25, 30],
            [2005, 9713, 31, 31],
            [2005, 9714, 35, 48],
            [2005, 9715, 64, 49],
            [2005, 9716, 25, 25],
            [2005, 9717, 35, 33],
            [2005, 9718, 30, 28],
            [2005, 9720, 50, 41],
            [2005, 9721, 62, 37],
            [2005, 9722, 38, 42],
            [2005, 9723, 53, 38],
            [2005, 9724, 62, 53],
            [2005, 9725, 70, 48],
            [2005, 9726, 24, 27],
            [2005, 9727, 46, 31],
            [2005, 9728, 25, 25],
            [2005, 9729, 21, 23],
            [2005, 9730, 41, 49],
            [2005, 9731, 66, 53],
            [2005, 9735, 44, 44],
            [2005, 9736, 49, 50],
            [2005, 9737, 33, 21],
            [2005, 9738, 37, 43],
            [2005, 9739, 46, 39],
            [2005, 9740, 87, 87],
            [2005, 9741, 83, 69],
            [2005, 9742, 51, 43],
            [2005, 9743, 33, 29],
            [2005, 9744, 80, 51],
            [2005, 9745, 40, 23],
            [2005, 9746, 44, 28],
            [2005, 9747, 39, 49],
            [2005, 9748, 39, 41],
            [2005, 9751, 38, 42],
            [2005, 9752, 38, 51],
            [2005, 9755, 35, 34],
            [2005, 9756, 35, 33],
            [2005, 9757, 20, 17],
            [2005, 9758, 25, 18],
            [2005, 9759, 15, 14],
            [2005, 9760, 38, 28],
            [2005, 9761, 45, 35],
            [2005, 9762, 36, 28],
            [2005, 9763, 25, 19],
            [2005, 9764, 35, 23],
            [2005, 9765, 39, 35],
            [2005, 9766, 32, 23],
            [2005, 9767, 50, 33],
            [2005, 9768, 33, 25],
            [2005, 9769, 20, 21],
            [2005, 9770, 43, 35],
            [2005, 9771, 49, 43],
            [2005, 9772, 43, 31],
            [2005, 9773, 42, 34],
            [2005, 9774, 30, 22],
            [2005, 9775, 29, 21],
            [2005, 9776, 45, 30],
            [2005, 9777, 38, 28],
            [2005, 9778, 42, 32],
            [2005, 9779, 36, 31],
            [2005, 9780, 42, 30],
            [2005, 9781, 45, 30],
            [2005, 9782, 60, 37],
            [2005, 9783, 61, 48],
            [2005, 9784, 30, 21],
            [2005, 9785, 27, 20],
            [2005, 9786, 19, 14],
            [2005, 9787, 37, 28],
            [2005, 9788, 50, 33],
            [2005, 9789, 34, 30],
            [2005, 9790, 40, 28],
            [2005, 9791, 81, 46],
            [2005, 9792, 46, 40],
            [2005, 9793, 16, 12],
            [2005, 9794, 15, 13],
            [2005, 9795, 13, 12],
            [2005, 9796, 18, 18],
            [2005, 9797, 15, 12],
            [2005, 9798, 14, 14],
            [2005, 9799, 45, 40],
            [2005, 9800, 22, 20],
            [2005, 9801, 18, 16],
            [2005, 9802, 18, 15],
            [2005, 9803, 10, 9],
            [2005, 9804, 17, 13],
            [2005, 9805, 33, 25],
            [2005, 9806, 22, 18],
            [2005, 9807, 27, 16],
            [2005, 9808, 94, 55],
            [2005, 9809, 57, 32],
            [2005, 9811, 46, 26],
            [2005, 9812, 56, 31],
            [2005, 9813, 70, 37],
            [2005, 9814, 23, 14],
            [2005, 9815, 45, 25],
            [2005, 9816, 55, 30],
            [2005, 9817, 30, 17],
            [2005, 9818, 61, 26],
            [2005, 9819, 70, 54],
            [2005, 9820, 96, 57],
            [2005, 9821, 46, 34],
            [2005, 9822, 23, 19],
            [2005, 9823, 32, 21],
            [2005, 9824, 37, 35],
            [2005, 9825, 18, 15],
            [2005, 9826, 47, 32],
            [2005, 9827, 49, 31],
            [2005, 9828, 42, 29],
            [2005, 9829, 39, 26],
            [2005, 9830, 35, 26],
            [2005, 9831, 39, 25],
            [2005, 9832, 44, 28],
            [2005, 9833, 31, 23],
            [2005, 9834, 80, 47],
            [2005, 9835, 32, 28],
            [2005, 9836, 65, 50],
            [2005, 9837, 33, 27],
            [2005, 9838, 65, 45],
            [2005, 9839, 17, 16],
            [2005, 9840, 78, 47],
            [2005, 9841, 74, 43],
            [2005, 9842, 32, 20],
            [2005, 9843, 29, 25],
            [2005, 9844, 35, 28],
            [2005, 9845, 34, 27],
            [2005, 9846, 28, 18],
            [2005, 9847, 14, 11],
            [2005, 9848, 28, 18],
            [2005, 9849, 30, 24],
            [2005, 9850, 25, 16],
            [2005, 9851, 24, 18],
            [2005, 9852, 21, 16],
            [2005, 9853, 25, 19],
            [2005, 9854, 15, 12],
            [2005, 9855, 42, 32],
            [2005, 9856, 17, 18],
            [2005, 9857, 15, 13],
            [2005, 9858, 41, 38],
            [2005, 9859, 57, 35],
            [2005, 9860, 70, 38],
            [2005, 9861, 54, 48],
            [2005, 9862, 31, 26],
            [2005, 9863, 42, 28],
            [2005, 9864, 61, 30],
            [2005, 9865, 38, 27],
            [2005, 9866, 55, 33],
            [2005, 9867, 20, 16],
            [2005, 9868, 44, 29],
            [2005, 9869, 44, 32],
            [2005, 9870, 42, 42],
            [2005, 9871, 44, 28],
            [2005, 9872, 29, 25],
            [2005, 9873, 49, 40],
            [2005, 9874, 42, 37],
            [2005, 9875, 29, 23],
            [2005, 9876, 27, 23],
            [2005, 9877, 38, 39],
            [2005, 9878, 39, 30],
            [2005, 9879, 38, 34],
            [2005, 9880, 40, 50],
            [2005, 9881, 65, 54],
            [2005, 9882, 55, 45],
            [2005, 9883, 33, 24],
            [2005, 9884, 33, 37],
            [2005, 9885, 41, 25],
            [2005, 9886, 40, 25],
            [2005, 9887, 37, 26],
            [2005, 9888, 47, 34],
            [2005, 9889, 44, 30],
            [2005, 9890, 40, 30],
            [2005, 9891, 31, 22],
            [2005, 9892, 34, 26],
            [2005, 9893, 35, 18],
            [2005, 9894, 45, 30],
            [2005, 9895, 27, 17],
            [2005, 9896, 11, 12],
            [2005, 9897, 36, 29],
            [2005, 9898, 35, 27],
            [2005, 9899, 25, 20],
            [2005, 9900, 55, 51],
            [2005, 9901, 46, 36],
            [2005, 9902, 80, 59],
            [2005, 9903, 60, 45],
            [2005, 9904, 56, 40],
            [2005, 9905, 56, 48],
            [2005, 9906, 40, 26],
            [2005, 9907, 30, 28],
            [2005, 9908, 58, 39],
            [2005, 9909, 16, 15],
            [2005, 9910, 52, 45],
            [2005, 9911, 69, 45],
            [2005, 9912, 51, 37],
            [2005, 9913, 23, 21],
            [2005, 9914, 32, 24],
            [2005, 9915, 30, 26],
            [2005, 9916, 41, 28],
            [2005, 9917, 37, 37],
            [2005, 9918, 75, 40],
            [2005, 9919, 55, 38],
            [2005, 9920, 88, 76],
            [2005, 9921, 28, 23],
            [2005, 9922, 26, 16],
            [2005, 9923, 32, 18],
            [2005, 9924, 43, 25],
            [2005, 9925, 52, 62],
            [2005, 9926, 60, 45],
            [2005, 9927, 33, 35],
            [2005, 9928, 54, 30],
            [2005, 9929, 56, 40],
            [2005, 9930, 39, 26],
            [2005, 9931, 67, 38],
            [2005, 9932, 90, 76],
            [2005, 9933, 51, 55],
            [2005, 9934, 47, 35],
            [2005, 9935, 40, 38],
            [2005, 9936, 37, 35],
            [2005, 9937, 30, 40],
            [2005, 9938, 17, 15],
            [2005, 9939, 48, 57],
            [2005, 9940, 38, 38],
            [2005, 9941, 38, 22],
            [2005, 9942, 22, 18],
            [2005, 9943, 60, 40],
            [2005, 9944, 47, 37],
            [2005, 9945, 70, 36],
            [2005, 9946, 45, 28],
            [2005, 9947, 50, 29],
            [2005, 9948, 120, 70],
            [2005, 9949, 75, 50],
            [2005, 9950, 50, 33],
            [2005, 9951, 36, 31],
            [2005, 9952, 49, 26],
            [2005, 9953, 24, 22],
            [2005, 9954, 120, 70],
            [2005, 9955, 22, 22],
            [2005, 9956, 42, 31],
            [2005, 9957, 77, 40],
            [2005, 9958, 35, 25],
            [2005, 9959, 99, 45],
            [2005, 9960, 50, 25],
            [2005, 9961, 42, 31],
            [2005, 9962, 31, 32],
            [2005, 9963, 80, 36],
            [2005, 9964, 44, 30],
            [2005, 9965, 35, 17],
            [2005, 9966, 65, 30],
            [2005, 9967, 81, 32],
            [2005, 9968, 39, 32],
            [2005, 9969, 28, 20],
            [2005, 9970, 60, 30],
            [2005, 9971, 35, 26],
            [2005, 9972, 92, 39],
            [2005, 9973, 50, 34],
            [2005, 9974, 36, 21],
            [2005, 9975, 99, 37],
            [2005, 9976, 70, 40],
            [2005, 9977, 35, 19],
            [2005, 9978, 59, 23],
            [2005, 9979, 80, 37],
            [2005, 9980, 53, 23],
            [2005, 9981, 30, 17],
            [2005, 9982, 17, 13],
            [2005, 9983, 60, 30],
            [2005, 9984, 38, 24],
            [2005, 9985, 39, 22],
            [2005, 9986, 41, 25],
            [2005, 9987, 45, 36],
            [2005, 9988, 70, 45],
            [2005, 9989, 35, 28],
            [2005, 9990, 36, 29],
            [2005, 9991, 40, 31],
            [2005, 9992, 42, 46],
            [2005, 9993, 33, 34],
            [2005, 9994, 27, 23],
            [2005, 9995, 39, 33],
            [2005, 9996, 34, 29],
            [2005, 9997, 17, 27],
            [2005, 9998, 18, 15],
            [2005, 9999, 28, 29],
            [2005, 10000, 25, 20],
            [2005, 10001, 19, 15],
            [2005, 10002, 17, 14],
            [2005, 10003, 52, 29],
            [2005, 10004, 36, 23],
            [2005, 10005, 22, 17],
            [2005, 10006, 33, 25],
            [2005, 10007, 32, 34],
            [2005, 10008, 47, 44],
            [2005, 10009, 43, 28],
            [2005, 10010, 48, 28],
            [2005, 10011, 41, 26],
            [2005, 10012, 49, 23],
            [2005, 10013, 30, 24],
            [2005, 10014, 36, 32],
            [2005, 10015, 29, 26],
            [2005, 10016, 33, 32],
            [2005, 10017, 39, 30],
            [2005, 10018, 38, 32],
            [2005, 10019, 38, 29],
            [2005, 10020, 47, 38],
            [2005, 10021, 53, 37],
            [2005, 10022, 53, 40],
            [2005, 10023, 49, 36],
            [2005, 10024, 72, 48],
            [2005, 10025, 63, 48],
            [2005, 10026, 57, 41],
            [2005, 10027, 48, 37],
            [2005, 10030, 47, 37],
            [2005, 10031, 72, 60],
            [2005, 10032, 63, 46],
            [2005, 10033, 40, 29],
            [2005, 10034, 48, 31],
            [2005, 10035, 66, 37],
            [2005, 10036, 72, 34],
            [2005, 10037, 67, 38],
            [2005, 10038, 29, 19],
            [2005, 10039, 20, 20],
            [2005, 10040, 27, 19],
            [2005, 10041, 27, 16],
            [2005, 10042, 50, 33],
            [2005, 10043, 51, 27],
            [2005, 10044, 58, 27],
            [2005, 10045, 34, 21],
            [2005, 10046, 47, 31],
            [2005, 10047, 44, 24],
            [2005, 10048, 41, 26],
            [2005, 10049, 31, 22],
            [2005, 10050, 40, 28],
            [2005, 10051, 50, 34],
            [2005, 10052, 50, 41],
            [2005, 10053, 53, 39],
            [2005, 10054, 46, 39],
            [2005, 10055, 51, 42],
            [2005, 10056, 45, 42],
            [2005, 10057, 53, 43],
            [2005, 10058, 30, 32],
            [2005, 10059, 55, 31],
            [2005, 10060, 45, 30],
            [2005, 10061, 51, 45],
            [2005, 10063, 20, 20],
            [2005, 10064, 34, 27],
            [2005, 10065, 31, 34],
            [2005, 10066, 35, 30],
            [2005, 10067, 48, 37],
            [2005, 10068, 58, 42],
            [2005, 10069, 49, 38],
            [2005, 10070, 38, 23],
            [2005, 10071, 46, 33],
            [2005, 10072, 51, 21],
            [2005, 10073, 49, 25],
            [2005, 10074, 47, 25],
            [2005, 10075, 53, 31],
            [2005, 10076, 52, 31],
            [2005, 10077, 48, 31],
            [2005, 10078, 61, 37],
            [2005, 10079, 38, 28],
            [2005, 10080, 37, 31],
            [2005, 10081, 57, 38],
            [2005, 10082, 38, 40],
            [2005, 10083, 37, 33],
            [2005, 10084, 39, 28],
            [2005, 10085, 38, 21],
            [2005, 10086, 41, 25],
            [2005, 10087, 38, 18],
            [2005, 10088, 50, 33],
            [2005, 10089, 51, 34],
            [2005, 10090, 40, 31],
            [2005, 10091, 51, 25],
            [2005, 10092, 52, 27],
            [2005, 10093, 37, 31],
            [2005, 10094, 64, 41],
            [2005, 10095, 57, 38],
            [2005, 10096, 47, 30],
            [2005, 10097, 42, 29],
            [2005, 10098, 47, 32],
            [2005, 10099, 59, 41],
            [2005, 10101, 58, 45],
            [2005, 10102, 49, 36],
            [2005, 10103, 51, 45],
            [2005, 10104, 19, 18],
            [2005, 10105, 28, 20],
            [2005, 10106, 28, 25],
            [2005, 10107, 49, 43],
            [2005, 10108, 54, 46],
            [2005, 10109, 100, 64],
            [2005, 10110, 46, 38],
            [2005, 10111, 63, 47],
            [2005, 10112, 63, 49],
            [2005, 10113, 92, 74],
            [2005, 10114, 56, 36],
            [2005, 10115, 37, 27],
            [2005, 10116, 41, 33],
            [2005, 10117, 40, 35],
            [2005, 10118, 43, 43],
            [2005, 10119, 24, 15],
            [2005, 10120, 29, 19],
            [2005, 10121, 56, 46],
            [2005, 10122, 55, 45],
            [2005, 10123, 72, 59],
            [2005, 10124, 61, 56],
            [2005, 10125, 57, 34],
            [2005, 10126, 51, 32],
            [2005, 10127, 50, 30],
            [2005, 10128, 51, 36],
            [2005, 10129, 77, 50],
            [2005, 10130, 72, 49],
            [2005, 10131, 39, 31],
            [2005, 10132, 40, 31],
            [2005, 10133, 51, 29],
            [2005, 10134, 80, 56],
            [2005, 10135, 78, 61],
            [2005, 10136, 45, 25],
            [2005, 10137, 56, 38],
            [2005, 10138, 46, 27],
            [2005, 10139, 47, 29],
            [2005, 10141, 43, 29],
            [2005, 10142, 47, 29],
            [2005, 10144, 57, 29],
            [2005, 10145, 39, 36],
            [2005, 10146, 43, 38],
            [2005, 10148, 40, 24],
            [2005, 10149, 42, 42],
            [2005, 10150, 25, 28],
            [2005, 10151, 41, 36],
            [2005, 10152, 52, 40],
            [2005, 10153, 58, 44],
            [2005, 10154, 22, 23],
            [2005, 10155, 50, 47],
            [2005, 10156, 33, 28],
            [2005, 10157, 53, 39],
            [2005, 10158, 31, 32],
            [2005, 10159, 42, 32],
            [2005, 10160, 44, 28],
            [2005, 10161, 60, 36],
            [2005, 10162, 48, 25],
            [2005, 10163, 68, 35],
            [2005, 10164, 47, 25],
            [2005, 10165, 53, 29],
            [2005, 10166, 40, 24],
            [2005, 10167, 46, 34],
            [2005, 10168, 48, 37],
            [2005, 10169, 50, 36],
            [2005, 10170, 28, 31],
            [2005, 10171, 43, 35],
            [2005, 10172, 34, 28],
            [2005, 10173, 42, 34],
            [2005, 10174, 42, 27],
            [2005, 10175, 48, 33],
            [2005, 10176, 18, 19],
            [2005, 10177, 16, 18],
            [2005, 10178, 19, 19],
            [2005, 10179, 17, 19],
            [2005, 10180, 36, 28],
            [2005, 10181, 22, 15],
            [2005, 10182, 34, 34],
            [2005, 10183, 41, 25],
            [2005, 10184, 51, 35],
            [2005, 10185, 30, 26],
            [2005, 10186, 30, 25],
            [2005, 10187, 19, 15],
            [2005, 10188, 50, 35],
            [2005, 10189, 51, 30],
            [2005, 10190, 19, 14],
            [2005, 10191, 44, 24],
            [2005, 10192, 31, 21],
            [2005, 10193, 19, 18],
            [2005, 10194, 15, 11],
            [2005, 10195, 14, 12],
            [2005, 10234, 42, 33],
            [2005, 10235, 34, 29],
            [2005, 10236, 34, 30],
            [2005, 10237, 25, 24],
            [2005, 10238, 33, 30],
            [2005, 10239, 47, 39],
            [2005, 10240, 28, 26],
            [2005, 10241, 23, 28],
            [2005, 10242, 29, 25],
            [2005, 10243, 33, 27],
            [2005, 10244, 33, 34],
            [2005, 10245, 17, 22],
            [2005, 10246, 31, 27],
            [2005, 10247, 20, 22],
            [2005, 10248, 33, 24],
            [2005, 10249, 20, 24],
            [2005, 10250, 32, 29],
            [2005, 10251, 31, 26],
            [2005, 10252, 32, 29],
            [2005, 10253, 32, 31],
            [2005, 10255, 31, 29],
            [2005, 10256, 38, 34],
            [2005, 10257, 30, 26],
            [2005, 10258, 34, 31],
            [2005, 10259, 16, 23],
            [2005, 10260, 33, 30],
            [2005, 10261, 35, 27],
            [2005, 10263, 19, 22],
            [2005, 10264, 34, 29],
            [2005, 10267, 23, 22],
            [2005, 10268, 33, 26],
            [2005, 10269, 22, 23],
            [2005, 10270, 29, 29],
            [2005, 10271, 34, 27],
            [2005, 10272, 27, 25],
            [2005, 10276, 27, 26],
            [2005, 10277, 35, 31],
            [2005, 10278, 21, 25],
            [2005, 10279, 32, 29],
            [2005, 10280, 20, 26],
            [2005, 10281, 32, 33],
            [2005, 10283, 21, 23],
            [2005, 10284, 27, 27],
            [2005, 10285, 20, 21],
            [2005, 10286, 27, 24],
            [2005, 10287, 27, 24],
            [2005, 10288, 28, 22],
            [2005, 10289, 32, 27],
            [2005, 10290, 29, 25],
            [2005, 10291, 29, 26],
            [2005, 10292, 22, 24],
            [2005, 10293, 29, 29],
            [2005, 10294, 16, 22],
            [2005, 10295, 21, 25],
            [2005, 10296, 29, 28],
            [2005, 10297, 21, 23],
            [2005, 10298, 28, 27],
            [2005, 10299, 21, 23],
            [2005, 10300, 29, 26],
            [2005, 10301, 29, 29],
            [2005, 10302, 21, 24],
            [2005, 10303, 32, 31],
            [2005, 10304, 21, 25],
            [2005, 10305, 30, 29],
            [2005, 10306, 25, 28],
            [2005, 10307, 25, 27],
            [2005, 10309, 27, 25],
            [2005, 10310, 21, 25],
            [2005, 10311, 31, 30],
            [2005, 10312, 25, 24],
            [2005, 10313, 35, 27],
            [2005, 10314, 34, 28],
            [2005, 10315, 31, 24],
            [2005, 10317, 23, 23],
            [2005, 10318, 38, 30],
            [2005, 10319, 23, 27],
            [2005, 10320, 46, 30],
            [2005, 10321, 24, 23],
            [2005, 10322, 32, 32],
            [2005, 10323, 22, 27],
            [2005, 10326, 42, 33],
            [2005, 10327, 22, 24],
            [2005, 10329, 27, 23],
            [2005, 10330, 25, 27],
            [2005, 10332, 19, 22],
            [2005, 10333, 30, 29],
            [2005, 10334, 31, 29],
            [2005, 10335, 30, 31],
            [2005, 10337, 22, 22],
            [2005, 10338, 35, 29],
            [2005, 10339, 24, 25],
            [2005, 10340, 37, 29],
            [2005, 10341, 20, 21],
            [2005, 10342, 30, 25],
            [2005, 10343, 26, 24],
            [2005, 10344, 25, 28],
            [2005, 10347, 20, 27],
            [2005, 10354, 19, 21],
            [2005, 10355, 32, 28],
            [2005, 10356, 23, 25],
            [2005, 10357, 31, 31],
            [2005, 10358, 30, 26],
            [2005, 10360, 19, 22],
            [2005, 10361, 33, 27],
            [2005, 10362, 30, 29],
            [2005, 10363, 42, 30],
            [2005, 10364, 50, 30],
            [2005, 10366, 33, 30],
            [2005, 10367, 40, 28],
            [2005, 10368, 48, 33],
            [2005, 10369, 40, 29],
            [2005, 10370, 51, 35],
            [2005, 10371, 29, 34],
            [2005, 10372, 19, 22],
            [2005, 10374, 21, 24],
            [2005, 10376, 20, 21],
            [2005, 10377, 25, 25],
            [2005, 10378, 27, 27],
            [2005, 10380, 24, 25],
            [2005, 10381, 42, 32],
            [2005, 10382, 25, 26],
            [2005, 10383, 50, 32],
            [2005, 10384, 29, 28],
            [2005, 10385, 52, 33],
            [2005, 10388, 17, 24],
            [2005, 10390, 23, 26],
            [2005, 10391, 28, 24],
            [2005, 10392, 27, 27],
            [2005, 10394, 20, 21],
            [2005, 10395, 30, 27],
            [2005, 10396, 21, 23],
            [2005, 10398, 21, 25],
            [2005, 10399, 31, 28],
            [2005, 10400, 22, 24],
            [2005, 10402, 20, 26],
            [2005, 10403, 35, 34],
            [2005, 10404, 24, 27],
            [2005, 10408, 20, 26],
            [2005, 10409, 31, 33],
            [2005, 10410, 22, 27],
            [2005, 10411, 34, 31],
            [2005, 10412, 32, 21],
            [2005, 10413, 57, 36],
            [2005, 10417, 33, 33],
            [2005, 10418, 20, 22],
            [2005, 10419, 28, 28],
            [2005, 10420, 33, 33],
            [2005, 10422, 26, 28],
            [2005, 10424, 36, 30],
            [2005, 10425, 20, 24],
            [2005, 10426, 30, 30],
            [2005, 10427, 25, 24],
            [2005, 10428, 27, 29],
            [2005, 10431, 21, 25],
            [2005, 10432, 33, 29],
            [2005, 10433, 19, 22],
            [2005, 10434, 33, 28],
            [2005, 10435, 31, 26],
            [2005, 10436, 24, 23],
            [2005, 10437, 29, 23],
            [2005, 10438, 22, 24],
            [2005, 10439, 31, 32],
            [2005, 10440, 20, 25],
            [2005, 10441, 30, 27],
            [2005, 10442, 25, 26],
            [2005, 10443, 20, 21],
            [2005, 10444, 32, 24],
            [2005, 10445, 35, 29],
            [2005, 10447, 19, 20],
            [2005, 10448, 31, 27],
            [2005, 10450, 19, 23],
            [2005, 10453, 44, 26],
            [2005, 10454, 38, 25],
            [2005, 10455, 44, 29],
            [2005, 10456, 19, 22],
            [2005, 10458, 20, 22],
            [2005, 10459, 27, 24],
            [2005, 10461, 21, 26],
            [2005, 10463, 17, 21],
            [2005, 10464, 26, 27],
            [2005, 10467, 20, 26],
            [2005, 10469, 23, 23],
            [2005, 10471, 22, 21],
            [2005, 10474, 13, 11],
            [2005, 10475, 13, 11],
            [2005, 10476, 15, 16],
            [2005, 10477, 17, 17],
            [2005, 10478, 23, 28],
            [2005, 10479, 32, 24],
            [2005, 10480, 19, 20],
            [2005, 10482, 20, 23],
            [2005, 10483, 26, 28],
            [2005, 10484, 20, 23],
            [2005, 10485, 25, 29],
            [2005, 10486, 20, 23],
            [2005, 10487, 25, 30],
            [2005, 10490, 18, 30],
            [2005, 10491, 9, 18],
            [2005, 10492, 8, 13],
            [2005, 10493, 33, 42],
            [2005, 10494, 11, 34],
            [2005, 10495, 10, 27],
            [2005, 10496, 7, 16],
            [2005, 10497, 28, 44],
            [2005, 10498, 8, 16],
            [2005, 10499, 9, 39],
            [2005, 10500, 10, 40],
            [2005, 10501, 10, 45],
            [2005, 10502, 30, 61],
            [2005, 10503, 11, 40],
            [2005, 10504, 12, 50],
            [2005, 10505, 32, 45],
            [2005, 10506, 12, 28],
            [2005, 10507, 9, 20],
            [2005, 10508, 22, 49],
            [2005, 10509, 29, 35],
            [2005, 10510, 12, 35],
            [2005, 10511, 8, 18],
            [2005, 10512, 19, 21],
            [2005, 10513, 29, 28],
            [2005, 10514, 15, 22],
            [2005, 10515, 15, 23],
            [2005, 10516, 14, 20],
            [2005, 10517, 19, 25],
            [2005, 10518, 14, 14],
            [2005, 10519, 17, 14],
            [2005, 10520, 9, 9],
            [2005, 10521, 14, 18],
            [2005, 10522, 16, 18],
            [2005, 10523, 14, 18],
            [2005, 10524, 22, 20],
            [2005, 10525, 15, 18],
            [2005, 10526, 14, 18],
            [2005, 10527, 11, 13],
            [2005, 10528, 17, 18],
            [2005, 10529, 17, 18],
            [2005, 10530, 14, 18],
            [2005, 10531, 14, 16],
            [2005, 10532, 22, 21],
            [2005, 10533, 32, 27],
            [2005, 10534, 20, 13],
            [2005, 10535, 31, 25],
            [2005, 10536, 16, 19],
            [2005, 10537, 22, 20],
            [2005, 10538, 29, 24],
            [2005, 10539, 17, 17],
            [2005, 10540, 31, 25],
            [2005, 10541, 36, 31],
            [2005, 10542, 38, 28],
            [2005, 10543, 7, 7],
            [2005, 10544, 11, 9],
            [2005, 10545, 7, 7],
            [2005, 10546, 10, 8],
            [2005, 10547, 8, 8],
            [2005, 10548, 12, 9],
            [2005, 10549, 8, 8],
            [2005, 10550, 9, 11],
            [2005, 10551, 9, 8],
            [2005, 10552, 7, 7],
            [2005, 10553, 24, 16],
            [2005, 10554, 19, 13],
            [2005, 10555, 11, 8],
            [2005, 10556, 20, 13],
            [2005, 10557, 10, 10],
            [2005, 10558, 30, 20],
            [2005, 10559, 14, 9],
            [2005, 10560, 20, 13],
            [2005, 10577, 21, 13],
            [2005, 10578, 29, 32],
            [2005, 10579, 53, 37],
            [2005, 10580, 68, 40],
            [2005, 10581, 63, 53],
            [2005, 10582, 52, 39],
            [2005, 10583, 49, 42],
            [2005, 10584, 49, 42],
            [2005, 10585, 40, 41],
            [2005, 10586, 52, 47],
            [2005, 10587, 47, 40],
            [2005, 10588, 41, 38],
            [2005, 10589, 46, 42],
            [2005, 10590, 60, 47],
            [2005, 10591, 68, 63],
            [2005, 10592, 53, 31],
            [2005, 10593, 48, 39],
            [2005, 10594, 53, 49],
            [2005, 10595, 39, 41],
            [2005, 10596, 40, 37],
            [2005, 10597, 46, 38],
            [2005, 10598, 41, 31],
            [2005, 10602, 26, 29],
            [2005, 10603, 38, 35],
            [2005, 10604, 34, 24],
            [2005, 10605, 16, 12],
            [2005, 10606, 14, 10],
            [2005, 10607, 18, 14],
            [2005, 10608, 14, 10],
            [2005, 10609, 14, 10],
            [2005, 10610, 21, 11],
            [2005, 10611, 21, 14],
            [2005, 10612, 18, 14],
            [2005, 10613, 43, 30],
            [2005, 10614, 43, 24],
            [2005, 10615, 42, 30],
            [2005, 10616, 37, 27],
            [2005, 10617, 46, 33],
            [2005, 10618, 48, 27],
            [2005, 10619, 34, 22],
            [2005, 10620, 28, 19],
            [2005, 10621, 39, 26],
            [2005, 10622, 32, 18],
            [2005, 10623, 39, 25],
            [2005, 10624, 44, 24],
            [2005, 10625, 29, 20],
            [2005, 10626, 42, 25],
            [2005, 10627, 42, 30],
            [2005, 10628, 46, 30],
            [2005, 10629, 46, 30],
            [2005, 10630, 42, 26],
            [2005, 10631, 42, 24],
            [2005, 10632, 34, 21],
            [2005, 10633, 50, 38],
            [2005, 10634, 45, 30],
            [2005, 10635, 46, 32],
            [2005, 10636, 38, 27],
            [2005, 10637, 50, 31],
            [2005, 10638, 22, 16],
            [2005, 10639, 47, 32],
            [2005, 10640, 45, 27],
            [2005, 10641, 42, 28],
            [2005, 10642, 51, 30],
            [2005, 10643, 39, 25],
            [2005, 10644, 54, 33],
            [2005, 10645, 32, 28],
            [2005, 10646, 44, 28],
            [2005, 10647, 46, 28],
            [2005, 10648, 40, 32],
            [2005, 10649, 42, 25],
            [2005, 10650, 44, 31],
            [2005, 10651, 42, 31],
            [2005, 10652, 36, 23],
            [2005, 10653, 46, 29],
            [2005, 10654, 38, 28],
            [2005, 10655, 45, 32],
            [2005, 10656, 45, 28],
            [2005, 10657, 37, 27],
            [2005, 10658, 48, 27],
            [2005, 10659, 19, 17],
            [2005, 10660, 48, 33],
            [2005, 10661, 63, 28],
            [2005, 10662, 46, 28],
            [2005, 10663, 37, 26],
            [2005, 10664, 40, 29],
            [2005, 10665, 47, 32],
            [2005, 10666, 66, 33],
            [2005, 10667, 56, 31],
            [2005, 10668, 40, 29],
            [2005, 10669, 20, 16],
            [2005, 10670, 38, 26],
            [2005, 10671, 48, 28],
            [2005, 10672, 48, 26],
            [2005, 10673, 32, 22],
            [2005, 10674, 35, 21],
            [2005, 10675, 45, 34],
            [2005, 10676, 39, 33],
            [2005, 10677, 35, 21],
            [2005, 10678, 38, 24],
            [2005, 10679, 51, 27],
            [2005, 10680, 35, 28],
            [2005, 10681, 42, 32],
            [2005, 10682, 39, 24],
            [2005, 10683, 34, 23],
            [2005, 10684, 26, 19],
            [2005, 10685, 75, 37],
            [2005, 10686, 41, 35],
            [2005, 10687, 39, 34],
            [2005, 10688, 53, 37],
            [2005, 10689, 53, 34],
            [2005, 10690, 54, 36],
            [2005, 10691, 55, 36],
            [2005, 10692, 48, 32],
            [2005, 10693, 69, 34],
            [2005, 10694, 54, 31],
            [2005, 10695, 54, 30],
            [2005, 10696, 47, 28],
            [2005, 10697, 31, 23],
            [2005, 10698, 36, 29],
            [2005, 10699, 42, 33],
            [2005, 10700, 20, 15],
            [2005, 10701, 47, 29],
            [2005, 10702, 63, 26],
            [2005, 10703, 64, 26],
            [2005, 10704, 46, 25],
            [2005, 10705, 48, 23],
            [2005, 10706, 46, 33],
            [2005, 10707, 40, 38],
            [2005, 10708, 51, 38],
            [2005, 10709, 46, 39],
            [2005, 10710, 60, 30],
            [2005, 10711, 45, 30],
            [2005, 10712, 48, 35],
            [2005, 10713, 57, 35],
            [2005, 10714, 43, 27],
            [2005, 10715, 55, 31],
            [2005, 10716, 46, 36],
            [2005, 10717, 46, 36],
            [2005, 10718, 42, 37],
            [2005, 10719, 54, 33],
            [2005, 10720, 56, 36],
            [2005, 10721, 27, 20],
            [2005, 10722, 55, 35],
            [2005, 10723, 46, 34],
            [2005, 10724, 48, 35],
            [2005, 10725, 45, 36],
            [2005, 10726, 35, 24],
            [2005, 10727, 46, 27],
            [2005, 10728, 46, 27],
            [2005, 10729, 50, 33],
            [2005, 10730, 57, 32],
            [2005, 10731, 37, 31],
            [2005, 10732, 55, 35],
            [2005, 10733, 47, 32],
            [2005, 10734, 47, 30],
            [2005, 10735, 47, 26],
            [2005, 10736, 47, 32],
            [2005, 10737, 69, 40],
            [2005, 10738, 48, 28],
            [2005, 10739, 27, 15],
            [2005, 10740, 45, 30],
            [2005, 10741, 46, 35],
            [2005, 10742, 45, 30],
            [2005, 10743, 40, 27],
            [2005, 10744, 39, 24],
            [2005, 10745, 44, 27],
            [2005, 10746, 45, 24],
            [2005, 10747, 27, 16],
            [2005, 10748, 38, 25],
            [2005, 10749, 43, 29],
            [2005, 10750, 46, 30],
            [2005, 10751, 45, 30],
            [2005, 10752, 45, 32],
            [2005, 10753, 50, 33],
            [2005, 10754, 39, 25],
            [2005, 10755, 19, 15],
            [2005, 10756, 75, 45],
            [2005, 10757, 20, 14],
            [2005, 10758, 28, 18],
            [2005, 10759, 49, 26],
            [2005, 10760, 50, 30],
            [2005, 10761, 43, 28],
            [2005, 10762, 45, 35],
            [2005, 10763, 38, 25],
            [2005, 10764, 26, 21],
            [2005, 10765, 34, 23],
            [2005, 10766, 55, 32],
            [2005, 10767, 47, 30],
            [2005, 10768, 42, 30],
            [2005, 10769, 44, 27],
            [2005, 10770, 46, 32],
            [2005, 10771, 47, 34],
            [2005, 10772, 34, 38],
            [2005, 10773, 45, 41],
            [2005, 10774, 38, 23],
            [2005, 10775, 44, 23],
            [2005, 10776, 38, 22],
            [2005, 10777, 29, 20],
            [2005, 10778, 66, 33],
            [2005, 10779, 35, 26],
            [2005, 10780, 44, 27],
            [2005, 10781, 40, 27],
            [2005, 10782, 44, 30],
            [2005, 10783, 49, 33],
            [2005, 10784, 45, 29],
            [2005, 10785, 48, 26],
            [2005, 10786, 42, 30],
            [2005, 10787, 48, 28],
            [2005, 10788, 43, 32],
            [2005, 10789, 42, 25],
            [2005, 10790, 48, 25],
            [2005, 10791, 48, 25],
            [2005, 10792, 35, 28],
            [2005, 10793, 45, 28],
            [2005, 10794, 48, 32],
            [2005, 10795, 48, 30],
            [2005, 10796, 46, 32],
            [2005, 10797, 43, 29],
            [2005, 10798, 38, 28],
            [2005, 10799, 21, 16],
            [2005, 10800, 44, 30],
            [2005, 10801, 56, 33],
            [2005, 10802, 46, 25],
            [2005, 10803, 34, 20],
            [2005, 10804, 54, 30],
            [2005, 10805, 63, 31],
            [2005, 10806, 41, 31],
            [2005, 10807, 45, 23],
            [2005, 10808, 35, 20],
            [2005, 10809, 29, 25],
            [2005, 10810, 46, 29],
            [2005, 10811, 43, 26],
            [2005, 10812, 56, 41],
            [2005, 10814, 37, 27],
            [2005, 10815, 46, 29],
            [2005, 10816, 46, 30],
            [2005, 10817, 46, 30],
            [2005, 10818, 47, 31],
            [2005, 10819, 46, 29],
            [2005, 10820, 46, 27],
            [2005, 10821, 41, 28],
            [2005, 10822, 44, 29],
            [2005, 10823, 46, 27],
            [2005, 10824, 37, 26],
            [2005, 10825, 38, 32],
            [2005, 10826, 40, 24],
            [2005, 10827, 38, 29],
            [2005, 10828, 33, 26],
            [2005, 10829, 46, 30],
            [2005, 10830, 45, 27],
            [2005, 10831, 46, 30],
            [2005, 10832, 44, 26],
            [2005, 10833, 44, 26],
            [2005, 10834, 45, 27],
            [2005, 10835, 46, 28],
            [2005, 10836, 43, 27],
            [2005, 10837, 49, 27],
            [2005, 10838, 44, 27],
            [2005, 10839, 36, 26],
            [2005, 10840, 27, 20],
            [2005, 10841, 60, 30],
            [2005, 10842, 33, 30],
            [2005, 10843, 44, 29],
            [2005, 10844, 34, 25],
            [2005, 10845, 31, 23],
            [2005, 10846, 33, 25],
            [2005, 10847, 40, 28],
            [2005, 10848, 44, 30],
            [2005, 10849, 46, 30],
            [2005, 10850, 40, 27],
            [2005, 10851, 45, 29],
            [2005, 10852, 44, 28],
            [2005, 10853, 53, 36],
            [2005, 10854, 44, 31],
            [2005, 10855, 48, 27],
            [2005, 10856, 46, 30],
            [2005, 10857, 47, 31],
            [2005, 10858, 43, 27],
            [2005, 10859, 48, 27],
            [2005, 10860, 55, 29],
            [2005, 10861, 51, 29],
            [2005, 10862, 48, 27],
            [2005, 10863, 24, 19],
            [2005, 10864, 59, 29],
            [2005, 10865, 43, 30],
            [2005, 10866, 36, 22],
            [2005, 10867, 44, 26],
            [2005, 10868, 45, 26],
            [2005, 10869, 61, 32],
            [2005, 10870, 55, 33],
            [2005, 10871, 47, 25],
            [2005, 10872, 58, 28],
            [2005, 10873, 52, 31],
            [2005, 10874, 52, 32],
            [2005, 10875, 48, 30],
            [2005, 10876, 53, 26],
            [2005, 10877, 56, 29],
            [2005, 10878, 46, 26],
            [2005, 10879, 48, 30],
            [2005, 10880, 49, 30],
            [2005, 10881, 35, 25],
            [2005, 10882, 54, 30],
            [2005, 10883, 62, 33],
            [2005, 10884, 68, 33],
            [2005, 10885, 48, 31],
            [2005, 10886, 44, 24],
            [2005, 10887, 38, 27],
            [2005, 10888, 56, 30],
            [2005, 10889, 45, 28],
            [2005, 10890, 37, 24],
            [2005, 10891, 29, 21],
            [2005, 10892, 32, 20],
            [2005, 10893, 47, 36],
            [2005, 10894, 46, 36],
            [2005, 10895, 70, 35],
            [2005, 10896, 46, 33],
            [2005, 10897, 48, 35],
            [2005, 10898, 44, 34],
            [2005, 10899, 53, 30],
            [2005, 10900, 44, 29],
            [2005, 10901, 41, 29],
            [2005, 10902, 38, 23],
            [2005, 10903, 48, 32],
            [2005, 10904, 48, 30],
            [2005, 10905, 37, 23],
            [2005, 10906, 48, 33],
            [2005, 10907, 46, 32],
            [2005, 10908, 45, 27],
            [2005, 10909, 54, 35],
            [2005, 10910, 43, 31],
            [2005, 10911, 54, 31],
            [2005, 10912, 54, 40],
            [2005, 10913, 38, 32],
            [2005, 10914, 66, 33],
            [2005, 10915, 49, 38],
            [2005, 10916, 52, 37],
            [2005, 10917, 56, 36],
            [2005, 10918, 35, 29],
            [2005, 10978, 44, 30],
            [2005, 10979, 43, 26],
            [2005, 10980, 39, 24],
            [2005, 11091, 8, 5],
            [2005, 11092, 10, 8],
            [2005, 11093, 12, 7],
            [2005, 11094, 15, 12],
            [2005, 11095, 10, 7],
            [2005, 11096, 18, 12],
            [2005, 11097, 10, 8],
            [2005, 11098, 9, 7],
            [2005, 11099, 32, 18],
            [2005, 11100, 13, 11],
            [2005, 11101, 11, 9],
            [2005, 11102, 12, 9],
            [2005, 11103, 14, 10],
            [2005, 11104, 43, 22],
            [2005, 11105, 32, 22],
            [2005, 11106, 27, 15],
            [2005, 11107, 16, 10],
            [2005, 11108, 9, 6],
            [2005, 11109, 16, 12],
            [2005, 11110, 15, 9],
            [2005, 11111, 12, 7],
            [2005, 11112, 23, 14],
            [2005, 11113, 26, 16],
            [2005, 11114, 45, 30],
            [2005, 11115, 7, 6],
            [2005, 11116, 8, 6],
            [2005, 11117, 8, 5],
            [2005, 11118, 14, 9],
            [2005, 11119, 42, 24],
            [2005, 11120, 27, 16],
            [2005, 11121, 9, 6],
            [2005, 11122, 12, 8],
            [2005, 11123, 18, 12],
            [2005, 11124, 9, 8],
            [2005, 11125, 25, 15],
            [2005, 11126, 13, 11],
            [2005, 11127, 7, 7],
            [2005, 11128, 13, 7],
            [2005, 11129, 7, 6],
            [2005, 11130, 15, 10],
            [2005, 11131, 7, 6],
            [2005, 11132, 24, 14],
            [2005, 11133, 11, 8],
            [2005, 11134, 6, 4],
            [2005, 11135, 53, 25],
            [2005, 11136, 10, 8],
            [2005, 11137, 6, 5],
            [2005, 11138, 19, 11],
            [2005, 11139, 10, 6],
            [2005, 11140, 10, 9],
            [2005, 11141, 8, 6],
            [2005, 11142, 9, 7],
            [2005, 11143, 7, 6],
            [2005, 11144, 9, 8],
            [2005, 11145, 30, 19],
            [2005, 11146, 7, 6],
            [2005, 11147, 5, 3],
            [2005, 11148, 37, 22],
            [2005, 11149, 18, 11],
            [2005, 11150, 18, 16],
            [2005, 11151, 22, 15],
            [2005, 11152, 16, 11],
            [2005, 11153, 14, 9],
            [2005, 11154, 25, 18],
            [2005, 11155, 18, 10],
            [2005, 11156, 11, 10],
            [2005, 11157, 14, 10],
            [2005, 11158, 14, 10],
            [2005, 11159, 20, 10],
            [2005, 11160, 29, 15],
            [2005, 11161, 12, 10],
            [2005, 11162, 18, 12],
            [2005, 11163, 14, 12],
            [2005, 11164, 17, 15],
            [2005, 11165, 17, 12],
            [2005, 11166, 40, 26],
            [2005, 11167, 75, 43],
            [2005, 11168, 26, 18],
            [2005, 11169, 8, 8],
            [2005, 11170, 10, 9],
            [2005, 11171, 12, 10],
            [2005, 11172, 10, 9],
            [2005, 11173, 12, 11],
            [2005, 11174, 6, 6],
            [2005, 11175, 6, 6],
            [2005, 11176, 6, 6],
            [2005, 11177, 21, 18],
            [2005, 11178, 7, 7],
            [2005, 11179, 14, 12],
            [2005, 11180, 13, 10],
            [2005, 11181, 16, 13],
            [2005, 11182, 14, 11],
            [2005, 11183, 14, 13],
            [2005, 11184, 97, 75],
            [2005, 11185, 97, 75],
            [2005, 11186, 97, 75],
            [2005, 11187, 97, 75],
            [2005, 11188, 97, 75],
            [2005, 11189, 74, 76],
            [2005, 11195, 18, 17],
            [2005, 11197, 81, 40],
            [2005, 11199, 45, 26],
            [2005, 11201, 10, 10],
            [2005, 11202, 44, 29],
            [2005, 11203, 12, 13],
            [2005, 11204, 75, 49],
            [2005, 11205, 108, 74],
            [2005, 11206, 59, 52],
            [2005, 11207, 10, 11],
            [2005, 11209, 221, 179],
            [2005, 11210, 741, 95],
            [2005, 11211, 102, 103],
            [2005, 11212, 741, 103],
            [2005, 11213, 741, 95],
            [2005, 11214, 741, 95],
            [2005, 11215, 102, 103],
            [2005, 11216, 741, 103],
            [2005, 11217, 102, 103],
            [2005, 11218, 741, 103],
            [2005, 11219, 102, 103],
            [2005, 11220, 741, 95],
            [2005, 11221, 102, 103],
            [2005, 11222, 102, 103],
            [2005, 11223, 102, 103],
            [2005, 11224, 102, 103],
            [2005, 11225, 741, 103],
            [2005, 11226, 741, 103],
            [2005, 11228, 102, 103],
            [2005, 11229, 102, 103],
            [2005, 11230, 102, 103],
            [2005, 11231, 102, 103],
            [2005, 11232, 102, 103],
            [2005, 11233, 102, 103],
            [2005, 11234, 102, 103],
            [2005, 11235, 102, 103],
            [2005, 11236, 102, 103],
            [2005, 11237, 741, 103],
            [2005, 11238, 741, 103],
            [2005, 11239, 102, 103],
            [2005, 11240, 102, 103],
            [2005, 11241, 102, 103],
            [2005, 11242, 102, 103],
            [2005, 11243, 741, 95],
            [2005, 11245, 102, 103],
            [2005, 11246, 221, 171],
            [2005, 11247, 221, 171],
            [2005, 11248, 102, 103],
            [2005, 11249, 102, 103],
            [2005, 11250, 102, 103],
            [2005, 11251, 102, 103],
            [2005, 11252, 102, 103],
            [2005, 11253, 102, 103],
            [2005, 11254, 102, 103],
            [2005, 11255, 102, 103],
            [2005, 11256, 102, 103],
            [2005, 11257, 741, 103],
            [2005, 11258, 741, 103],
            [2005, 11259, 741, 95],
            [2005, 11260, 741, 103],
            [2005, 11262, 102, 103],
            [2005, 11263, 102, 103],
            [2005, 11264, 102, 103],
            [2005, 11265, 102, 103],
            [2005, 11266, 102, 103],
            [2005, 11267, 102, 103],
            [2005, 11268, 102, 103],
            [2005, 11269, 102, 103],
            [2005, 11270, 221, 171],
            [2005, 11271, 741, 103],
            [2005, 11272, 741, 103],
            [2005, 11274, 102, 103],
            [2005, 11275, 102, 103],
            [2005, 11276, 102, 103],
            [2005, 11277, 102, 103],
            [2005, 11278, 102, 103],
            [2005, 11279, 221, 171],
            [2005, 11280, 741, 103],
            [2005, 11281, 741, 103],
            [2005, 11283, 102, 103],
            [2005, 11284, 102, 103],
            [2005, 11285, 102, 103],
            [2005, 11286, 102, 103],
            [2005, 11287, 102, 103],
            [2005, 11288, 102, 103],
            [2005, 11289, 102, 103],
            [2005, 11290, 741, 103],
            [2005, 11291, 741, 103],
            [2005, 11292, 14, 18],
            [2005, 11293, 10, 12],
            [2005, 11294, 12, 15],
            [2005, 11295, 12, 15],
            [2005, 11296, 31, 54],
            [2005, 11298, 23, 20],
            [2005, 11300, 40, 40],
            [2005, 11303, 19, 17],
            [2005, 11304, 30, 20],
            [2005, 11305, 54, 43],
            [2005, 11306, 14, 20],
            [2005, 11307, 16, 20],
            [2005, 11308, 16, 25],
            [2005, 11309, 25, 21],
            [2005, 11310, 19, 19],
            [2005, 11311, 20, 20],
            [2005, 11312, 22, 18],
            [2005, 11313, 17, 19],
            [2005, 11314, 34, 35],
            [2005, 11315, 33, 29],
            [2005, 11316, 29, 32],
            [2005, 11317, 33, 32],
            [2005, 11318, 19, 21],
            [2005, 11319, 21, 19],
            [2005, 11320, 20, 17],
            [2005, 11321, 45, 31],
            [2005, 11322, 55, 31],
            [2005, 11323, 25, 26],
            [2005, 11324, 29, 20],
            [2005, 11325, 34, 22],
            [2005, 11326, 26, 28],
            [2005, 11327, 30, 23],
            [2005, 11328, 28, 31],
            [2005, 11329, 22, 26],
            [2005, 11330, 34, 35],
            [2005, 11331, 32, 32],
            [2005, 11332, 20, 17],
            [2005, 11333, 38, 27],
            [2005, 11334, 43, 28],
            [2005, 11335, 29, 22],
            [2005, 11336, 13, 14],
            [2005, 11337, 25, 26],
            [2005, 11338, 26, 28],
            [2005, 11339, 33, 28],
            [2005, 11340, 33, 32],
            [2005, 11341, 37, 30],
            [2005, 11342, 33, 30],
            [2005, 11343, 34, 35],
            [2005, 11344, 33, 33],
            [2005, 11345, 27, 31],
            [2005, 11346, 40, 30],
            [2005, 11347, 33, 28],
            [2005, 11348, 44, 37],
            [2005, 11349, 21, 18],
            [2005, 11350, 33, 32],
            [2005, 11351, 29, 32],
            [2005, 11352, 29, 32],
            [2005, 11353, 38, 35],
            [2005, 11354, 29, 23],
            [2005, 11355, 33, 28],
            [2005, 11356, 32, 26],
            [2005, 11357, 27, 24],
            [2005, 11358, 25, 26],
            [2005, 11359, 40, 38],
            [2005, 11360, 36, 25],
            [2005, 11361, 44, 37],
            [2005, 11362, 28, 26],
            [2005, 11363, 9, 10],
            [2005, 11364, 11, 12],
            [2005, 11365, 33, 23],
            [2005, 11366, 21, 21],
            [2005, 11367, 44, 41],
            [2005, 11368, 20, 21],
            [2005, 11369, 43, 44],
            [2005, 11370, 20, 24],
            [2005, 11371, 30, 29],
            [2005, 11372, 32, 33],
            [2005, 11373, 50, 32],
            [2005, 11374, 39, 37],
            [2005, 11375, 56, 42],
            [2005, 11376, 20, 20],
            [2005, 11377, 42, 38],
            [2005, 11378, 27, 28],
            [2005, 11384, 48, 44],
            [2005, 11385, 67, 67],
            [2005, 11386, 65, 67],
            [2005, 11387, 88, 73],
            [2005, 11388, 67, 60],
            [2005, 11389, 48, 40],
            [2005, 11390, 52, 46],
            [2005, 11391, 45, 37],
            [2005, 11392, 88, 73],
            [2005, 11393, 61, 53],
            [2005, 11394, 94, 67],
            [2005, 11395, 88, 73],
            [2005, 11396, 87, 83],
            [2005, 11397, 87, 78],
            [2005, 11398, 56, 52],
            [2005, 11399, 86, 83],
            [2005, 11400, 88, 73],
            [2005, 11401, 71, 33],
            [2005, 11402, 54, 53],
            [2005, 11403, 52, 55],
            [2005, 11404, 93, 75],
            [2005, 11405, 64, 59],
            [2005, 11406, 80, 70],
            [2005, 11407, 39, 37],
            [2005, 11408, 81, 62],
            [2005, 11409, 51, 42],
            [2005, 11410, 72, 55],
            [2005, 11411, 53, 45],
            [2005, 11412, 85, 83],
            [2005, 11413, 82, 75],
            [2005, 11414, 56, 65],
            [2005, 11415, 88, 73],
            [2005, 11416, 38, 34],
            [2005, 11417, 52, 48],
            [2005, 11418, 60, 65],
            [2005, 11419, 51, 48],
            [2005, 11420, 70, 57],
            [2005, 11421, 95, 71],
            [2005, 11422, 62, 62],
            [2005, 11423, 53, 61],
            [2005, 11424, 52, 41],
            [2005, 11425, 22, 18],
            [2005, 11426, 9, 7],
            [2005, 11427, 8, 8],
            [2005, 11428, 52, 25],
            [2005, 11429, 15, 12],
            [2005, 11430, 9, 10],
            [2005, 11431, 12, 10],
            [2005, 11432, 8, 8],
            [2005, 11433, 10, 12],
            [2005, 11434, 10, 9],
            [2005, 11435, 7, 8],
            [2005, 11436, 20, 20],
            [2005, 11437, 12, 11],
            [2005, 11438, 10, 9],
            [2005, 11439, 11, 9],
            [2005, 11440, 16, 14],
            [2005, 11441, 45, 27],
            [2005, 11442, 9, 8],
            [2005, 11443, 11, 11],
            [2005, 11444, 14, 9],
            [2005, 11445, 8, 8],
            [2005, 11446, 11, 9],
            [2005, 11447, 17, 14],
            [2005, 11448, 12, 10],
            [2005, 11449, 12, 8],
            [2005, 11450, 12, 10],
            [2005, 11451, 9, 7],
            [2005, 11452, 10, 9],
            [2005, 11453, 30, 19],
            [2005, 11454, 13, 11],
            [2005, 11455, 8, 8],
            [2005, 11456, 8, 8],
            [2005, 11457, 9, 9],
            [2005, 11458, 6, 7],
            [2005, 11459, 6, 6],
            [2005, 11460, 7, 6],
            [2005, 11461, 9, 8],
            [2005, 11462, 7, 7],
            [2005, 11463, 10, 9],
            [2005, 11464, 9, 7],
            [2005, 11465, 18, 14],
            [2005, 11466, 14, 9],
            [2005, 11467, 15, 11],
            [2005, 11468, 37, 24],
            [2005, 11469, 16, 12],
            [2005, 11470, 20, 16],
            [2005, 11471, 15, 14],
            [2005, 11472, 27, 17],
            [2005, 11473, 10, 9],
            [2005, 11474, 8, 9],
            [2005, 11475, 9, 9],
            [2005, 11476, 12, 9],
            [2005, 11477, 24, 19],
            [2005, 11478, 29, 19],
            [2005, 11479, 11, 9],
            [2005, 11480, 21, 17],
            [2005, 11481, 15, 14],
            [2005, 11482, 17, 14],
            [2005, 11483, 19, 15],
            [2005, 11484, 20, 15],
            [2005, 11485, 25, 18],
            [2005, 11486, 22, 15],
            [2005, 11487, 17, 14],
            [2005, 11488, 24, 18],
            [2005, 11489, 13, 11],
            [2005, 11490, 14, 13],
            [2005, 11491, 11, 9],
            [2005, 11492, 8, 7],
            [2005, 11493, 8, 8],
            [2005, 11494, 6, 7],
            [2005, 11495, 6, 6],
            [2005, 11496, 7, 8],
            [2005, 11497, 9, 8],
            [2005, 11498, 9, 8],
            [2005, 11499, 9, 9],
            [2005, 11500, 22, 20],
            [2005, 11501, 8, 8],
            [2005, 11502, 12, 10],
            [2005, 11503, 7, 8],
            [2005, 11504, 9, 9],
            [2005, 11505, 14, 11],
            [2005, 11506, 10, 10],
            [2005, 11507, 11, 12],
            [2005, 11508, 7, 8],
            [2005, 11509, 27, 16],
            [2005, 11510, 11, 9],
            [2005, 11511, 12, 9],
            [2005, 11512, 19, 12],
            [2005, 11513, 13, 11],
            [2005, 11514, 9, 9],
            [2005, 11515, 9, 9],
            [2005, 11516, 14, 11],
            [2005, 11517, 20, 18],
            [2005, 11518, 10, 15],
            [2005, 11519, 22, 14],
            [2005, 11520, 32, 20],
            [2005, 11521, 8, 6],
            [2005, 11522, 10, 10],
            [2005, 11523, 11, 9],
            [2005, 11524, 8, 7],
            [2005, 11525, 11, 8],
            [2005, 11526, 16, 11],
            [2005, 11527, 10, 10],
            [2005, 11528, 8, 7],
            [2005, 11529, 76, 75],
            [2005, 11530, 77, 83],
            [2005, 11531, 65, 43],
            [2005, 11532, 68, 87],
            [2005, 11533, 40, 35],
            [2005, 11534, 86, 83],
            [2005, 11535, 96, 79],
            [2005, 11536, 38, 50],
            [2005, 11537, 93, 65],
            [2005, 11538, 85, 69],
            [2005, 11539, 70, 53],
            [2005, 11540, 51, 39],
            [2005, 11541, 96, 71],
            [2005, 11542, 89, 73],
            [2005, 11543, 99, 68],
            [2005, 11544, 44, 48],
            [2005, 11545, 49, 65],
            [2005, 11546, 102, 73],
            [2005, 11547, 96, 73],
            [2005, 11548, 102, 73],
            [2005, 11549, 51, 41],
            [2005, 11550, 96, 72],
            [2005, 11551, 61, 49],
            [2005, 11552, 89, 83],
            [2005, 11553, 95, 83],
            [2005, 11554, 34, 53],
            [2005, 11555, 57, 54],
            [2005, 11556, 97, 72],
            [2005, 11557, 94, 72],
            [2005, 11558, 59, 83],
            [2005, 11559, 96, 72],
            [2005, 11560, 42, 54],
            [2005, 11561, 90, 68],
            [2005, 11562, 94, 72],
            [2005, 11563, 101, 83],
            [2005, 11564, 81, 83],
            [2005, 11565, 102, 70],
            [2005, 11566, 70, 83],
            [2005, 11567, 96, 72],
            [2005, 11568, 94, 67],
            [2005, 11569, 94, 82],
            [2005, 11570, 94, 72],
            [2005, 11571, 10, 11],
            [2005, 11572, 17, 14],
            [2005, 11573, 120, 90],
            [2005, 11574, 12, 12],
            [2005, 11575, 31, 30],
            [2005, 11576, 14, 14],
            [2005, 11577, 14, 14],
            [2005, 11578, 19, 19],
            [2005, 11579, 18, 24],
            [2005, 11580, 11, 13],
            [2005, 11581, 14, 17],
            [2005, 11582, 18, 20],
            [2005, 11583, 35, 27],
            [2005, 11585, 29, 17],
            [2005, 11586, 49, 25],
            [2005, 11587, 14, 13],
            [2005, 11588, 64, 32],
            [2005, 11589, 45, 27],
            [2005, 11590, 36, 25],
            [2005, 11591, 29, 21],
            [2005, 11592, 60, 35],
            [2005, 11593, 53, 23],
            [2005, 11594, 82, 44],
            [2005, 11595, 43, 26],
            [2005, 11596, 28, 28],
            [2005, 11597, 76, 44],
            [2005, 11598, 27, 14],
            [2005, 11599, 30, 23],
            [2005, 11600, 26, 23],
            [2005, 11601, 52, 32],
            [2005, 11602, 57, 34],
            [2005, 11603, 60, 30],
            [2005, 11604, 16, 17],
            [2005, 11605, 23, 18],
            [2005, 11606, 37, 30],
            [2005, 11607, 36, 27],
            [2005, 11608, 31, 30],
            [2005, 11609, 37, 22],
            [2005, 11610, 29, 33],
            [2005, 11611, 34, 24],
            [2005, 11612, 39, 26],
            [2005, 11613, 36, 24],
            [2005, 11614, 26, 24],
            [2005, 11615, 28, 18],
            [2005, 11616, 26, 22],
            [2005, 11617, 27, 23],
            [2005, 11618, 33, 32],
            [2005, 11619, 25, 21],
            [2005, 11620, 23, 21],
            [2005, 11621, 34, 24],
            [2005, 11622, 25, 30],
            [2005, 11623, 22, 22],
            [2005, 11624, 35, 25],
            [2005, 11625, 22, 26],
            [2005, 11626, 22, 25],
            [2005, 11627, 33, 20],
            [2005, 11628, 31, 26],
            [2005, 11629, 28, 29],
            [2005, 11630, 49, 26],
            [2005, 11631, 49, 36],
            [2005, 11632, 30, 26],
            [2005, 11633, 21, 22],
            [2005, 11634, 36, 32],
            [2005, 11635, 25, 21],
            [2005, 11636, 23, 23],
            [2005, 11637, 32, 25],
            [2005, 11638, 37, 25],
            [2005, 11639, 26, 26],
            [2005, 11640, 51, 34],
            [2005, 11641, 30, 20],
            [2005, 11642, 22, 20],
            [2005, 11643, 35, 25],
            [2005, 11644, 29, 20],
            [2005, 11645, 32, 27],
            [2005, 11646, 16, 19],
            [2005, 11647, 27, 23],
            [2005, 11648, 20, 21],
            [2005, 11649, 23, 20],
            [2005, 11650, 18, 19],
            [2005, 11651, 27, 27],
            [2005, 11652, 30, 22],
            [2005, 11653, 45, 27],
            [2005, 11654, 38, 24],
            [2005, 11655, 39, 28],
            [2005, 11656, 43, 25],
            [2005, 11657, 55, 35],
            [2005, 11658, 29, 23],
            [2005, 11659, 49, 38],
            [2005, 11660, 31, 29],
            [2005, 11661, 29, 22],
            [2005, 11662, 42, 26],
            [2005, 11663, 31, 22],
            [2005, 11664, 26, 26],
            [2005, 11665, 57, 26],
            [2005, 11666, 43, 25],
            [2005, 11667, 50, 32],
            [2005, 11668, 33, 24],
            [2005, 11669, 33, 22],
            [2005, 11670, 38, 28],
            [2005, 11671, 39, 26],
            [2005, 11672, 34, 28],
            [2005, 11673, 42, 28],
            [2005, 11674, 34, 29],
            [2005, 11675, 43, 40],
            [2005, 11676, 41, 28],
            [2005, 11677, 58, 43],
            [2005, 11678, 48, 31],
            [2005, 11679, 40, 24],
            [2005, 11680, 40, 25],
            [2005, 11681, 33, 26],
            [2005, 11682, 55, 25],
            [2005, 11683, 25, 20],
            [2005, 11684, 35, 24],
            [2005, 11685, 24, 22],
            [2005, 11686, 42, 24],
            [2005, 11687, 20, 20],
            [2005, 11688, 53, 38],
            [2005, 11689, 38, 24],
            [2005, 11690, 25, 21],
            [2005, 11691, 32, 25],
            [2005, 11692, 36, 27],
            [2005, 11693, 20, 20],
            [2005, 11694, 19, 19],
            [2005, 11695, 22, 21],
            [2005, 11696, 24, 23],
            [2005, 11697, 24, 24],
            [2005, 11698, 19, 19],
            [2005, 11699, 40, 32],
            [2005, 11700, 30, 25],
            [2005, 11701, 30, 29],
            [2005, 11702, 35, 25],
            [2005, 11703, 19, 17],
            [2005, 11704, 21, 22],
            [2005, 11705, 46, 26],
            [2005, 11706, 128, 61],
            [2005, 11707, 28, 22],
            [2005, 11708, 27, 23],
            [2005, 11709, 55, 27],
            [2005, 11710, 74, 34],
            [2005, 11712, 44, 34],
            [2005, 11713, 77, 37],
            [2005, 11714, 36, 11],
            [2005, 11715, 58, 71],
            [2005, 11716, 58, 72],
            [2005, 11717, 33, 48],
            [2005, 11718, 122, 60],
            [2005, 11719, 132, 50],
            [2005, 11720, 68, 80],
            [2005, 11721, 20, 25],
            [2005, 11722, 70, 70],
            [2005, 11723, 111, 108],
            [2005, 11724, 65, 52],
            [2005, 11725, 150, 150],
            [2005, 11726, 72, 65],
            [2005, 11727, 150, 150],
            [2005, 11728, 62, 50],
            [2005, 11729, 135, 103],
            [2005, 11730, 38, 28],
            [2005, 11731, 70, 70],
            [2005, 11732, 100, 100],
            [2005, 11733, 150, 136],
            [2005, 11734, 74, 60],
            [2005, 11735, 155, 108],
            [2005, 11736, 110, 100],
            [2005, 11737, 46, 50],
            [2005, 11738, 70, 70],
            [2005, 11739, 28, 22],
            [2005, 11741, 23, 29],
            [2005, 11742, 70, 70],
            [2005, 11743, 164, 66],
            [2005, 11744, 120, 105],
            [2005, 11745, 76, 31],
            [2005, 11746, 31, 19],
            [2005, 11747, 92, 50],
            [2005, 11748, 120, 120],
            [2005, 11749, 82, 63],
            [2005, 11750, 101, 50],
            [2005, 11751, 179, 130],
            [2005, 11752, 62, 50],
            [2005, 11753, 99, 50],
            [2005, 11754, 61, 50],
            [2005, 11755, 19, 21],
            [2005, 11756, 70, 70],
            [2005, 11757, 90, 48],
            [2005, 11758, 52, 67],
            [2005, 11759, 25, 21],
            [2005, 11760, 70, 70],
            [2005, 11761, 85, 60],
            [2005, 11762, 62, 50],
            [2005, 11763, 27, 30],
            [2005, 11764, 76, 46],
            [2005, 11765, 158, 80],
            [2005, 11766, 60, 50],
            [2005, 11767, 173, 63],
            [2005, 11768, 102, 86],
            [2005, 11769, 180, 142],
            [2005, 11770, 107, 66],
            [2005, 11771, 100, 50],
            [2005, 11772, 134, 143],
            [2005, 11773, 137, 104],
            [2005, 11774, 120, 77],
            [2005, 11775, 47, 42],
            [2005, 11776, 65, 60],
            [2005, 11777, 35, 30],
            [2005, 11779, 75, 100],
            [2005, 11780, 32, 19],
            [2005, 11781, 20, 22],
            [2005, 11782, 16, 19],
            [2005, 11783, 36, 26],
            [2005, 11784, 26, 22],
            [2005, 11785, 32, 30],
            [2005, 11786, 67, 43],
            [2005, 11787, 39, 38],
            [2005, 11788, 44, 36],
            [2005, 11789, 42, 35],
            [2005, 11790, 15, 18],
            [2005, 11791, 45, 21],
            [2005, 11792, 70, 70],
            [2005, 11793, 70, 70],
            [2005, 11794, 34, 25],
            [2005, 11795, 25, 26],
            [2005, 11796, 49, 42],
            [2005, 11797, 47, 34],
            [2005, 11798, 38, 27],
            [2005, 11799, 38, 28],
            [2005, 11800, 37, 30],
            [2005, 11801, 40, 27],
            [2005, 11802, 38, 32],
            [2005, 11803, 42, 31],
            [2005, 11804, 36, 30],
            [2005, 11805, 39, 29],
            [2005, 11806, 47, 38],
            [2005, 11807, 29, 26],
            [2005, 11808, 30, 18],
            [2005, 11809, 22, 14],
            [2005, 11810, 25, 17],
            [2005, 11811, 23, 17],
            [2005, 11812, 32, 23],
            [2005, 11813, 12, 13],
            [2005, 11814, 23, 21],
            [2005, 11815, 22, 19],
            [2005, 11816, 24, 20],
            [2005, 11817, 18, 12],
            [2005, 11818, 19, 20],
            [2005, 11819, 29, 15],
            [2005, 11820, 18, 14],
            [2005, 11821, 26, 17],
            [2005, 11822, 25, 16],
            [2005, 11823, 40, 22],
            [2005, 11824, 22, 19],
            [2005, 11825, 26, 18],
            [2005, 11826, 21, 19],
            [2005, 11827, 21, 18],
            [2005, 11828, 16, 13],
            [2005, 11829, 24, 22],
            [2005, 11830, 14, 12],
            [2005, 11831, 18, 17],
            [2005, 11832, 29, 19],
            [2005, 11833, 26, 15],
            [2005, 11834, 6, 6],
            [2005, 11835, 25, 13],
            [2005, 11836, 27, 18],
            [2005, 11837, 11, 11],
            [2005, 11838, 7, 6],
            [2005, 11839, 12, 11],
            [2005, 11840, 8, 7],
            [2005, 11841, 6, 5],
            [2005, 11842, 22, 17],
            [2005, 11843, 25, 21],
            [2005, 11844, 20, 21],
            [2005, 11845, 23, 19],
            [2005, 11846, 32, 21],
            [2005, 11847, 23, 18],
            [2005, 11848, 15, 12],
            [2005, 11849, 23, 18],
            [2005, 11850, 17, 13],
            [2005, 11851, 24, 17],
            [2005, 11852, 21, 18],
            [2005, 11853, 22, 15],
            [2005, 11854, 18, 20],
            [2005, 11855, 17, 16],
            [2005, 11856, 25, 25],
            [2005, 11858, 75, 85],
            [2005, 11859, 75, 85],
            [2005, 11860, 65, 85],
            [2006, 25, 12, 9],
            [2006, 48, 46, 31],
            [2006, 49, 26, 19],
            [2006, 62, 18, 24],
            [2006, 65, 18, 16],
            [2006, 82, 15, 16],
            [2006, 83, 28, 30],
            [2006, 101, 42, 33],
            [2006, 119, 31, 22],
            [2006, 163, 31, 29],
            [2006, 200, 31, 23],
            [2006, 204, 15, 24],
            [2006, 220, 11, 14],
            [2006, 226, 21, 19],
            [2006, 231, 44, 31],
            [2006, 233, 17, 18],
            [2006, 234, 12, 12],
            [2006, 240, 63, 37],
            [2006, 246, 31, 18],
            [2006, 282, 37, 26],
            [2006, 310, 13, 15],
            [2006, 314, 17, 22],
            [2006, 324, 32, 27],
            [2006, 327, 35, 30],
            [2006, 346, 42, 34],
            [2006, 355, 35, 27],
            [2006, 379, 13, 12],
            [2006, 389, 24, 24],
            [2006, 399, 46, 28],
            [2006, 425, 11, 17],
            [2006, 430, 18, 20],
            [2006, 436, 41, 34],
            [2006, 479, 43, 34],
            [2006, 480, 50, 28],
            [2006, 503, 95, 27],
            [2006, 504, 9, 10],
            [2006, 541, 112, 41],
            [2006, 585, 44, 31],
            [2006, 590, 43, 49],
            [2006, 593, 42, 34],
            [2006, 597, 31, 14],
            [2006, 604, 96, 52],
            [2006, 612, 27, 27],
            [2006, 618, 20, 16],
            [2006, 662, 46, 39],
            [2006, 663, 54, 27],
            [2006, 669, 25, 17],
            [2006, 686, 17, 18],
            [2006, 694, 30, 24],
            [2006, 700, 42, 33],
            [2006, 703, 15, 15],
            [2006, 716, 42, 35],
            [2006, 734, 19, 23],
            [2006, 751, 25, 20],
            [2006, 766, 77, 41],
            [2006, 769, 46, 29],
            [2006, 803, 26, 24],
            [2006, 805, 22, 20],
            [2006, 820, 50, 29],
            [2006, 822, 14, 18],
            [2006, 827, 11, 13],
            [2006, 845, 42, 37],
            [2006, 865, 70, 27],
            [2006, 871, 31, 19],
            [2006, 878, 7, 6],
            [2006, 882, 36, 27],
            [2006, 894, 18, 13],
            [2006, 913, 17, 17],
            [2006, 922, 27, 31],
            [2006, 938, 11, 12],
            [2006, 940, 11, 13],
            [2006, 941, 33, 35],
            [2006, 964, 11, 15],
            [2006, 969, 40, 33],
            [2006, 971, 11, 11],
            [2006, 985, 57, 36],
            [2006, 998, 36, 28],
            [2006, 1003, 8, 6],
            [2006, 1008, 33, 33],
            [2006, 1016, 8, 10],
            [2006, 1030, 9, 12],
            [2006, 1048, 34, 32],
            [2006, 1056, 21, 30],
            [2006, 1059, 46, 45],
            [2006, 1106, 52, 29],
            [2006, 1111, 38, 38],
            [2006, 1132, 11, 12],
            [2006, 1136, 32, 30],
            [2006, 1145, 25, 20],
            [2006, 1150, 26, 21],
            [2006, 1156, 23, 17],
            [2006, 1157, 34, 31],
            [2006, 1159, 73, 28],
            [2006, 1174, 24, 31],
            [2006, 1186, 15, 15],
            [2006, 1203, 11, 17],
            [2006, 1213, 18, 16],
            [2006, 1221, 15, 17],
            [2006, 1226, 28, 23],
            [2006, 1234, 14, 15],
            [2006, 1235, 23, 18],
            [2006, 1238, 14, 21],
            [2006, 1247, 34, 24],
            [2006, 1254, 44, 23],
            [2006, 1268, 28, 24],
            [2006, 1275, 26, 17],
            [2006, 1281, 11, 11],
            [2006, 1295, 36, 33],
            [2006, 1302, 40, 43],
            [2006, 1303, 51, 31],
            [2006, 1320, 34, 34],
            [2006, 1396, 13, 16],
            [2006, 1420, 49, 40],
            [2006, 1445, 63, 23],
            [2006, 1456, 22, 21],
            [2006, 1466, 25, 22],
            [2006, 1473, 13, 10],
            [2006, 1481, 32, 22],
            [2006, 1491, 11, 8],
            [2006, 1507, 33, 28],
            [2006, 1515, 18, 15],
            [2006, 1525, 33, 31],
            [2006, 1530, 65, 41],
            [2006, 1536, 17, 21],
            [2006, 1557, 38, 27],
            [2006, 1577, 23, 17],
            [2006, 1580, 35, 29],
            [2006, 1587, 14, 15],
            [2006, 1589, 39, 23],
            [2006, 1598, 11, 8],
            [2006, 1628, 28, 17],
            [2006, 1635, 17, 13],
            [2006, 1638, 40, 30],
            [2006, 1645, 48, 30],
            [2006, 1673, 74, 40],
            [2006, 1685, 30, 28],
            [2006, 1704, 16, 15],
            [2006, 1717, 44, 31],
            [2006, 1730, 14, 11],
            [2006, 1769, 43, 36],
            [2006, 1772, 10, 12],
            [2006, 1774, 21, 18],
            [2006, 1794, 27, 25],
            [2006, 1795, 12, 9],
            [2006, 1797, 44, 28],
            [2006, 1798, 34, 34],
            [2006, 1824, 61, 34],
            [2006, 1841, 32, 31],
            [2006, 1845, 21, 21],
            [2006, 1864, 98, 58],
            [2006, 1866, 37, 24],
            [2006, 1891, 29, 22],
            [2006, 1894, 26, 15],
            [2006, 1903, 53, 28],
            [2006, 1921, 13, 11],
            [2006, 1930, 10, 8],
            [2006, 1952, 160, 59],
            [2006, 1962, 12, 13],
            [2006, 1965, 58, 35],
            [2006, 2011, 19, 18],
            [2006, 2017, 36, 30],
            [2006, 2023, 7, 7],
            [2006, 2035, 39, 28],
            [2006, 2048, 15, 26],
            [2006, 2056, 22, 39],
            [2006, 2064, 45, 28],
            [2006, 2098, 12, 15],
            [2006, 2142, 9, 10],
            [2006, 2178, 15, 14],
            [2006, 2190, 25, 19],
            [2006, 2198, 17, 15],
            [2006, 2208, 70, 37],
            [2006, 2213, 36, 28],
            [2006, 2227, 15, 17],
            [2006, 2244, 20, 20],
            [2006, 2250, 36, 25],
            [2006, 2277, 24, 18],
            [2006, 2280, 13, 10],
            [2006, 2282, 17, 39],
            [2006, 2300, 43, 34],
            [2006, 2311, 28, 26],
            [2006, 2316, 42, 31],
            [2006, 2343, 35, 25],
            [2006, 2352, 36, 28],
            [2006, 2371, 44, 28],
            [2006, 2384, 22, 24],
            [2006, 2429, 15, 16],
            [2006, 2435, 14, 16],
            [2006, 2443, 41, 28],
            [2006, 2458, 28, 21],
            [2006, 2459, 19, 18],
            [2006, 2467, 14, 14],
            [2006, 2483, 39, 42],
            [2006, 2485, 18, 14],
            [2006, 2500, 23, 17],
            [2006, 2501, 44, 30],
            [2006, 2505, 38, 25],
            [2006, 2524, 10, 9],
            [2006, 2533, 10, 16],
            [2006, 2539, 73, 23],
            [2006, 2547, 15, 28],
            [2006, 2554, 11, 20],
            [2006, 2576, 52, 30],
            [2006, 2585, 40, 28],
            [2006, 2595, 34, 29],
            [2006, 2606, 13, 13],
            [2006, 2627, 37, 24],
            [2006, 2635, 14, 15],
            [2006, 2670, 34, 23],
            [2006, 2671, 39, 36],
            [2006, 2692, 30, 23],
            [2006, 2695, 17, 13],
            [2006, 2720, 26, 28],
            [2006, 2723, 34, 34],
            [2006, 2758, 30, 25],
            [2006, 2775, 44, 28],
            [2006, 2785, 10, 11],
            [2006, 2798, 16, 17],
            [2006, 2822, 22, 18],
            [2006, 2835, 23, 21],
            [2006, 2836, 17, 17],
            [2006, 2879, 20, 18],
            [2006, 2883, 33, 36],
            [2006, 2914, 39, 26],
            [2006, 2922, 13, 14],
            [2006, 2991, 34, 26],
            [2006, 3019, 39, 21],
            [2006, 3033, 57, 43],
            [2006, 3046, 47, 22],
            [2006, 3053, 51, 34],
            [2006, 3066, 41, 28],
            [2006, 3086, 124, 48],
            [2006, 3091, 12, 14],
            [2006, 3092, 40, 27],
            [2006, 3119, 11, 19],
            [2006, 3126, 32, 24],
            [2006, 3134, 30, 31],
            [2006, 3142, 24, 29],
            [2006, 3158, 18, 20],
            [2006, 3164, 40, 30],
            [2006, 3171, 28, 17],
            [2006, 3182, 107, 40],
            [2006, 3221, 38, 29],
            [2006, 3246, 77, 38],
            [2006, 3252, 39, 26],
            [2006, 3254, 21, 25],
            [2006, 3273, 48, 30],
            [2006, 3274, 20, 18],
            [2006, 3301, 34, 28],
            [2006, 3308, 46, 29],
            [2006, 3309, 33, 33],
            [2006, 3321, 36, 24],
            [2006, 3327, 36, 28],
            [2006, 3348, 41, 28],
            [2006, 3364, 11, 14],
            [2006, 3372, 40, 28],
            [2006, 3382, 26, 17],
            [2006, 3434, 7, 7],
            [2006, 3438, 44, 25],
            [2006, 3451, 58, 41],
            [2006, 3454, 11, 11],
            [2006, 3459, 23, 19],
            [2006, 3462, 40, 23],
            [2006, 3494, 11, 12],
            [2006, 3503, 88, 43],
            [2006, 3515, 13, 33],
            [2006, 3517, 37, 27],
            [2006, 3559, 34, 27],
            [2006, 3569, 43, 44],
            [2006, 3579, 16, 26],
            [2006, 3590, 17, 22],
            [2006, 3593, 48, 49],
            [2006, 3659, 37, 27],
            [2006, 3669, 14, 18],
            [2006, 3700, 19, 17],
            [2006, 3718, 43, 31],
            [2006, 3726, 13, 12],
            [2006, 3729, 134, 46],
            [2006, 3765, 14, 18],
            [2006, 3833, 30, 30],
            [2006, 3859, 11, 15],
            [2006, 3884, 42, 26],
            [2006, 3889, 45, 24],
            [2006, 3925, 45, 30],
            [2006, 3943, 22, 22],
            [2006, 3956, 38, 46],
            [2006, 3972, 134, 64],
            [2006, 3976, 17, 17],
            [2006, 3985, 21, 19],
            [2006, 3993, 15, 15],
            [2006, 4015, 41, 26],
            [2006, 4022, 42, 27],
            [2006, 4026, 24, 16],
            [2006, 4027, 47, 28],
            [2006, 4028, 21, 20],
            [2006, 4043, 17, 16],
            [2006, 4074, 17, 23],
            [2006, 4091, 31, 28],
            [2006, 4107, 48, 26],
            [2006, 4125, 15, 16],
            [2006, 4165, 32, 30],
            [2006, 4173, 15, 17],
            [2006, 4176, 10, 12],
            [2006, 4209, 36, 33],
            [2006, 4246, 12, 21],
            [2006, 4285, 24, 28],
            [2006, 4299, 31, 22],
            [2006, 4301, 44, 46],
            [2006, 4310, 25, 25],
            [2006, 4312, 36, 26],
            [2006, 4325, 41, 22],
            [2006, 4353, 22, 14],
            [2006, 4358, 12, 13],
            [2006, 4362, 67, 40],
            [2006, 4380, 16, 19],
            [2006, 4382, 83, 29],
            [2006, 4386, 18, 19],
            [2006, 4413, 11, 11],
            [2006, 4414, 16, 22],
            [2006, 4426, 15, 15],
            [2006, 4440, 35, 27],
            [2006, 4442, 16, 20],
            [2006, 4454, 12, 11],
            [2006, 4464, 42, 24],
            [2006, 4470, 23, 22],
            [2006, 4477, 26, 28],
            [2006, 4487, 19, 24],
            [2006, 4491, 38, 27],
            [2006, 4518, 48, 31],
            [2006, 4536, 18, 18],
            [2006, 4545, 37, 29],
            [2006, 4610, 48, 28],
            [2006, 4617, 115, 44],
            [2006, 4618, 22, 19],
            [2006, 4623, 17, 19],
            [2006, 4626, 27, 17],
            [2006, 4634, 24, 23],
            [2006, 4638, 76, 29],
            [2006, 4644, 13, 17],
            [2006, 4648, 32, 23],
            [2006, 4660, 45, 28],
            [2006, 4670, 42, 28],
            [2006, 4676, 12, 15],
            [2006, 4689, 36, 25],
            [2006, 4710, 8, 6],
            [2006, 4724, 24, 17],
            [2006, 4732, 50, 58],
            [2006, 4734, 13, 14],
            [2006, 4738, 32, 34],
            [2006, 4745, 20, 19],
            [2006, 4749, 34, 27],
            [2006, 4762, 37, 32],
            [2006, 4764, 21, 26],
            [2006, 4789, 43, 25],
            [2006, 4794, 20, 17],
            [2006, 4801, 14, 18],
            [2006, 4805, 12, 17],
            [2006, 4820, 39, 32],
            [2006, 4828, 59, 44],
            [2006, 4832, 17, 20],
            [2006, 4840, 44, 27],
            [2006, 4849, 17, 17],
            [2006, 4863, 37, 30],
            [2006, 4865, 26, 18],
            [2006, 4871, 12, 16],
            [2006, 4880, 17, 19],
            [2006, 4888, 39, 32],
            [2006, 4897, 13, 17],
            [2006, 4912, 10, 20],
            [2006, 4914, 22, 17],
            [2006, 4918, 18, 16],
            [2006, 4926, 47, 43],
            [2006, 4939, 20, 17],
            [2006, 4944, 15, 14],
            [2006, 4951, 28, 28],
            [2006, 4973, 29, 29],
            [2006, 4976, 11, 12],
            [2006, 4978, 48, 36],
            [2006, 4983, 15, 12],
            [2006, 4992, 18, 17],
            [2006, 5006, 72, 33],
            [2006, 5019, 55, 37],
            [2006, 5031, 10, 12],
            [2006, 5038, 14, 16],
            [2006, 5048, 29, 25],
            [2006, 5050, 22, 18],
            [2006, 5051, 12, 15],
            [2006, 5062, 35, 21],
            [2006, 5063, 19, 24],
            [2006, 5073, 51, 33],
            [2006, 5081, 31, 21],
            [2006, 5091, 70, 31],
            [2006, 5092, 11, 14],
            [2006, 5095, 14, 15],
            [2006, 5107, 85, 28],
            [2006, 5108, 18, 23],
            [2006, 5130, 43, 37],
            [2006, 5149, 19, 17],
            [2006, 5159, 55, 31],
            [2006, 5184, 28, 19],
            [2006, 5185, 24, 15],
            [2006, 5186, 14, 15],
            [2006, 5187, 14, 16],
            [2006, 5188, 16, 19],
            [2006, 5189, 15, 10],
            [2006, 5217, 41, 31],
            [2006, 5219, 17, 34],
            [2006, 5220, 15, 37],
            [2006, 5221, 11, 25],
            [2006, 5222, 16, 20],
            [2006, 5223, 11, 24],
            [2006, 5224, 16, 34],
            [2006, 5225, 15, 35],
            [2006, 5226, 12, 37],
            [2006, 5227, 27, 47],
            [2006, 5228, 18, 45],
            [2006, 5229, 11, 31],
            [2006, 5230, 15, 29],
            [2006, 5231, 12, 26],
            [2006, 5232, 18, 38],
            [2006, 5233, 23, 50],
            [2006, 5234, 10, 19],
            [2006, 5235, 33, 31],
            [2006, 5236, 15, 30],
            [2006, 5237, 23, 39],
            [2006, 5238, 15, 27],
            [2006, 5239, 21, 44],
            [2006, 5240, 19, 50],
            [2006, 5241, 24, 44],
            [2006, 5242, 18, 30],
            [2006, 5243, 23, 48],
            [2006, 5244, 20, 50],
            [2006, 5245, 24, 48],
            [2006, 5247, 27, 13],
            [2006, 5248, 29, 18],
            [2006, 5273, 22, 15],
            [2006, 5276, 23, 30],
            [2006, 5279, 21, 20],
            [2006, 5287, 12, 12],
            [2006, 5290, 20, 18],
            [2006, 5298, 14, 14],
            [2006, 5299, 20, 17],
            [2006, 5303, 27, 19],
            [2006, 5305, 20, 16],
            [2006, 5314, 18, 19],
            [2006, 5315, 20, 21],
            [2006, 5317, 27, 32],
            [2006, 5321, 23, 23],
            [2006, 5323, 19, 19],
            [2006, 5328, 15, 14],
            [2006, 5332, 17, 20],
            [2006, 5333, 14, 14],
            [2006, 5336, 15, 13],
            [2006, 5337, 15, 14],
            [2006, 5338, 24, 21],
            [2006, 5339, 21, 23],
            [2006, 5340, 21, 22],
            [2006, 5343, 13, 11],
            [2006, 5344, 30, 28],
            [2006, 5347, 17, 18],
            [2006, 5349, 20, 20],
            [2006, 5350, 20, 21],
            [2006, 5353, 21, 19],
            [2006, 5355, 15, 16],
            [2006, 5357, 20, 19],
            [2006, 5359, 16, 20],
            [2006, 5366, 21, 18],
            [2006, 5371, 25, 25],
            [2006, 5372, 20, 18],
            [2006, 5375, 14, 14],
            [2006, 5377, 20, 19],
            [2006, 5383, 20, 27],
            [2006, 5385, 22, 20],
            [2006, 5387, 14, 12],
            [2006, 5400, 14, 13],
            [2006, 5403, 23, 21],
            [2006, 5404, 18, 18],
            [2006, 5407, 17, 19],
            [2006, 5408, 20, 20],
            [2006, 5411, 20, 14],
            [2006, 5412, 20, 20],
            [2006, 5414, 13, 13],
            [2006, 5415, 21, 20],
            [2006, 5418, 20, 23],
            [2006, 5420, 15, 14],
            [2006, 5421, 19, 15],
            [2006, 5422, 25, 23],
            [2006, 5425, 16, 17],
            [2006, 5426, 16, 18],
            [2006, 5428, 19, 22],
            [2006, 5431, 19, 17],
            [2006, 5432, 21, 23],
            [2006, 5434, 10, 11],
            [2006, 5436, 16, 16],
            [2006, 5437, 22, 19],
            [2006, 5440, 24, 21],
            [2006, 5441, 20, 23],
            [2006, 5444, 22, 26],
            [2006, 5447, 17, 17],
            [2006, 5449, 20, 23],
            [2006, 5450, 20, 21],
            [2006, 5452, 21, 21],
            [2006, 5453, 22, 22],
            [2006, 5454, 14, 14],
            [2006, 5455, 18, 16],
            [2006, 5457, 13, 19],
            [2006, 5459, 15, 15],
            [2006, 5462, 18, 20],
            [2006, 5463, 13, 13],
            [2006, 5464, 17, 18],
            [2006, 5465, 21, 18],
            [2006, 5472, 21, 20],
            [2006, 5473, 20, 17],
            [2006, 5476, 15, 17],
            [2006, 5479, 16, 16],
            [2006, 5480, 23, 21],
            [2006, 5482, 18, 16],
            [2006, 5486, 18, 18],
            [2006, 5489, 22, 30],
            [2006, 5492, 22, 25],
            [2006, 5494, 21, 21],
            [2006, 5495, 20, 16],
            [2006, 5498, 29, 27],
            [2006, 5499, 18, 20],
            [2006, 5501, 23, 28],
            [2006, 5505, 19, 20],
            [2006, 5508, 21, 22],
            [2006, 5528, 13, 12],
            [2006, 5532, 21, 18],
            [2006, 5534, 17, 14],
            [2006, 5539, 21, 17],
            [2006, 5541, 20, 18],
            [2006, 5544, 20, 20],
            [2006, 5545, 20, 20],
            [2006, 5547, 29, 27],
            [2006, 5550, 17, 17],
            [2006, 5571, 23, 19],
            [2006, 5944, 7, 7],
            [2006, 5945, 8, 9],
            [2006, 5946, 6, 5],
            [2006, 5962, 68, 73],
            [2006, 5989, 210, 163],
            [2006, 5990, 210, 163],
            [2006, 5991, 210, 163],
            [2006, 5992, 210, 171],
            [2006, 5993, 210, 163],
            [2006, 5996, 38, 25],
            [2006, 6068, 38, 29],
            [2006, 6069, 43, 35],
            [2006, 6070, 40, 32],
            [2006, 6071, 28, 23],
            [2006, 6073, 25, 27],
            [2006, 6074, 33, 28],
            [2006, 6075, 30, 35],
            [2006, 6076, 31, 27],
            [2006, 6077, 29, 26],
            [2006, 6078, 31, 31],
            [2006, 6079, 35, 28],
            [2006, 6080, 26, 32],
            [2006, 6081, 20, 23],
            [2006, 6082, 33, 28],
            [2006, 6083, 31, 25],
            [2006, 6084, 39, 27],
            [2006, 6085, 35, 29],
            [2006, 6087, 28, 25],
            [2006, 6088, 25, 27],
            [2006, 6089, 28, 25],
            [2006, 6090, 43, 29],
            [2006, 6091, 20, 24],
            [2006, 6092, 31, 28],
            [2006, 6093, 38, 34],
            [2006, 6094, 33, 28],
            [2006, 6095, 20, 20],
            [2006, 6096, 31, 23],
            [2006, 6097, 34, 25],
            [2006, 6098, 30, 24],
            [2006, 6099, 28, 27],
            [2006, 6100, 25, 28],
            [2006, 6101, 25, 23],
            [2006, 6102, 23, 22],
            [2006, 6103, 31, 25],
            [2006, 6104, 35, 24],
            [2006, 6105, 28, 27],
            [2006, 6106, 26, 23],
            [2006, 6108, 32, 26],
            [2006, 6109, 19, 22],
            [2006, 6110, 31, 28],
            [2006, 6111, 15, 19],
            [2006, 6112, 23, 27],
            [2006, 6113, 23, 23],
            [2006, 6114, 30, 23],
            [2006, 6115, 22, 24],
            [2006, 6116, 24, 25],
            [2006, 6117, 26, 25],
            [2006, 6118, 40, 28],
            [2006, 6119, 28, 27],
            [2006, 6120, 20, 21],
            [2006, 6121, 20, 24],
            [2006, 6122, 28, 24],
            [2006, 6123, 23, 23],
            [2006, 6124, 30, 25],
            [2006, 6125, 26, 31],
            [2006, 6126, 27, 26],
            [2006, 6127, 24, 28],
            [2006, 6128, 24, 28],
            [2006, 6130, 28, 26],
            [2006, 6131, 31, 25],
            [2006, 6132, 33, 28],
            [2006, 6133, 31, 25],
            [2006, 6134, 31, 25],
            [2006, 6135, 40, 35],
            [2006, 6136, 54, 45],
            [2006, 6137, 17, 19],
            [2006, 6138, 24, 26],
            [2006, 6139, 28, 26],
            [2006, 6140, 20, 23],
            [2006, 6141, 23, 27],
            [2006, 6142, 18, 25],
            [2006, 6143, 26, 25],
            [2006, 6145, 29, 28],
            [2006, 6146, 15, 19],
            [2006, 6147, 20, 26],
            [2006, 6148, 20, 23],
            [2006, 6149, 27, 28],
            [2006, 6150, 16, 20],
            [2006, 6151, 21, 20],
            [2006, 6152, 18, 20],
            [2006, 6153, 19, 22],
            [2006, 6154, 23, 27],
            [2006, 6155, 20, 22],
            [2006, 6156, 25, 23],
            [2006, 6157, 30, 26],
            [2006, 6158, 21, 22],
            [2006, 6159, 29, 26],
            [2006, 6160, 21, 22],
            [2006, 6161, 18, 19],
            [2006, 6162, 20, 20],
            [2006, 6163, 35, 32],
            [2006, 6164, 30, 27],
            [2006, 6165, 24, 23],
            [2006, 6166, 37, 27],
            [2006, 6167, 31, 33],
            [2006, 6244, 47, 29],
            [2006, 6353, 45, 39],
            [2006, 6357, 34, 34],
            [2006, 6358, 39, 35],
            [2006, 6360, 103, 59],
            [2006, 6361, 101, 53],
            [2006, 6371, 117, 102],
            [2006, 6374, 107, 122],
            [2006, 6375, 173, 64],
            [2006, 6380, 75, 42],
            [2006, 6382, 71, 48],
            [2006, 6385, 97, 86],
            [2006, 6388, 146, 82],
            [2006, 6391, 61, 40],
            [2006, 6393, 164, 143],
            [2006, 6395, 83, 44],
            [2006, 6400, 94, 61],
            [2006, 6405, 136, 47],
            [2006, 6408, 272, 87],
            [2006, 6411, 58, 44],
            [2006, 6412, 79, 88],
            [2006, 6413, 98, 76],
            [2006, 6414, 123, 57],
            [2006, 6416, 121, 62],
            [2006, 6421, 57, 53],
            [2006, 6422, 74, 62],
            [2006, 6425, 71, 40],
            [2006, 6426, 80, 69],
            [2006, 6430, 48, 60],
            [2006, 6431, 62, 63],
            [2006, 6432, 110, 96],
            [2006, 6433, 39, 35],
            [2006, 6436, 140, 57],
            [2006, 6438, 71, 59],
            [2006, 6441, 47, 47],
            [2006, 6442, 47, 32],
            [2006, 6448, 65, 47],
            [2006, 6450, 146, 115],
            [2006, 6452, 164, 86],
            [2006, 6462, 103, 81],
            [2006, 6463, 88, 85],
            [2006, 6467, 181, 170],
            [2006, 6469, 64, 81],
            [2006, 6471, 54, 43],
            [2006, 6474, 117, 67],
            [2006, 6476, 68, 46],
            [2006, 6477, 178, 91],
            [2006, 6478, 120, 45],
            [2006, 6483, 87, 63],
            [2006, 6486, 177, 73],
            [2006, 6489, 95, 47],
            [2006, 6492, 26, 30],
            [2006, 6494, 29, 25],
            [2006, 6495, 58, 45],
            [2006, 6496, 63, 46],
            [2006, 6499, 127, 98],
            [2006, 6502, 36, 40],
            [2006, 6512, 54, 46],
            [2006, 6514, 140, 93],
            [2006, 6515, 125, 67],
            [2006, 6516, 88, 115],
            [2006, 6518, 79, 80],
            [2006, 6519, 167, 159],
            [2006, 6521, 52, 34],
            [2006, 6524, 126, 109],
            [2006, 6527, 49, 47],
            [2006, 6529, 104, 107],
            [2006, 6530, 53, 43],
            [2006, 6532, 56, 45],
            [2006, 6534, 58, 59],
            [2006, 6565, 125, 89],
            [2006, 6566, 51, 40],
            [2006, 6568, 59, 47],
            [2006, 6570, 117, 70],
            [2006, 6576, 49, 47],
            [2006, 6581, 155, 98],
            [2006, 6584, 107, 48],
            [2006, 6585, 53, 49],
            [2006, 6587, 99, 70],
            [2006, 6589, 139, 55],
            [2006, 6590, 168, 79],
            [2006, 6602, 93, 44],
            [2006, 6607, 114, 51],
            [2006, 6609, 74, 52],
            [2006, 6612, 85, 70],
            [2006, 6614, 29, 29],
            [2006, 6615, 65, 50],
            [2006, 6616, 73, 94],
            [2006, 6621, 103, 46],
            [2006, 6623, 103, 78],
            [2006, 6630, 72, 84],
            [2006, 6631, 36, 36],
            [2006, 6633, 23, 26],
            [2006, 6634, 30, 27],
            [2006, 6635, 35, 29],
            [2006, 6636, 38, 38],
            [2006, 6637, 28, 27],
            [2006, 6638, 43, 31],
            [2006, 6639, 28, 33],
            [2006, 6640, 25, 56],
            [2006, 6643, 37, 23],
            [2006, 6649, 39, 26],
            [2006, 6650, 39, 27],
            [2006, 6651, 29, 21],
            [2006, 6652, 28, 28],
            [2006, 6653, 37, 31],
            [2006, 6654, 37, 26],
            [2006, 6655, 28, 23],
            [2006, 6656, 30, 27],
            [2006, 6657, 24, 29],
            [2006, 6660, 34, 22],
            [2006, 6661, 28, 25],
            [2006, 6662, 28, 28],
            [2006, 6663, 28, 26],
            [2006, 6664, 40, 29],
            [2006, 6665, 27, 28],
            [2006, 6666, 27, 25],
            [2006, 6667, 28, 27],
            [2006, 6668, 28, 21],
            [2006, 6669, 24, 29],
            [2006, 6670, 29, 26],
            [2006, 6671, 38, 27],
            [2006, 6672, 31, 24],
            [2006, 6673, 33, 25],
            [2006, 6674, 30, 28],
            [2006, 6675, 28, 25],
            [2006, 6676, 38, 32],
            [2006, 6677, 27, 28],
            [2006, 6678, 28, 25],
            [2006, 6679, 54, 45],
            [2006, 6680, 26, 23],
            [2006, 6682, 26, 24],
            [2006, 6683, 23, 24],
            [2006, 6684, 26, 28],
            [2006, 6685, 20, 23],
            [2006, 6686, 20, 23],
            [2006, 6687, 20, 25],
            [2006, 6688, 20, 23],
            [2006, 6689, 22, 24],
            [2006, 6690, 20, 23],
            [2006, 6699, 25, 73],
            [2006, 6700, 75, 36],
            [2006, 6701, 61, 38],
            [2006, 6702, 35, 23],
            [2006, 6704, 74, 40],
            [2006, 6715, 39, 32],
            [2006, 6716, 30, 29],
            [2006, 6718, 31, 50],
            [2006, 6722, 35, 29],
            [2006, 6723, 77, 45],
            [2006, 6726, 45, 60],
            [2006, 6728, 51, 32],
            [2006, 6734, 50, 36],
            [2006, 6737, 31, 85],
            [2006, 6738, 64, 44],
            [2006, 6741, 14, 15],
            [2006, 6748, 26, 24],
            [2006, 6749, 26, 25],
            [2006, 6750, 36, 35],
            [2006, 6752, 18, 23],
            [2006, 6753, 31, 29],
            [2006, 6754, 31, 28],
            [2006, 6755, 38, 35],
            [2006, 6756, 28, 31],
            [2006, 6757, 28, 27],
            [2006, 6758, 28, 36],
            [2006, 6759, 20, 23],
            [2006, 6760, 36, 35],
            [2006, 6761, 31, 34],
            [2006, 6762, 31, 32],
            [2006, 6763, 21, 20],
            [2006, 6764, 30, 32],
            [2006, 6766, 43, 36],
            [2006, 6767, 31, 27],
            [2006, 6768, 30, 28],
            [2006, 6769, 35, 40],
            [2006, 6770, 32, 34],
            [2006, 6771, 24, 33],
            [2006, 6772, 24, 28],
            [2006, 6773, 38, 36],
            [2006, 6777, 40, 37],
            [2006, 6778, 23, 26],
            [2006, 6779, 32, 33],
            [2006, 6780, 34, 33],
            [2006, 6781, 37, 33],
            [2006, 6782, 53, 41],
            [2006, 6783, 32, 37],
            [2006, 6784, 26, 32],
            [2006, 6785, 40, 31],
            [2006, 6786, 32, 34],
            [2006, 6787, 30, 33],
            [2006, 6789, 33, 33],
            [2006, 6790, 35, 101],
            [2006, 6791, 89, 85],
            [2006, 6794, 21, 40],
            [2006, 6795, 42, 62],
            [2006, 6798, 35, 27],
            [2006, 6803, 31, 76],
            [2006, 6804, 50, 101],
            [2006, 6805, 75, 132],
            [2006, 6806, 30, 62],
            [2006, 6807, 35, 45],
            [2006, 6808, 21, 40],
            [2006, 6812, 166, 75],
            [2006, 6813, 31, 60],
            [2006, 6814, 126, 103],
            [2006, 6816, 81, 90],
            [2006, 6818, 17, 18],
            [2006, 6819, 31, 38],
            [2006, 6820, 31, 31],
            [2006, 6821, 48, 39],
            [2006, 6822, 44, 42],
            [2006, 6823, 30, 33],
            [2006, 6833, 61, 48],
            [2006, 6834, 151, 103],
            [2006, 6835, 280, 135],
            [2006, 6836, 40, 60],
            [2006, 6837, 21, 28],
            [2006, 6838, 135, 90],
            [2006, 6841, 28, 21],
            [2006, 6845, 31, 61],
            [2006, 6846, 38, 56],
            [2006, 6847, 40, 45],
            [2006, 6848, 40, 21],
            [2006, 6849, 70, 43],
            [2006, 6850, 45, 49],
            [2006, 6851, 21, 46],
            [2006, 6852, 85, 124],
            [2006, 6853, 31, 53],
            [2006, 6854, 151, 79],
            [2006, 6855, 40, 40],
            [2006, 6856, 30, 54],
            [2006, 6857, 35, 73],
            [2006, 6858, 50, 53],
            [2006, 6859, 57, 47],
            [2006, 6860, 25, 31],
            [2006, 6861, 30, 49],
            [2006, 6862, 35, 40],
            [2006, 6867, 14, 20],
            [2006, 6868, 15, 15],
            [2006, 6869, 15, 15],
            [2006, 6870, 15, 17],
            [2006, 6871, 16, 17],
            [2006, 6872, 15, 17],
            [2006, 6873, 20, 16],
            [2006, 6874, 11, 16],
            [2006, 6875, 14, 17],
            [2006, 6876, 11, 15],
            [2006, 6877, 18, 23],
            [2006, 6878, 14, 16],
            [2006, 6879, 16, 20],
            [2006, 6880, 19, 19],
            [2006, 6881, 11, 13],
            [2006, 6882, 15, 17],
            [2006, 6883, 19, 21],
            [2006, 6910, 54, 43],
            [2006, 6912, 19, 11],
            [2006, 6914, 12, 12],
            [2006, 6918, 28, 23],
            [2006, 6920, 20, 19],
            [2006, 6922, 12, 11],
            [2006, 6928, 17, 16],
            [2006, 6930, 20, 16],
            [2006, 6931, 35, 33],
            [2006, 6934, 16, 15],
            [2006, 6938, 16, 14],
            [2006, 6940, 12, 11],
            [2006, 6942, 19, 17],
            [2006, 6944, 11, 10],
            [2006, 6948, 12, 11],
            [2006, 6950, 13, 11],
            [2006, 6952, 47, 22],
            [2006, 6954, 25, 16],
            [2006, 6957, 62, 49],
            [2006, 6958, 13, 11],
            [2006, 6960, 15, 15],
            [2006, 6962, 13, 11],
            [2006, 6965, 9, 10],
            [2006, 6966, 21, 34],
            [2006, 6967, 16, 35],
            [2006, 6968, 33, 55],
            [2006, 6969, 19, 33],
            [2006, 6970, 21, 33],
            [2006, 7007, 49, 24],
            [2006, 7008, 60, 28],
            [2006, 7011, 10, 10],
            [2006, 7013, 21, 17],
            [2006, 7014, 14, 9],
            [2006, 7015, 8, 8],
            [2006, 7019, 11, 9],
            [2006, 7021, 12, 11],
            [2006, 7027, 16, 16],
            [2006, 7029, 31, 25],
            [2006, 7031, 15, 19],
            [2006, 7033, 22, 19],
            [2006, 7035, 11, 12],
            [2006, 7039, 20, 14],
            [2006, 7050, 16, 14],
            [2006, 7052, 15, 18],
            [2006, 7054, 16, 15],
            [2006, 7056, 12, 14],
            [2006, 7057, 51, 35],
            [2006, 7058, 24, 16],
            [2006, 7062, 15, 13],
            [2006, 7063, 43, 29],
            [2006, 7066, 11, 12],
            [2006, 7068, 59, 25],
            [2006, 7070, 31, 28],
            [2006, 7072, 10, 11],
            [2006, 7074, 15, 14],
            [2006, 7076, 23, 18],
            [2006, 7078, 11, 11],
            [2006, 7080, 36, 31],
            [2006, 7082, 17, 16],
            [2006, 7084, 48, 23],
            [2006, 7086, 11, 13],
            [2006, 7088, 45, 25],
            [2006, 7090, 15, 11],
            [2006, 7091, 50, 33],
            [2006, 7092, 42, 31],
            [2006, 7093, 65, 51],
            [2006, 7094, 42, 30],
            [2006, 7098, 21, 22],
            [2006, 7156, 17, 18],
            [2006, 7259, 75, 49],
            [2006, 7260, 99, 76],
            [2006, 7261, 80, 63],
            [2006, 7262, 69, 70],
            [2006, 7263, 91, 74],
            [2006, 7264, 81, 81],
            [2006, 7265, 88, 72],
            [2006, 7266, 107, 80],
            [2006, 7267, 81, 65],
            [2006, 7268, 110, 82],
            [2006, 7269, 106, 79],
            [2006, 7270, 72, 47],
            [2006, 7271, 60, 55],
            [2006, 7272, 103, 76],
            [2006, 7273, 78, 78],
            [2006, 7274, 98, 71],
            [2006, 7275, 89, 73],
            [2006, 7276, 56, 46],
            [2006, 7277, 86, 69],
            [2006, 7278, 71, 73],
            [2006, 7279, 79, 58],
            [2006, 7280, 108, 80],
            [2006, 7281, 83, 66],
            [2006, 7282, 69, 70],
            [2006, 7283, 13, 19],
            [2006, 7284, 11, 10],
            [2006, 7285, 12, 11],
            [2006, 7286, 15, 20],
            [2006, 7287, 13, 23],
            [2006, 7288, 28, 28],
            [2006, 7289, 26, 21],
            [2006, 7290, 42, 31],
            [2006, 7291, 33, 28],
            [2006, 7292, 32, 34],
            [2006, 7293, 24, 21],
            [2006, 7294, 21, 20],
            [2006, 7295, 13, 14],
            [2006, 7296, 23, 20],
            [2006, 7297, 25, 22],
            [2006, 7298, 15, 16],
            [2006, 7299, 16, 18],
            [2006, 7300, 18, 24],
            [2006, 7301, 13, 22],
            [2006, 7302, 36, 40],
            [2006, 7303, 73, 68],
            [2006, 7304, 29, 31],
            [2006, 7305, 37, 37],
            [2006, 7306, 29, 32],
            [2006, 7307, 47, 50],
            [2006, 7308, 38, 40],
            [2006, 7309, 30, 32],
            [2006, 7310, 78, 65],
            [2006, 7311, 66, 63],
            [2006, 7312, 34, 36],
            [2006, 7328, 20, 25],
            [2006, 7329, 37, 36],
            [2006, 7330, 21, 16],
            [2006, 7337, 15, 12],
            [2006, 7342, 13, 10],
            [2006, 7343, 15, 8],
            [2006, 7344, 11, 9],
            [2006, 7348, 15, 8],
            [2006, 7352, 12, 11],
            [2006, 7354, 26, 15],
            [2006, 7356, 14, 11],
            [2006, 7357, 24, 15],
            [2006, 7358, 14, 10],
            [2006, 7359, 24, 15],
            [2006, 7360, 14, 10],
            [2006, 7362, 17, 12],
            [2006, 7363, 12, 10],
            [2006, 7364, 13, 11],
            [2006, 7367, 15, 12],
            [2006, 7370, 11, 10],
            [2006, 7371, 13, 10],
            [2006, 7372, 13, 10],
            [2006, 7373, 13, 10],
            [2006, 7374, 11, 8],
            [2006, 7375, 11, 8],
            [2006, 7376, 7, 8],
            [2006, 7377, 11, 8],
            [2006, 7378, 20, 18],
            [2006, 7379, 30, 23],
            [2006, 7398, 26, 39],
            [2006, 7399, 28, 30],
            [2006, 7401, 24, 34],
            [2006, 7403, 20, 26],
            [2006, 7405, 22, 28],
            [2006, 7406, 32, 35],
            [2006, 7407, 34, 45],
            [2006, 7410, 19, 27],
            [2006, 7411, 50, 46],
            [2006, 7413, 11, 13],
            [2006, 7414, 18, 25],
            [2006, 7415, 11, 14],
            [2006, 7416, 25, 31],
            [2006, 7417, 19, 17],
            [2006, 7420, 27, 30],
            [2006, 7421, 25, 29],
            [2006, 7423, 54, 60],
            [2006, 7433, 75, 55],
            [2006, 7434, 90, 90],
            [2006, 7435, 42, 75],
            [2006, 7436, 56, 77],
            [2006, 7437, 19, 18],
            [2006, 7438, 38, 30],
            [2006, 7441, 23, 15],
            [2006, 7442, 40, 21],
            [2006, 7443, 75, 108],
            [2006, 7444, 66, 108],
            [2006, 7445, 35, 73],
            [2006, 7446, 46, 80],
            [2006, 7447, 19, 18],
            [2006, 7448, 37, 30],
            [2006, 7449, 21, 21],
            [2006, 7450, 21, 20],
            [2006, 7451, 13, 13],
            [2006, 7452, 22, 19],
            [2006, 7453, 68, 45],
            [2006, 7454, 20, 15],
            [2006, 7455, 23, 21],
            [2006, 7456, 50, 46],
            [2006, 7457, 50, 39],
            [2006, 7458, 35, 32],
            [2006, 7459, 53, 45],
            [2006, 7460, 61, 52],
            [2006, 7461, 36, 32],
            [2006, 7462, 42, 38],
            [2006, 7463, 55, 40],
            [2006, 7464, 57, 43],
            [2006, 7465, 48, 36],
            [2006, 7466, 50, 34],
            [2006, 7467, 52, 46],
            [2006, 7468, 40, 36],
            [2006, 7469, 65, 38],
            [2006, 7470, 63, 46],
            [2006, 7471, 67, 51],
            [2006, 7472, 75, 52],
            [2006, 7473, 40, 36],
            [2006, 7474, 55, 45],
            [2006, 7475, 50, 45],
            [2006, 7476, 43, 37],
            [2006, 7477, 37, 34],
            [2006, 7478, 45, 36],
            [2006, 7479, 40, 36],
            [2006, 7480, 53, 43],
            [2006, 7481, 40, 37],
            [2006, 7482, 50, 36],
            [2006, 7483, 50, 45],
            [2006, 7484, 44, 40],
            [2006, 7485, 75, 55],
            [2006, 7486, 54, 40],
            [2006, 7487, 44, 37],
            [2006, 7488, 48, 36],
            [2006, 7489, 85, 40],
            [2006, 7490, 35, 34],
            [2006, 7491, 45, 37],
            [2006, 7492, 58, 43],
            [2006, 7493, 46, 39],
            [2006, 7494, 55, 39],
            [2006, 7495, 51, 45],
            [2006, 7496, 75, 56],
            [2006, 7497, 47, 36],
            [2006, 7498, 36, 37],
            [2006, 7499, 40, 32],
            [2006, 7500, 49, 43],
            [2006, 7501, 60, 47],
            [2006, 7502, 50, 38],
            [2006, 7503, 50, 39],
            [2006, 7504, 50, 33],
            [2006, 7505, 65, 39],
            [2006, 7506, 57, 43],
            [2006, 7507, 50, 37],
            [2006, 7508, 48, 38],
            [2006, 7509, 52, 45],
            [2006, 7510, 50, 45],
            [2006, 7511, 54, 40],
            [2006, 7512, 50, 45],
            [2006, 7513, 48, 36],
            [2006, 7514, 86, 65],
            [2006, 7515, 55, 40],
            [2006, 7516, 50, 45],
            [2006, 7517, 74, 55],
            [2006, 7518, 58, 43],
            [2006, 7519, 41, 38],
            [2006, 7520, 45, 40],
            [2006, 7521, 35, 36],
            [2006, 7522, 63, 46],
            [2006, 7523, 45, 39],
            [2006, 7524, 61, 55],
            [2006, 7525, 50, 45],
            [2006, 7526, 49, 36],
            [2006, 7527, 35, 36],
            [2006, 7528, 63, 46],
            [2006, 7529, 75, 67],
            [2006, 7530, 55, 46],
            [2006, 7531, 38, 38],
            [2006, 7532, 50, 45],
            [2006, 7533, 70, 49],
            [2006, 7534, 69, 63],
            [2006, 7535, 46, 42],
            [2006, 7536, 50, 43],
            [2006, 7537, 67, 42],
            [2006, 7538, 51, 39],
            [2006, 7539, 60, 40],
            [2006, 7540, 63, 36],
            [2006, 7541, 55, 40],
            [2006, 7542, 63, 47],
            [2006, 7543, 51, 38],
            [2006, 7544, 53, 40],
            [2006, 7545, 47, 37],
            [2006, 7546, 47, 36],
            [2006, 7547, 47, 36],
            [2006, 7548, 46, 40],
            [2006, 7549, 50, 45],
            [2006, 7550, 39, 36],
            [2006, 7551, 42, 38],
            [2006, 7552, 59, 43],
            [2006, 7553, 47, 40],
            [2006, 7554, 67, 58],
            [2006, 7555, 67, 51],
            [2006, 7556, 51, 45],
            [2006, 7557, 74, 52],
            [2006, 7558, 41, 32],
            [2006, 7559, 47, 36],
            [2006, 7560, 42, 38],
            [2006, 7561, 73, 52],
            [2006, 7562, 65, 55],
            [2006, 7563, 63, 46],
            [2006, 7564, 51, 38],
            [2006, 7565, 52, 40],
            [2006, 7566, 44, 39],
            [2006, 7567, 75, 45],
            [2006, 7568, 43, 40],
            [2006, 7569, 43, 40],
            [2006, 7570, 43, 39],
            [2006, 7571, 43, 39],
            [2006, 7572, 43, 39],
            [2006, 7573, 47, 38],
            [2006, 7574, 44, 39],
            [2006, 7575, 54, 40],
            [2006, 7576, 57, 43],
            [2006, 7577, 63, 46],
            [2006, 7578, 50, 40],
            [2006, 7579, 59, 43],
            [2006, 7580, 63, 46],
            [2006, 7581, 45, 39],
            [2006, 7582, 55, 45],
            [2006, 7583, 60, 45],
            [2006, 7584, 41, 37],
            [2006, 7585, 45, 40],
            [2006, 7586, 75, 56],
            [2006, 7587, 46, 40],
            [2006, 7588, 48, 40],
            [2006, 7589, 75, 56],
            [2006, 7590, 52, 46],
            [2006, 7591, 48, 36],
            [2006, 7592, 46, 46],
            [2006, 7593, 55, 42],
            [2006, 7594, 43, 39],
            [2006, 7595, 58, 40],
            [2006, 7596, 40, 36],
            [2006, 7597, 45, 40],
            [2006, 7598, 62, 43],
            [2006, 7599, 56, 45],
            [2006, 7600, 50, 45],
            [2006, 7601, 39, 36],
            [2006, 7602, 54, 34],
            [2006, 7603, 55, 47],
            [2006, 7604, 55, 46],
            [2006, 7605, 50, 45],
            [2006, 7606, 50, 40],
            [2006, 7607, 50, 46],
            [2006, 7608, 42, 38],
            [2006, 7609, 45, 45],
            [2006, 7610, 35, 36],
            [2006, 7611, 40, 37],
            [2006, 7612, 54, 46],
            [2006, 7613, 55, 40],
            [2006, 7614, 47, 39],
            [2006, 7615, 63, 46],
            [2006, 7616, 51, 38],
            [2006, 7617, 47, 36],
            [2006, 7618, 54, 40],
            [2006, 7619, 51, 45],
            [2006, 7620, 48, 40],
            [2006, 7621, 51, 45],
            [2006, 7622, 59, 43],
            [2006, 7623, 44, 39],
            [2006, 7624, 68, 46],
            [2006, 7625, 40, 36],
            [2006, 7626, 55, 40],
            [2006, 7627, 45, 39],
            [2006, 7628, 63, 46],
            [2006, 7629, 35, 38],
            [2006, 7630, 43, 37],
            [2006, 7631, 47, 43],
            [2006, 7632, 56, 38],
            [2006, 7633, 45, 36],
            [2006, 7634, 15, 20],
            [2006, 7635, 14, 18],
            [2006, 7636, 17, 22],
            [2006, 7637, 27, 25],
            [2006, 7638, 53, 35],
            [2006, 7639, 11, 12],
            [2006, 7640, 10, 10],
            [2006, 7641, 15, 17],
            [2006, 7642, 29, 30],
            [2006, 7643, 21, 18],
            [2006, 7644, 24, 29],
            [2006, 7645, 18, 19],
            [2006, 7646, 23, 22],
            [2006, 7647, 29, 22],
            [2006, 7648, 11, 11],
            [2006, 7649, 11, 11],
            [2006, 7650, 17, 15],
            [2006, 7651, 12, 12],
            [2006, 7652, 14, 14],
            [2006, 7653, 33, 27],
            [2006, 7654, 11, 11],
            [2006, 7655, 13, 13],
            [2006, 7656, 13, 13],
            [2006, 7657, 22, 24],
            [2006, 7658, 21, 24],
            [2006, 7659, 14, 18],
            [2006, 7661, 10, 10],
            [2006, 7662, 17, 14],
            [2006, 7663, 15, 17],
            [2006, 7664, 20, 26],
            [2006, 7665, 25, 29],
            [2006, 7666, 13, 12],
            [2006, 7667, 15, 14],
            [2006, 7668, 13, 12],
            [2006, 7669, 11, 8],
            [2006, 7672, 9, 9],
            [2006, 7673, 8, 7],
            [2006, 7674, 17, 15],
            [2006, 7676, 6, 7],
            [2006, 7677, 5, 6],
            [2006, 7678, 10, 8],
            [2006, 7679, 11, 9],
            [2006, 7680, 30, 18],
            [2006, 7681, 5, 3],
            [2006, 7682, 16, 13],
            [2006, 7683, 3, 3],
            [2006, 7684, 13, 12],
            [2006, 7685, 12, 11],
            [2006, 7686, 19, 17],
            [2006, 7687, 5, 4],
            [2006, 7688, 14, 13],
            [2006, 7690, 7, 8],
            [2006, 7691, 24, 22],
            [2006, 7692, 10, 8],
            [2006, 7693, 9, 9],
            [2006, 7694, 9, 9],
            [2006, 7695, 25, 19],
            [2006, 7696, 3, 3],
            [2006, 7697, 16, 12],
            [2006, 7698, 9, 8],
            [2006, 7699, 12, 14],
            [2006, 7700, 13, 10],
            [2006, 7701, 9, 8],
            [2006, 7702, 22, 13],
            [2006, 7703, 12, 12],
            [2006, 7705, 23, 13],
            [2006, 7706, 11, 10],
            [2006, 7707, 12, 10],
            [2006, 7708, 9, 7],
            [2006, 7709, 12, 13],
            [2006, 7710, 6, 5],
            [2006, 7711, 14, 11],
            [2006, 7713, 26, 12],
            [2006, 7714, 10, 9],
            [2006, 7716, 18, 23],
            [2006, 7717, 39, 31],
            [2006, 7718, 27, 39],
            [2006, 7719, 18, 27],
            [2006, 7722, 28, 36],
            [2006, 7723, 20, 47],
            [2006, 7725, 20, 19],
            [2006, 7726, 25, 22],
            [2006, 7729, 28, 30],
            [2006, 7730, 18, 23],
            [2006, 7731, 31, 27],
            [2006, 7734, 26, 32],
            [2006, 7736, 16, 27],
            [2006, 7737, 33, 29],
            [2006, 7738, 18, 23],
            [2006, 7739, 60, 39],
            [2006, 7740, 43, 41],
            [2006, 7741, 76, 49],
            [2006, 7743, 25, 35],
            [2006, 7744, 55, 46],
            [2006, 7749, 28, 30],
            [2006, 7753, 35, 34],
            [2006, 7754, 27, 37],
            [2006, 7755, 20, 32],
            [2006, 7757, 36, 97],
            [2006, 7758, 65, 104],
            [2006, 7759, 29, 27],
            [2006, 7760, 55, 40],
            [2006, 7761, 47, 57],
            [2006, 7762, 111, 85],
            [2006, 7763, 14, 18],
            [2006, 7764, 13, 15],
            [2006, 7765, 15, 19],
            [2006, 7766, 9, 15],
            [2006, 7767, 24, 26],
            [2006, 7768, 10, 17],
            [2006, 7769, 28, 28],
            [2006, 7770, 14, 16],
            [2006, 7771, 33, 28],
            [2006, 7772, 13, 15],
            [2006, 7773, 22, 24],
            [2006, 7774, 12, 18],
            [2006, 7775, 32, 30],
            [2006, 7776, 13, 23],
            [2006, 7778, 9, 12],
            [2006, 7780, 17, 18],
            [2006, 7781, 24, 26],
            [2006, 7784, 15, 25],
            [2006, 7785, 31, 33],
            [2006, 7786, 14, 16],
            [2006, 7787, 22, 25],
            [2006, 7790, 19, 25],
            [2006, 7791, 34, 36],
            [2006, 7792, 16, 23],
            [2006, 7793, 31, 30],
            [2006, 7795, 120, 101],
            [2006, 7796, 105, 43],
            [2006, 7797, 120, 73],
            [2006, 7798, 120, 38],
            [2006, 7799, 82, 53],
            [2006, 7800, 88, 34],
            [2006, 7801, 120, 66],
            [2006, 7802, 25, 31],
            [2006, 7803, 187, 90],
            [2006, 7804, 120, 48],
            [2006, 7805, 88, 50],
            [2006, 7806, 120, 76],
            [2006, 7807, 92, 72],
            [2006, 7808, 120, 33],
            [2006, 7809, 103, 70],
            [2006, 7810, 100, 86],
            [2006, 7811, 211, 108],
            [2006, 7812, 56, 39],
            [2006, 7813, 75, 37],
            [2006, 7815, 69, 40],
            [2006, 7816, 120, 85],
            [2006, 7817, 38, 47],
            [2006, 7818, 62, 57],
            [2006, 7819, 54, 73],
            [2006, 7820, 72, 48],
            [2006, 7821, 148, 69],
            [2006, 7822, 70, 51],
            [2006, 7823, 50, 22],
            [2006, 7824, 186, 92],
            [2006, 7825, 120, 41],
            [2006, 7826, 70, 50],
            [2006, 7827, 120, 37],
            [2006, 7828, 120, 119],
            [2006, 7829, 80, 50],
            [2006, 7830, 120, 61],
            [2006, 7831, 80, 41],
            [2006, 7832, 128, 80],
            [2006, 7833, 60, 38],
            [2006, 7834, 128, 70],
            [2006, 7835, 72, 36],
            [2006, 7836, 120, 75],
            [2006, 7837, 46, 36],
            [2006, 7838, 120, 30],
            [2006, 7839, 104, 80],
            [2006, 7840, 154, 90],
            [2006, 7841, 80, 39],
            [2006, 7842, 37, 30],
            [2006, 7843, 47, 23],
            [2006, 7844, 120, 47],
            [2006, 7845, 48, 45],
            [2006, 7846, 120, 56],
            [2006, 7847, 94, 36],
            [2006, 7848, 120, 58],
            [2006, 7849, 223, 90],
            [2006, 7850, 73, 97],
            [2006, 7851, 120, 74],
            [2006, 7852, 66, 45],
            [2006, 7853, 40, 52],
            [2006, 7854, 31, 38],
            [2006, 7855, 60, 38],
            [2006, 7856, 151, 89],
            [2006, 7857, 89, 38],
            [2006, 7858, 32, 39],
            [2006, 7859, 112, 65],
            [2006, 7860, 107, 69],
            [2006, 7861, 51, 36],
            [2006, 7862, 190, 62],
            [2006, 7863, 236, 87],
            [2006, 7864, 36, 31],
            [2006, 7865, 47, 42],
            [2006, 7866, 120, 63],
            [2006, 7867, 52, 38],
            [2006, 7868, 50, 45],
            [2006, 7869, 120, 62],
            [2006, 7870, 54, 38],
            [2006, 7871, 61, 40],
            [2006, 7872, 120, 90],
            [2006, 7873, 120, 73],
            [2006, 7874, 46, 38],
            [2006, 7875, 145, 73],
            [2006, 7876, 120, 90],
            [2006, 7877, 120, 65],
            [2006, 7878, 170, 51],
            [2006, 7879, 126, 87],
            [2006, 7880, 80, 49],
            [2006, 7881, 55, 59],
            [2006, 7882, 40, 34],
            [2006, 7883, 70, 58],
            [2006, 7884, 50, 57],
            [2006, 7885, 64, 47],
            [2006, 7886, 57, 39],
            [2006, 7887, 73, 42],
            [2006, 7888, 119, 47],
            [2006, 7889, 188, 90],
            [2006, 7890, 58, 83],
            [2006, 7891, 63, 39],
            [2006, 7892, 42, 38],
            [2006, 7893, 35, 34],
            [2006, 7894, 117, 79],
            [2006, 7895, 72, 41],
            [2006, 7896, 167, 78],
            [2006, 7897, 120, 56],
            [2006, 7898, 25, 33],
            [2006, 7899, 60, 86],
            [2006, 7900, 129, 80],
            [2006, 7901, 120, 55],
            [2006, 7902, 120, 68],
            [2006, 7903, 107, 56],
            [2006, 7904, 89, 69],
            [2006, 7905, 63, 59],
            [2006, 7906, 106, 75],
            [2006, 7907, 121, 57],
            [2006, 7908, 146, 55],
            [2006, 7909, 79, 47],
            [2006, 7910, 114, 53],
            [2006, 7911, 82, 56],
            [2006, 7912, 121, 97],
            [2006, 7913, 120, 52],
            [2006, 7914, 90, 61],
            [2006, 7915, 103, 78],
            [2006, 7916, 120, 52],
            [2006, 7917, 80, 46],
            [2006, 7918, 65, 38],
            [2006, 7919, 39, 36],
            [2006, 7920, 81, 47],
            [2006, 7921, 53, 15],
            [2006, 7922, 32, 40],
            [2006, 7923, 110, 38],
            [2006, 7924, 50, 43],
            [2006, 7925, 59, 38],
            [2006, 7926, 285, 47],
            [2006, 7927, 38, 49],
            [2006, 7928, 23, 50],
            [2006, 7929, 120, 53],
            [2006, 7930, 96, 49],
            [2006, 7931, 56, 36],
            [2006, 7932, 46, 36],
            [2006, 7933, 95, 60],
            [2006, 7934, 70, 69],
            [2006, 7935, 120, 61],
            [2006, 7936, 112, 54],
            [2006, 7937, 68, 48],
            [2006, 7938, 20, 16],
            [2006, 7939, 120, 86],
            [2006, 7940, 120, 71],
            [2006, 7941, 120, 85],
            [2006, 7942, 120, 71],
            [2006, 7943, 55, 36],
            [2006, 7944, 30, 42],
            [2006, 7945, 110, 40],
            [2006, 7946, 46, 78],
            [2006, 7947, 78, 55],
            [2006, 7948, 39, 37],
            [2006, 7949, 66, 90],
            [2006, 7950, 55, 52],
            [2006, 7951, 120, 64],
            [2006, 7952, 58, 62],
            [2006, 7953, 42, 18],
            [2006, 7954, 96, 30],
            [2006, 7955, 160, 54],
            [2006, 7956, 97, 40],
            [2006, 7957, 103, 47],
            [2006, 7958, 120, 48],
            [2006, 7959, 120, 37],
            [2006, 7960, 53, 45],
            [2006, 7961, 120, 90],
            [2006, 7962, 190, 90],
            [2006, 7963, 22, 26],
            [2006, 7964, 65, 90],
            [2006, 7965, 120, 38],
            [2006, 7966, 137, 97],
            [2006, 7967, 67, 36],
            [2006, 7968, 120, 85],
            [2006, 7969, 95, 72],
            [2006, 7970, 120, 72],
            [2006, 7971, 27, 39],
            [2006, 7972, 40, 44],
            [2006, 7974, 70, 35],
            [2006, 7975, 178, 90],
            [2006, 7976, 179, 58],
            [2006, 7977, 49, 57],
            [2006, 7978, 120, 69],
            [2006, 7979, 109, 65],
            [2006, 7980, 120, 52],
            [2006, 7981, 82, 30],
            [2006, 7982, 74, 42],
            [2006, 7983, 94, 36],
            [2006, 7984, 120, 90],
            [2006, 7985, 56, 54],
            [2006, 7986, 85, 38],
            [2006, 7987, 73, 47],
            [2006, 7988, 33, 44],
            [2006, 7989, 120, 37],
            [2006, 7990, 86, 38],
            [2006, 7992, 103, 53],
            [2006, 7993, 111, 70],
            [2006, 7994, 56, 43],
            [2006, 7995, 202, 90],
            [2006, 7996, 114, 54],
            [2006, 7997, 137, 90],
            [2006, 7998, 57, 24],
            [2006, 7999, 136, 84],
            [2006, 8000, 103, 36],
            [2006, 8001, 127, 84],
            [2006, 8002, 96, 72],
            [2006, 8003, 30, 35],
            [2006, 8004, 100, 70],
            [2006, 8005, 20, 19],
            [2006, 8006, 13, 15],
            [2006, 8007, 24, 25],
            [2006, 8008, 22, 23],
            [2006, 8009, 14, 14],
            [2006, 8010, 13, 14],
            [2006, 8011, 19, 19],
            [2006, 8012, 12, 12],
            [2006, 8013, 7, 6],
            [2006, 8014, 9, 9],
            [2006, 8015, 10, 8],
            [2006, 8016, 6, 5],
            [2006, 8017, 11, 11],
            [2006, 8018, 7, 6],
            [2006, 8019, 13, 13],
            [2006, 8020, 11, 11],
            [2006, 8021, 6, 5],
            [2006, 8022, 20, 22],
            [2006, 8023, 15, 15],
            [2006, 8024, 20, 17],
            [2006, 8025, 16, 19],
            [2006, 8026, 17, 18],
            [2006, 8027, 14, 11],
            [2006, 8028, 13, 12],
            [2006, 8029, 19, 17],
            [2006, 8030, 20, 16],
            [2006, 8031, 12, 11],
            [2006, 8032, 18, 22],
            [2006, 8033, 17, 17],
            [2006, 8034, 20, 23],
            [2006, 8035, 18, 23],
            [2006, 8036, 16, 17],
            [2006, 8037, 20, 21],
            [2006, 8038, 30, 42],
            [2006, 8039, 26, 42],
            [2006, 8040, 19, 42],
            [2006, 8041, 7, 12],
            [2006, 8042, 7, 9],
            [2006, 8043, 10, 13],
            [2006, 8044, 10, 15],
            [2006, 8045, 5, 3],
            [2006, 8046, 5, 3],
            [2006, 8047, 5, 5],
            [2006, 8048, 14, 19],
            [2006, 8049, 11, 15],
            [2006, 8050, 9, 10],
            [2006, 8051, 18, 19],
            [2006, 8052, 30, 41],
            [2006, 8053, 20, 33],
            [2006, 8054, 16, 28],
            [2006, 8055, 28, 40],
            [2006, 8056, 39, 43],
            [2006, 8057, 19, 27],
            [2006, 8058, 16, 23],
            [2006, 8059, 22, 24],
            [2006, 8060, 24, 26],
            [2006, 8061, 47, 51],
            [2006, 8062, 50, 63],
            [2006, 8063, 10, 11],
            [2006, 8064, 12, 17],
            [2006, 8065, 13, 13],
            [2006, 8068, 7, 10],
            [2006, 8069, 7, 11],
            [2006, 8071, 47, 19],
            [2006, 8073, 20, 14],
            [2006, 8074, 11, 10],
            [2006, 8075, 20, 13],
            [2006, 8076, 48, 25],
            [2006, 8086, 14, 31],
            [2006, 8087, 15, 25],
            [2006, 8088, 17, 28],
            [2006, 8089, 20, 34],
            [2006, 8090, 19, 26],
            [2006, 8091, 21, 43],
            [2006, 8092, 18, 34],
            [2006, 8093, 20, 42],
            [2006, 8094, 14, 42],
            [2006, 8095, 19, 23],
            [2006, 8096, 20, 29],
            [2006, 8097, 19, 25],
            [2006, 8098, 11, 26],
            [2006, 8099, 22, 26],
            [2006, 8102, 18, 18],
            [2006, 8103, 26, 34],
            [2006, 8107, 16, 20],
            [2006, 8109, 20, 26],
            [2006, 8110, 18, 22],
            [2006, 8116, 45, 60],
            [2006, 8117, 46, 62],
            [2006, 8118, 23, 31],
            [2006, 8119, 15, 31],
            [2006, 8120, 28, 27],
            [2006, 8121, 23, 24],
            [2006, 8124, 24, 34],
            [2006, 8126, 22, 22],
            [2006, 8127, 27, 31],
            [2006, 8131, 30, 38],
            [2006, 8133, 18, 22],
            [2006, 8134, 32, 35],
            [2006, 8136, 18, 22],
            [2006, 8137, 26, 32],
            [2006, 8138, 29, 29],
            [2006, 8140, 38, 55],
            [2006, 8141, 35, 46],
            [2006, 8145, 22, 33],
            [2006, 8149, 17, 23],
            [2006, 8151, 18, 24],
            [2006, 8153, 30, 32],
            [2006, 8154, 22, 28],
            [2006, 8155, 54, 44],
            [2006, 8159, 28, 30],
            [2006, 8160, 24, 29],
            [2006, 8164, 20, 26],
            [2006, 8167, 40, 44],
            [2006, 8168, 39, 58],
            [2006, 8170, 20, 35],
            [2006, 8171, 27, 26],
            [2006, 8175, 16, 24],
            [2006, 8177, 27, 29],
            [2006, 8178, 23, 25],
            [2006, 8184, 27, 24],
            [2006, 8185, 22, 22],
            [2006, 8187, 30, 35],
            [2006, 8188, 18, 20],
            [2006, 8194, 34, 34],
            [2006, 8195, 20, 25],
            [2006, 8196, 15, 20],
            [2006, 8198, 33, 39],
            [2006, 8200, 20, 30],
            [2006, 8202, 38, 68],
            [2006, 8205, 34, 32],
            [2006, 8208, 20, 30],
            [2006, 8210, 17, 28],
            [2006, 8217, 21, 35],
            [2006, 8218, 13, 18],
            [2006, 8219, 41, 34],
            [2006, 8220, 29, 25],
            [2006, 8221, 52, 32],
            [2006, 8222, 25, 18],
            [2006, 8223, 20, 31],
            [2006, 8224, 49, 41],
            [2006, 8225, 13, 20],
            [2006, 8227, 25, 29],
            [2006, 8228, 25, 55],
            [2006, 8231, 18, 22],
            [2006, 8232, 70, 48],
            [2006, 8234, 18, 25],
            [2006, 8236, 20, 20],
            [2006, 8238, 46, 38],
            [2006, 8241, 14, 20],
            [2006, 8248, 15, 19],
            [2006, 8250, 23, 22],
            [2006, 8251, 22, 27],
            [2006, 8254, 32, 34],
            [2006, 8255, 60, 46],
            [2006, 8256, 20, 27],
            [2006, 8259, 21, 27],
            [2006, 8260, 23, 27],
            [2006, 8262, 28, 32],
            [2006, 8264, 30, 39],
            [2006, 8265, 50, 45],
            [2006, 8268, 18, 31],
            [2006, 8270, 16, 28],
            [2006, 8271, 28, 36],
            [2006, 8276, 27, 25],
            [2006, 8277, 20, 21],
            [2006, 8287, 20, 26],
            [2006, 8288, 18, 20],
            [2006, 8294, 42, 60],
            [2006, 8298, 29, 41],
            [2006, 8299, 27, 21],
            [2006, 8300, 35, 30],
            [2006, 8302, 20, 19],
            [2006, 8309, 12, 18],
            [2006, 8310, 25, 28],
            [2006, 8311, 12, 13],
            [2006, 8312, 12, 13],
            [2006, 8313, 11, 12],
            [2006, 8314, 12, 12],
            [2006, 8315, 17, 15],
            [2006, 8316, 11, 11],
            [2006, 8317, 30, 23],
            [2006, 8319, 21, 17],
            [2006, 8322, 29, 25],
            [2006, 8323, 23, 20],
            [2006, 8324, 40, 31],
            [2006, 8336, 19, 16],
            [2006, 8337, 12, 14],
            [2006, 8338, 12, 12],
            [2006, 8339, 30, 31],
            [2006, 8340, 15, 17],
            [2006, 8341, 22, 23],
            [2006, 8342, 15, 15],
            [2006, 8343, 15, 14],
            [2006, 8344, 15, 14],
            [2006, 8345, 21, 21],
            [2006, 8346, 18, 20],
            [2006, 8347, 15, 17],
            [2006, 8348, 20, 20],
            [2006, 8349, 21, 18],
            [2006, 8350, 18, 21],
            [2006, 8351, 14, 11],
            [2006, 8352, 20, 24],
            [2006, 8353, 11, 12],
            [2006, 8354, 23, 25],
            [2006, 8355, 14, 14],
            [2006, 8356, 24, 23],
            [2006, 8357, 19, 14],
            [2006, 8358, 21, 18],
            [2006, 8359, 29, 32],
            [2006, 8360, 26, 26],
            [2006, 8361, 13, 12],
            [2006, 8362, 20, 21],
            [2006, 8363, 27, 28],
            [2006, 8364, 23, 21],
            [2006, 8365, 21, 20],
            [2006, 8366, 20, 20],
            [2006, 8367, 18, 16],
            [2006, 8368, 17, 22],
            [2006, 8369, 18, 20],
            [2006, 8370, 20, 17],
            [2006, 8371, 18, 16],
            [2006, 8372, 19, 17],
            [2006, 8373, 22, 24],
            [2006, 8374, 18, 21],
            [2006, 8375, 16, 19],
            [2006, 8376, 23, 23],
            [2006, 8377, 20, 17],
            [2006, 8378, 21, 17],
            [2006, 8379, 22, 21],
            [2006, 8380, 25, 21],
            [2006, 8381, 20, 20],
            [2006, 8382, 16, 18],
            [2006, 8383, 21, 23],
            [2006, 8384, 20, 25],
            [2006, 8385, 18, 21],
            [2006, 8386, 15, 15],
            [2006, 8387, 21, 20],
            [2006, 8388, 21, 18],
            [2006, 8389, 16, 17],
            [2006, 8390, 13, 13],
            [2006, 8391, 20, 18],
            [2006, 8392, 20, 19],
            [2006, 8393, 25, 30],
            [2006, 8394, 21, 20],
            [2006, 8395, 17, 18],
            [2006, 8396, 46, 38],
            [2006, 8397, 55, 41],
            [2006, 8398, 38, 29],
            [2006, 8399, 48, 31],
            [2006, 8400, 43, 40],
            [2006, 8401, 48, 31],
            [2006, 8402, 41, 31],
            [2006, 8403, 45, 30],
            [2006, 8404, 39, 34],
            [2006, 8405, 45, 30],
            [2006, 8406, 47, 32],
            [2006, 8407, 70, 41],
            [2006, 8408, 60, 37],
            [2006, 8409, 34, 28],
            [2006, 8410, 65, 32],
            [2006, 8411, 60, 48],
            [2006, 8412, 42, 39],
            [2006, 8413, 50, 37],
            [2006, 8414, 49, 31],
            [2006, 8415, 53, 41],
            [2006, 8416, 30, 29],
            [2006, 8417, 56, 34],
            [2006, 8418, 21, 27],
            [2006, 8419, 63, 37],
            [2006, 8420, 63, 34],
            [2006, 8421, 53, 40],
            [2006, 8422, 38, 33],
            [2006, 8423, 57, 40],
            [2006, 8424, 70, 48],
            [2006, 8425, 39, 44],
            [2006, 8426, 50, 30],
            [2006, 8427, 62, 32],
            [2006, 8428, 41, 33],
            [2006, 8429, 46, 35],
            [2006, 8430, 46, 35],
            [2006, 8431, 64, 39],
            [2006, 8432, 61, 44],
            [2006, 8433, 48, 43],
            [2006, 8434, 51, 34],
            [2006, 8435, 60, 36],
            [2006, 8436, 54, 41],
            [2006, 8438, 35, 30],
            [2006, 8439, 33, 34],
            [2006, 8440, 62, 38],
            [2006, 8441, 53, 36],
            [2006, 8442, 40, 37],
            [2006, 8443, 46, 40],
            [2006, 8444, 49, 44],
            [2006, 8445, 45, 24],
            [2006, 8446, 46, 29],
            [2006, 8447, 46, 37],
            [2006, 8448, 38, 33],
            [2006, 8449, 48, 27],
            [2006, 8450, 49, 36],
            [2006, 8451, 21, 27],
            [2006, 8452, 21, 32],
            [2006, 8453, 20, 24],
            [2006, 8454, 21, 25],
            [2006, 8455, 21, 27],
            [2006, 8456, 21, 27],
            [2006, 8457, 49, 44],
            [2006, 8458, 38, 30],
            [2006, 8459, 46, 33],
            [2006, 8460, 39, 35],
            [2006, 8461, 48, 32],
            [2006, 8462, 52, 36],
            [2006, 8463, 49, 41],
            [2006, 8464, 52, 40],
            [2006, 8465, 33, 35],
            [2006, 8466, 39, 37],
            [2006, 8467, 48, 31],
            [2006, 8468, 57, 36],
            [2006, 8469, 64, 32],
            [2006, 8470, 48, 38],
            [2006, 8471, 35, 37],
            [2006, 8472, 53, 29],
            [2006, 8473, 46, 36],
            [2006, 8474, 38, 35],
            [2006, 8475, 48, 37],
            [2006, 8476, 49, 38],
            [2006, 8477, 47, 37],
            [2006, 8478, 24, 29],
            [2006, 8479, 48, 34],
            [2006, 8480, 53, 42],
            [2006, 8481, 46, 37],
            [2006, 8482, 39, 33],
            [2006, 8483, 46, 33],
            [2006, 8484, 47, 35],
            [2006, 8485, 47, 39],
            [2006, 8486, 32, 27],
            [2006, 8487, 46, 33],
            [2006, 8488, 35, 30],
            [2006, 8489, 40, 45],
            [2006, 8490, 47, 37],
            [2006, 8491, 46, 37],
            [2006, 8492, 55, 31],
            [2006, 8493, 47, 32],
            [2006, 8494, 32, 27],
            [2006, 8495, 49, 48],
            [2006, 8496, 26, 31],
            [2006, 8497, 46, 43],
            [2006, 8498, 32, 33],
            [2006, 8499, 40, 32],
            [2006, 8500, 50, 36],
            [2006, 8501, 48, 51],
            [2006, 8502, 53, 35],
            [2006, 8503, 58, 38],
            [2006, 8504, 39, 37],
            [2006, 8505, 49, 39],
            [2006, 8506, 54, 41],
            [2006, 8507, 48, 38],
            [2006, 8508, 45, 32],
            [2006, 8509, 38, 33],
            [2006, 8510, 49, 37],
            [2006, 8511, 54, 34],
            [2006, 8512, 46, 43],
            [2006, 8513, 44, 40],
            [2006, 8514, 46, 44],
            [2006, 8515, 41, 38],
            [2006, 8516, 58, 51],
            [2006, 8517, 46, 23],
            [2006, 8518, 57, 49],
            [2006, 8519, 38, 32],
            [2006, 8520, 41, 32],
            [2006, 8521, 37, 32],
            [2006, 8522, 39, 35],
            [2006, 8523, 51, 33],
            [2006, 8524, 36, 31],
            [2006, 8525, 48, 33],
            [2006, 8526, 46, 37],
            [2006, 8527, 46, 44],
            [2006, 8528, 47, 39],
            [2006, 8529, 54, 40],
            [2006, 8530, 35, 31],
            [2006, 8531, 53, 47],
            [2006, 8532, 59, 43],
            [2006, 8533, 54, 47],
            [2006, 8534, 51, 39],
            [2006, 8535, 51, 49],
            [2006, 8536, 18, 29],
            [2006, 8537, 35, 26],
            [2006, 8538, 37, 25],
            [2006, 8539, 35, 29],
            [2006, 8540, 27, 34],
            [2006, 8541, 35, 42],
            [2006, 8542, 28, 36],
            [2006, 8543, 18, 35],
            [2006, 8544, 26, 47],
            [2006, 8546, 25, 37],
            [2006, 8547, 30, 47],
            [2006, 8548, 15, 18],
            [2006, 8549, 15, 27],
            [2006, 8550, 20, 25],
            [2006, 8551, 30, 27],
            [2006, 8552, 28, 33],
            [2006, 8553, 28, 40],
            [2006, 8554, 35, 28],
            [2006, 8555, 31, 30],
            [2006, 8556, 28, 40],
            [2006, 8557, 35, 40],
            [2006, 8558, 26, 28],
            [2006, 8559, 25, 29],
            [2006, 8560, 40, 31],
            [2006, 8561, 25, 27],
            [2006, 8562, 64, 38],
            [2006, 8563, 36, 38],
            [2006, 8564, 140, 98],
            [2006, 8565, 10, 11],
            [2006, 8566, 22, 14],
            [2006, 8567, 20, 18],
            [2006, 8568, 14, 15],
            [2006, 8569, 19, 15],
            [2006, 8570, 10, 10],
            [2006, 8571, 14, 11],
            [2006, 8572, 12, 12],
            [2006, 8573, 13, 11],
            [2006, 8574, 15, 13],
            [2006, 8575, 10, 10],
            [2006, 8576, 26, 19],
            [2006, 8577, 14, 16],
            [2006, 8578, 22, 20],
            [2006, 8579, 14, 18],
            [2006, 8580, 18, 17],
            [2006, 8581, 13, 12],
            [2006, 8582, 16, 15],
            [2006, 8583, 20, 18],
            [2006, 8584, 14, 14],
            [2006, 8719, 24, 23],
            [2006, 8720, 25, 24],
            [2006, 8721, 26, 25],
            [2006, 8722, 24, 23],
            [2006, 8723, 26, 24],
            [2006, 8724, 24, 24],
            [2006, 8725, 26, 21],
            [2006, 8726, 25, 23],
            [2006, 8727, 22, 22],
            [2006, 8728, 19, 21],
            [2006, 8729, 23, 21],
            [2006, 8730, 20, 20],
            [2006, 8731, 21, 20],
            [2006, 8732, 25, 22],
            [2006, 8733, 26, 22],
            [2006, 8734, 26, 22],
            [2006, 8735, 21, 21],
            [2006, 8736, 21, 21],
            [2006, 8737, 20, 20],
            [2006, 8738, 21, 20],
            [2006, 8739, 21, 21],
            [2006, 8740, 21, 20],
            [2006, 8741, 24, 21],
            [2006, 8742, 23, 21],
            [2006, 8743, 22, 22],
            [2006, 8744, 23, 22],
            [2006, 8745, 24, 22],
            [2006, 8746, 27, 23],
            [2006, 8747, 27, 23],
            [2006, 8748, 27, 23],
            [2006, 8749, 23, 22],
            [2006, 8750, 22, 22],
            [2006, 8751, 22, 23],
            [2006, 8752, 21, 21],
            [2006, 8753, 19, 20],
            [2006, 8754, 21, 21],
            [2006, 8755, 20, 21],
            [2006, 8756, 27, 22],
            [2006, 8757, 19, 20],
            [2006, 8758, 21, 21],
            [2006, 8759, 22, 21],
            [2006, 8760, 29, 30],
            [2006, 8761, 22, 21],
            [2006, 8762, 27, 22],
            [2006, 8763, 18, 18],
            [2006, 8764, 29, 22],
            [2006, 8765, 24, 20],
            [2006, 8766, 26, 22],
            [2006, 8767, 27, 23],
            [2006, 8768, 27, 23],
            [2006, 8769, 27, 23],
            [2006, 8770, 27, 23],
            [2006, 8771, 27, 24],
            [2006, 8772, 28, 23],
            [2006, 8773, 21, 20],
            [2006, 8774, 21, 20],
            [2006, 8775, 21, 21],
            [2006, 8776, 21, 20],
            [2006, 8777, 22, 22],
            [2006, 8778, 29, 23],
            [2006, 8779, 10, 10],
            [2006, 8780, 12, 9],
            [2006, 8781, 15, 13],
            [2006, 8782, 13, 10],
            [2006, 8783, 10, 8],
            [2006, 8784, 12, 9],
            [2006, 8785, 7, 7],
            [2006, 8786, 9, 10],
            [2006, 8787, 11, 10],
            [2006, 8788, 12, 10],
            [2006, 8790, 10, 8],
            [2006, 8791, 6, 6],
            [2006, 8792, 11, 10],
            [2006, 8793, 8, 8],
            [2006, 8794, 8, 7],
            [2006, 8795, 9, 7],
            [2006, 8796, 13, 9],
            [2006, 8797, 15, 9],
            [2006, 8798, 9, 8],
            [2006, 8799, 14, 13],
            [2006, 8800, 10, 8],
            [2006, 8801, 10, 9],
            [2006, 8802, 8, 7],
            [2006, 8803, 8, 8],
            [2006, 8804, 7, 8],
            [2006, 8805, 9, 8],
            [2006, 8806, 9, 10],
            [2006, 8807, 11, 11],
            [2006, 8808, 9, 8],
            [2006, 8809, 6, 8],
            [2006, 8810, 10, 10],
            [2006, 8811, 7, 9],
            [2006, 8812, 11, 9],
            [2006, 8814, 6, 7],
            [2006, 8815, 9, 9],
            [2006, 8816, 11, 7],
            [2006, 8817, 14, 10],
            [2006, 8818, 39, 32],
            [2006, 8819, 35, 31],
            [2006, 8820, 43, 35],
            [2006, 8821, 39, 27],
            [2006, 8822, 42, 34],
            [2006, 8823, 31, 25],
            [2006, 8824, 22, 18],
            [2006, 8825, 34, 27],
            [2006, 8826, 22, 21],
            [2006, 8827, 37, 27],
            [2006, 8828, 37, 27],
            [2006, 8829, 39, 31],
            [2006, 8830, 27, 28],
            [2006, 8831, 33, 25],
            [2006, 8832, 19, 11],
            [2006, 8833, 30, 24],
            [2006, 8834, 34, 30],
            [2006, 8835, 27, 19],
            [2006, 8836, 41, 33],
            [2006, 8837, 30, 21],
            [2006, 8838, 38, 30],
            [2006, 8839, 24, 13],
            [2006, 8840, 34, 24],
            [2006, 8841, 23, 13],
            [2006, 8842, 15, 18],
            [2006, 8843, 19, 12],
            [2006, 8844, 27, 22],
            [2006, 8845, 14, 16],
            [2006, 8846, 32, 26],
            [2006, 8847, 18, 19],
            [2006, 8848, 40, 32],
            [2006, 8849, 27, 21],
            [2006, 8850, 34, 29],
            [2006, 8851, 22, 22],
            [2006, 8852, 32, 25],
            [2006, 8853, 14, 17],
            [2006, 8854, 32, 27],
            [2006, 8855, 20, 14],
            [2006, 8856, 30, 25],
            [2006, 8857, 22, 13],
            [2006, 8858, 27, 14],
            [2006, 8859, 39, 33],
            [2006, 8860, 27, 12],
            [2006, 8861, 32, 27],
            [2006, 8862, 24, 21],
            [2006, 8863, 34, 29],
            [2006, 8864, 21, 21],
            [2006, 8865, 31, 25],
            [2006, 8866, 22, 21],
            [2006, 8867, 41, 34],
            [2006, 8868, 37, 31],
            [2006, 8869, 42, 34],
            [2006, 8870, 41, 33],
            [2006, 8871, 32, 27],
            [2006, 8872, 35, 29],
            [2006, 8873, 26, 22],
            [2006, 8874, 30, 25],
            [2006, 8875, 32, 27],
            [2006, 8876, 18, 18],
            [2006, 8877, 39, 29],
            [2006, 8878, 24, 21],
            [2006, 8879, 18, 11],
            [2006, 8880, 30, 25],
            [2006, 8881, 42, 34],
            [2006, 8882, 27, 23],
            [2006, 8883, 42, 33],
            [2006, 8884, 17, 15],
            [2006, 8885, 44, 33],
            [2006, 8886, 33, 25],
            [2006, 8887, 19, 11],
            [2006, 8888, 37, 31],
            [2006, 8889, 41, 33],
            [2006, 8890, 13, 16],
            [2006, 8891, 32, 28],
            [2006, 8892, 14, 11],
            [2006, 8893, 32, 28],
            [2006, 8894, 19, 18],
            [2006, 8895, 15, 11],
            [2006, 8896, 24, 20],
            [2006, 8897, 15, 10],
            [2006, 8898, 19, 18],
            [2006, 8899, 41, 34],
            [2006, 8900, 32, 27],
            [2006, 8901, 37, 29],
            [2006, 8902, 29, 24],
            [2006, 8903, 25, 21],
            [2006, 8904, 33, 27],
            [2006, 8905, 23, 19],
            [2006, 8906, 30, 24],
            [2006, 8907, 19, 19],
            [2006, 8908, 28, 24],
            [2006, 8909, 21, 18],
            [2006, 8910, 21, 12],
            [2006, 8911, 22, 13],
            [2006, 8912, 39, 33],
            [2006, 8913, 26, 23],
            [2006, 8914, 39, 29],
            [2006, 8915, 27, 22],
            [2006, 8916, 40, 32],
            [2006, 8917, 32, 22],
            [2006, 8918, 41, 33],
            [2006, 8919, 30, 26],
            [2006, 8920, 32, 27],
            [2006, 8921, 33, 29],
            [2006, 8922, 30, 24],
            [2006, 8923, 24, 20],
            [2006, 8924, 14, 13],
            [2006, 8925, 11, 10],
            [2006, 8926, 14, 12],
            [2006, 8927, 15, 15],
            [2006, 8928, 13, 12],
            [2006, 8929, 10, 10],
            [2006, 8930, 9, 10],
            [2006, 8931, 13, 14],
            [2006, 8932, 16, 18],
            [2006, 8933, 23, 22],
            [2006, 8934, 26, 23],
            [2006, 8935, 35, 30],
            [2006, 8936, 25, 18],
            [2006, 8937, 32, 27],
            [2006, 8938, 24, 18],
            [2006, 8939, 31, 24],
            [2006, 8940, 18, 16],
            [2006, 8941, 30, 24],
            [2006, 8942, 18, 16],
            [2006, 8943, 26, 19],
            [2006, 8944, 31, 25],
            [2006, 8945, 22, 19],
            [2006, 8946, 31, 25],
            [2006, 8947, 22, 18],
            [2006, 8948, 30, 25],
            [2006, 8949, 25, 20],
            [2006, 8950, 22, 19],
            [2006, 8951, 28, 25],
            [2006, 8952, 23, 19],
            [2006, 8953, 32, 26],
            [2006, 8954, 24, 17],
            [2006, 8955, 39, 32],
            [2006, 8956, 26, 23],
            [2006, 8957, 26, 18],
            [2006, 8958, 42, 34],
            [2006, 8959, 27, 19],
            [2006, 8960, 41, 33],
            [2006, 8961, 27, 19],
            [2006, 8962, 35, 32],
            [2006, 8963, 30, 26],
            [2006, 8964, 19, 12],
            [2006, 8965, 38, 31],
            [2006, 8966, 36, 28],
            [2006, 8967, 39, 30],
            [2006, 8968, 30, 25],
            [2006, 8969, 18, 13],
            [2006, 8970, 39, 32],
            [2006, 8971, 30, 26],
            [2006, 8972, 17, 13],
            [2006, 8973, 37, 29],
            [2006, 8974, 13, 17],
            [2006, 8975, 41, 33],
            [2006, 8976, 42, 34],
            [2006, 8977, 26, 21],
            [2006, 8978, 14, 11],
            [2006, 8979, 37, 31],
            [2006, 8980, 30, 25],
            [2006, 8981, 29, 23],
            [2006, 8983, 34, 28],
            [2006, 8984, 27, 20],
            [2006, 8985, 33, 27],
            [2006, 8986, 25, 20],
            [2006, 8987, 27, 25],
            [2006, 8988, 18, 26],
            [2006, 8989, 34, 28],
            [2006, 8990, 23, 20],
            [2006, 8991, 32, 27],
            [2006, 8992, 18, 18],
            [2006, 8993, 33, 29],
            [2006, 8994, 38, 31],
            [2006, 8995, 35, 27],
            [2006, 8996, 41, 31],
            [2006, 8997, 22, 21],
            [2006, 8998, 27, 20],
            [2006, 8999, 19, 11],
            [2006, 9000, 42, 34],
            [2006, 9001, 38, 28],
            [2006, 9002, 37, 29],
            [2006, 9003, 23, 21],
            [2006, 9004, 41, 31],
            [2006, 9005, 20, 18],
            [2006, 9006, 34, 27],
            [2006, 9007, 27, 19],
            [2006, 9008, 36, 24],
            [2006, 9009, 32, 24],
            [2006, 9010, 25, 20],
            [2006, 9011, 19, 11],
            [2006, 9012, 27, 25],
            [2006, 9013, 20, 22],
            [2006, 9014, 36, 28],
            [2006, 9015, 19, 14],
            [2006, 9016, 19, 14],
            [2006, 9017, 39, 30],
            [2006, 9018, 26, 26],
            [2006, 9019, 30, 27],
            [2006, 9020, 18, 18],
            [2006, 9021, 34, 29],
            [2006, 9022, 27, 22],
            [2006, 9023, 31, 25],
            [2006, 9024, 36, 29],
            [2006, 9025, 30, 25],
            [2006, 9026, 31, 18],
            [2006, 9027, 27, 17],
            [2006, 9028, 37, 29],
            [2006, 9030, 38, 29],
            [2006, 9031, 32, 26],
            [2006, 9032, 41, 28],
            [2006, 9033, 30, 26],
            [2006, 9034, 42, 31],
            [2006, 9035, 37, 31],
            [2006, 9036, 36, 29],
            [2006, 9037, 16, 14],
            [2006, 9038, 27, 24],
            [2006, 9039, 15, 18],
            [2006, 9040, 34, 28],
            [2006, 9041, 23, 19],
            [2006, 9042, 37, 29],
            [2006, 9043, 33, 28],
            [2006, 9044, 22, 14],
            [2006, 9045, 33, 25],
            [2006, 9046, 26, 20],
            [2006, 9047, 33, 27],
            [2006, 9048, 29, 21],
            [2006, 9049, 45, 33],
            [2006, 9050, 27, 20],
            [2006, 9051, 39, 29],
            [2006, 9052, 41, 26],
            [2006, 9053, 31, 31],
            [2006, 9054, 35, 27],
            [2006, 9055, 41, 21],
            [2006, 9056, 42, 25],
            [2006, 9057, 39, 29],
            [2006, 9058, 25, 18],
            [2006, 9059, 42, 31],
            [2006, 9060, 39, 28],
            [2006, 9061, 49, 39],
            [2006, 9062, 21, 21],
            [2006, 9063, 33, 24],
            [2006, 9064, 16, 18],
            [2006, 9065, 22, 21],
            [2006, 9066, 16, 17],
            [2006, 9067, 29, 22],
            [2006, 9068, 26, 18],
            [2006, 9069, 33, 32],
            [2006, 9070, 17, 17],
            [2006, 9071, 25, 29],
            [2006, 9072, 13, 16],
            [2006, 9073, 14, 16],
            [2006, 9074, 29, 27],
            [2006, 9075, 20, 21],
            [2006, 9076, 23, 25],
            [2006, 9077, 34, 22],
            [2006, 9078, 26, 16],
            [2006, 9079, 34, 29],
            [2006, 9080, 21, 18],
            [2006, 9081, 27, 22],
            [2006, 9082, 41, 30],
            [2006, 9083, 30, 24],
            [2006, 9084, 37, 27],
            [2006, 9085, 19, 19],
            [2006, 9086, 36, 28],
            [2006, 9087, 39, 27],
            [2006, 9088, 27, 17],
            [2006, 9089, 17, 14],
            [2006, 9090, 22, 18],
            [2006, 9091, 22, 15],
            [2006, 9092, 39, 25],
            [2006, 9093, 20, 19],
            [2006, 9094, 41, 34],
            [2006, 9095, 14, 12],
            [2006, 9096, 26, 30],
            [2006, 9097, 28, 21],
            [2006, 9098, 36, 23],
            [2006, 9099, 19, 13],
            [2006, 9100, 33, 22],
            [2006, 9101, 15, 17],
            [2006, 9102, 36, 28],
            [2006, 9103, 24, 22],
            [2006, 9104, 36, 28],
            [2006, 9105, 21, 14],
            [2006, 9106, 28, 15],
            [2006, 9107, 33, 25],
            [2006, 9108, 34, 25],
            [2006, 9109, 32, 26],
            [2006, 9110, 35, 28],
            [2006, 9111, 25, 13],
            [2006, 9112, 41, 33],
            [2006, 9113, 32, 27],
            [2006, 9114, 41, 25],
            [2006, 9115, 14, 14],
            [2006, 9116, 22, 15],
            [2006, 9117, 28, 12],
            [2006, 9118, 33, 27],
            [2006, 9119, 17, 12],
            [2006, 9120, 24, 20],
            [2006, 9121, 30, 25],
            [2006, 9122, 37, 29],
            [2006, 9123, 26, 18],
            [2006, 9124, 38, 30],
            [2006, 9125, 16, 23],
            [2006, 9126, 38, 32],
            [2006, 9127, 28, 25],
            [2006, 9128, 34, 27],
            [2006, 9129, 34, 29],
            [2006, 9130, 43, 32],
            [2006, 9131, 25, 25],
            [2006, 9132, 32, 30],
            [2006, 9133, 26, 18],
            [2006, 9134, 30, 26],
            [2006, 9135, 42, 29],
            [2006, 9136, 33, 28],
            [2006, 9137, 16, 11],
            [2006, 9138, 18, 15],
            [2006, 9139, 27, 24],
            [2006, 9140, 32, 30],
            [2006, 9141, 25, 23],
            [2006, 9142, 38, 34],
            [2006, 9143, 20, 20],
            [2006, 9144, 23, 26],
            [2006, 9145, 32, 26],
            [2006, 9146, 40, 31],
            [2006, 9149, 20, 16],
            [2006, 9150, 20, 20],
            [2006, 9151, 20, 20],
            [2006, 9152, 21, 21],
            [2006, 9153, 12, 13],
            [2006, 9154, 14, 14],
            [2006, 9155, 20, 20],
            [2006, 9156, 22, 22],
            [2006, 9157, 21, 22],
            [2006, 9158, 13, 13],
            [2006, 9159, 20, 22],
            [2006, 9160, 16, 14],
            [2006, 9161, 17, 17],
            [2006, 9162, 21, 22],
            [2006, 9163, 20, 20],
            [2006, 9164, 20, 17],
            [2006, 9165, 19, 21],
            [2006, 9166, 17, 17],
            [2006, 9167, 15, 15],
            [2006, 9168, 22, 21],
            [2006, 9169, 22, 21],
            [2006, 9170, 22, 25],
            [2006, 9171, 21, 20],
            [2006, 9172, 20, 18],
            [2006, 9173, 18, 20],
            [2006, 9174, 16, 17],
            [2006, 9175, 17, 16],
            [2006, 9176, 11, 14],
            [2006, 9177, 19, 17],
            [2006, 9178, 16, 19],
            [2006, 9179, 20, 22],
            [2006, 9180, 15, 15],
            [2006, 9181, 21, 20],
            [2006, 9182, 20, 20],
            [2006, 9183, 20, 21],
            [2006, 9184, 22, 21],
            [2006, 9185, 20, 19],
            [2006, 9186, 13, 14],
            [2006, 9187, 21, 20],
            [2006, 9188, 21, 20],
            [2006, 9189, 21, 21],
            [2006, 9190, 14, 14],
            [2006, 9191, 19, 18],
            [2006, 9192, 17, 18],
            [2006, 9193, 21, 22],
            [2006, 9194, 26, 28],
            [2006, 9195, 28, 30],
            [2006, 9196, 29, 22],
            [2006, 9198, 26, 22],
            [2006, 9199, 25, 22],
            [2006, 9200, 25, 22],
            [2006, 9201, 32, 27],
            [2006, 9202, 32, 29],
            [2006, 9203, 10, 12],
            [2006, 9204, 9, 10],
            [2006, 9209, 24, 22],
            [2006, 9211, 32, 31],
            [2006, 9214, 37, 32],
            [2006, 9218, 22, 20],
            [2006, 9226, 37, 26],
            [2006, 9227, 40, 33],
            [2006, 9228, 35, 37],
            [2006, 9229, 33, 33],
            [2006, 9230, 32, 27],
            [2006, 9232, 33, 29],
            [2006, 9233, 29, 30],
            [2006, 9234, 29, 30],
            [2006, 9235, 29, 30],
            [2006, 9237, 28, 19],
            [2006, 9238, 32, 30],
            [2006, 9242, 33, 30],
            [2006, 9244, 37, 32],
            [2006, 9245, 24, 24],
            [2006, 9248, 32, 26],
            [2006, 9254, 70, 70],
            [2006, 9255, 43, 31],
            [2006, 9257, 53, 46],
            [2006, 9258, 33, 70],
            [2006, 9259, 43, 44],
            [2006, 9260, 38, 33],
            [2006, 9261, 55, 64],
            [2006, 9263, 40, 40],
            [2006, 9264, 34, 36],
            [2006, 9265, 37, 39],
            [2006, 9266, 61, 64],
            [2006, 9267, 56, 52],
            [2006, 9268, 52, 50],
            [2006, 9269, 72, 69],
            [2006, 9270, 66, 68],
            [2006, 9271, 68, 69],
            [2006, 9272, 68, 74],
            [2006, 9273, 71, 75],
            [2006, 9274, 76, 67],
            [2006, 9275, 44, 43],
            [2006, 9276, 70, 67],
            [2006, 9277, 63, 51],
            [2006, 9278, 69, 68],
            [2006, 9279, 69, 63],
            [2006, 9280, 46, 45],
            [2006, 9281, 73, 59],
            [2006, 9282, 70, 67],
            [2006, 9283, 64, 62],
            [2006, 9284, 92, 90],
            [2006, 9285, 56, 58],
            [2006, 9286, 85, 88],
            [2006, 9287, 89, 85],
            [2006, 9288, 52, 38],
            [2006, 9289, 78, 81],
            [2006, 9290, 59, 66],
            [2006, 9291, 82, 79],
            [2006, 9292, 70, 70],
            [2006, 9293, 59, 42],
            [2006, 9294, 48, 86],
            [2006, 9295, 62, 70],
            [2006, 9296, 65, 80],
            [2006, 9297, 100, 95],
            [2006, 9298, 60, 65],
            [2006, 9299, 81, 86],
            [2006, 9300, 81, 80],
            [2006, 9301, 62, 66],
            [2006, 9302, 95, 90],
            [2006, 9303, 71, 78],
            [2006, 9304, 75, 130],
            [2006, 9305, 74, 82],
            [2006, 9306, 97, 90],
            [2006, 9307, 40, 51],
            [2006, 9308, 51, 63],
            [2006, 9309, 46, 104],
            [2006, 9310, 57, 100],
            [2006, 9311, 50, 54],
            [2006, 9312, 57, 60],
            [2006, 9313, 53, 59],
            [2006, 9314, 71, 77],
            [2006, 9315, 31, 31],
            [2006, 9316, 37, 25],
            [2006, 9317, 12, 14],
            [2006, 9318, 13, 15],
            [2006, 9319, 28, 32],
            [2006, 9320, 38, 36],
            [2006, 9327, 12, 14],
            [2006, 9328, 19, 20],
            [2006, 9329, 27, 28],
            [2006, 9330, 34, 34],
            [2006, 9331, 22, 22],
            [2006, 9332, 22, 25],
            [2006, 9333, 11, 14],
            [2006, 9334, 11, 12],
            [2006, 9335, 22, 22],
            [2006, 9336, 20, 20],
            [2006, 9337, 13, 16],
            [2006, 9338, 10, 12],
            [2006, 9339, 15, 17],
            [2006, 9340, 35, 32],
            [2006, 9341, 17, 20],
            [2006, 9342, 24, 24],
            [2006, 9343, 8, 9],
            [2006, 9344, 15, 15],
            [2006, 9345, 16, 20],
            [2006, 9346, 12, 13],
            [2006, 9347, 10, 11],
            [2006, 9348, 21, 20],
            [2006, 9349, 16, 19],
            [2006, 9350, 33, 34],
            [2006, 9351, 28, 23],
            [2006, 9352, 32, 30],
            [2006, 9353, 15, 18],
            [2006, 9354, 23, 24],
            [2006, 9355, 17, 15],
            [2006, 9356, 27, 25],
            [2006, 9357, 15, 18],
            [2006, 9358, 20, 21],
            [2006, 9359, 16, 20],
            [2006, 9360, 22, 26],
            [2006, 9361, 20, 18],
            [2006, 9362, 27, 26],
            [2006, 9363, 20, 20],
            [2006, 9364, 30, 22],
            [2006, 9365, 16, 19],
            [2006, 9366, 41, 38],
            [2006, 9367, 19, 21],
            [2006, 9368, 47, 43],
            [2006, 9369, 26, 27],
            [2006, 9370, 15, 16],
            [2006, 9371, 22, 23],
            [2006, 9372, 41, 30],
            [2006, 9373, 18, 18],
            [2006, 9374, 29, 28],
            [2006, 9375, 17, 19],
            [2006, 9376, 41, 37],
            [2006, 9377, 12, 12],
            [2006, 9378, 17, 19],
            [2006, 9379, 23, 28],
            [2006, 9380, 20, 23],
            [2006, 9381, 45, 39],
            [2006, 9382, 21, 26],
            [2006, 9383, 41, 30],
            [2006, 9384, 15, 15],
            [2006, 9385, 15, 16],
            [2006, 9386, 14, 14],
            [2006, 9387, 13, 13],
            [2006, 9388, 13, 14],
            [2006, 9389, 15, 14],
            [2006, 9390, 16, 18],
            [2006, 9391, 21, 21],
            [2006, 9392, 17, 17],
            [2006, 9393, 21, 19],
            [2006, 9394, 12, 12],
            [2006, 9395, 17, 18],
            [2006, 9396, 17, 20],
            [2006, 9397, 34, 32],
            [2006, 9398, 29, 35],
            [2006, 9399, 39, 37],
            [2006, 9400, 20, 21],
            [2006, 9401, 66, 64],
            [2006, 9402, 34, 25],
            [2006, 9403, 92, 69],
            [2006, 9406, 85, 73],
            [2006, 9411, 90, 67],
            [2006, 9416, 50, 60],
            [2006, 9417, 92, 70],
            [2006, 9420, 91, 68],
            [2006, 9423, 73, 65],
            [2006, 9428, 90, 69],
            [2006, 9431, 91, 68],
            [2006, 9436, 78, 69],
            [2006, 9443, 91, 69],
            [2006, 9444, 90, 67],
            [2006, 9451, 85, 70],
            [2006, 9452, 91, 71],
            [2006, 9453, 82, 63],
            [2006, 9456, 78, 69],
            [2006, 9457, 76, 71],
            [2006, 9458, 91, 69],
            [2006, 9465, 45, 36],
            [2006, 9470, 90, 68],
            [2006, 9473, 41, 43],
            [2006, 9474, 85, 76],
            [2006, 9477, 32, 35],
            [2006, 9478, 45, 42],
            [2006, 9487, 24, 29],
            [2006, 9488, 41, 42],
            [2006, 9491, 37, 38],
            [2006, 9492, 47, 41],
            [2006, 9497, 39, 26],
            [2006, 9498, 84, 43],
            [2006, 9509, 73, 73],
            [2006, 9519, 21, 25],
            [2006, 9520, 73, 53],
            [2006, 9525, 21, 20],
            [2006, 9526, 42, 37],
            [2006, 9529, 32, 28],
            [2006, 9530, 46, 39],
            [2006, 9531, 37, 34],
            [2006, 9532, 69, 70],
            [2006, 9539, 43, 34],
            [2006, 9540, 66, 70],
            [2006, 9541, 34, 33],
            [2006, 9542, 46, 39],
            [2006, 9543, 32, 34],
            [2006, 9544, 44, 38],
            [2006, 9547, 32, 35],
            [2006, 9548, 45, 39],
            [2006, 9549, 29, 29],
            [2006, 9550, 46, 36],
            [2006, 9551, 32, 34],
            [2006, 9552, 69, 70],
            [2006, 9553, 37, 32],
            [2006, 9554, 45, 39],
            [2006, 9555, 44, 45],
            [2006, 9556, 70, 76],
            [2006, 9557, 39, 34],
            [2006, 9558, 74, 70],
            [2006, 9561, 38, 40],
            [2006, 9562, 61, 74],
            [2006, 9581, 41, 39],
            [2006, 9582, 45, 42],
            [2006, 9593, 32, 34],
            [2006, 9594, 52, 71],
            [2006, 9595, 34, 34],
            [2006, 9596, 45, 43],
            [2006, 9597, 25, 23],
            [2006, 9598, 54, 50],
            [2006, 9609, 31, 31],
            [2006, 9610, 43, 38],
            [2006, 9611, 40, 33],
            [2006, 9612, 45, 38],
            [2006, 9613, 46, 45],
            [2006, 9614, 72, 76],
            [2006, 9617, 17, 15],
            [2006, 9618, 44, 38],
            [2006, 9619, 21, 20],
            [2006, 9620, 21, 20],
            [2006, 9633, 41, 39],
            [2006, 9634, 72, 69],
            [2006, 9639, 17, 20],
            [2006, 9640, 64, 53],
            [2006, 9641, 42, 30],
            [2006, 9642, 85, 65],
            [2006, 9643, 26, 30],
            [2006, 9644, 45, 42],
            [2006, 9651, 85, 56],
            [2006, 9652, 85, 56],
            [2006, 9653, 47, 42],
            [2006, 9654, 50, 32],
            [2006, 9661, 72, 42],
            [2006, 9662, 90, 40],
            [2006, 9663, 66, 42],
            [2006, 9664, 66, 42],
            [2006, 9665, 38, 33],
            [2006, 9666, 44, 33],
            [2006, 9667, 21, 18],
            [2006, 9668, 32, 28],
            [2006, 9670, 75, 44],
            [2006, 9673, 34, 23],
            [2006, 9674, 44, 24],
            [2006, 9675, 26, 28],
            [2006, 9676, 45, 36],
            [2006, 9677, 20, 21],
            [2006, 9678, 35, 25],
            [2006, 9681, 40, 32],
            [2006, 9682, 52, 33],
            [2006, 9687, 17, 23],
            [2006, 9689, 22, 21],
            [2006, 9690, 38, 30],
            [2006, 9691, 45, 28],
            [2006, 9692, 38, 31],
            [2006, 9693, 33, 29],
            [2006, 9694, 40, 32],
            [2006, 9695, 33, 32],
            [2006, 9696, 40, 31],
            [2006, 9699, 23, 26],
            [2006, 9700, 71, 40],
            [2006, 9701, 25, 22],
            [2006, 9702, 70, 35],
            [2006, 9704, 65, 34],
            [2006, 9705, 33, 38],
            [2006, 9706, 68, 44],
            [2006, 9709, 21, 17],
            [2006, 9710, 24, 18],
            [2006, 9711, 25, 30],
            [2006, 9712, 25, 29],
            [2006, 9713, 31, 31],
            [2006, 9714, 35, 46],
            [2006, 9715, 58, 44],
            [2006, 9716, 25, 24],
            [2006, 9717, 35, 31],
            [2006, 9718, 28, 26],
            [2006, 9720, 45, 36],
            [2006, 9721, 58, 35],
            [2006, 9722, 37, 40],
            [2006, 9723, 51, 37],
            [2006, 9724, 57, 49],
            [2006, 9725, 64, 44],
            [2006, 9726, 24, 26],
            [2006, 9727, 45, 30],
            [2006, 9728, 25, 24],
            [2006, 9729, 21, 23],
            [2006, 9730, 40, 47],
            [2006, 9731, 64, 52],
            [2006, 9735, 42, 40],
            [2006, 9736, 48, 45],
            [2006, 9737, 30, 20],
            [2006, 9738, 35, 40],
            [2006, 9739, 45, 37],
            [2006, 9740, 85, 85],
            [2006, 9741, 73, 61],
            [2006, 9742, 49, 41],
            [2006, 9743, 31, 27],
            [2006, 9744, 68, 44],
            [2006, 9745, 40, 23],
            [2006, 9746, 43, 28],
            [2006, 9747, 38, 44],
            [2006, 9748, 38, 38],
            [2006, 9751, 34, 36],
            [2006, 9752, 37, 45],
            [2006, 9755, 33, 31],
            [2006, 9756, 35, 32],
            [2006, 9757, 18, 16],
            [2006, 9758, 25, 18],
            [2006, 9759, 15, 14],
            [2006, 9760, 36, 27],
            [2006, 9761, 43, 33],
            [2006, 9762, 34, 26],
            [2006, 9763, 25, 19],
            [2006, 9764, 31, 21],
            [2006, 9765, 35, 30],
            [2006, 9766, 28, 22],
            [2006, 9767, 48, 29],
            [2006, 9768, 28, 23],
            [2006, 9769, 18, 19],
            [2006, 9770, 40, 31],
            [2006, 9771, 46, 38],
            [2006, 9772, 39, 29],
            [2006, 9773, 38, 29],
            [2006, 9774, 29, 19],
            [2006, 9775, 25, 20],
            [2006, 9776, 42, 27],
            [2006, 9777, 36, 27],
            [2006, 9778, 40, 30],
            [2006, 9779, 34, 31],
            [2006, 9780, 37, 28],
            [2006, 9781, 42, 28],
            [2006, 9782, 57, 35],
            [2006, 9783, 57, 42],
            [2006, 9784, 26, 20],
            [2006, 9785, 25, 20],
            [2006, 9786, 18, 13],
            [2006, 9787, 33, 26],
            [2006, 9788, 45, 30],
            [2006, 9789, 32, 26],
            [2006, 9790, 34, 26],
            [2006, 9791, 70, 40],
            [2006, 9792, 45, 37],
            [2006, 9793, 15, 12],
            [2006, 9794, 14, 12],
            [2006, 9795, 12, 12],
            [2006, 9796, 17, 17],
            [2006, 9797, 14, 11],
            [2006, 9798, 14, 13],
            [2006, 9799, 44, 40],
            [2006, 9800, 20, 19],
            [2006, 9801, 18, 14],
            [2006, 9802, 17, 14],
            [2006, 9803, 9, 9],
            [2006, 9804, 16, 13],
            [2006, 9805, 31, 23],
            [2006, 9806, 22, 17],
            [2006, 9807, 25, 15],
            [2006, 9808, 85, 53],
            [2006, 9809, 51, 28],
            [2006, 9811, 41, 24],
            [2006, 9812, 50, 30],
            [2006, 9813, 65, 37],
            [2006, 9814, 20, 13],
            [2006, 9815, 39, 23],
            [2006, 9816, 50, 27],
            [2006, 9817, 28, 15],
            [2006, 9818, 54, 24],
            [2006, 9819, 65, 50],
            [2006, 9820, 82, 52],
            [2006, 9821, 42, 32],
            [2006, 9822, 22, 18],
            [2006, 9823, 30, 20],
            [2006, 9824, 33, 35],
            [2006, 9825, 18, 15],
            [2006, 9826, 43, 30],
            [2006, 9827, 44, 29],
            [2006, 9828, 39, 28],
            [2006, 9829, 36, 24],
            [2006, 9830, 32, 24],
            [2006, 9831, 36, 23],
            [2006, 9832, 40, 26],
            [2006, 9833, 29, 22],
            [2006, 9834, 70, 44],
            [2006, 9835, 30, 26],
            [2006, 9836, 58, 46],
            [2006, 9837, 31, 25],
            [2006, 9838, 56, 41],
            [2006, 9839, 16, 15],
            [2006, 9840, 72, 43],
            [2006, 9841, 66, 40],
            [2006, 9842, 30, 19],
            [2006, 9843, 27, 23],
            [2006, 9844, 33, 26],
            [2006, 9845, 31, 25],
            [2006, 9846, 26, 18],
            [2006, 9847, 14, 11],
            [2006, 9848, 26, 17],
            [2006, 9849, 28, 22],
            [2006, 9850, 23, 16],
            [2006, 9851, 22, 17],
            [2006, 9852, 20, 16],
            [2006, 9853, 24, 18],
            [2006, 9854, 14, 11],
            [2006, 9855, 38, 29],
            [2006, 9856, 17, 17],
            [2006, 9857, 15, 13],
            [2006, 9858, 37, 35],
            [2006, 9859, 53, 34],
            [2006, 9860, 65, 36],
            [2006, 9861, 49, 44],
            [2006, 9862, 28, 24],
            [2006, 9863, 38, 26],
            [2006, 9864, 55, 30],
            [2006, 9865, 36, 26],
            [2006, 9866, 53, 32],
            [2006, 9867, 19, 16],
            [2006, 9868, 40, 27],
            [2006, 9869, 40, 30],
            [2006, 9870, 40, 38],
            [2006, 9871, 40, 26],
            [2006, 9872, 28, 23],
            [2006, 9873, 45, 37],
            [2006, 9874, 38, 34],
            [2006, 9875, 26, 21],
            [2006, 9876, 25, 21],
            [2006, 9877, 33, 36],
            [2006, 9878, 35, 28],
            [2006, 9879, 36, 31],
            [2006, 9880, 38, 41],
            [2006, 9881, 60, 47],
            [2006, 9882, 51, 41],
            [2006, 9883, 31, 23],
            [2006, 9884, 31, 33],
            [2006, 9885, 39, 24],
            [2006, 9886, 36, 23],
            [2006, 9887, 35, 24],
            [2006, 9888, 44, 32],
            [2006, 9889, 42, 28],
            [2006, 9890, 37, 29],
            [2006, 9891, 28, 21],
            [2006, 9892, 31, 24],
            [2006, 9893, 32, 17],
            [2006, 9894, 40, 28],
            [2006, 9895, 26, 16],
            [2006, 9896, 11, 11],
            [2006, 9897, 33, 27],
            [2006, 9898, 31, 25],
            [2006, 9899, 24, 19],
            [2006, 9900, 51, 46],
            [2006, 9901, 43, 34],
            [2006, 9902, 78, 53],
            [2006, 9903, 56, 43],
            [2006, 9904, 50, 38],
            [2006, 9905, 50, 44],
            [2006, 9906, 36, 23],
            [2006, 9907, 28, 26],
            [2006, 9908, 51, 36],
            [2006, 9909, 16, 14],
            [2006, 9910, 48, 41],
            [2006, 9911, 60, 40],
            [2006, 9912, 45, 36],
            [2006, 9913, 22, 19],
            [2006, 9914, 30, 23],
            [2006, 9915, 27, 24],
            [2006, 9916, 37, 26],
            [2006, 9917, 33, 34],
            [2006, 9918, 65, 38],
            [2006, 9919, 48, 37],
            [2006, 9920, 81, 62],
            [2006, 9921, 26, 23],
            [2006, 9922, 24, 15],
            [2006, 9923, 31, 17],
            [2006, 9924, 39, 24],
            [2006, 9925, 47, 55],
            [2006, 9926, 53, 42],
            [2006, 9927, 30, 32],
            [2006, 9928, 50, 29],
            [2006, 9929, 48, 36],
            [2006, 9930, 36, 26],
            [2006, 9931, 58, 36],
            [2006, 9932, 81, 68],
            [2006, 9933, 47, 49],
            [2006, 9934, 43, 32],
            [2006, 9935, 37, 35],
            [2006, 9936, 34, 32],
            [2006, 9937, 28, 38],
            [2006, 9938, 16, 14],
            [2006, 9939, 44, 45],
            [2006, 9940, 35, 36],
            [2006, 9941, 36, 21],
            [2006, 9942, 20, 17],
            [2006, 9943, 50, 39],
            [2006, 9944, 47, 36],
            [2006, 9945, 60, 33],
            [2006, 9946, 41, 26],
            [2006, 9947, 50, 28],
            [2006, 9948, 100, 64],
            [2006, 9949, 70, 48],
            [2006, 9950, 50, 32],
            [2006, 9951, 33, 29],
            [2006, 9952, 45, 25],
            [2006, 9953, 22, 19],
            [2006, 9954, 100, 63],
            [2006, 9955, 21, 20],
            [2006, 9956, 38, 29],
            [2006, 9957, 71, 37],
            [2006, 9958, 31, 23],
            [2006, 9959, 85, 42],
            [2006, 9960, 44, 23],
            [2006, 9961, 39, 31],
            [2006, 9962, 29, 30],
            [2006, 9963, 70, 34],
            [2006, 9964, 41, 28],
            [2006, 9965, 33, 17],
            [2006, 9966, 58, 29],
            [2006, 9967, 75, 30],
            [2006, 9968, 36, 30],
            [2006, 9969, 24, 19],
            [2006, 9970, 54, 28],
            [2006, 9971, 34, 24],
            [2006, 9972, 85, 37],
            [2006, 9973, 47, 32],
            [2006, 9974, 33, 20],
            [2006, 9975, 80, 34],
            [2006, 9976, 65, 37],
            [2006, 9977, 33, 19],
            [2006, 9978, 54, 23],
            [2006, 9979, 73, 34],
            [2006, 9980, 48, 22],
            [2006, 9981, 27, 16],
            [2006, 9982, 16, 13],
            [2006, 9983, 55, 28],
            [2006, 9984, 35, 23],
            [2006, 9985, 36, 21],
            [2006, 9986, 37, 23],
            [2006, 9987, 42, 34],
            [2006, 9988, 65, 42],
            [2006, 9989, 33, 26],
            [2006, 9990, 32, 26],
            [2006, 9991, 38, 29],
            [2006, 9992, 39, 39],
            [2006, 9993, 31, 31],
            [2006, 9994, 25, 22],
            [2006, 9995, 37, 31],
            [2006, 9996, 32, 27],
            [2006, 9997, 16, 25],
            [2006, 9998, 17, 15],
            [2006, 9999, 26, 28],
            [2006, 10000, 23, 18],
            [2006, 10001, 18, 15],
            [2006, 10002, 16, 13],
            [2006, 10003, 47, 27],
            [2006, 10004, 33, 22],
            [2006, 10005, 22, 17],
            [2006, 10006, 29, 22],
            [2006, 10007, 47, 38],
            [2006, 10008, 45, 41],
            [2006, 10009, 45, 28],
            [2006, 10017, 37, 27],
            [2006, 10018, 52, 32],
            [2006, 10032, 75, 42],
            [2006, 10037, 79, 35],
            [2006, 10038, 40, 25],
            [2006, 10046, 58, 35],
            [2006, 10047, 42, 26],
            [2006, 10049, 35, 30],
            [2006, 10056, 56, 50],
            [2006, 10057, 60, 49],
            [2006, 10058, 25, 29],
            [2006, 10059, 50, 31],
            [2006, 10065, 35, 50],
            [2006, 10066, 57, 65],
            [2006, 10071, 45, 35],
            [2006, 10076, 45, 29],
            [2006, 10091, 46, 30],
            [2006, 10094, 60, 42],
            [2006, 10098, 54, 37],
            [2006, 10101, 77, 50],
            [2006, 10102, 60, 38],
            [2006, 10103, 70, 48],
            [2006, 10109, 157, 57],
            [2006, 10110, 50, 45],
            [2006, 10111, 100, 48],
            [2006, 10112, 95, 46],
            [2006, 10113, 105, 61],
            [2006, 10114, 80, 38],
            [2006, 10117, 73, 45],
            [2006, 10122, 87, 57],
            [2006, 10125, 75, 44],
            [2006, 10127, 42, 30],
            [2006, 10128, 50, 40],
            [2006, 10131, 52, 38],
            [2006, 10132, 50, 31],
            [2006, 10133, 78, 38],
            [2006, 10139, 55, 41],
            [2006, 10144, 50, 29],
            [2006, 10180, 40, 24],
            [2006, 10183, 37, 24],
            [2006, 10184, 47, 31],
            [2006, 10185, 27, 22],
            [2006, 10186, 27, 22],
            [2006, 10187, 18, 15],
            [2006, 10188, 47, 30],
            [2006, 10189, 45, 29],
            [2006, 10190, 18, 13],
            [2006, 10191, 40, 24],
            [2006, 10192, 29, 21],
            [2006, 10193, 18, 18],
            [2006, 10194, 14, 11],
            [2006, 10195, 13, 11],
            [2006, 10490, 18, 26],
            [2006, 10491, 9, 18],
            [2006, 10492, 8, 13],
            [2006, 10493, 32, 38],
            [2006, 10494, 11, 30],
            [2006, 10495, 10, 27],
            [2006, 10496, 7, 15],
            [2006, 10497, 28, 39],
            [2006, 10498, 8, 15],
            [2006, 10499, 9, 35],
            [2006, 10500, 10, 33],
            [2006, 10501, 10, 39],
            [2006, 10502, 28, 51],
            [2006, 10503, 11, 35],
            [2006, 10504, 12, 45],
            [2006, 10505, 31, 39],
            [2006, 10506, 12, 24],
            [2006, 10507, 9, 18],
            [2006, 10508, 22, 45],
            [2006, 10509, 29, 35],
            [2006, 10510, 12, 32],
            [2006, 10511, 8, 17],
            [2006, 10514, 15, 21],
            [2006, 10515, 15, 22],
            [2006, 10516, 14, 19],
            [2006, 10518, 14, 14],
            [2006, 10519, 17, 14],
            [2006, 10520, 9, 9],
            [2006, 10521, 14, 17],
            [2006, 10522, 16, 18],
            [2006, 10523, 14, 18],
            [2006, 10524, 21, 20],
            [2006, 10525, 15, 18],
            [2006, 10526, 14, 17],
            [2006, 10527, 11, 13],
            [2006, 10528, 17, 18],
            [2006, 10529, 17, 18],
            [2006, 10530, 14, 18],
            [2006, 10531, 14, 16],
            [2006, 10532, 22, 21],
            [2006, 10533, 32, 27],
            [2006, 10534, 20, 13],
            [2006, 10535, 31, 25],
            [2006, 10536, 16, 19],
            [2006, 10537, 22, 20],
            [2006, 10538, 29, 24],
            [2006, 10539, 17, 17],
            [2006, 10540, 31, 25],
            [2006, 10541, 34, 29],
            [2006, 10542, 35, 27],
            [2006, 10543, 7, 7],
            [2006, 10544, 11, 9],
            [2006, 10545, 7, 7],
            [2006, 10546, 10, 8],
            [2006, 10547, 8, 8],
            [2006, 10548, 12, 9],
            [2006, 10549, 8, 8],
            [2006, 10550, 9, 11],
            [2006, 10551, 9, 8],
            [2006, 10552, 7, 7],
            [2006, 10553, 24, 16],
            [2006, 10554, 19, 13],
            [2006, 10555, 11, 8],
            [2006, 10556, 20, 13],
            [2006, 10557, 10, 10],
            [2006, 10558, 29, 20],
            [2006, 10559, 13, 9],
            [2006, 10560, 20, 13],
            [2006, 10577, 20, 13],
            [2006, 10578, 34, 34],
            [2006, 10579, 46, 34],
            [2006, 10580, 61, 38],
            [2006, 10581, 60, 51],
            [2006, 10582, 52, 39],
            [2006, 10583, 46, 32],
            [2006, 10584, 47, 41],
            [2006, 10585, 40, 40],
            [2006, 10586, 49, 45],
            [2006, 10587, 46, 39],
            [2006, 10588, 41, 38],
            [2006, 10589, 46, 41],
            [2006, 10590, 56, 45],
            [2006, 10591, 74, 60],
            [2006, 10592, 47, 31],
            [2006, 10593, 46, 39],
            [2006, 10594, 51, 47],
            [2006, 10595, 41, 40],
            [2006, 10596, 40, 37],
            [2006, 10597, 46, 38],
            [2006, 10598, 51, 31],
            [2006, 10603, 36, 33],
            [2006, 10604, 33, 24],
            [2006, 10605, 14, 11],
            [2006, 10606, 13, 10],
            [2006, 10607, 15, 12],
            [2006, 10608, 14, 10],
            [2006, 10609, 13, 10],
            [2006, 10610, 20, 11],
            [2006, 10611, 20, 14],
            [2006, 10612, 17, 14],
            [2006, 10613, 40, 28],
            [2006, 10614, 39, 23],
            [2006, 10615, 42, 29],
            [2006, 10616, 32, 23],
            [2006, 10617, 43, 30],
            [2006, 10618, 43, 26],
            [2006, 10619, 28, 21],
            [2006, 10620, 28, 19],
            [2006, 10621, 32, 24],
            [2006, 10622, 30, 18],
            [2006, 10623, 39, 25],
            [2006, 10624, 39, 24],
            [2006, 10625, 28, 20],
            [2006, 10626, 36, 23],
            [2006, 10627, 39, 29],
            [2006, 10628, 42, 28],
            [2006, 10629, 44, 28],
            [2006, 10630, 36, 24],
            [2006, 10631, 36, 23],
            [2006, 10632, 34, 21],
            [2006, 10633, 46, 32],
            [2006, 10634, 43, 28],
            [2006, 10635, 43, 29],
            [2006, 10636, 36, 25],
            [2006, 10637, 43, 29],
            [2006, 10638, 21, 15],
            [2006, 10639, 45, 29],
            [2006, 10640, 44, 26],
            [2006, 10641, 38, 27],
            [2006, 10642, 47, 28],
            [2006, 10643, 39, 25],
            [2006, 10644, 46, 30],
            [2006, 10645, 30, 28],
            [2006, 10646, 41, 27],
            [2006, 10647, 44, 28],
            [2006, 10648, 40, 31],
            [2006, 10649, 41, 25],
            [2006, 10650, 41, 29],
            [2006, 10651, 38, 30],
            [2006, 10652, 32, 22],
            [2006, 10653, 42, 28],
            [2006, 10654, 35, 28],
            [2006, 10655, 44, 31],
            [2006, 10656, 42, 28],
            [2006, 10657, 37, 26],
            [2006, 10658, 45, 26],
            [2006, 10659, 18, 16],
            [2006, 10660, 45, 30],
            [2006, 10661, 51, 27],
            [2006, 10662, 44, 27],
            [2006, 10663, 31, 24],
            [2006, 10664, 32, 26],
            [2006, 10665, 43, 31],
            [2006, 10666, 53, 30],
            [2006, 10667, 47, 30],
            [2006, 10668, 35, 26],
            [2006, 10669, 20, 16],
            [2006, 10670, 31, 23],
            [2006, 10671, 43, 27],
            [2006, 10672, 45, 25],
            [2006, 10673, 29, 21],
            [2006, 10674, 31, 20],
            [2006, 10675, 39, 31],
            [2006, 10676, 39, 31],
            [2006, 10677, 32, 21],
            [2006, 10678, 36, 23],
            [2006, 10679, 46, 26],
            [2006, 10680, 34, 27],
            [2006, 10681, 42, 31],
            [2006, 10682, 39, 24],
            [2006, 10683, 31, 22],
            [2006, 10684, 26, 19],
            [2006, 10685, 70, 37],
            [2006, 10686, 37, 31],
            [2006, 10687, 39, 30],
            [2006, 10688, 48, 34],
            [2006, 10689, 48, 30],
            [2006, 10690, 49, 31],
            [2006, 10691, 49, 31],
            [2006, 10692, 36, 27],
            [2006, 10693, 57, 30],
            [2006, 10694, 47, 29],
            [2006, 10695, 46, 28],
            [2006, 10696, 45, 27],
            [2006, 10697, 30, 22],
            [2006, 10698, 32, 26],
            [2006, 10699, 38, 32],
            [2006, 10700, 20, 15],
            [2006, 10701, 44, 28],
            [2006, 10702, 53, 26],
            [2006, 10703, 53, 26],
            [2006, 10704, 42, 25],
            [2006, 10705, 39, 22],
            [2006, 10706, 42, 30],
            [2006, 10707, 38, 34],
            [2006, 10708, 47, 32],
            [2006, 10709, 43, 35],
            [2006, 10710, 51, 28],
            [2006, 10711, 43, 28],
            [2006, 10712, 44, 33],
            [2006, 10713, 50, 32],
            [2006, 10714, 40, 26],
            [2006, 10715, 49, 29],
            [2006, 10716, 42, 31],
            [2006, 10717, 44, 31],
            [2006, 10718, 39, 33],
            [2006, 10719, 47, 30],
            [2006, 10720, 50, 31],
            [2006, 10721, 26, 19],
            [2006, 10722, 49, 31],
            [2006, 10723, 44, 30],
            [2006, 10724, 45, 31],
            [2006, 10725, 42, 34],
            [2006, 10726, 34, 24],
            [2006, 10727, 44, 26],
            [2006, 10728, 42, 26],
            [2006, 10729, 43, 30],
            [2006, 10730, 49, 29],
            [2006, 10731, 37, 29],
            [2006, 10732, 49, 31],
            [2006, 10733, 43, 31],
            [2006, 10734, 45, 28],
            [2006, 10735, 43, 26],
            [2006, 10736, 45, 31],
            [2006, 10737, 56, 35],
            [2006, 10738, 45, 27],
            [2006, 10739, 26, 15],
            [2006, 10740, 43, 28],
            [2006, 10741, 42, 32],
            [2006, 10742, 43, 28],
            [2006, 10743, 40, 26],
            [2006, 10744, 39, 24],
            [2006, 10745, 42, 26],
            [2006, 10746, 44, 24],
            [2006, 10747, 26, 16],
            [2006, 10748, 33, 23],
            [2006, 10749, 40, 28],
            [2006, 10750, 44, 28],
            [2006, 10751, 44, 28],
            [2006, 10752, 43, 31],
            [2006, 10753, 44, 30],
            [2006, 10754, 34, 23],
            [2006, 10755, 18, 15],
            [2006, 10756, 70, 45],
            [2006, 10757, 20, 14],
            [2006, 10758, 27, 18],
            [2006, 10759, 45, 26],
            [2006, 10760, 46, 28],
            [2006, 10761, 40, 27],
            [2006, 10762, 44, 33],
            [2006, 10763, 36, 25],
            [2006, 10764, 24, 20],
            [2006, 10765, 34, 23],
            [2006, 10766, 49, 29],
            [2006, 10767, 45, 28],
            [2006, 10768, 39, 29],
            [2006, 10769, 41, 26],
            [2006, 10770, 44, 30],
            [2006, 10771, 45, 30],
            [2006, 10772, 31, 33],
            [2006, 10773, 42, 37],
            [2006, 10774, 38, 23],
            [2006, 10775, 43, 23],
            [2006, 10776, 35, 22],
            [2006, 10777, 25, 19],
            [2006, 10778, 54, 30],
            [2006, 10779, 31, 24],
            [2006, 10780, 43, 26],
            [2006, 10781, 40, 26],
            [2006, 10782, 39, 29],
            [2006, 10783, 41, 32],
            [2006, 10784, 41, 28],
            [2006, 10785, 45, 26],
            [2006, 10786, 40, 28],
            [2006, 10787, 45, 28],
            [2006, 10788, 40, 29],
            [2006, 10789, 42, 25],
            [2006, 10790, 45, 25],
            [2006, 10791, 45, 25],
            [2006, 10792, 35, 27],
            [2006, 10793, 42, 28],
            [2006, 10794, 44, 31],
            [2006, 10795, 43, 28],
            [2006, 10796, 40, 31],
            [2006, 10797, 40, 28],
            [2006, 10798, 38, 28],
            [2006, 10799, 19, 16],
            [2006, 10800, 40, 29],
            [2006, 10801, 50, 30],
            [2006, 10802, 42, 25],
            [2006, 10803, 34, 20],
            [2006, 10804, 48, 28],
            [2006, 10805, 54, 28],
            [2006, 10806, 40, 29],
            [2006, 10807, 44, 23],
            [2006, 10808, 34, 20],
            [2006, 10809, 28, 23],
            [2006, 10810, 44, 28],
            [2006, 10811, 36, 24],
            [2006, 10812, 109, 44],
            [2006, 10814, 36, 25],
            [2006, 10815, 44, 28],
            [2006, 10816, 43, 28],
            [2006, 10817, 44, 30],
            [2006, 10818, 45, 29],
            [2006, 10819, 44, 28],
            [2006, 10820, 42, 26],
            [2006, 10821, 38, 28],
            [2006, 10822, 41, 28],
            [2006, 10823, 42, 26],
            [2006, 10824, 37, 26],
            [2006, 10825, 38, 31],
            [2006, 10826, 37, 23],
            [2006, 10827, 36, 28],
            [2006, 10828, 33, 26],
            [2006, 10829, 42, 28],
            [2006, 10830, 44, 26],
            [2006, 10831, 44, 28],
            [2006, 10832, 43, 26],
            [2006, 10833, 43, 26],
            [2006, 10834, 44, 26],
            [2006, 10835, 44, 28],
            [2006, 10836, 40, 26],
            [2006, 10837, 46, 26],
            [2006, 10838, 41, 26],
            [2006, 10839, 34, 26],
            [2006, 10840, 26, 19],
            [2006, 10841, 60, 30],
            [2006, 10842, 32, 30],
            [2006, 10843, 41, 28],
            [2006, 10844, 34, 24],
            [2006, 10845, 30, 22],
            [2006, 10846, 30, 24],
            [2006, 10847, 40, 28],
            [2006, 10848, 41, 28],
            [2006, 10849, 44, 28],
            [2006, 10850, 38, 27],
            [2006, 10851, 41, 28],
            [2006, 10852, 43, 28],
            [2006, 10853, 48, 31],
            [2006, 10854, 41, 30],
            [2006, 10855, 45, 26],
            [2006, 10856, 42, 28],
            [2006, 10857, 45, 30],
            [2006, 10858, 40, 26],
            [2006, 10859, 45, 26],
            [2006, 10860, 48, 28],
            [2006, 10861, 45, 28],
            [2006, 10862, 45, 26],
            [2006, 10863, 23, 19],
            [2006, 10864, 51, 27],
            [2006, 10865, 40, 28],
            [2006, 10866, 36, 22],
            [2006, 10867, 41, 26],
            [2006, 10868, 44, 26],
            [2006, 10869, 53, 31],
            [2006, 10870, 48, 30],
            [2006, 10871, 44, 25],
            [2006, 10872, 47, 26],
            [2006, 10873, 45, 30],
            [2006, 10874, 46, 31],
            [2006, 10875, 45, 28],
            [2006, 10876, 47, 26],
            [2006, 10877, 42, 28],
            [2006, 10878, 43, 26],
            [2006, 10879, 45, 28],
            [2006, 10880, 45, 28],
            [2006, 10881, 30, 23],
            [2006, 10882, 49, 28],
            [2006, 10883, 53, 30],
            [2006, 10884, 56, 29],
            [2006, 10885, 45, 29],
            [2006, 10886, 40, 23],
            [2006, 10887, 36, 25],
            [2006, 10888, 50, 28],
            [2006, 10889, 43, 28],
            [2006, 10890, 33, 23],
            [2006, 10891, 29, 21],
            [2006, 10892, 29, 19],
            [2006, 10893, 43, 31],
            [2006, 10894, 44, 31],
            [2006, 10895, 67, 35],
            [2006, 10896, 44, 30],
            [2006, 10897, 45, 33],
            [2006, 10898, 43, 30],
            [2006, 10899, 48, 29],
            [2006, 10900, 41, 28],
            [2006, 10901, 39, 28],
            [2006, 10902, 31, 22],
            [2006, 10903, 45, 31],
            [2006, 10904, 43, 28],
            [2006, 10905, 36, 23],
            [2006, 10906, 45, 31],
            [2006, 10907, 42, 29],
            [2006, 10908, 44, 26],
            [2006, 10909, 48, 31],
            [2006, 10910, 39, 29],
            [2006, 10911, 46, 30],
            [2006, 10912, 48, 35],
            [2006, 10913, 36, 28],
            [2006, 10914, 54, 30],
            [2006, 10915, 46, 35],
            [2006, 10916, 48, 33],
            [2006, 10917, 49, 31],
            [2006, 10918, 34, 28],
            [2006, 10978, 41, 28],
            [2006, 10979, 42, 25],
            [2006, 10980, 34, 23],
            [2006, 11091, 8, 5],
            [2006, 11092, 10, 8],
            [2006, 11093, 12, 7],
            [2006, 11094, 13, 11],
            [2006, 11095, 10, 7],
            [2006, 11096, 17, 12],
            [2006, 11097, 10, 8],
            [2006, 11098, 9, 7],
            [2006, 11099, 32, 18],
            [2006, 11100, 12, 11],
            [2006, 11101, 11, 9],
            [2006, 11102, 12, 9],
            [2006, 11103, 13, 10],
            [2006, 11104, 38, 22],
            [2006, 11105, 30, 22],
            [2006, 11106, 25, 15],
            [2006, 11107, 14, 10],
            [2006, 11108, 9, 6],
            [2006, 11109, 16, 12],
            [2006, 11110, 13, 9],
            [2006, 11111, 11, 7],
            [2006, 11112, 22, 14],
            [2006, 11113, 23, 15],
            [2006, 11114, 38, 26],
            [2006, 11115, 7, 6],
            [2006, 11116, 8, 6],
            [2006, 11117, 8, 5],
            [2006, 11118, 13, 9],
            [2006, 11119, 36, 23],
            [2006, 11120, 26, 16],
            [2006, 11121, 9, 6],
            [2006, 11122, 12, 8],
            [2006, 11123, 15, 11],
            [2006, 11124, 9, 8],
            [2006, 11125, 23, 15],
            [2006, 11126, 12, 11],
            [2006, 11127, 7, 7],
            [2006, 11128, 12, 7],
            [2006, 11129, 7, 6],
            [2006, 11130, 15, 10],
            [2006, 11131, 7, 6],
            [2006, 11132, 24, 14],
            [2006, 11133, 11, 8],
            [2006, 11134, 6, 4],
            [2006, 11135, 42, 23],
            [2006, 11136, 10, 8],
            [2006, 11137, 6, 5],
            [2006, 11138, 19, 11],
            [2006, 11139, 10, 6],
            [2006, 11140, 10, 9],
            [2006, 11141, 8, 6],
            [2006, 11142, 9, 7],
            [2006, 11143, 7, 6],
            [2006, 11144, 9, 8],
            [2006, 11145, 29, 19],
            [2006, 11146, 7, 6],
            [2006, 11147, 5, 3],
            [2006, 11148, 31, 22],
            [2006, 11149, 17, 11],
            [2006, 11150, 18, 15],
            [2006, 11151, 21, 14],
            [2006, 11152, 16, 11],
            [2006, 11153, 13, 9],
            [2006, 11154, 25, 18],
            [2006, 11155, 17, 10],
            [2006, 11156, 11, 10],
            [2006, 11157, 14, 10],
            [2006, 11158, 13, 10],
            [2006, 11159, 20, 10],
            [2006, 11160, 28, 15],
            [2006, 11161, 12, 10],
            [2006, 11162, 18, 12],
            [2006, 11163, 13, 12],
            [2006, 11164, 17, 14],
            [2006, 11165, 17, 12],
            [2006, 11166, 35, 24],
            [2006, 11168, 24, 17],
            [2006, 11169, 8, 8],
            [2006, 11170, 10, 9],
            [2006, 11171, 11, 10],
            [2006, 11172, 10, 9],
            [2006, 11173, 12, 10],
            [2006, 11174, 6, 6],
            [2006, 11175, 6, 6],
            [2006, 11176, 6, 6],
            [2006, 11177, 21, 16],
            [2006, 11178, 7, 7],
            [2006, 11179, 13, 12],
            [2006, 11180, 13, 10],
            [2006, 11181, 16, 13],
            [2006, 11182, 14, 10],
            [2006, 11183, 12, 13],
            [2006, 11184, 92, 71],
            [2006, 11185, 92, 71],
            [2006, 11186, 92, 71],
            [2006, 11187, 92, 71],
            [2006, 11188, 92, 71],
            [2006, 11189, 70, 63],
            [2006, 11195, 17, 14],
            [2006, 11197, 106, 48],
            [2006, 11199, 69, 38],
            [2006, 11201, 10, 11],
            [2006, 11202, 43, 27],
            [2006, 11203, 11, 13],
            [2006, 11204, 72, 47],
            [2006, 11205, 106, 74],
            [2006, 11206, 57, 51],
            [2006, 11207, 10, 11],
            [2006, 11209, 210, 171],
            [2006, 11210, 704, 95],
            [2006, 11211, 97, 98],
            [2006, 11212, 704, 98],
            [2006, 11213, 704, 95],
            [2006, 11214, 704, 95],
            [2006, 11215, 97, 98],
            [2006, 11216, 704, 98],
            [2006, 11217, 97, 98],
            [2006, 11218, 704, 98],
            [2006, 11219, 97, 98],
            [2006, 11220, 704, 95],
            [2006, 11221, 97, 98],
            [2006, 11222, 97, 98],
            [2006, 11223, 97, 103],
            [2006, 11224, 97, 98],
            [2006, 11225, 704, 98],
            [2006, 11226, 704, 98],
            [2006, 11228, 97, 98],
            [2006, 11229, 97, 98],
            [2006, 11230, 97, 98],
            [2006, 11231, 97, 98],
            [2006, 11232, 97, 98],
            [2006, 11233, 97, 98],
            [2006, 11234, 97, 103],
            [2006, 11235, 97, 98],
            [2006, 11236, 97, 98],
            [2006, 11237, 704, 98],
            [2006, 11238, 704, 98],
            [2006, 11239, 97, 98],
            [2006, 11240, 97, 98],
            [2006, 11241, 97, 98],
            [2006, 11242, 97, 98],
            [2006, 11243, 704, 95],
            [2006, 11245, 97, 98],
            [2006, 11246, 210, 163],
            [2006, 11247, 210, 163],
            [2006, 11248, 97, 98],
            [2006, 11249, 97, 98],
            [2006, 11250, 97, 98],
            [2006, 11251, 97, 98],
            [2006, 11252, 97, 98],
            [2006, 11253, 97, 98],
            [2006, 11254, 97, 103],
            [2006, 11255, 97, 98],
            [2006, 11256, 97, 98],
            [2006, 11257, 704, 98],
            [2006, 11258, 704, 98],
            [2006, 11259, 704, 95],
            [2006, 11260, 704, 98],
            [2006, 11262, 97, 98],
            [2006, 11263, 97, 98],
            [2006, 11264, 97, 98],
            [2006, 11265, 97, 98],
            [2006, 11266, 97, 98],
            [2006, 11267, 97, 98],
            [2006, 11268, 97, 98],
            [2006, 11269, 97, 98],
            [2006, 11270, 210, 163],
            [2006, 11271, 704, 98],
            [2006, 11272, 704, 98],
            [2006, 11274, 97, 98],
            [2006, 11275, 97, 103],
            [2006, 11276, 97, 98],
            [2006, 11277, 97, 98],
            [2006, 11278, 97, 98],
            [2006, 11279, 210, 163],
            [2006, 11280, 704, 98],
            [2006, 11281, 704, 98],
            [2006, 11283, 97, 103],
            [2006, 11284, 97, 98],
            [2006, 11285, 97, 103],
            [2006, 11286, 97, 98],
            [2006, 11287, 97, 103],
            [2006, 11288, 97, 98],
            [2006, 11289, 97, 98],
            [2006, 11290, 704, 98],
            [2006, 11291, 704, 98],
            [2006, 11296, 31, 53],
            [2006, 11298, 22, 20],
            [2006, 11300, 39, 36],
            [2006, 11303, 19, 17],
            [2006, 11304, 29, 20],
            [2006, 11305, 48, 38],
            [2006, 11306, 38, 32],
            [2006, 11307, 37, 30],
            [2006, 11308, 17, 26],
            [2006, 11309, 27, 24],
            [2006, 11310, 21, 21],
            [2006, 11311, 18, 21],
            [2006, 11312, 23, 20],
            [2006, 11313, 16, 20],
            [2006, 11314, 33, 33],
            [2006, 11315, 32, 28],
            [2006, 11316, 28, 30],
            [2006, 11317, 33, 31],
            [2006, 11318, 19, 20],
            [2006, 11319, 20, 18],
            [2006, 11320, 20, 16],
            [2006, 11321, 42, 29],
            [2006, 11322, 48, 29],
            [2006, 11323, 25, 24],
            [2006, 11324, 28, 19],
            [2006, 11325, 31, 22],
            [2006, 11326, 26, 28],
            [2006, 11327, 29, 22],
            [2006, 11328, 28, 30],
            [2006, 11329, 21, 23],
            [2006, 11330, 33, 33],
            [2006, 11331, 32, 30],
            [2006, 11332, 20, 16],
            [2006, 11333, 37, 26],
            [2006, 11334, 41, 27],
            [2006, 11335, 28, 22],
            [2006, 11336, 13, 14],
            [2006, 11337, 24, 24],
            [2006, 11338, 26, 28],
            [2006, 11339, 32, 27],
            [2006, 11340, 32, 31],
            [2006, 11341, 36, 29],
            [2006, 11342, 33, 29],
            [2006, 11343, 33, 32],
            [2006, 11344, 32, 30],
            [2006, 11345, 27, 30],
            [2006, 11346, 38, 29],
            [2006, 11347, 32, 27],
            [2006, 11348, 42, 34],
            [2006, 11349, 20, 18],
            [2006, 11350, 32, 31],
            [2006, 11351, 28, 30],
            [2006, 11352, 28, 30],
            [2006, 11353, 37, 32],
            [2006, 11354, 28, 22],
            [2006, 11355, 32, 27],
            [2006, 11356, 32, 26],
            [2006, 11357, 27, 23],
            [2006, 11358, 24, 24],
            [2006, 11359, 39, 35],
            [2006, 11360, 32, 23],
            [2006, 11361, 42, 34],
            [2006, 11362, 27, 24],
            [2006, 11363, 9, 10],
            [2006, 11364, 11, 11],
            [2006, 11365, 30, 23],
            [2006, 11366, 21, 20],
            [2006, 11367, 42, 37],
            [2006, 11368, 18, 19],
            [2006, 11369, 35, 34],
            [2006, 11370, 18, 21],
            [2006, 11371, 28, 27],
            [2006, 11372, 32, 31],
            [2006, 11373, 45, 29],
            [2006, 11374, 38, 35],
            [2006, 11375, 52, 38],
            [2006, 11376, 19, 19],
            [2006, 11377, 36, 33],
            [2006, 11378, 26, 26],
            [2006, 11384, 44, 36],
            [2006, 11385, 65, 66],
            [2006, 11386, 64, 66],
            [2006, 11387, 77, 70],
            [2006, 11388, 64, 58],
            [2006, 11389, 43, 35],
            [2006, 11390, 46, 37],
            [2006, 11391, 41, 33],
            [2006, 11392, 77, 70],
            [2006, 11393, 52, 42],
            [2006, 11394, 90, 66],
            [2006, 11395, 77, 70],
            [2006, 11396, 77, 76],
            [2006, 11397, 77, 73],
            [2006, 11398, 47, 39],
            [2006, 11399, 76, 76],
            [2006, 11400, 77, 70],
            [2006, 11401, 56, 30],
            [2006, 11402, 46, 40],
            [2006, 11403, 46, 44],
            [2006, 11404, 80, 71],
            [2006, 11405, 52, 45],
            [2006, 11406, 73, 68],
            [2006, 11407, 37, 33],
            [2006, 11408, 73, 62],
            [2006, 11409, 45, 35],
            [2006, 11410, 58, 43],
            [2006, 11411, 46, 36],
            [2006, 11412, 76, 76],
            [2006, 11413, 74, 71],
            [2006, 11414, 47, 45],
            [2006, 11415, 77, 70],
            [2006, 11416, 38, 31],
            [2006, 11417, 45, 38],
            [2006, 11418, 60, 65],
            [2006, 11419, 45, 38],
            [2006, 11420, 54, 42],
            [2006, 11421, 90, 68],
            [2006, 11422, 51, 44],
            [2006, 11423, 46, 43],
            [2006, 11424, 45, 34],
            [2006, 11425, 22, 18],
            [2006, 11426, 9, 7],
            [2006, 11427, 8, 8],
            [2006, 11428, 51, 25],
            [2006, 11429, 15, 12],
            [2006, 11430, 9, 10],
            [2006, 11431, 12, 10],
            [2006, 11432, 8, 8],
            [2006, 11433, 10, 12],
            [2006, 11434, 10, 9],
            [2006, 11435, 7, 8],
            [2006, 11436, 20, 19],
            [2006, 11437, 12, 11],
            [2006, 11438, 10, 9],
            [2006, 11439, 11, 9],
            [2006, 11440, 16, 14],
            [2006, 11441, 44, 27],
            [2006, 11442, 9, 8],
            [2006, 11443, 11, 11],
            [2006, 11444, 13, 9],
            [2006, 11445, 8, 8],
            [2006, 11446, 11, 9],
            [2006, 11447, 17, 14],
            [2006, 11448, 12, 10],
            [2006, 11449, 12, 8],
            [2006, 11450, 12, 10],
            [2006, 11451, 9, 7],
            [2006, 11452, 10, 9],
            [2006, 11453, 30, 19],
            [2006, 11454, 13, 11],
            [2006, 11455, 8, 8],
            [2006, 11456, 8, 8],
            [2006, 11457, 9, 9],
            [2006, 11458, 6, 7],
            [2006, 11459, 6, 6],
            [2006, 11460, 7, 6],
            [2006, 11461, 9, 8],
            [2006, 11462, 7, 7],
            [2006, 11463, 10, 9],
            [2006, 11464, 9, 7],
            [2006, 11465, 17, 14],
            [2006, 11466, 14, 9],
            [2006, 11467, 15, 11],
            [2006, 11468, 36, 23],
            [2006, 11469, 15, 11],
            [2006, 11470, 19, 16],
            [2006, 11471, 15, 14],
            [2006, 11472, 27, 17],
            [2006, 11473, 10, 9],
            [2006, 11474, 8, 9],
            [2006, 11475, 9, 9],
            [2006, 11476, 11, 9],
            [2006, 11477, 24, 19],
            [2006, 11478, 29, 18],
            [2006, 11479, 11, 9],
            [2006, 11480, 21, 17],
            [2006, 11481, 14, 13],
            [2006, 11482, 16, 13],
            [2006, 11483, 19, 15],
            [2006, 11484, 19, 15],
            [2006, 11485, 24, 17],
            [2006, 11486, 21, 15],
            [2006, 11487, 16, 13],
            [2006, 11488, 23, 17],
            [2006, 11489, 12, 11],
            [2006, 11490, 13, 12],
            [2006, 11491, 11, 9],
            [2006, 11492, 8, 7],
            [2006, 11493, 8, 8],
            [2006, 11494, 6, 7],
            [2006, 11495, 6, 6],
            [2006, 11496, 7, 8],
            [2006, 11497, 9, 8],
            [2006, 11498, 9, 8],
            [2006, 11499, 9, 9],
            [2006, 11500, 21, 19],
            [2006, 11501, 8, 8],
            [2006, 11502, 12, 10],
            [2006, 11503, 7, 8],
            [2006, 11504, 9, 9],
            [2006, 11505, 14, 11],
            [2006, 11506, 10, 10],
            [2006, 11507, 11, 12],
            [2006, 11508, 7, 8],
            [2006, 11509, 26, 16],
            [2006, 11510, 11, 9],
            [2006, 11511, 12, 9],
            [2006, 11512, 19, 12],
            [2006, 11513, 13, 11],
            [2006, 11514, 9, 9],
            [2006, 11515, 9, 9],
            [2006, 11516, 14, 11],
            [2006, 11517, 19, 17],
            [2006, 11518, 10, 15],
            [2006, 11519, 21, 14],
            [2006, 11520, 32, 19],
            [2006, 11521, 8, 6],
            [2006, 11522, 10, 10],
            [2006, 11523, 11, 9],
            [2006, 11524, 8, 7],
            [2006, 11525, 11, 8],
            [2006, 11526, 16, 11],
            [2006, 11527, 10, 10],
            [2006, 11528, 8, 7],
            [2006, 11529, 73, 68],
            [2006, 11530, 71, 76],
            [2006, 11531, 52, 35],
            [2006, 11532, 68, 84],
            [2006, 11533, 39, 33],
            [2006, 11534, 76, 76],
            [2006, 11535, 91, 73],
            [2006, 11536, 37, 38],
            [2006, 11537, 80, 65],
            [2006, 11538, 76, 68],
            [2006, 11539, 54, 40],
            [2006, 11540, 44, 34],
            [2006, 11541, 91, 68],
            [2006, 11542, 78, 70],
            [2006, 11543, 97, 68],
            [2006, 11544, 43, 37],
            [2006, 11545, 44, 45],
            [2006, 11546, 85, 70],
            [2006, 11547, 91, 70],
            [2006, 11548, 85, 70],
            [2006, 11549, 45, 36],
            [2006, 11550, 91, 69],
            [2006, 11551, 51, 41],
            [2006, 11552, 78, 76],
            [2006, 11553, 81, 76],
            [2006, 11554, 33, 42],
            [2006, 11555, 50, 40],
            [2006, 11556, 82, 69],
            [2006, 11557, 90, 69],
            [2006, 11558, 59, 76],
            [2006, 11559, 91, 69],
            [2006, 11560, 41, 42],
            [2006, 11561, 65, 50],
            [2006, 11562, 90, 69],
            [2006, 11563, 84, 76],
            [2006, 11564, 73, 76],
            [2006, 11565, 85, 68],
            [2006, 11566, 67, 76],
            [2006, 11567, 91, 69],
            [2006, 11568, 90, 66],
            [2006, 11569, 90, 75],
            [2006, 11570, 90, 69],
            [2006, 11571, 10, 11],
            [2006, 11572, 16, 14],
            [2006, 11573, 118, 90],
            [2006, 11574, 12, 12],
            [2006, 11576, 14, 14],
            [2006, 11577, 14, 14],
            [2006, 11578, 19, 19],
            [2006, 11579, 17, 24],
            [2006, 11580, 11, 13],
            [2006, 11581, 14, 17],
            [2006, 11582, 18, 20],
            [2006, 11583, 53, 33],
            [2006, 11585, 42, 27],
            [2006, 11586, 54, 28],
            [2006, 11588, 101, 33],
            [2006, 11590, 33, 23],
            [2006, 11592, 72, 31],
            [2006, 11593, 38, 20],
            [2006, 11594, 124, 60],
            [2006, 11596, 38, 34],
            [2006, 11598, 25, 20],
            [2006, 11601, 62, 46],
            [2006, 11604, 14, 16],
            [2006, 11605, 22, 18],
            [2006, 11606, 42, 27],
            [2006, 11607, 35, 26],
            [2006, 11614, 25, 20],
            [2006, 11648, 22, 18],
            [2006, 11665, 52, 33],
            [2006, 11694, 16, 22],
            [2006, 11698, 19, 18],
            [2006, 11703, 19, 19],
            [2006, 11705, 54, 40],
            [2006, 11706, 172, 60],
            [2006, 11709, 70, 31],
            [2006, 11710, 84, 33],
            [2006, 11714, 11, 11],
            [2006, 11715, 56, 64],
            [2006, 11716, 50, 61],
            [2006, 11717, 32, 43],
            [2006, 11718, 107, 55],
            [2006, 11719, 111, 47],
            [2006, 11720, 60, 66],
            [2006, 11721, 19, 23],
            [2006, 11722, 62, 59],
            [2006, 11723, 98, 92],
            [2006, 11724, 59, 48],
            [2006, 11725, 115, 115],
            [2006, 11726, 65, 58],
            [2006, 11727, 128, 122],
            [2006, 11728, 58, 47],
            [2006, 11729, 113, 87],
            [2006, 11730, 34, 26],
            [2006, 11731, 67, 64],
            [2006, 11732, 86, 84],
            [2006, 11733, 130, 113],
            [2006, 11734, 69, 55],
            [2006, 11735, 127, 90],
            [2006, 11736, 97, 86],
            [2006, 11737, 38, 41],
            [2006, 11738, 62, 59],
            [2006, 11739, 25, 20],
            [2006, 11741, 21, 26],
            [2006, 11742, 62, 59],
            [2006, 11743, 140, 60],
            [2006, 11744, 105, 89],
            [2006, 11745, 73, 30],
            [2006, 11746, 31, 19],
            [2006, 11747, 81, 47],
            [2006, 11748, 107, 102],
            [2006, 11749, 75, 57],
            [2006, 11750, 88, 46],
            [2006, 11751, 149, 108],
            [2006, 11752, 54, 44],
            [2006, 11753, 89, 47],
            [2006, 11754, 59, 48],
            [2006, 11755, 18, 19],
            [2006, 11756, 62, 59],
            [2006, 11757, 79, 45],
            [2006, 11758, 49, 60],
            [2006, 11759, 23, 20],
            [2006, 11760, 62, 59],
            [2006, 11761, 73, 52],
            [2006, 11762, 59, 47],
            [2006, 11763, 24, 27],
            [2006, 11764, 66, 41],
            [2006, 11765, 130, 70],
            [2006, 11766, 54, 46],
            [2006, 11767, 147, 58],
            [2006, 11768, 93, 76],
            [2006, 11769, 150, 116],
            [2006, 11770, 93, 60],
            [2006, 11771, 83, 45],
            [2006, 11772, 113, 117],
            [2006, 11773, 115, 88],
            [2006, 11774, 105, 68],
            [2006, 11775, 45, 40],
            [2006, 11776, 63, 56],
            [2006, 11777, 32, 28],
            [2006, 11779, 70, 86],
            [2006, 11780, 31, 19],
            [2006, 11781, 20, 22],
            [2006, 11782, 16, 18],
            [2006, 11783, 35, 25],
            [2006, 11784, 25, 21],
            [2006, 11785, 31, 29],
            [2006, 11786, 65, 42],
            [2006, 11787, 38, 37],
            [2006, 11788, 42, 35],
            [2006, 11789, 40, 34],
            [2006, 11790, 15, 18],
            [2006, 11791, 43, 21],
            [2006, 11792, 64, 63],
            [2006, 11793, 67, 64],
            [2006, 11795, 23, 24],
            [2006, 11796, 42, 37],
            [2006, 11797, 44, 33],
            [2006, 11798, 37, 27],
            [2006, 11799, 37, 28],
            [2006, 11800, 33, 27],
            [2006, 11801, 35, 26],
            [2006, 11802, 37, 31],
            [2006, 11803, 38, 29],
            [2006, 11804, 32, 28],
            [2006, 11805, 37, 28],
            [2006, 11806, 44, 36],
            [2006, 11807, 27, 25],
            [2006, 11808, 28, 18],
            [2006, 11809, 21, 13],
            [2006, 11810, 23, 17],
            [2006, 11811, 21, 16],
            [2006, 11812, 30, 22],
            [2006, 11813, 12, 12],
            [2006, 11814, 22, 20],
            [2006, 11815, 21, 18],
            [2006, 11816, 23, 19],
            [2006, 11817, 17, 11],
            [2006, 11818, 19, 19],
            [2006, 11819, 26, 15],
            [2006, 11820, 17, 14],
            [2006, 11821, 24, 17],
            [2006, 11822, 23, 16],
            [2006, 11823, 38, 21],
            [2006, 11824, 21, 18],
            [2006, 11825, 24, 18],
            [2006, 11826, 20, 18],
            [2006, 11827, 20, 17],
            [2006, 11828, 16, 13],
            [2006, 11829, 23, 21],
            [2006, 11830, 14, 12],
            [2006, 11831, 18, 17],
            [2006, 11832, 28, 19],
            [2006, 11833, 24, 15],
            [2006, 11834, 6, 6],
            [2006, 11835, 24, 13],
            [2006, 11836, 25, 18],
            [2006, 11837, 11, 11],
            [2006, 11838, 7, 6],
            [2006, 11839, 12, 10],
            [2006, 11840, 8, 7],
            [2006, 11841, 6, 5],
            [2006, 11842, 21, 17],
            [2006, 11843, 23, 20],
            [2006, 11844, 19, 20],
            [2006, 11845, 23, 19],
            [2006, 11846, 31, 20],
            [2006, 11847, 21, 17],
            [2006, 11848, 15, 12],
            [2006, 11849, 22, 18],
            [2006, 11850, 17, 13],
            [2006, 11851, 24, 17],
            [2006, 11852, 20, 17],
            [2006, 11853, 20, 15],
            [2006, 11854, 18, 19],
            [2006, 11855, 17, 15],
            [2006, 11858, 71, 81],
            [2006, 11859, 71, 81],
            [2006, 11860, 62, 81],
            [2006, 11861, 16, 17],
            [2006, 11862, 27, 24],
            [2006, 11863, 19, 22],
            [2006, 11864, 23, 34],
            [2006, 11865, 35, 35],
            [2006, 11866, 38, 35],
            [2006, 11867, 55, 48],
            [2006, 11868, 52, 70],
            [2006, 11869, 28, 27],
            [2006, 11870, 50, 40],
            [2006, 11871, 58, 47],
            [2006, 11872, 30, 30],
            [2006, 11873, 35, 45],
            [2006, 11874, 45, 36],
            [2006, 11875, 34, 30],
            [2006, 11876, 41, 60],
            [2006, 11877, 50, 32],
            [2006, 11878, 24, 20],
            [2006, 11879, 38, 40],
            [2006, 11880, 52, 48],
            [2006, 11881, 55, 43],
            [2006, 11882, 35, 34],
            [2006, 11883, 48, 35],
            [2006, 11884, 60, 41],
            [2006, 11885, 35, 38],
            [2006, 11886, 30, 32],
            [2006, 11887, 40, 34],
            [2006, 11888, 30, 29],
            [2006, 11889, 28, 34],
            [2006, 11890, 30, 33],
            [2006, 11891, 34, 29],
            [2006, 11892, 32, 36],
            [2006, 11893, 39, 32],
            [2006, 11894, 29, 32],
            [2006, 11895, 43, 43],
            [2006, 11896, 40, 38],
            [2006, 11897, 47, 36],
            [2006, 11898, 35, 38],
            [2006, 11899, 43, 61],
            [2006, 11900, 22, 21],
            [2006, 11901, 45, 56],
            [2006, 11902, 30, 49],
            [2006, 11903, 40, 38],
            [2006, 11904, 35, 35],
            [2006, 11905, 50, 49],
            [2006, 11906, 45, 38],
            [2006, 11907, 58, 42],
            [2006, 11908, 31, 31],
            [2006, 11909, 30, 31],
            [2006, 11910, 45, 47],
            [2006, 11911, 26, 30],
            [2006, 11912, 36, 38],
            [2006, 11913, 38, 28],
            [2006, 11914, 24, 22],
            [2006, 11915, 26, 28],
            [2006, 11916, 40, 56],
            [2006, 11917, 38, 37],
            [2006, 11918, 27, 28],
            [2006, 11919, 19, 26],
            [2006, 11920, 28, 26],
            [2006, 11921, 27, 33],
            [2006, 11922, 24, 28],
            [2006, 11923, 20, 26],
            [2006, 11924, 20, 20],
            [2006, 11925, 25, 21],
            [2006, 11926, 19, 16],
            [2006, 11927, 30, 34],
            [2006, 11928, 19, 16],
            [2006, 11929, 17, 13],
            [2006, 11930, 15, 14],
            [2006, 11931, 33, 31],
            [2006, 11932, 52, 32],
            [2006, 11933, 42, 29],
            [2006, 11934, 25, 23],
            [2006, 11935, 31, 29],
            [2006, 11936, 26, 23],
            [2006, 11937, 42, 35],
            [2006, 11938, 41, 27],
            [2006, 11939, 50, 31],
            [2006, 11940, 60, 37],
            [2006, 11941, 40, 31],
            [2006, 11942, 49, 34],
            [2006, 11943, 20, 17],
            [2006, 11944, 43, 29],
            [2006, 11945, 30, 26],
            [2006, 11946, 85, 48],
            [2006, 11947, 35, 27],
            [2006, 11948, 60, 47],
            [2006, 11949, 57, 33],
            [2006, 11950, 34, 33],
            [2006, 11951, 52, 40],
            [2006, 11952, 68, 48],
            [2006, 11953, 51, 41],
            [2006, 11954, 29, 28],
            [2006, 11955, 60, 38],
            [2006, 11956, 66, 38],
            [2006, 11957, 30, 25],
            [2006, 11958, 44, 22],
            [2006, 11959, 27, 18],
            [2006, 11960, 30, 25],
            [2006, 11961, 30, 26],
            [2006, 11962, 28, 28],
            [2006, 11963, 48, 26],
            [2006, 11964, 30, 19],
            [2006, 11965, 70, 45],
            [2006, 11966, 39, 30],
            [2006, 11967, 41, 25],
            [2006, 11968, 70, 48],
            [2006, 11969, 14, 18],
            [2006, 11970, 34, 22],
            [2006, 11971, 45, 37],
            [2006, 11972, 46, 37],
            [2006, 11973, 44, 27],
            [2006, 11974, 64, 48],
            [2006, 11975, 100, 62],
            [2006, 11976, 44, 30],
            [2006, 11977, 53, 47],
            [2006, 11978, 37, 30],
            [2006, 11979, 42, 30],
            [2006, 11980, 87, 59],
            [2006, 11981, 45, 32],
            [2006, 11982, 43, 29],
            [2006, 11983, 27, 23],
            [2006, 11984, 77, 47],
            [2006, 11985, 45, 21],
            [2006, 11986, 55, 40],
            [2006, 11987, 43, 26],
            [2006, 11988, 51, 27],
            [2006, 11989, 37, 32],
            [2006, 11990, 40, 29],
            [2006, 11991, 73, 35],
            [2006, 11992, 49, 43],
            [2006, 11993, 22, 20],
            [2006, 11994, 23, 20],
            [2006, 11995, 25, 25],
            [2006, 11996, 73, 50],
            [2006, 11997, 39, 23],
            [2006, 11998, 63, 50],
            [2006, 11999, 30, 26],
            [2006, 12000, 22, 29],
            [2006, 12001, 36, 22],
            [2006, 12002, 27, 28],
            [2006, 12003, 35, 33],
            [2006, 12004, 13, 16],
            [2006, 12005, 31, 30],
            [2006, 12006, 16, 18],
            [2006, 12007, 42, 21],
            [2006, 12008, 29, 33],
            [2006, 12009, 30, 22],
            [2006, 12010, 30, 23],
            [2006, 12011, 18, 18],
            [2006, 12012, 19, 17],
            [2006, 12013, 14, 13],
            [2006, 12014, 29, 29],
            [2006, 12015, 20, 18],
            [2006, 12016, 31, 27],
            [2006, 12017, 35, 22],
            [2006, 12018, 22, 22],
            [2006, 12019, 34, 24],
            [2006, 12020, 20, 22],
            [2006, 12021, 27, 24],
            [2006, 12022, 31, 23],
            [2006, 12023, 15, 13],
            [2006, 12024, 22, 22],
            [2006, 12025, 50, 38],
            [2006, 12026, 24, 20],
            [2006, 12027, 14, 15],
            [2006, 12028, 15, 19],
            [2006, 12029, 18, 15],
            [2006, 12030, 16, 17],
            [2006, 12031, 27, 21],
            [2006, 12032, 17, 16],
            [2006, 12033, 21, 18],
            [2006, 12034, 25, 17],
            [2006, 12035, 17, 20],
            [2006, 12036, 20, 19],
            [2006, 12037, 22, 19],
            [2006, 12038, 25, 29],
            [2006, 12039, 21, 22],
            [2006, 12040, 80, 26],
            [2006, 12041, 70, 32],
            [2006, 12042, 15, 17],
            [2006, 12043, 29, 22],
            [2006, 12044, 21, 19],
            [2006, 12045, 41, 35],
            [2006, 12046, 44, 27],
            [2006, 12047, 20, 22],
            [2006, 12048, 24, 21],
            [2006, 12049, 14, 18],
            [2006, 12050, 26, 26],
            [2006, 12051, 15, 17],
            [2006, 12052, 35, 21],
            [2006, 12053, 33, 33],
            [2006, 12054, 13, 16],
            [2006, 12055, 35, 20],
            [2006, 12056, 27, 21],
            [2006, 12057, 27, 30],
            [2006, 12058, 23, 20],
            [2006, 12059, 21, 16],
            [2006, 12060, 31, 24],
            [2006, 12061, 16, 16],
            [2006, 12062, 20, 21],
            [2006, 12063, 10, 11],
            [2006, 12064, 27, 22],
            [2006, 12065, 36, 27],
            [2006, 12066, 29, 21],
            [2006, 12067, 20, 18],
            [2006, 12068, 17, 15],
            [2006, 12069, 42, 31],
            [2006, 12070, 17, 20],
            [2006, 12071, 27, 25],
            [2006, 12072, 34, 22],
            [2006, 12073, 14, 17],
            [2006, 12074, 21, 27],
            [2006, 12075, 16, 14],
            [2006, 12076, 18, 15],
            [2006, 12077, 18, 18],
            [2006, 12078, 30, 26],
            [2006, 12079, 31, 23],
            [2006, 12080, 15, 21],
            [2006, 12081, 17, 19],
            [2006, 12082, 30, 30],
            [2006, 12083, 40, 36],
            [2006, 12084, 20, 20],
            [2006, 12085, 32, 26],
            [2006, 12086, 32, 26],
            [2006, 12087, 56, 35],
            [2006, 12088, 17, 16],
            [2006, 12089, 35, 24],
            [2006, 12090, 21, 17],
            [2006, 12091, 37, 18],
            [2006, 12092, 55, 27],
            [2006, 12093, 10, 13],
            [2006, 12094, 33, 22],
            [2006, 12095, 75, 45],
            [2006, 12096, 36, 28],
            [2006, 12097, 40, 27],
            [2006, 12098, 38, 22],
            [2006, 12099, 80, 36],
            [2006, 12100, 11, 10],
            [2006, 12101, 17, 13],
            [2006, 12102, 10, 13],
            [2006, 12103, 41, 22],
            [2006, 12104, 66, 30],
            [2006, 12105, 30, 17],
            [2006, 12106, 13, 12],
            [2006, 12107, 25, 19],
            [2006, 12108, 27, 22],
            [2006, 12109, 34, 25],
            [2006, 12110, 20, 18],
            [2006, 12111, 40, 25],
            [2006, 12112, 45, 26],
            [2006, 12113, 19, 16],
            [2006, 12114, 29, 18],
            [2006, 12115, 11, 13],
            [2006, 12116, 14, 14],
            [2006, 12117, 35, 26],
            [2006, 12118, 27, 20],
            [2006, 12119, 86, 35],
            [2006, 12120, 23, 20],
            [2006, 12121, 25, 18],
            [2007, 25, 12, 9],
            [2007, 48, 41, 28],
            [2007, 49, 25, 18],
            [2007, 65, 18, 16],
            [2007, 82, 15, 16],
            [2007, 83, 27, 28],
            [2007, 101, 38, 30],
            [2007, 119, 29, 21],
            [2007, 163, 30, 28],
            [2007, 200, 29, 22],
            [2007, 204, 15, 21],
            [2007, 220, 11, 13],
            [2007, 226, 20, 18],
            [2007, 231, 42, 28],
            [2007, 234, 12, 12],
            [2007, 240, 63, 36],
            [2007, 246, 28, 17],
            [2007, 282, 36, 25],
            [2007, 310, 12, 14],
            [2007, 314, 17, 21],
            [2007, 324, 31, 26],
            [2007, 327, 34, 29],
            [2007, 346, 41, 33],
            [2007, 355, 33, 26],
            [2007, 379, 13, 12],
            [2007, 389, 23, 22],
            [2007, 399, 41, 26],
            [2007, 425, 11, 16],
            [2007, 430, 18, 19],
            [2007, 436, 40, 33],
            [2007, 479, 40, 32],
            [2007, 480, 50, 28],
            [2007, 503, 92, 27],
            [2007, 504, 8, 10],
            [2007, 541, 91, 37],
            [2007, 585, 42, 28],
            [2007, 590, 42, 47],
            [2007, 593, 40, 33],
            [2007, 597, 30, 14],
            [2007, 604, 93, 50],
            [2007, 612, 26, 27],
            [2007, 618, 19, 15],
            [2007, 662, 45, 37],
            [2007, 663, 52, 26],
            [2007, 669, 24, 17],
            [2007, 686, 16, 17],
            [2007, 694, 29, 23],
            [2007, 700, 40, 31],
            [2007, 703, 15, 15],
            [2007, 716, 38, 31],
            [2007, 734, 18, 20],
            [2007, 751, 23, 19],
            [2007, 766, 77, 41],
            [2007, 769, 45, 28],
            [2007, 803, 24, 23],
            [2007, 805, 19, 19],
            [2007, 820, 48, 29],
            [2007, 822, 13, 17],
            [2007, 827, 11, 13],
            [2007, 845, 39, 35],
            [2007, 865, 68, 26],
            [2007, 871, 29, 19],
            [2007, 878, 7, 6],
            [2007, 882, 34, 27],
            [2007, 894, 18, 13],
            [2007, 913, 16, 16],
            [2007, 922, 23, 25],
            [2007, 938, 11, 12],
            [2007, 940, 11, 13],
            [2007, 941, 32, 34],
            [2007, 964, 11, 14],
            [2007, 969, 39, 32],
            [2007, 971, 10, 11],
            [2007, 985, 51, 32],
            [2007, 998, 34, 28],
            [2007, 1003, 8, 6],
            [2007, 1008, 32, 31],
            [2007, 1016, 8, 9],
            [2007, 1030, 9, 12],
            [2007, 1048, 33, 30],
            [2007, 1059, 44, 43],
            [2007, 1106, 45, 27],
            [2007, 1111, 37, 37],
            [2007, 1132, 11, 12],
            [2007, 1136, 31, 29],
            [2007, 1145, 24, 19],
            [2007, 1150, 23, 20],
            [2007, 1156, 22, 17],
            [2007, 1157, 33, 31],
            [2007, 1159, 71, 27],
            [2007, 1174, 22, 28],
            [2007, 1186, 15, 15],
            [2007, 1203, 11, 17],
            [2007, 1213, 17, 15],
            [2007, 1221, 14, 17],
            [2007, 1226, 28, 23],
            [2007, 1234, 14, 15],
            [2007, 1235, 23, 18],
            [2007, 1238, 14, 20],
            [2007, 1247, 30, 23],
            [2007, 1254, 42, 23],
            [2007, 1268, 26, 22],
            [2007, 1275, 26, 17],
            [2007, 1281, 11, 10],
            [2007, 1295, 34, 31],
            [2007, 1302, 38, 39],
            [2007, 1303, 44, 30],
            [2007, 1320, 32, 34],
            [2007, 1396, 13, 16],
            [2007, 1420, 35, 37],
            [2007, 1445, 61, 23],
            [2007, 1456, 20, 20],
            [2007, 1466, 23, 20],
            [2007, 1473, 12, 9],
            [2007, 1481, 29, 21],
            [2007, 1491, 10, 8],
            [2007, 1507, 33, 28],
            [2007, 1515, 17, 15],
            [2007, 1525, 32, 29],
            [2007, 1530, 63, 40],
            [2007, 1536, 17, 21],
            [2007, 1557, 38, 26],
            [2007, 1577, 22, 17],
            [2007, 1580, 33, 28],
            [2007, 1587, 14, 15],
            [2007, 1589, 36, 22],
            [2007, 1598, 11, 8],
            [2007, 1628, 26, 17],
            [2007, 1635, 17, 13],
            [2007, 1638, 39, 29],
            [2007, 1645, 48, 30],
            [2007, 1673, 63, 36],
            [2007, 1685, 28, 27],
            [2007, 1704, 16, 15],
            [2007, 1717, 42, 30],
            [2007, 1730, 14, 11],
            [2007, 1769, 42, 35],
            [2007, 1772, 10, 12],
            [2007, 1774, 20, 17],
            [2007, 1794, 26, 24],
            [2007, 1795, 12, 9],
            [2007, 1797, 41, 26],
            [2007, 1798, 33, 32],
            [2007, 1824, 59, 33],
            [2007, 1841, 32, 31],
            [2007, 1845, 18, 19],
            [2007, 1864, 95, 57],
            [2007, 1866, 32, 22],
            [2007, 1891, 28, 21],
            [2007, 1894, 23, 15],
            [2007, 1903, 47, 27],
            [2007, 1921, 13, 11],
            [2007, 1930, 10, 8],
            [2007, 1952, 126, 49],
            [2007, 1962, 12, 12],
            [2007, 1965, 57, 34],
            [2007, 2011, 19, 18],
            [2007, 2017, 33, 30],
            [2007, 2023, 7, 7],
            [2007, 2035, 35, 28],
            [2007, 2056, 21, 37],
            [2007, 2064, 41, 26],
            [2007, 2098, 12, 15],
            [2007, 2142, 9, 10],
            [2007, 2178, 15, 14],
            [2007, 2190, 25, 19],
            [2007, 2198, 16, 15],
            [2007, 2208, 64, 36],
            [2007, 2213, 34, 27],
            [2007, 2227, 14, 16],
            [2007, 2244, 19, 19],
            [2007, 2250, 34, 25],
            [2007, 2277, 24, 17],
            [2007, 2280, 11, 9],
            [2007, 2282, 17, 34],
            [2007, 2300, 40, 32],
            [2007, 2311, 26, 24],
            [2007, 2316, 40, 30],
            [2007, 2343, 34, 25],
            [2007, 2352, 36, 26],
            [2007, 2371, 42, 28],
            [2007, 2384, 21, 21],
            [2007, 2429, 15, 16],
            [2007, 2435, 13, 16],
            [2007, 2443, 38, 26],
            [2007, 2458, 27, 21],
            [2007, 2459, 17, 17],
            [2007, 2467, 14, 14],
            [2007, 2483, 37, 41],
            [2007, 2485, 18, 14],
            [2007, 2500, 23, 17],
            [2007, 2501, 41, 30],
            [2007, 2505, 38, 25],
            [2007, 2524, 10, 9],
            [2007, 2533, 10, 16],
            [2007, 2539, 71, 22],
            [2007, 2547, 15, 28],
            [2007, 2554, 11, 20],
            [2007, 2576, 46, 27],
            [2007, 2585, 38, 27],
            [2007, 2595, 32, 29],
            [2007, 2606, 13, 13],
            [2007, 2627, 32, 22],
            [2007, 2635, 14, 15],
            [2007, 2670, 33, 22],
            [2007, 2671, 38, 33],
            [2007, 2692, 24, 21],
            [2007, 2695, 17, 13],
            [2007, 2723, 34, 32],
            [2007, 2758, 30, 25],
            [2007, 2775, 42, 28],
            [2007, 2785, 10, 10],
            [2007, 2798, 16, 17],
            [2007, 2822, 21, 18],
            [2007, 2835, 22, 20],
            [2007, 2836, 16, 17],
            [2007, 2879, 19, 17],
            [2007, 2883, 32, 35],
            [2007, 2914, 39, 25],
            [2007, 2922, 12, 13],
            [2007, 2991, 33, 24],
            [2007, 3019, 38, 21],
            [2007, 3033, 56, 41],
            [2007, 3046, 46, 22],
            [2007, 3053, 46, 29],
            [2007, 3066, 39, 28],
            [2007, 3086, 105, 44],
            [2007, 3091, 12, 14],
            [2007, 3092, 36, 26],
            [2007, 3119, 11, 17],
            [2007, 3126, 29, 23],
            [2007, 3134, 28, 29],
            [2007, 3142, 24, 29],
            [2007, 3158, 18, 19],
            [2007, 3164, 37, 29],
            [2007, 3171, 26, 17],
            [2007, 3182, 85, 35],
            [2007, 3221, 38, 27],
            [2007, 3246, 67, 35],
            [2007, 3252, 37, 25],
            [2007, 3254, 20, 24],
            [2007, 3273, 43, 28],
            [2007, 3274, 20, 18],
            [2007, 3301, 33, 27],
            [2007, 3308, 43, 28],
            [2007, 3309, 32, 31],
            [2007, 3321, 31, 22],
            [2007, 3327, 35, 27],
            [2007, 3348, 38, 26],
            [2007, 3364, 11, 14],
            [2007, 3372, 38, 26],
            [2007, 3382, 24, 17],
            [2007, 3434, 7, 7],
            [2007, 3438, 42, 25],
            [2007, 3451, 56, 40],
            [2007, 3454, 10, 11],
            [2007, 3462, 36, 22],
            [2007, 3494, 11, 11],
            [2007, 3503, 86, 41],
            [2007, 3515, 13, 32],
            [2007, 3517, 34, 26],
            [2007, 3559, 32, 26],
            [2007, 3569, 39, 40],
            [2007, 3579, 15, 24],
            [2007, 3590, 17, 21],
            [2007, 3593, 47, 49],
            [2007, 3659, 37, 27],
            [2007, 3669, 14, 17],
            [2007, 3700, 18, 15],
            [2007, 3718, 42, 30],
            [2007, 3726, 13, 12],
            [2007, 3729, 117, 42],
            [2007, 3765, 13, 18],
            [2007, 3833, 30, 22],
            [2007, 3859, 11, 15],
            [2007, 3884, 39, 25],
            [2007, 3889, 40, 24],
            [2007, 3915, 21, 33],
            [2007, 3925, 44, 29],
            [2007, 3943, 21, 21],
            [2007, 3956, 36, 44],
            [2007, 3972, 130, 62],
            [2007, 3976, 17, 17],
            [2007, 3985, 20, 18],
            [2007, 3993, 15, 15],
            [2007, 4015, 38, 25],
            [2007, 4022, 41, 25],
            [2007, 4026, 24, 16],
            [2007, 4027, 41, 26],
            [2007, 4028, 20, 19],
            [2007, 4043, 16, 16],
            [2007, 4074, 17, 21],
            [2007, 4091, 29, 27],
            [2007, 4107, 43, 25],
            [2007, 4125, 15, 16],
            [2007, 4165, 32, 29],
            [2007, 4173, 15, 17],
            [2007, 4176, 10, 11],
            [2007, 4209, 35, 32],
            [2007, 4246, 12, 20],
            [2007, 4285, 23, 27],
            [2007, 4299, 31, 21],
            [2007, 4301, 43, 45],
            [2007, 4310, 25, 25],
            [2007, 4312, 33, 26],
            [2007, 4325, 35, 21],
            [2007, 4353, 21, 13],
            [2007, 4358, 12, 13],
            [2007, 4362, 58, 34],
            [2007, 4380, 16, 19],
            [2007, 4382, 80, 28],
            [2007, 4386, 17, 18],
            [2007, 4413, 11, 11],
            [2007, 4414, 16, 20],
            [2007, 4426, 15, 15],
            [2007, 4440, 33, 26],
            [2007, 4442, 16, 19],
            [2007, 4454, 11, 11],
            [2007, 4464, 37, 23],
            [2007, 4470, 23, 21],
            [2007, 4477, 26, 27],
            [2007, 4487, 18, 23],
            [2007, 4491, 36, 27],
            [2007, 4518, 44, 30],
            [2007, 4536, 18, 17],
            [2007, 4545, 35, 27],
            [2007, 4610, 44, 28],
            [2007, 4617, 95, 38],
            [2007, 4618, 21, 18],
            [2007, 4623, 17, 19],
            [2007, 4626, 26, 17],
            [2007, 4634, 22, 21],
            [2007, 4638, 61, 27],
            [2007, 4644, 13, 17],
            [2007, 4648, 30, 22],
            [2007, 4660, 40, 26],
            [2007, 4670, 39, 26],
            [2007, 4676, 12, 15],
            [2007, 4689, 35, 25],
            [2007, 4710, 8, 6],
            [2007, 4724, 23, 17],
            [2007, 4732, 48, 56],
            [2007, 4734, 13, 13],
            [2007, 4738, 31, 33],
            [2007, 4745, 20, 19],
            [2007, 4749, 32, 26],
            [2007, 4762, 36, 30],
            [2007, 4764, 20, 26],
            [2007, 4789, 42, 25],
            [2007, 4794, 19, 17],
            [2007, 4801, 14, 17],
            [2007, 4805, 12, 17],
            [2007, 4820, 37, 30],
            [2007, 4828, 57, 44],
            [2007, 4832, 17, 19],
            [2007, 4840, 42, 26],
            [2007, 4849, 16, 16],
            [2007, 4863, 36, 29],
            [2007, 4865, 25, 18],
            [2007, 4871, 12, 15],
            [2007, 4888, 37, 31],
            [2007, 4897, 13, 16],
            [2007, 4912, 10, 19],
            [2007, 4914, 23, 17],
            [2007, 4918, 18, 15],
            [2007, 4926, 47, 43],
            [2007, 4939, 20, 16],
            [2007, 4944, 15, 14],
            [2007, 4951, 27, 27],
            [2007, 4973, 28, 28],
            [2007, 4976, 11, 11],
            [2007, 4978, 46, 35],
            [2007, 4983, 14, 12],
            [2007, 4992, 17, 16],
            [2007, 5006, 69, 32],
            [2007, 5019, 54, 36],
            [2007, 5031, 10, 11],
            [2007, 5038, 14, 16],
            [2007, 5048, 29, 25],
            [2007, 5050, 22, 18],
            [2007, 5051, 12, 15],
            [2007, 5062, 34, 21],
            [2007, 5063, 19, 24],
            [2007, 5073, 49, 32],
            [2007, 5081, 28, 21],
            [2007, 5091, 68, 30],
            [2007, 5092, 11, 14],
            [2007, 5095, 14, 15],
            [2007, 5107, 82, 27],
            [2007, 5108, 18, 21],
            [2007, 5130, 40, 33],
            [2007, 5149, 19, 17],
            [2007, 5159, 47, 30],
            [2007, 5184, 26, 19],
            [2007, 5185, 22, 15],
            [2007, 5186, 14, 15],
            [2007, 5187, 14, 16],
            [2007, 5188, 16, 19],
            [2007, 5189, 14, 10],
            [2007, 5217, 39, 30],
            [2007, 5219, 17, 31],
            [2007, 5220, 15, 34],
            [2007, 5221, 11, 22],
            [2007, 5222, 15, 20],
            [2007, 5223, 11, 23],
            [2007, 5224, 16, 32],
            [2007, 5225, 15, 32],
            [2007, 5226, 12, 33],
            [2007, 5227, 27, 42],
            [2007, 5228, 18, 40],
            [2007, 5229, 11, 29],
            [2007, 5230, 15, 27],
            [2007, 5231, 12, 24],
            [2007, 5232, 17, 33],
            [2007, 5233, 22, 44],
            [2007, 5234, 10, 17],
            [2007, 5235, 30, 29],
            [2007, 5236, 15, 26],
            [2007, 5237, 22, 35],
            [2007, 5238, 15, 24],
            [2007, 5239, 21, 38],
            [2007, 5240, 18, 44],
            [2007, 5241, 23, 39],
            [2007, 5242, 18, 27],
            [2007, 5243, 22, 43],
            [2007, 5244, 20, 44],
            [2007, 5245, 23, 43],
            [2007, 5247, 26, 13],
            [2007, 5248, 27, 18],
            [2007, 5273, 21, 15],
            [2007, 5276, 22, 28],
            [2007, 5279, 20, 19],
            [2007, 5287, 12, 11],
            [2007, 5290, 18, 17],
            [2007, 5298, 14, 14],
            [2007, 5299, 18, 17],
            [2007, 5303, 26, 19],
            [2007, 5305, 20, 16],
            [2007, 5314, 17, 18],
            [2007, 5315, 18, 20],
            [2007, 5317, 25, 29],
            [2007, 5321, 23, 21],
            [2007, 5323, 17, 17],
            [2007, 5328, 14, 13],
            [2007, 5332, 16, 19],
            [2007, 5333, 13, 12],
            [2007, 5336, 13, 12],
            [2007, 5337, 15, 14],
            [2007, 5338, 23, 19],
            [2007, 5339, 21, 21],
            [2007, 5340, 20, 21],
            [2007, 5343, 12, 11],
            [2007, 5344, 29, 26],
            [2007, 5347, 17, 18],
            [2007, 5349, 18, 19],
            [2007, 5350, 18, 20],
            [2007, 5353, 19, 17],
            [2007, 5355, 14, 13],
            [2007, 5357, 19, 17],
            [2007, 5359, 16, 19],
            [2007, 5366, 20, 18],
            [2007, 5371, 24, 24],
            [2007, 5372, 18, 18],
            [2007, 5375, 14, 14],
            [2007, 5377, 18, 17],
            [2007, 5383, 19, 26],
            [2007, 5385, 21, 18],
            [2007, 5387, 13, 12],
            [2007, 5400, 14, 13],
            [2007, 5403, 20, 19],
            [2007, 5404, 18, 18],
            [2007, 5407, 17, 19],
            [2007, 5408, 19, 19],
            [2007, 5411, 19, 13],
            [2007, 5412, 19, 19],
            [2007, 5414, 13, 13],
            [2007, 5415, 19, 18],
            [2007, 5418, 19, 21],
            [2007, 5420, 15, 14],
            [2007, 5421, 17, 15],
            [2007, 5422, 21, 21],
            [2007, 5425, 16, 17],
            [2007, 5426, 16, 17],
            [2007, 5428, 19, 20],
            [2007, 5431, 19, 16],
            [2007, 5432, 21, 23],
            [2007, 5434, 10, 11],
            [2007, 5436, 15, 14],
            [2007, 5437, 21, 19],
            [2007, 5440, 23, 20],
            [2007, 5441, 20, 21],
            [2007, 5444, 22, 25],
            [2007, 5447, 17, 17],
            [2007, 5449, 19, 21],
            [2007, 5450, 19, 20],
            [2007, 5452, 21, 20],
            [2007, 5453, 21, 21],
            [2007, 5454, 14, 14],
            [2007, 5455, 17, 16],
            [2007, 5457, 13, 18],
            [2007, 5459, 15, 15],
            [2007, 5462, 17, 19],
            [2007, 5463, 12, 12],
            [2007, 5464, 17, 17],
            [2007, 5465, 19, 18],
            [2007, 5472, 19, 19],
            [2007, 5473, 19, 16],
            [2007, 5476, 15, 17],
            [2007, 5479, 16, 16],
            [2007, 5480, 22, 20],
            [2007, 5482, 17, 16],
            [2007, 5486, 17, 17],
            [2007, 5489, 21, 28],
            [2007, 5492, 20, 23],
            [2007, 5494, 21, 20],
            [2007, 5495, 18, 15],
            [2007, 5498, 27, 25],
            [2007, 5499, 17, 18],
            [2007, 5501, 21, 25],
            [2007, 5505, 17, 19],
            [2007, 5508, 19, 21],
            [2007, 5528, 12, 12],
            [2007, 5532, 19, 18],
            [2007, 5534, 16, 14],
            [2007, 5539, 20, 17],
            [2007, 5541, 19, 18],
            [2007, 5544, 18, 20],
            [2007, 5545, 18, 18],
            [2007, 5547, 27, 26],
            [2007, 5550, 17, 17],
            [2007, 5571, 22, 17],
            [2007, 5944, 7, 7],
            [2007, 5945, 8, 9],
            [2007, 5946, 6, 5],
            [2007, 5962, 68, 70],
            [2007, 5989, 150, 160],
            [2007, 5990, 150, 160],
            [2007, 5991, 150, 160],
            [2007, 5992, 150, 160],
            [2007, 5993, 150, 160],
            [2007, 5996, 35, 25],
            [2007, 6068, 35, 28],
            [2007, 6069, 38, 32],
            [2007, 6070, 36, 31],
            [2007, 6071, 27, 23],
            [2007, 6073, 23, 25],
            [2007, 6074, 31, 27],
            [2007, 6075, 28, 31],
            [2007, 6076, 28, 24],
            [2007, 6077, 28, 25],
            [2007, 6078, 28, 27],
            [2007, 6079, 32, 27],
            [2007, 6080, 24, 29],
            [2007, 6081, 19, 21],
            [2007, 6082, 31, 27],
            [2007, 6083, 29, 24],
            [2007, 6084, 35, 26],
            [2007, 6085, 32, 27],
            [2007, 6087, 27, 24],
            [2007, 6088, 23, 24],
            [2007, 6089, 26, 24],
            [2007, 6090, 38, 28],
            [2007, 6091, 19, 23],
            [2007, 6092, 29, 27],
            [2007, 6093, 36, 31],
            [2007, 6094, 31, 27],
            [2007, 6095, 17, 19],
            [2007, 6096, 29, 23],
            [2007, 6097, 32, 24],
            [2007, 6098, 28, 24],
            [2007, 6099, 26, 26],
            [2007, 6100, 23, 27],
            [2007, 6101, 23, 23],
            [2007, 6102, 21, 21],
            [2007, 6103, 29, 24],
            [2007, 6104, 32, 23],
            [2007, 6105, 26, 26],
            [2007, 6106, 24, 22],
            [2007, 6108, 30, 24],
            [2007, 6109, 18, 21],
            [2007, 6110, 29, 27],
            [2007, 6111, 14, 17],
            [2007, 6112, 22, 26],
            [2007, 6113, 22, 22],
            [2007, 6114, 27, 22],
            [2007, 6115, 19, 22],
            [2007, 6116, 23, 24],
            [2007, 6117, 25, 24],
            [2007, 6118, 36, 27],
            [2007, 6119, 27, 26],
            [2007, 6120, 18, 20],
            [2007, 6121, 19, 23],
            [2007, 6122, 27, 24],
            [2007, 6123, 22, 22],
            [2007, 6124, 28, 24],
            [2007, 6125, 25, 29],
            [2007, 6126, 26, 25],
            [2007, 6127, 23, 27],
            [2007, 6128, 23, 27],
            [2007, 6130, 26, 25],
            [2007, 6131, 29, 24],
            [2007, 6132, 31, 27],
            [2007, 6133, 29, 24],
            [2007, 6134, 29, 24],
            [2007, 6135, 36, 32],
            [2007, 6136, 47, 40],
            [2007, 6137, 16, 18],
            [2007, 6138, 22, 23],
            [2007, 6139, 26, 24],
            [2007, 6140, 18, 21],
            [2007, 6141, 21, 24],
            [2007, 6142, 16, 23],
            [2007, 6143, 25, 24],
            [2007, 6145, 27, 26],
            [2007, 6146, 14, 17],
            [2007, 6147, 19, 24],
            [2007, 6148, 18, 21],
            [2007, 6149, 26, 27],
            [2007, 6150, 15, 19],
            [2007, 6151, 19, 19],
            [2007, 6152, 16, 19],
            [2007, 6153, 17, 20],
            [2007, 6154, 21, 25],
            [2007, 6155, 18, 20],
            [2007, 6156, 23, 21],
            [2007, 6157, 27, 24],
            [2007, 6158, 20, 20],
            [2007, 6159, 26, 23],
            [2007, 6160, 20, 21],
            [2007, 6161, 16, 17],
            [2007, 6162, 19, 19],
            [2007, 6163, 31, 28],
            [2007, 6164, 27, 25],
            [2007, 6165, 22, 21],
            [2007, 6166, 34, 26],
            [2007, 6167, 29, 31],
            [2007, 6244, 35, 28],
            [2007, 6353, 40, 34],
            [2007, 6357, 31, 28],
            [2007, 6358, 39, 29],
            [2007, 6391, 50, 32],
            [2007, 6433, 27, 30],
            [2007, 6438, 73, 60],
            [2007, 6442, 30, 25],
            [2007, 6463, 70, 73],
            [2007, 6471, 48, 34],
            [2007, 6492, 27, 29],
            [2007, 6494, 29, 25],
            [2007, 6495, 50, 35],
            [2007, 6502, 27, 27],
            [2007, 6614, 21, 20],
            [2007, 6631, 33, 33],
            [2007, 6633, 21, 24],
            [2007, 6634, 28, 25],
            [2007, 6635, 32, 27],
            [2007, 6636, 35, 34],
            [2007, 6637, 27, 26],
            [2007, 6638, 38, 29],
            [2007, 6639, 27, 30],
            [2007, 6640, 25, 45],
            [2007, 6643, 37, 25],
            [2007, 6649, 35, 25],
            [2007, 6650, 35, 26],
            [2007, 6651, 27, 21],
            [2007, 6652, 26, 26],
            [2007, 6653, 34, 29],
            [2007, 6654, 34, 25],
            [2007, 6655, 26, 22],
            [2007, 6656, 28, 26],
            [2007, 6657, 23, 28],
            [2007, 6660, 32, 22],
            [2007, 6661, 26, 24],
            [2007, 6662, 26, 26],
            [2007, 6663, 26, 25],
            [2007, 6664, 36, 28],
            [2007, 6665, 26, 27],
            [2007, 6666, 26, 24],
            [2007, 6667, 27, 26],
            [2007, 6668, 27, 21],
            [2007, 6669, 22, 28],
            [2007, 6670, 28, 25],
            [2007, 6671, 35, 26],
            [2007, 6672, 29, 24],
            [2007, 6673, 31, 24],
            [2007, 6674, 28, 27],
            [2007, 6675, 26, 24],
            [2007, 6676, 35, 30],
            [2007, 6677, 26, 27],
            [2007, 6678, 26, 24],
            [2007, 6679, 51, 40],
            [2007, 6680, 24, 22],
            [2007, 6682, 25, 24],
            [2007, 6683, 21, 23],
            [2007, 6684, 24, 26],
            [2007, 6685, 19, 21],
            [2007, 6686, 19, 21],
            [2007, 6687, 19, 24],
            [2007, 6688, 19, 21],
            [2007, 6689, 20, 22],
            [2007, 6690, 19, 21],
            [2007, 6697, 21, 24],
            [2007, 6699, 24, 65],
            [2007, 6700, 70, 46],
            [2007, 6701, 48, 34],
            [2007, 6702, 55, 45],
            [2007, 6704, 50, 39],
            [2007, 6715, 55, 31],
            [2007, 6716, 52, 31],
            [2007, 6718, 21, 35],
            [2007, 6722, 47, 31],
            [2007, 6723, 85, 55],
            [2007, 6726, 18, 50],
            [2007, 6728, 55, 38],
            [2007, 6734, 52, 32],
            [2007, 6737, 27, 75],
            [2007, 6738, 46, 41],
            [2007, 6741, 14, 15],
            [2007, 6748, 25, 24],
            [2007, 6749, 24, 24],
            [2007, 6750, 32, 32],
            [2007, 6752, 16, 21],
            [2007, 6753, 29, 27],
            [2007, 6754, 29, 27],
            [2007, 6755, 36, 33],
            [2007, 6756, 27, 28],
            [2007, 6757, 26, 25],
            [2007, 6758, 26, 32],
            [2007, 6759, 19, 21],
            [2007, 6760, 33, 33],
            [2007, 6761, 29, 32],
            [2007, 6762, 30, 30],
            [2007, 6763, 19, 19],
            [2007, 6764, 28, 30],
            [2007, 6766, 38, 33],
            [2007, 6767, 29, 26],
            [2007, 6768, 28, 26],
            [2007, 6769, 32, 36],
            [2007, 6770, 30, 32],
            [2007, 6771, 23, 31],
            [2007, 6772, 23, 25],
            [2007, 6773, 35, 33],
            [2007, 6777, 37, 34],
            [2007, 6778, 20, 24],
            [2007, 6779, 29, 30],
            [2007, 6780, 33, 31],
            [2007, 6781, 34, 31],
            [2007, 6782, 50, 37],
            [2007, 6783, 30, 34],
            [2007, 6784, 25, 30],
            [2007, 6785, 36, 29],
            [2007, 6786, 30, 32],
            [2007, 6787, 28, 31],
            [2007, 6789, 31, 30],
            [2007, 6790, 21, 65],
            [2007, 6791, 65, 71],
            [2007, 6794, 18, 47],
            [2007, 6795, 32, 41],
            [2007, 6798, 60, 32],
            [2007, 6803, 24, 80],
            [2007, 6804, 50, 75],
            [2007, 6805, 52, 65],
            [2007, 6806, 24, 55],
            [2007, 6807, 48, 51],
            [2007, 6808, 19, 40],
            [2007, 6812, 181, 85],
            [2007, 6813, 20, 56],
            [2007, 6814, 148, 100],
            [2007, 6816, 48, 86],
            [2007, 6818, 17, 17],
            [2007, 6819, 29, 35],
            [2007, 6820, 30, 30],
            [2007, 6821, 46, 38],
            [2007, 6822, 42, 40],
            [2007, 6823, 29, 31],
            [2007, 6833, 32, 35],
            [2007, 6834, 92, 95],
            [2007, 6835, 135, 115],
            [2007, 6836, 40, 45],
            [2007, 6837, 16, 28],
            [2007, 6838, 129, 86],
            [2007, 6841, 27, 21],
            [2007, 6845, 21, 53],
            [2007, 6846, 16, 41],
            [2007, 6847, 21, 45],
            [2007, 6848, 21, 30],
            [2007, 6849, 56, 41],
            [2007, 6850, 21, 35],
            [2007, 6851, 38, 46],
            [2007, 6852, 92, 100],
            [2007, 6853, 22, 55],
            [2007, 6854, 95, 77],
            [2007, 6855, 21, 40],
            [2007, 6856, 17, 52],
            [2007, 6857, 28, 61],
            [2007, 6858, 21, 40],
            [2007, 6859, 32, 27],
            [2007, 6860, 18, 45],
            [2007, 6861, 21, 45],
            [2007, 6862, 32, 35],
            [2007, 6867, 14, 19],
            [2007, 6868, 15, 15],
            [2007, 6869, 15, 15],
            [2007, 6870, 15, 17],
            [2007, 6871, 16, 17],
            [2007, 6872, 15, 17],
            [2007, 6873, 20, 16],
            [2007, 6874, 11, 16],
            [2007, 6875, 14, 17],
            [2007, 6876, 11, 15],
            [2007, 6877, 17, 21],
            [2007, 6878, 14, 16],
            [2007, 6879, 16, 20],
            [2007, 6880, 19, 19],
            [2007, 6881, 11, 13],
            [2007, 6882, 15, 17],
            [2007, 6883, 19, 21],
            [2007, 6910, 48, 40],
            [2007, 6912, 19, 11],
            [2007, 6914, 12, 12],
            [2007, 6918, 28, 23],
            [2007, 6920, 20, 19],
            [2007, 6922, 12, 11],
            [2007, 6928, 17, 16],
            [2007, 6930, 18, 16],
            [2007, 6931, 35, 33],
            [2007, 6934, 16, 15],
            [2007, 6938, 16, 14],
            [2007, 6940, 12, 11],
            [2007, 6942, 19, 17],
            [2007, 6944, 10, 10],
            [2007, 6948, 12, 11],
            [2007, 6950, 13, 11],
            [2007, 6952, 47, 22],
            [2007, 6954, 25, 16],
            [2007, 6957, 62, 49],
            [2007, 6958, 13, 11],
            [2007, 6960, 15, 15],
            [2007, 6962, 13, 11],
            [2007, 6965, 9, 10],
            [2007, 6966, 21, 33],
            [2007, 6967, 15, 32],
            [2007, 6968, 31, 50],
            [2007, 6969, 19, 32],
            [2007, 6970, 20, 32],
            [2007, 7007, 40, 24],
            [2007, 7008, 60, 28],
            [2007, 7011, 10, 10],
            [2007, 7013, 21, 17],
            [2007, 7014, 14, 9],
            [2007, 7015, 8, 8],
            [2007, 7019, 11, 9],
            [2007, 7021, 12, 11],
            [2007, 7027, 16, 16],
            [2007, 7029, 31, 25],
            [2007, 7031, 15, 19],
            [2007, 7033, 22, 19],
            [2007, 7035, 11, 12],
            [2007, 7039, 20, 14],
            [2007, 7050, 16, 14],
            [2007, 7052, 15, 18],
            [2007, 7054, 16, 15],
            [2007, 7056, 12, 14],
            [2007, 7057, 49, 35],
            [2007, 7058, 24, 16],
            [2007, 7062, 15, 13],
            [2007, 7063, 43, 29],
            [2007, 7066, 11, 11],
            [2007, 7068, 57, 25],
            [2007, 7070, 29, 28],
            [2007, 7072, 10, 10],
            [2007, 7074, 14, 14],
            [2007, 7076, 21, 18],
            [2007, 7078, 11, 11],
            [2007, 7080, 34, 31],
            [2007, 7082, 17, 16],
            [2007, 7084, 47, 23],
            [2007, 7086, 11, 13],
            [2007, 7088, 39, 25],
            [2007, 7090, 15, 11],
            [2007, 7091, 48, 33],
            [2007, 7092, 40, 31],
            [2007, 7093, 64, 48],
            [2007, 7094, 39, 30],
            [2007, 7098, 21, 22],
            [2007, 7156, 17, 17],
            [2007, 7259, 68, 45],
            [2007, 7260, 91, 70],
            [2007, 7261, 75, 59],
            [2007, 7262, 67, 65],
            [2007, 7263, 85, 69],
            [2007, 7264, 77, 74],
            [2007, 7265, 88, 72],
            [2007, 7266, 101, 76],
            [2007, 7267, 77, 61],
            [2007, 7268, 109, 82],
            [2007, 7269, 101, 75],
            [2007, 7270, 65, 43],
            [2007, 7271, 54, 50],
            [2007, 7272, 98, 73],
            [2007, 7273, 70, 68],
            [2007, 7274, 91, 67],
            [2007, 7275, 86, 70],
            [2007, 7276, 53, 43],
            [2007, 7277, 86, 69],
            [2007, 7278, 71, 70],
            [2007, 7279, 67, 51],
            [2007, 7280, 102, 76],
            [2007, 7281, 83, 66],
            [2007, 7282, 69, 68],
            [2007, 7283, 13, 19],
            [2007, 7284, 11, 10],
            [2007, 7285, 12, 11],
            [2007, 7286, 15, 20],
            [2007, 7287, 13, 23],
            [2007, 7288, 28, 28],
            [2007, 7289, 26, 21],
            [2007, 7290, 40, 31],
            [2007, 7291, 32, 28],
            [2007, 7292, 31, 33],
            [2007, 7293, 24, 21],
            [2007, 7294, 21, 20],
            [2007, 7295, 12, 14],
            [2007, 7296, 23, 20],
            [2007, 7297, 25, 22],
            [2007, 7298, 15, 16],
            [2007, 7299, 16, 17],
            [2007, 7300, 17, 22],
            [2007, 7301, 13, 21],
            [2007, 7302, 33, 36],
            [2007, 7303, 71, 64],
            [2007, 7304, 28, 30],
            [2007, 7305, 34, 35],
            [2007, 7306, 28, 31],
            [2007, 7307, 47, 50],
            [2007, 7308, 37, 38],
            [2007, 7309, 29, 31],
            [2007, 7310, 77, 63],
            [2007, 7311, 66, 62],
            [2007, 7312, 31, 33],
            [2007, 7313, 123, 35],
            [2007, 7314, 25, 16],
            [2007, 7315, 16, 12],
            [2007, 7316, 38, 60],
            [2007, 7317, 40, 31],
            [2007, 7318, 120, 81],
            [2007, 7319, 42, 31],
            [2007, 7320, 74, 57],
            [2007, 7321, 82, 90],
            [2007, 7322, 71, 40],
            [2007, 7323, 86, 70],
            [2007, 7324, 68, 54],
            [2007, 7325, 104, 40],
            [2007, 7326, 26, 16],
            [2007, 7327, 181, 109],
            [2007, 7328, 20, 24],
            [2007, 7329, 35, 33],
            [2007, 7330, 21, 16],
            [2007, 7337, 15, 12],
            [2007, 7342, 12, 9],
            [2007, 7343, 15, 8],
            [2007, 7344, 11, 9],
            [2007, 7348, 15, 8],
            [2007, 7352, 12, 11],
            [2007, 7354, 25, 15],
            [2007, 7356, 14, 10],
            [2007, 7357, 24, 15],
            [2007, 7358, 14, 10],
            [2007, 7359, 24, 15],
            [2007, 7360, 13, 10],
            [2007, 7362, 17, 12],
            [2007, 7363, 12, 9],
            [2007, 7364, 12, 11],
            [2007, 7367, 15, 12],
            [2007, 7370, 11, 10],
            [2007, 7371, 12, 9],
            [2007, 7372, 12, 9],
            [2007, 7373, 13, 9],
            [2007, 7374, 10, 8],
            [2007, 7375, 11, 8],
            [2007, 7376, 7, 8],
            [2007, 7377, 10, 8],
            [2007, 7378, 20, 18],
            [2007, 7379, 30, 23],
            [2007, 7398, 25, 36],
            [2007, 7399, 28, 29],
            [2007, 7401, 23, 32],
            [2007, 7403, 19, 25],
            [2007, 7405, 21, 26],
            [2007, 7406, 31, 33],
            [2007, 7407, 33, 42],
            [2007, 7410, 17, 22],
            [2007, 7411, 43, 30],
            [2007, 7413, 11, 13],
            [2007, 7414, 16, 23],
            [2007, 7415, 11, 13],
            [2007, 7416, 28, 30],
            [2007, 7417, 22, 20],
            [2007, 7420, 26, 27],
            [2007, 7421, 26, 25],
            [2007, 7423, 62, 51],
            [2007, 7433, 74, 53],
            [2007, 7434, 95, 86],
            [2007, 7435, 35, 41],
            [2007, 7436, 45, 45],
            [2007, 7437, 25, 22],
            [2007, 7438, 75, 35],
            [2007, 7441, 37, 27],
            [2007, 7442, 42, 23],
            [2007, 7443, 34, 45],
            [2007, 7444, 52, 75],
            [2007, 7445, 35, 57],
            [2007, 7446, 43, 61],
            [2007, 7447, 20, 22],
            [2007, 7448, 51, 36],
            [2007, 7449, 19, 19],
            [2007, 7450, 21, 20],
            [2007, 7451, 13, 12],
            [2007, 7452, 21, 17],
            [2007, 7453, 63, 42],
            [2007, 7454, 19, 14],
            [2007, 7455, 22, 20],
            [2007, 7456, 43, 40],
            [2007, 7457, 43, 37],
            [2007, 7458, 31, 30],
            [2007, 7459, 50, 39],
            [2007, 7460, 57, 46],
            [2007, 7461, 33, 29],
            [2007, 7462, 41, 36],
            [2007, 7463, 51, 36],
            [2007, 7464, 54, 40],
            [2007, 7465, 42, 32],
            [2007, 7466, 47, 33],
            [2007, 7467, 45, 41],
            [2007, 7468, 36, 32],
            [2007, 7469, 58, 34],
            [2007, 7470, 57, 42],
            [2007, 7471, 60, 44],
            [2007, 7472, 71, 45],
            [2007, 7473, 36, 32],
            [2007, 7474, 51, 39],
            [2007, 7475, 43, 39],
            [2007, 7476, 38, 33],
            [2007, 7477, 34, 31],
            [2007, 7478, 43, 33],
            [2007, 7479, 36, 32],
            [2007, 7480, 49, 40],
            [2007, 7481, 36, 33],
            [2007, 7482, 47, 32],
            [2007, 7483, 43, 39],
            [2007, 7484, 39, 36],
            [2007, 7485, 71, 49],
            [2007, 7486, 48, 36],
            [2007, 7487, 39, 33],
            [2007, 7488, 42, 32],
            [2007, 7489, 73, 38],
            [2007, 7490, 32, 30],
            [2007, 7491, 43, 33],
            [2007, 7492, 55, 40],
            [2007, 7493, 44, 35],
            [2007, 7494, 51, 35],
            [2007, 7495, 45, 39],
            [2007, 7496, 71, 51],
            [2007, 7497, 42, 32],
            [2007, 7498, 34, 34],
            [2007, 7499, 36, 29],
            [2007, 7500, 46, 40],
            [2007, 7501, 56, 42],
            [2007, 7502, 46, 36],
            [2007, 7503, 47, 35],
            [2007, 7504, 44, 32],
            [2007, 7505, 57, 35],
            [2007, 7506, 52, 40],
            [2007, 7507, 47, 33],
            [2007, 7508, 42, 35],
            [2007, 7509, 49, 39],
            [2007, 7510, 43, 39],
            [2007, 7511, 48, 36],
            [2007, 7512, 43, 39],
            [2007, 7513, 42, 32],
            [2007, 7514, 73, 56],
            [2007, 7515, 51, 38],
            [2007, 7516, 43, 39],
            [2007, 7517, 70, 49],
            [2007, 7518, 55, 40],
            [2007, 7519, 35, 33],
            [2007, 7520, 42, 35],
            [2007, 7521, 32, 32],
            [2007, 7522, 59, 43],
            [2007, 7523, 42, 34],
            [2007, 7524, 53, 46],
            [2007, 7525, 43, 39],
            [2007, 7526, 43, 33],
            [2007, 7527, 31, 32],
            [2007, 7528, 54, 40],
            [2007, 7529, 69, 59],
            [2007, 7530, 51, 42],
            [2007, 7531, 36, 31],
            [2007, 7532, 43, 39],
            [2007, 7533, 59, 45],
            [2007, 7534, 62, 52],
            [2007, 7535, 44, 39],
            [2007, 7536, 43, 38],
            [2007, 7537, 63, 39],
            [2007, 7538, 45, 37],
            [2007, 7539, 56, 36],
            [2007, 7540, 54, 33],
            [2007, 7541, 51, 38],
            [2007, 7542, 53, 41],
            [2007, 7543, 45, 34],
            [2007, 7544, 46, 35],
            [2007, 7545, 44, 33],
            [2007, 7546, 42, 32],
            [2007, 7547, 42, 32],
            [2007, 7548, 41, 36],
            [2007, 7549, 47, 39],
            [2007, 7550, 35, 32],
            [2007, 7551, 41, 36],
            [2007, 7552, 55, 39],
            [2007, 7553, 44, 35],
            [2007, 7554, 56, 50],
            [2007, 7555, 60, 47],
            [2007, 7556, 48, 39],
            [2007, 7557, 65, 45],
            [2007, 7558, 39, 29],
            [2007, 7559, 44, 32],
            [2007, 7560, 41, 36],
            [2007, 7561, 69, 45],
            [2007, 7562, 59, 49],
            [2007, 7563, 57, 42],
            [2007, 7564, 44, 34],
            [2007, 7565, 44, 36],
            [2007, 7566, 39, 35],
            [2007, 7567, 71, 39],
            [2007, 7568, 38, 35],
            [2007, 7569, 40, 35],
            [2007, 7570, 38, 35],
            [2007, 7571, 38, 35],
            [2007, 7572, 38, 37],
            [2007, 7573, 42, 31],
            [2007, 7574, 39, 35],
            [2007, 7575, 48, 36],
            [2007, 7576, 54, 40],
            [2007, 7577, 57, 42],
            [2007, 7578, 47, 36],
            [2007, 7579, 51, 38],
            [2007, 7580, 57, 42],
            [2007, 7581, 43, 35],
            [2007, 7582, 51, 42],
            [2007, 7583, 56, 39],
            [2007, 7584, 37, 33],
            [2007, 7585, 43, 38],
            [2007, 7586, 68, 51],
            [2007, 7587, 44, 36],
            [2007, 7588, 45, 36],
            [2007, 7589, 68, 51],
            [2007, 7590, 49, 42],
            [2007, 7591, 42, 32],
            [2007, 7592, 44, 42],
            [2007, 7593, 51, 39],
            [2007, 7594, 40, 35],
            [2007, 7595, 55, 36],
            [2007, 7596, 36, 32],
            [2007, 7597, 43, 36],
            [2007, 7598, 55, 40],
            [2007, 7599, 53, 39],
            [2007, 7600, 43, 39],
            [2007, 7601, 37, 32],
            [2007, 7602, 51, 31],
            [2007, 7603, 52, 43],
            [2007, 7604, 52, 40],
            [2007, 7605, 47, 39],
            [2007, 7606, 47, 36],
            [2007, 7607, 48, 42],
            [2007, 7608, 41, 36],
            [2007, 7609, 41, 39],
            [2007, 7610, 33, 33],
            [2007, 7611, 36, 35],
            [2007, 7612, 50, 42],
            [2007, 7613, 51, 36],
            [2007, 7614, 42, 35],
            [2007, 7615, 57, 42],
            [2007, 7616, 45, 34],
            [2007, 7617, 44, 32],
            [2007, 7618, 49, 38],
            [2007, 7619, 45, 39],
            [2007, 7620, 45, 36],
            [2007, 7621, 45, 39],
            [2007, 7622, 51, 38],
            [2007, 7623, 39, 35],
            [2007, 7624, 64, 40],
            [2007, 7625, 36, 33],
            [2007, 7626, 51, 38],
            [2007, 7627, 43, 37],
            [2007, 7628, 57, 42],
            [2007, 7629, 32, 36],
            [2007, 7630, 40, 33],
            [2007, 7631, 44, 38],
            [2007, 7632, 53, 34],
            [2007, 7633, 43, 33],
            [2007, 7634, 14, 18],
            [2007, 7635, 12, 16],
            [2007, 7636, 15, 20],
            [2007, 7637, 26, 23],
            [2007, 7638, 51, 34],
            [2007, 7639, 11, 12],
            [2007, 7640, 10, 10],
            [2007, 7641, 15, 16],
            [2007, 7642, 28, 28],
            [2007, 7643, 21, 18],
            [2007, 7644, 23, 26],
            [2007, 7645, 18, 19],
            [2007, 7646, 21, 21],
            [2007, 7647, 27, 21],
            [2007, 7648, 11, 11],
            [2007, 7649, 11, 11],
            [2007, 7650, 17, 15],
            [2007, 7651, 12, 11],
            [2007, 7652, 14, 14],
            [2007, 7653, 30, 25],
            [2007, 7654, 11, 11],
            [2007, 7655, 13, 12],
            [2007, 7656, 13, 12],
            [2007, 7657, 21, 22],
            [2007, 7658, 20, 23],
            [2007, 7659, 14, 17],
            [2007, 7661, 10, 10],
            [2007, 7662, 17, 14],
            [2007, 7663, 15, 17],
            [2007, 7664, 19, 24],
            [2007, 7665, 23, 26],
            [2007, 7666, 12, 11],
            [2007, 7667, 13, 13],
            [2007, 7668, 13, 12],
            [2007, 7669, 11, 8],
            [2007, 7672, 9, 9],
            [2007, 7673, 8, 7],
            [2007, 7674, 17, 14],
            [2007, 7676, 6, 7],
            [2007, 7677, 5, 6],
            [2007, 7678, 10, 8],
            [2007, 7679, 11, 9],
            [2007, 7680, 27, 17],
            [2007, 7681, 5, 3],
            [2007, 7682, 16, 13],
            [2007, 7683, 3, 3],
            [2007, 7684, 13, 12],
            [2007, 7685, 11, 10],
            [2007, 7686, 19, 17],
            [2007, 7687, 5, 4],
            [2007, 7688, 14, 13],
            [2007, 7690, 7, 8],
            [2007, 7691, 24, 21],
            [2007, 7692, 10, 8],
            [2007, 7693, 9, 9],
            [2007, 7694, 9, 9],
            [2007, 7695, 25, 19],
            [2007, 7696, 3, 3],
            [2007, 7697, 16, 12],
            [2007, 7698, 9, 8],
            [2007, 7699, 12, 14],
            [2007, 7700, 12, 10],
            [2007, 7701, 9, 8],
            [2007, 7702, 22, 13],
            [2007, 7703, 11, 12],
            [2007, 7705, 23, 13],
            [2007, 7706, 11, 10],
            [2007, 7707, 11, 10],
            [2007, 7708, 9, 7],
            [2007, 7709, 11, 13],
            [2007, 7710, 6, 5],
            [2007, 7711, 14, 10],
            [2007, 7713, 25, 12],
            [2007, 7714, 10, 9],
            [2007, 7716, 17, 22],
            [2007, 7717, 37, 29],
            [2007, 7718, 26, 37],
            [2007, 7719, 17, 24],
            [2007, 7722, 28, 35],
            [2007, 7723, 19, 43],
            [2007, 7725, 20, 19],
            [2007, 7726, 25, 22],
            [2007, 7729, 26, 28],
            [2007, 7730, 18, 22],
            [2007, 7731, 30, 25],
            [2007, 7734, 25, 29],
            [2007, 7736, 15, 25],
            [2007, 7737, 32, 28],
            [2007, 7738, 17, 22],
            [2007, 7739, 60, 38],
            [2007, 7740, 41, 38],
            [2007, 7741, 74, 48],
            [2007, 7743, 24, 33],
            [2007, 7744, 54, 43],
            [2007, 7749, 28, 28],
            [2007, 7753, 35, 33],
            [2007, 7754, 26, 34],
            [2007, 7755, 19, 30],
            [2007, 7757, 32, 87],
            [2007, 7758, 60, 101],
            [2007, 7759, 28, 29],
            [2007, 7760, 75, 49],
            [2007, 7761, 18, 37],
            [2007, 7762, 60, 65],
            [2007, 7763, 13, 16],
            [2007, 7764, 12, 14],
            [2007, 7765, 13, 17],
            [2007, 7766, 9, 13],
            [2007, 7795, 110, 80],
            [2007, 7796, 95, 40],
            [2007, 7797, 115, 60],
            [2007, 7798, 94, 36],
            [2007, 7799, 75, 49],
            [2007, 7800, 80, 32],
            [2007, 7801, 110, 52],
            [2007, 7802, 25, 29],
            [2007, 7803, 180, 84],
            [2007, 7804, 110, 46],
            [2007, 7805, 80, 45],
            [2007, 7806, 110, 63],
            [2007, 7807, 85, 61],
            [2007, 7808, 110, 31],
            [2007, 7809, 95, 58],
            [2007, 7810, 96, 81],
            [2007, 7811, 198, 104],
            [2007, 7812, 50, 37],
            [2007, 7813, 69, 36],
            [2007, 7815, 67, 39],
            [2007, 7816, 110, 76],
            [2007, 7817, 38, 45],
            [2007, 7818, 58, 51],
            [2007, 7819, 52, 69],
            [2007, 7820, 68, 44],
            [2007, 7821, 135, 65],
            [2007, 7822, 62, 47],
            [2007, 7823, 41, 22],
            [2007, 7824, 172, 90],
            [2007, 7825, 101, 39],
            [2007, 7826, 65, 46],
            [2007, 7827, 110, 37],
            [2007, 7828, 116, 115],
            [2007, 7829, 70, 47],
            [2007, 7830, 87, 57],
            [2007, 7831, 76, 40],
            [2007, 7832, 118, 72],
            [2007, 7833, 55, 37],
            [2007, 7834, 115, 67],
            [2007, 7835, 68, 36],
            [2007, 7836, 113, 71],
            [2007, 7837, 46, 35],
            [2007, 7838, 110, 30],
            [2007, 7839, 94, 71],
            [2007, 7840, 146, 84],
            [2007, 7841, 76, 37],
            [2007, 7842, 37, 30],
            [2007, 7843, 46, 23],
            [2007, 7844, 110, 45],
            [2007, 7845, 41, 41],
            [2007, 7846, 110, 52],
            [2007, 7847, 87, 36],
            [2007, 7848, 110, 54],
            [2007, 7849, 215, 90],
            [2007, 7850, 65, 91],
            [2007, 7851, 104, 60],
            [2007, 7852, 58, 38],
            [2007, 7853, 37, 47],
            [2007, 7854, 29, 33],
            [2007, 7855, 56, 33],
            [2007, 7856, 140, 71],
            [2007, 7857, 85, 36],
            [2007, 7858, 30, 33],
            [2007, 7859, 102, 57],
            [2007, 7860, 103, 59],
            [2007, 7861, 47, 36],
            [2007, 7862, 182, 55],
            [2007, 7863, 225, 74],
            [2007, 7864, 34, 31],
            [2007, 7865, 47, 39],
            [2007, 7866, 110, 59],
            [2007, 7867, 48, 36],
            [2007, 7868, 46, 36],
            [2007, 7869, 92, 54],
            [2007, 7870, 50, 36],
            [2007, 7871, 57, 38],
            [2007, 7872, 116, 90],
            [2007, 7873, 116, 66],
            [2007, 7874, 45, 36],
            [2007, 7875, 128, 66],
            [2007, 7876, 116, 78],
            [2007, 7877, 115, 57],
            [2007, 7878, 160, 46],
            [2007, 7879, 116, 74],
            [2007, 7880, 71, 47],
            [2007, 7881, 51, 53],
            [2007, 7882, 38, 26],
            [2007, 7883, 64, 53],
            [2007, 7884, 41, 51],
            [2007, 7885, 58, 43],
            [2007, 7886, 54, 37],
            [2007, 7887, 65, 37],
            [2007, 7888, 110, 43],
            [2007, 7889, 175, 82],
            [2007, 7890, 50, 70],
            [2007, 7891, 59, 37],
            [2007, 7892, 35, 36],
            [2007, 7893, 32, 33],
            [2007, 7894, 107, 70],
            [2007, 7895, 68, 38],
            [2007, 7896, 158, 66],
            [2007, 7897, 111, 53],
            [2007, 7898, 25, 33],
            [2007, 7899, 49, 77],
            [2007, 7900, 119, 68],
            [2007, 7901, 114, 49],
            [2007, 7902, 94, 58],
            [2007, 7903, 100, 54],
            [2007, 7904, 78, 56],
            [2007, 7905, 59, 55],
            [2007, 7906, 100, 72],
            [2007, 7907, 111, 53],
            [2007, 7908, 130, 51],
            [2007, 7909, 75, 45],
            [2007, 7910, 90, 49],
            [2007, 7911, 78, 52],
            [2007, 7912, 111, 90],
            [2007, 7913, 112, 48],
            [2007, 7914, 80, 57],
            [2007, 7915, 93, 74],
            [2007, 7916, 110, 48],
            [2007, 7917, 70, 44],
            [2007, 7918, 60, 37],
            [2007, 7919, 39, 34],
            [2007, 7920, 77, 45],
            [2007, 7921, 50, 15],
            [2007, 7922, 29, 38],
            [2007, 7923, 99, 36],
            [2007, 7924, 43, 41],
            [2007, 7925, 52, 38],
            [2007, 7926, 268, 47],
            [2007, 7927, 31, 47],
            [2007, 7928, 23, 46],
            [2007, 7929, 111, 50],
            [2007, 7930, 91, 47],
            [2007, 7931, 50, 36],
            [2007, 7932, 45, 35],
            [2007, 7933, 91, 53],
            [2007, 7934, 66, 59],
            [2007, 7935, 116, 57],
            [2007, 7936, 108, 50],
            [2007, 7937, 64, 46],
            [2007, 7938, 20, 16],
            [2007, 7939, 101, 78],
            [2007, 7940, 103, 64],
            [2007, 7941, 102, 76],
            [2007, 7942, 101, 65],
            [2007, 7943, 53, 33],
            [2007, 7944, 30, 37],
            [2007, 7945, 101, 38],
            [2007, 7946, 46, 66],
            [2007, 7947, 75, 46],
            [2007, 7948, 39, 33],
            [2007, 7949, 63, 78],
            [2007, 7950, 53, 47],
            [2007, 7951, 116, 56],
            [2007, 7952, 56, 49],
            [2007, 7953, 42, 16],
            [2007, 7954, 92, 28],
            [2007, 7955, 150, 48],
            [2007, 7956, 94, 38],
            [2007, 7957, 101, 43],
            [2007, 7958, 110, 46],
            [2007, 7959, 108, 37],
            [2007, 7960, 51, 43],
            [2007, 7961, 105, 90],
            [2007, 7962, 181, 78],
            [2007, 7963, 22, 23],
            [2007, 7964, 64, 78],
            [2007, 7965, 109, 38],
            [2007, 7966, 130, 95],
            [2007, 7967, 66, 33],
            [2007, 7968, 108, 81],
            [2007, 7969, 93, 70],
            [2007, 7970, 105, 61],
            [2007, 7971, 27, 37],
            [2007, 7972, 39, 40],
            [2007, 7974, 67, 33],
            [2007, 7975, 170, 82],
            [2007, 7976, 170, 54],
            [2007, 7977, 48, 53],
            [2007, 7978, 106, 60],
            [2007, 7979, 106, 57],
            [2007, 7980, 105, 50],
            [2007, 7981, 73, 30],
            [2007, 7982, 72, 40],
            [2007, 7983, 85, 33],
            [2007, 7984, 101, 78],
            [2007, 7985, 54, 49],
            [2007, 7986, 77, 36],
            [2007, 7987, 66, 45],
            [2007, 7988, 31, 42],
            [2007, 7989, 108, 37],
            [2007, 7990, 83, 38],
            [2007, 7992, 96, 51],
            [2007, 7993, 94, 62],
            [2007, 7994, 53, 42],
            [2007, 7995, 184, 90],
            [2007, 7996, 100, 51],
            [2007, 7997, 133, 73],
            [2007, 7998, 53, 24],
            [2007, 7999, 128, 70],
            [2007, 8000, 94, 35],
            [2007, 8001, 109, 71],
            [2007, 8002, 83, 62],
            [2007, 8003, 30, 33],
            [2007, 8004, 94, 67],
            [2007, 8005, 19, 17],
            [2007, 8006, 12, 14],
            [2007, 8007, 24, 24],
            [2007, 8008, 22, 22],
            [2007, 8009, 13, 13],
            [2007, 8010, 12, 13],
            [2007, 8011, 17, 17],
            [2007, 8012, 11, 11],
            [2007, 8013, 7, 6],
            [2007, 8014, 9, 9],
            [2007, 8015, 10, 8],
            [2007, 8016, 6, 5],
            [2007, 8017, 11, 11],
            [2007, 8018, 7, 6],
            [2007, 8019, 13, 12],
            [2007, 8020, 11, 11],
            [2007, 8021, 6, 5],
            [2007, 8022, 19, 21],
            [2007, 8023, 15, 15],
            [2007, 8024, 18, 17],
            [2007, 8025, 16, 19],
            [2007, 8026, 17, 17],
            [2007, 8027, 14, 11],
            [2007, 8028, 12, 12],
            [2007, 8029, 19, 16],
            [2007, 8030, 18, 16],
            [2007, 8031, 12, 11],
            [2007, 8032, 18, 20],
            [2007, 8033, 17, 17],
            [2007, 8034, 19, 22],
            [2007, 8035, 18, 20],
            [2007, 8036, 16, 17],
            [2007, 8037, 18, 19],
            [2007, 8038, 29, 40],
            [2007, 8039, 24, 36],
            [2007, 8040, 18, 36],
            [2007, 8041, 7, 11],
            [2007, 8042, 7, 9],
            [2007, 8043, 10, 13],
            [2007, 8044, 10, 14],
            [2007, 8045, 5, 3],
            [2007, 8046, 5, 3],
            [2007, 8047, 5, 5],
            [2007, 8048, 14, 19],
            [2007, 8049, 11, 15],
            [2007, 8050, 9, 10],
            [2007, 8051, 17, 18],
            [2007, 8052, 29, 39],
            [2007, 8053, 19, 31],
            [2007, 8054, 14, 26],
            [2007, 8055, 27, 38],
            [2007, 8056, 36, 41],
            [2007, 8057, 18, 26],
            [2007, 8058, 15, 21],
            [2007, 8059, 21, 23],
            [2007, 8060, 22, 22],
            [2007, 8061, 44, 48],
            [2007, 8062, 47, 58],
            [2007, 8063, 10, 11],
            [2007, 8064, 12, 16],
            [2007, 8065, 12, 12],
            [2007, 8068, 7, 10],
            [2007, 8069, 7, 10],
            [2007, 8071, 42, 19],
            [2007, 8073, 17, 13],
            [2007, 8074, 9, 9],
            [2007, 8075, 18, 13],
            [2007, 8076, 42, 23],
            [2007, 8086, 14, 27],
            [2007, 8087, 15, 23],
            [2007, 8088, 16, 25],
            [2007, 8089, 20, 30],
            [2007, 8090, 19, 24],
            [2007, 8091, 21, 37],
            [2007, 8092, 17, 29],
            [2007, 8093, 19, 36],
            [2007, 8094, 14, 36],
            [2007, 8095, 18, 21],
            [2007, 8096, 20, 27],
            [2007, 8097, 18, 24],
            [2007, 8099, 21, 25],
            [2007, 8102, 18, 18],
            [2007, 8103, 24, 31],
            [2007, 8107, 16, 20],
            [2007, 8109, 19, 24],
            [2007, 8110, 17, 21],
            [2007, 8116, 43, 57],
            [2007, 8117, 46, 61],
            [2007, 8118, 23, 30],
            [2007, 8119, 15, 28],
            [2007, 8120, 27, 26],
            [2007, 8121, 22, 23],
            [2007, 8124, 23, 31],
            [2007, 8126, 22, 22],
            [2007, 8127, 27, 30],
            [2007, 8131, 30, 37],
            [2007, 8133, 18, 22],
            [2007, 8134, 32, 34],
            [2007, 8136, 18, 22],
            [2007, 8137, 26, 30],
            [2007, 8138, 27, 27],
            [2007, 8140, 36, 51],
            [2007, 8141, 34, 44],
            [2007, 8145, 22, 32],
            [2007, 8149, 17, 22],
            [2007, 8151, 17, 21],
            [2007, 8153, 28, 31],
            [2007, 8154, 22, 27],
            [2007, 8155, 52, 43],
            [2007, 8159, 27, 28],
            [2007, 8160, 23, 27],
            [2007, 8164, 20, 25],
            [2007, 8167, 39, 41],
            [2007, 8168, 37, 55],
            [2007, 8170, 20, 32],
            [2007, 8171, 25, 23],
            [2007, 8175, 15, 23],
            [2007, 8177, 26, 27],
            [2007, 8178, 23, 24],
            [2007, 8184, 25, 22],
            [2007, 8185, 21, 20],
            [2007, 8187, 29, 33],
            [2007, 8188, 18, 20],
            [2007, 8194, 33, 32],
            [2007, 8195, 20, 24],
            [2007, 8196, 14, 18],
            [2007, 8198, 31, 36],
            [2007, 8200, 20, 29],
            [2007, 8202, 36, 66],
            [2007, 8205, 33, 31],
            [2007, 8208, 20, 29],
            [2007, 8210, 17, 27],
            [2007, 8217, 20, 33],
            [2007, 8218, 13, 18],
            [2007, 8219, 40, 31],
            [2007, 8220, 27, 24],
            [2007, 8221, 51, 30],
            [2007, 8222, 23, 16],
            [2007, 8223, 20, 30],
            [2007, 8224, 47, 39],
            [2007, 8225, 13, 20],
            [2007, 8227, 24, 27],
            [2007, 8228, 25, 51],
            [2007, 8231, 18, 22],
            [2007, 8232, 69, 45],
            [2007, 8234, 18, 24],
            [2007, 8236, 20, 20],
            [2007, 8238, 45, 35],
            [2007, 8241, 14, 20],
            [2007, 8248, 15, 19],
            [2007, 8250, 23, 22],
            [2007, 8251, 20, 25],
            [2007, 8254, 30, 31],
            [2007, 8255, 59, 43],
            [2007, 8256, 19, 25],
            [2007, 8259, 20, 25],
            [2007, 8260, 23, 26],
            [2007, 8262, 27, 30],
            [2007, 8264, 28, 36],
            [2007, 8265, 49, 41],
            [2007, 8268, 17, 28],
            [2007, 8270, 16, 27],
            [2007, 8271, 28, 34],
            [2007, 8276, 27, 24],
            [2007, 8277, 19, 20],
            [2007, 8287, 19, 24],
            [2007, 8288, 18, 20],
            [2007, 8294, 41, 58],
            [2007, 8299, 26, 19],
            [2007, 8300, 35, 29],
            [2007, 8302, 20, 19],
            [2007, 8309, 12, 18],
            [2007, 8310, 25, 26],
            [2007, 8311, 12, 13],
            [2007, 8312, 12, 13],
            [2007, 8313, 11, 12],
            [2007, 8314, 12, 12],
            [2007, 8315, 17, 15],
            [2007, 8316, 11, 11],
            [2007, 8317, 29, 22],
            [2007, 8319, 19, 17],
            [2007, 8322, 28, 23],
            [2007, 8323, 23, 20],
            [2007, 8324, 39, 29],
            [2007, 8336, 18, 16],
            [2007, 8337, 12, 14],
            [2007, 8338, 12, 11],
            [2007, 8339, 29, 28],
            [2007, 8340, 15, 16],
            [2007, 8341, 21, 22],
            [2007, 8342, 15, 15],
            [2007, 8343, 15, 14],
            [2007, 8344, 15, 14],
            [2007, 8345, 21, 20],
            [2007, 8346, 17, 20],
            [2007, 8347, 15, 16],
            [2007, 8348, 19, 18],
            [2007, 8349, 20, 18],
            [2007, 8350, 17, 19],
            [2007, 8351, 14, 11],
            [2007, 8352, 18, 21],
            [2007, 8353, 11, 11],
            [2007, 8354, 21, 23],
            [2007, 8355, 14, 14],
            [2007, 8356, 23, 22],
            [2007, 8357, 17, 14],
            [2007, 8358, 20, 18],
            [2007, 8359, 28, 29],
            [2007, 8360, 24, 24],
            [2007, 8361, 12, 12],
            [2007, 8362, 18, 20],
            [2007, 8363, 25, 26],
            [2007, 8364, 21, 20],
            [2007, 8365, 19, 18],
            [2007, 8366, 19, 18],
            [2007, 8367, 18, 16],
            [2007, 8368, 17, 21],
            [2007, 8369, 17, 20],
            [2007, 8370, 19, 17],
            [2007, 8371, 18, 16],
            [2007, 8372, 19, 17],
            [2007, 8373, 20, 23],
            [2007, 8374, 17, 19],
            [2007, 8375, 16, 17],
            [2007, 8376, 22, 22],
            [2007, 8377, 19, 17],
            [2007, 8378, 20, 17],
            [2007, 8379, 22, 20],
            [2007, 8380, 23, 19],
            [2007, 8381, 18, 19],
            [2007, 8382, 16, 17],
            [2007, 8383, 20, 21],
            [2007, 8384, 19, 23],
            [2007, 8385, 17, 20],
            [2007, 8386, 15, 15],
            [2007, 8387, 20, 19],
            [2007, 8388, 20, 18],
            [2007, 8389, 16, 17],
            [2007, 8390, 12, 12],
            [2007, 8391, 18, 17],
            [2007, 8392, 18, 18],
            [2007, 8393, 23, 27],
            [2007, 8394, 20, 18],
            [2007, 8395, 17, 17],
            [2007, 8536, 18, 26],
            [2007, 8537, 33, 24],
            [2007, 8538, 35, 24],
            [2007, 8539, 34, 28],
            [2007, 8540, 26, 32],
            [2007, 8541, 32, 39],
            [2007, 8542, 25, 33],
            [2007, 8543, 17, 32],
            [2007, 8544, 25, 45],
            [2007, 8546, 24, 35],
            [2007, 8547, 30, 45],
            [2007, 8548, 15, 17],
            [2007, 8549, 14, 25],
            [2007, 8550, 19, 23],
            [2007, 8551, 28, 26],
            [2007, 8552, 26, 31],
            [2007, 8553, 24, 35],
            [2007, 8554, 34, 27],
            [2007, 8555, 28, 27],
            [2007, 8556, 25, 34],
            [2007, 8557, 29, 36],
            [2007, 8558, 24, 25],
            [2007, 8559, 23, 28],
            [2007, 8560, 39, 30],
            [2007, 8561, 24, 26],
            [2007, 8562, 60, 34],
            [2007, 8563, 33, 35],
            [2007, 8564, 128, 88],
            [2007, 8565, 10, 11],
            [2007, 8566, 21, 14],
            [2007, 8567, 20, 18],
            [2007, 8568, 14, 15],
            [2007, 8569, 19, 15],
            [2007, 8570, 10, 10],
            [2007, 8571, 14, 11],
            [2007, 8572, 12, 12],
            [2007, 8573, 13, 11],
            [2007, 8574, 15, 13],
            [2007, 8575, 10, 10],
            [2007, 8576, 23, 19],
            [2007, 8577, 14, 16],
            [2007, 8578, 21, 19],
            [2007, 8579, 14, 17],
            [2007, 8580, 18, 17],
            [2007, 8581, 12, 11],
            [2007, 8582, 16, 15],
            [2007, 8583, 20, 18],
            [2007, 8584, 13, 14],
            [2007, 8719, 24, 22],
            [2007, 8720, 25, 23],
            [2007, 8721, 26, 23],
            [2007, 8722, 24, 22],
            [2007, 8723, 26, 24],
            [2007, 8724, 24, 24],
            [2007, 8725, 26, 21],
            [2007, 8726, 25, 22],
            [2007, 8727, 22, 22],
            [2007, 8728, 19, 21],
            [2007, 8729, 23, 21],
            [2007, 8730, 19, 20],
            [2007, 8731, 20, 20],
            [2007, 8732, 25, 22],
            [2007, 8733, 26, 22],
            [2007, 8734, 26, 22],
            [2007, 8735, 21, 20],
            [2007, 8736, 21, 21],
            [2007, 8737, 20, 20],
            [2007, 8738, 21, 20],
            [2007, 8739, 21, 21],
            [2007, 8740, 21, 20],
            [2007, 8741, 23, 21],
            [2007, 8742, 23, 21],
            [2007, 8743, 22, 21],
            [2007, 8744, 23, 21],
            [2007, 8745, 24, 22],
            [2007, 8746, 26, 22],
            [2007, 8747, 27, 23],
            [2007, 8748, 26, 23],
            [2007, 8749, 23, 22],
            [2007, 8750, 22, 21],
            [2007, 8751, 22, 22],
            [2007, 8752, 21, 20],
            [2007, 8753, 19, 20],
            [2007, 8754, 21, 21],
            [2007, 8755, 20, 21],
            [2007, 8756, 26, 22],
            [2007, 8757, 19, 20],
            [2007, 8758, 21, 20],
            [2007, 8759, 22, 21],
            [2007, 8760, 29, 30],
            [2007, 8761, 22, 21],
            [2007, 8762, 26, 22],
            [2007, 8763, 18, 18],
            [2007, 8764, 28, 21],
            [2007, 8765, 23, 20],
            [2007, 8766, 26, 22],
            [2007, 8767, 26, 22],
            [2007, 8768, 26, 22],
            [2007, 8769, 27, 22],
            [2007, 8770, 26, 22],
            [2007, 8771, 26, 23],
            [2007, 8772, 27, 22],
            [2007, 8773, 21, 20],
            [2007, 8774, 21, 20],
            [2007, 8775, 21, 20],
            [2007, 8776, 21, 20],
            [2007, 8777, 22, 22],
            [2007, 8778, 28, 22],
            [2007, 8779, 10, 9],
            [2007, 8780, 12, 9],
            [2007, 8781, 15, 13],
            [2007, 8782, 12, 9],
            [2007, 8783, 10, 8],
            [2007, 8784, 12, 9],
            [2007, 8785, 7, 7],
            [2007, 8786, 9, 10],
            [2007, 8787, 10, 10],
            [2007, 8788, 12, 9],
            [2007, 8790, 10, 8],
            [2007, 8791, 6, 6],
            [2007, 8792, 11, 9],
            [2007, 8793, 8, 8],
            [2007, 8794, 8, 7],
            [2007, 8795, 9, 7],
            [2007, 8796, 13, 9],
            [2007, 8797, 15, 9],
            [2007, 8798, 9, 8],
            [2007, 8799, 13, 13],
            [2007, 8800, 10, 8],
            [2007, 8801, 10, 9],
            [2007, 8802, 8, 7],
            [2007, 8803, 8, 8],
            [2007, 8804, 7, 8],
            [2007, 8805, 9, 8],
            [2007, 8806, 9, 10],
            [2007, 8807, 10, 11],
            [2007, 8808, 9, 8],
            [2007, 8809, 6, 8],
            [2007, 8810, 10, 10],
            [2007, 8811, 7, 9],
            [2007, 8812, 11, 9],
            [2007, 8814, 6, 7],
            [2007, 8815, 9, 9],
            [2007, 8816, 10, 7],
            [2007, 8817, 13, 9],
            [2007, 8818, 38, 31],
            [2007, 8819, 35, 30],
            [2007, 8820, 40, 32],
            [2007, 8821, 38, 26],
            [2007, 8822, 40, 32],
            [2007, 8823, 31, 25],
            [2007, 8824, 22, 18],
            [2007, 8825, 34, 26],
            [2007, 8826, 22, 21],
            [2007, 8827, 37, 26],
            [2007, 8828, 37, 26],
            [2007, 8829, 38, 30],
            [2007, 8830, 27, 27],
            [2007, 8831, 33, 25],
            [2007, 8832, 19, 11],
            [2007, 8833, 30, 24],
            [2007, 8834, 33, 29],
            [2007, 8835, 26, 19],
            [2007, 8836, 39, 31],
            [2007, 8837, 30, 21],
            [2007, 8838, 38, 29],
            [2007, 8839, 24, 13],
            [2007, 8840, 34, 24],
            [2007, 8841, 23, 13],
            [2007, 8842, 15, 18],
            [2007, 8843, 19, 12],
            [2007, 8844, 26, 22],
            [2007, 8845, 14, 15],
            [2007, 8846, 31, 26],
            [2007, 8847, 18, 19],
            [2007, 8848, 39, 31],
            [2007, 8849, 26, 21],
            [2007, 8850, 32, 27],
            [2007, 8851, 22, 21],
            [2007, 8852, 32, 25],
            [2007, 8853, 14, 17],
            [2007, 8854, 31, 26],
            [2007, 8855, 20, 14],
            [2007, 8856, 30, 25],
            [2007, 8857, 21, 13],
            [2007, 8858, 27, 14],
            [2007, 8859, 38, 31],
            [2007, 8860, 27, 12],
            [2007, 8861, 31, 26],
            [2007, 8862, 24, 21],
            [2007, 8863, 32, 27],
            [2007, 8864, 21, 21],
            [2007, 8865, 31, 25],
            [2007, 8866, 22, 21],
            [2007, 8867, 39, 32],
            [2007, 8868, 37, 30],
            [2007, 8869, 40, 32],
            [2007, 8870, 39, 31],
            [2007, 8871, 32, 27],
            [2007, 8872, 35, 28],
            [2007, 8873, 26, 22],
            [2007, 8874, 30, 25],
            [2007, 8875, 31, 26],
            [2007, 8876, 18, 18],
            [2007, 8877, 38, 27],
            [2007, 8878, 23, 20],
            [2007, 8879, 18, 11],
            [2007, 8880, 30, 25],
            [2007, 8881, 40, 32],
            [2007, 8882, 26, 22],
            [2007, 8883, 40, 31],
            [2007, 8884, 17, 15],
            [2007, 8885, 41, 31],
            [2007, 8886, 33, 25],
            [2007, 8887, 19, 11],
            [2007, 8888, 37, 30],
            [2007, 8889, 39, 31],
            [2007, 8890, 13, 16],
            [2007, 8891, 32, 28],
            [2007, 8892, 14, 11],
            [2007, 8893, 31, 27],
            [2007, 8894, 19, 18],
            [2007, 8895, 15, 11],
            [2007, 8896, 24, 20],
            [2007, 8897, 15, 10],
            [2007, 8898, 19, 18],
            [2007, 8899, 39, 32],
            [2007, 8900, 31, 26],
            [2007, 8901, 36, 28],
            [2007, 8902, 27, 23],
            [2007, 8903, 25, 21],
            [2007, 8904, 33, 26],
            [2007, 8905, 23, 19],
            [2007, 8906, 30, 24],
            [2007, 8907, 19, 19],
            [2007, 8908, 28, 24],
            [2007, 8909, 21, 18],
            [2007, 8910, 21, 12],
            [2007, 8911, 21, 13],
            [2007, 8912, 38, 31],
            [2007, 8913, 26, 22],
            [2007, 8914, 38, 27],
            [2007, 8915, 27, 21],
            [2007, 8916, 39, 31],
            [2007, 8917, 31, 22],
            [2007, 8918, 39, 31],
            [2007, 8919, 30, 26],
            [2007, 8920, 31, 26],
            [2007, 8921, 33, 27],
            [2007, 8922, 30, 24],
            [2007, 8923, 24, 20],
            [2007, 8924, 14, 13],
            [2007, 8925, 11, 10],
            [2007, 8926, 14, 12],
            [2007, 8927, 15, 15],
            [2007, 8928, 13, 12],
            [2007, 8929, 10, 10],
            [2007, 8930, 9, 10],
            [2007, 8931, 13, 14],
            [2007, 8932, 16, 18],
            [2007, 8933, 23, 21],
            [2007, 8934, 26, 22],
            [2007, 8935, 33, 28],
            [2007, 8936, 25, 17],
            [2007, 8937, 31, 26],
            [2007, 8938, 24, 17],
            [2007, 8939, 31, 24],
            [2007, 8940, 18, 16],
            [2007, 8941, 30, 24],
            [2007, 8942, 18, 16],
            [2007, 8943, 26, 19],
            [2007, 8944, 31, 25],
            [2007, 8945, 22, 19],
            [2007, 8946, 31, 25],
            [2007, 8947, 21, 18],
            [2007, 8948, 30, 25],
            [2007, 8949, 25, 20],
            [2007, 8950, 22, 19],
            [2007, 8951, 27, 25],
            [2007, 8952, 23, 19],
            [2007, 8953, 30, 23],
            [2007, 8954, 24, 17],
            [2007, 8955, 38, 31],
            [2007, 8956, 26, 22],
            [2007, 8957, 26, 18],
            [2007, 8958, 40, 32],
            [2007, 8959, 26, 19],
            [2007, 8960, 39, 31],
            [2007, 8961, 26, 19],
            [2007, 8962, 33, 31],
            [2007, 8963, 30, 26],
            [2007, 8964, 19, 12],
            [2007, 8965, 36, 29],
            [2007, 8966, 35, 28],
            [2007, 8967, 38, 30],
            [2007, 8968, 30, 25],
            [2007, 8969, 18, 13],
            [2007, 8970, 38, 31],
            [2007, 8971, 28, 24],
            [2007, 8972, 16, 13],
            [2007, 8973, 36, 28],
            [2007, 8974, 12, 16],
            [2007, 8975, 39, 31],
            [2007, 8976, 40, 32],
            [2007, 8977, 26, 21],
            [2007, 8978, 14, 11],
            [2007, 8979, 37, 30],
            [2007, 8980, 30, 25],
            [2007, 8981, 29, 23],
            [2007, 8983, 34, 28],
            [2007, 8984, 26, 20],
            [2007, 8985, 33, 26],
            [2007, 8986, 25, 20],
            [2007, 8987, 27, 25],
            [2007, 8988, 18, 26],
            [2007, 8989, 34, 28],
            [2007, 8990, 23, 20],
            [2007, 8991, 32, 26],
            [2007, 8992, 18, 18],
            [2007, 8993, 33, 28],
            [2007, 8994, 36, 29],
            [2007, 8995, 35, 26],
            [2007, 8996, 39, 28],
            [2007, 8997, 22, 21],
            [2007, 8998, 27, 20],
            [2007, 8999, 19, 11],
            [2007, 9000, 40, 32],
            [2007, 9001, 36, 28],
            [2007, 9002, 36, 28],
            [2007, 9003, 23, 21],
            [2007, 9004, 39, 28],
            [2007, 9005, 20, 17],
            [2007, 9006, 34, 27],
            [2007, 9007, 26, 19],
            [2007, 9008, 35, 24],
            [2007, 9009, 31, 24],
            [2007, 9010, 25, 20],
            [2007, 9011, 19, 11],
            [2007, 9012, 27, 25],
            [2007, 9013, 20, 21],
            [2007, 9014, 36, 28],
            [2007, 9015, 19, 14],
            [2007, 9016, 19, 14],
            [2007, 9017, 38, 30],
            [2007, 9018, 26, 26],
            [2007, 9019, 30, 26],
            [2007, 9020, 18, 18],
            [2007, 9021, 34, 28],
            [2007, 9022, 25, 21],
            [2007, 9023, 31, 25],
            [2007, 9024, 36, 28],
            [2007, 9025, 30, 25],
            [2007, 9026, 29, 18],
            [2007, 9027, 27, 17],
            [2007, 9028, 36, 28],
            [2007, 9030, 36, 28],
            [2007, 9031, 32, 26],
            [2007, 9032, 41, 27],
            [2007, 9033, 30, 26],
            [2007, 9034, 40, 28],
            [2007, 9035, 36, 29],
            [2007, 9036, 35, 28],
            [2007, 9037, 16, 14],
            [2007, 9038, 27, 23],
            [2007, 9039, 15, 17],
            [2007, 9040, 34, 28],
            [2007, 9041, 23, 19],
            [2007, 9042, 36, 28],
            [2007, 9043, 33, 28],
            [2007, 9044, 21, 14],
            [2007, 9045, 33, 25],
            [2007, 9046, 25, 19],
            [2007, 9047, 33, 27],
            [2007, 9048, 28, 21],
            [2007, 9049, 41, 31],
            [2007, 9050, 26, 20],
            [2007, 9051, 38, 27],
            [2007, 9052, 39, 26],
            [2007, 9053, 31, 30],
            [2007, 9054, 35, 27],
            [2007, 9055, 39, 21],
            [2007, 9056, 40, 25],
            [2007, 9057, 38, 29],
            [2007, 9058, 25, 17],
            [2007, 9059, 40, 30],
            [2007, 9060, 38, 28],
            [2007, 9061, 43, 34],
            [2007, 9062, 21, 21],
            [2007, 9063, 33, 24],
            [2007, 9064, 16, 18],
            [2007, 9065, 22, 21],
            [2007, 9066, 16, 17],
            [2007, 9067, 28, 21],
            [2007, 9068, 26, 18],
            [2007, 9069, 33, 30],
            [2007, 9070, 17, 17],
            [2007, 9071, 25, 27],
            [2007, 9072, 13, 16],
            [2007, 9073, 14, 16],
            [2007, 9074, 29, 27],
            [2007, 9075, 20, 20],
            [2007, 9076, 23, 25],
            [2007, 9077, 34, 22],
            [2007, 9078, 26, 16],
            [2007, 9079, 32, 27],
            [2007, 9080, 21, 18],
            [2007, 9081, 27, 21],
            [2007, 9082, 39, 30],
            [2007, 9083, 30, 24],
            [2007, 9084, 37, 27],
            [2007, 9085, 19, 19],
            [2007, 9086, 35, 28],
            [2007, 9087, 38, 27],
            [2007, 9088, 26, 17],
            [2007, 9089, 16, 14],
            [2007, 9090, 21, 18],
            [2007, 9091, 21, 15],
            [2007, 9092, 38, 25],
            [2007, 9093, 20, 19],
            [2007, 9094, 39, 32],
            [2007, 9095, 14, 12],
            [2007, 9096, 26, 29],
            [2007, 9097, 27, 21],
            [2007, 9098, 35, 23],
            [2007, 9099, 19, 13],
            [2007, 9100, 33, 22],
            [2007, 9101, 15, 17],
            [2007, 9102, 35, 28],
            [2007, 9103, 23, 21],
            [2007, 9104, 35, 28],
            [2007, 9105, 21, 14],
            [2007, 9106, 28, 15],
            [2007, 9107, 33, 25],
            [2007, 9108, 34, 25],
            [2007, 9109, 31, 26],
            [2007, 9110, 33, 28],
            [2007, 9111, 25, 13],
            [2007, 9112, 39, 31],
            [2007, 9113, 32, 27],
            [2007, 9114, 38, 25],
            [2007, 9115, 14, 14],
            [2007, 9116, 22, 15],
            [2007, 9117, 27, 12],
            [2007, 9118, 30, 26],
            [2007, 9119, 17, 12],
            [2007, 9120, 23, 19],
            [2007, 9121, 30, 25],
            [2007, 9122, 37, 27],
            [2007, 9123, 26, 18],
            [2007, 9124, 38, 30],
            [2007, 9125, 16, 23],
            [2007, 9126, 36, 30],
            [2007, 9127, 28, 25],
            [2007, 9128, 34, 26],
            [2007, 9129, 32, 27],
            [2007, 9130, 40, 29],
            [2007, 9131, 25, 25],
            [2007, 9132, 29, 28],
            [2007, 9133, 26, 18],
            [2007, 9134, 28, 26],
            [2007, 9135, 41, 28],
            [2007, 9136, 30, 28],
            [2007, 9137, 16, 11],
            [2007, 9138, 17, 15],
            [2007, 9139, 27, 24],
            [2007, 9140, 29, 28],
            [2007, 9141, 25, 23],
            [2007, 9142, 35, 31],
            [2007, 9143, 19, 19],
            [2007, 9144, 23, 26],
            [2007, 9145, 31, 26],
            [2007, 9146, 39, 30],
            [2007, 9149, 19, 16],
            [2007, 9150, 18, 19],
            [2007, 9151, 18, 18],
            [2007, 9152, 20, 20],
            [2007, 9153, 12, 12],
            [2007, 9154, 14, 14],
            [2007, 9155, 19, 19],
            [2007, 9156, 21, 20],
            [2007, 9157, 20, 21],
            [2007, 9158, 12, 12],
            [2007, 9159, 18, 21],
            [2007, 9160, 16, 14],
            [2007, 9161, 16, 17],
            [2007, 9162, 20, 21],
            [2007, 9163, 19, 20],
            [2007, 9164, 18, 17],
            [2007, 9165, 17, 19],
            [2007, 9166, 15, 16],
            [2007, 9167, 14, 14],
            [2007, 9168, 21, 19],
            [2007, 9169, 20, 20],
            [2007, 9170, 21, 24],
            [2007, 9171, 19, 18],
            [2007, 9172, 18, 17],
            [2007, 9173, 18, 18],
            [2007, 9174, 16, 17],
            [2007, 9175, 17, 16],
            [2007, 9176, 11, 14],
            [2007, 9177, 17, 16],
            [2007, 9178, 16, 18],
            [2007, 9179, 19, 21],
            [2007, 9180, 15, 15],
            [2007, 9181, 19, 18],
            [2007, 9182, 19, 18],
            [2007, 9183, 18, 19],
            [2007, 9184, 21, 20],
            [2007, 9185, 19, 18],
            [2007, 9186, 12, 13],
            [2007, 9187, 19, 18],
            [2007, 9188, 20, 19],
            [2007, 9189, 20, 20],
            [2007, 9190, 13, 13],
            [2007, 9191, 19, 18],
            [2007, 9192, 16, 17],
            [2007, 9193, 20, 20],
            [2007, 9194, 26, 27],
            [2007, 9195, 27, 28],
            [2007, 9196, 29, 22],
            [2007, 9198, 24, 21],
            [2007, 9199, 24, 21],
            [2007, 9200, 24, 21],
            [2007, 9201, 31, 26],
            [2007, 9202, 31, 27],
            [2007, 9203, 10, 11],
            [2007, 9204, 9, 10],
            [2007, 9209, 23, 21],
            [2007, 9211, 31, 30],
            [2007, 9214, 36, 30],
            [2007, 9218, 21, 19],
            [2007, 9226, 36, 25],
            [2007, 9227, 39, 31],
            [2007, 9228, 33, 33],
            [2007, 9229, 32, 31],
            [2007, 9230, 31, 26],
            [2007, 9232, 32, 27],
            [2007, 9233, 28, 28],
            [2007, 9234, 28, 28],
            [2007, 9235, 28, 28],
            [2007, 9237, 26, 18],
            [2007, 9238, 31, 28],
            [2007, 9242, 32, 28],
            [2007, 9244, 36, 30],
            [2007, 9245, 23, 22],
            [2007, 9248, 31, 26],
            [2007, 9254, 70, 66],
            [2007, 9255, 42, 31],
            [2007, 9257, 46, 40],
            [2007, 9258, 31, 69],
            [2007, 9259, 38, 39],
            [2007, 9260, 36, 32],
            [2007, 9261, 48, 56],
            [2007, 9263, 36, 36],
            [2007, 9264, 31, 32],
            [2007, 9265, 32, 34],
            [2007, 9266, 55, 55],
            [2007, 9267, 52, 48],
            [2007, 9268, 51, 48],
            [2007, 9269, 68, 62],
            [2007, 9270, 63, 63],
            [2007, 9271, 64, 62],
            [2007, 9272, 60, 64],
            [2007, 9273, 69, 69],
            [2007, 9274, 70, 60],
            [2007, 9275, 40, 40],
            [2007, 9276, 70, 60],
            [2007, 9277, 61, 48],
            [2007, 9278, 66, 62],
            [2007, 9279, 69, 63],
            [2007, 9280, 41, 41],
            [2007, 9281, 69, 55],
            [2007, 9282, 69, 60],
            [2007, 9283, 56, 53],
            [2007, 9284, 85, 79],
            [2007, 9285, 50, 50],
            [2007, 9286, 79, 78],
            [2007, 9287, 82, 76],
            [2007, 9288, 51, 36],
            [2007, 9289, 72, 71],
            [2007, 9290, 59, 66],
            [2007, 9291, 80, 75],
            [2007, 9292, 67, 64],
            [2007, 9293, 59, 42],
            [2007, 9294, 44, 85],
            [2007, 9295, 56, 70],
            [2007, 9296, 62, 79],
            [2007, 9297, 100, 94],
            [2007, 9298, 53, 55],
            [2007, 9299, 81, 86],
            [2007, 9300, 76, 72],
            [2007, 9301, 55, 55],
            [2007, 9302, 95, 90],
            [2007, 9303, 71, 74],
            [2007, 9304, 75, 130],
            [2007, 9305, 73, 77],
            [2007, 9306, 96, 90],
            [2007, 9307, 40, 48],
            [2007, 9308, 51, 62],
            [2007, 9309, 46, 103],
            [2007, 9310, 57, 100],
            [2007, 9311, 46, 48],
            [2007, 9312, 57, 59],
            [2007, 9313, 53, 58],
            [2007, 9314, 71, 73],
            [2007, 9315, 31, 31],
            [2007, 9316, 37, 25],
            [2007, 9317, 12, 14],
            [2007, 9318, 13, 15],
            [2007, 9319, 28, 32],
            [2007, 9320, 34, 33],
            [2007, 9327, 12, 14],
            [2007, 9328, 18, 19],
            [2007, 9329, 27, 27],
            [2007, 9330, 32, 32],
            [2007, 9331, 22, 21],
            [2007, 9332, 22, 25],
            [2007, 9333, 11, 14],
            [2007, 9334, 10, 12],
            [2007, 9335, 22, 21],
            [2007, 9336, 20, 19],
            [2007, 9337, 13, 16],
            [2007, 9338, 10, 11],
            [2007, 9339, 15, 17],
            [2007, 9340, 35, 30],
            [2007, 9341, 17, 19],
            [2007, 9342, 24, 24],
            [2007, 9343, 8, 9],
            [2007, 9344, 15, 15],
            [2007, 9345, 16, 20],
            [2007, 9346, 12, 13],
            [2007, 9347, 10, 11],
            [2007, 9348, 20, 19],
            [2007, 9349, 16, 19],
            [2007, 9350, 32, 32],
            [2007, 9351, 27, 22],
            [2007, 9352, 31, 28],
            [2007, 9353, 15, 17],
            [2007, 9354, 22, 21],
            [2007, 9355, 17, 15],
            [2007, 9356, 25, 23],
            [2007, 9357, 15, 17],
            [2007, 9358, 19, 19],
            [2007, 9359, 16, 18],
            [2007, 9360, 22, 26],
            [2007, 9361, 20, 18],
            [2007, 9362, 27, 26],
            [2007, 9363, 20, 19],
            [2007, 9364, 30, 22],
            [2007, 9365, 16, 18],
            [2007, 9366, 39, 34],
            [2007, 9367, 19, 20],
            [2007, 9368, 42, 36],
            [2007, 9369, 24, 24],
            [2007, 9370, 15, 16],
            [2007, 9371, 22, 22],
            [2007, 9372, 39, 30],
            [2007, 9373, 18, 18],
            [2007, 9374, 29, 28],
            [2007, 9375, 17, 19],
            [2007, 9376, 39, 33],
            [2007, 9377, 11, 12],
            [2007, 9378, 16, 18],
            [2007, 9379, 23, 28],
            [2007, 9380, 20, 23],
            [2007, 9381, 41, 34],
            [2007, 9382, 21, 26],
            [2007, 9383, 39, 30],
            [2007, 9384, 15, 15],
            [2007, 9385, 15, 16],
            [2007, 9386, 14, 14],
            [2007, 9387, 13, 13],
            [2007, 9388, 12, 14],
            [2007, 9389, 15, 14],
            [2007, 9390, 16, 18],
            [2007, 9391, 20, 20],
            [2007, 9392, 17, 17],
            [2007, 9393, 20, 18],
            [2007, 9394, 12, 11],
            [2007, 9395, 17, 18],
            [2007, 9396, 17, 20],
            [2007, 9397, 34, 30],
            [2007, 9398, 29, 35],
            [2007, 9399, 37, 32],
            [2007, 9400, 20, 20],
            [2007, 9401, 64, 64],
            [2007, 9402, 34, 25],
            [2007, 9403, 55, 66],
            [2007, 9406, 110, 69],
            [2007, 9411, 65, 65],
            [2007, 9416, 46, 46],
            [2007, 9417, 65, 67],
            [2007, 9420, 65, 55],
            [2007, 9423, 55, 55],
            [2007, 9428, 65, 66],
            [2007, 9431, 65, 66],
            [2007, 9436, 65, 67],
            [2007, 9443, 65, 66],
            [2007, 9444, 75, 55],
            [2007, 9451, 110, 67],
            [2007, 9452, 65, 85],
            [2007, 9453, 65, 63],
            [2007, 9456, 65, 67],
            [2007, 9457, 50, 82],
            [2007, 9458, 65, 66],
            [2007, 9465, 40, 32],
            [2007, 9470, 65, 66],
            [2007, 9473, 35, 36],
            [2007, 9474, 98, 70],
            [2007, 9477, 35, 34],
            [2007, 9478, 103, 62],
            [2007, 9487, 23, 27],
            [2007, 9488, 44, 34],
            [2007, 9491, 31, 27],
            [2007, 9492, 50, 47],
            [2007, 9497, 37, 25],
            [2007, 9498, 72, 43],
            [2007, 9509, 65, 55],
            [2007, 9519, 21, 15],
            [2007, 9520, 103, 80],
            [2007, 9525, 21, 17],
            [2007, 9526, 43, 32],
            [2007, 9529, 31, 22],
            [2007, 9530, 80, 35],
            [2007, 9531, 28, 28],
            [2007, 9532, 78, 60],
            [2007, 9539, 39, 26],
            [2007, 9540, 83, 60],
            [2007, 9541, 25, 28],
            [2007, 9542, 59, 33],
            [2007, 9543, 28, 26],
            [2007, 9544, 63, 40],
            [2007, 9547, 21, 22],
            [2007, 9548, 61, 32],
            [2007, 9549, 18, 17],
            [2007, 9550, 70, 30],
            [2007, 9551, 31, 30],
            [2007, 9552, 87, 65],
            [2007, 9553, 31, 28],
            [2007, 9554, 42, 36],
            [2007, 9555, 40, 78],
            [2007, 9556, 104, 90],
            [2007, 9557, 33, 29],
            [2007, 9558, 110, 67],
            [2007, 9561, 27, 17],
            [2007, 9562, 82, 60],
            [2007, 9581, 31, 34],
            [2007, 9582, 62, 47],
            [2007, 9593, 31, 30],
            [2007, 9594, 57, 68],
            [2007, 9595, 31, 18],
            [2007, 9596, 69, 55],
            [2007, 9597, 21, 15],
            [2007, 9598, 76, 39],
            [2007, 9609, 31, 30],
            [2007, 9610, 89, 37],
            [2007, 9611, 38, 34],
            [2007, 9612, 74, 46],
            [2007, 9613, 41, 85],
            [2007, 9614, 120, 90],
            [2007, 9617, 13, 14],
            [2007, 9618, 88, 46],
            [2007, 9619, 21, 17],
            [2007, 9620, 18, 16],
            [2007, 9633, 38, 31],
            [2007, 9634, 64, 60],
            [2007, 9639, 17, 18],
            [2007, 9640, 99, 53],
            [2007, 9641, 39, 27],
            [2007, 9642, 120, 65],
            [2007, 9643, 21, 21],
            [2007, 9644, 96, 51],
            [2007, 9651, 75, 55],
            [2007, 9652, 70, 55],
            [2007, 9653, 37, 35],
            [2007, 9654, 45, 31],
            [2007, 9661, 70, 45],
            [2007, 9662, 65, 51],
            [2007, 9663, 64, 51],
            [2007, 9664, 53, 42],
            [2007, 9665, 35, 41],
            [2007, 9666, 55, 38],
            [2007, 9667, 18, 18],
            [2007, 9668, 30, 26],
            [2007, 9670, 65, 47],
            [2007, 9673, 41, 31],
            [2007, 9674, 43, 33],
            [2007, 9675, 20, 24],
            [2007, 9676, 31, 31],
            [2007, 9677, 16, 21],
            [2007, 9678, 21, 25],
            [2007, 9681, 60, 45],
            [2007, 9682, 71, 45],
            [2007, 9687, 31, 35],
            [2007, 9689, 25, 21],
            [2007, 9690, 46, 30],
            [2007, 9691, 25, 24],
            [2007, 9692, 42, 30],
            [2007, 9693, 22, 25],
            [2007, 9694, 30, 31],
            [2007, 9695, 46, 45],
            [2007, 9696, 64, 35],
            [2007, 9699, 20, 23],
            [2007, 9700, 55, 35],
            [2007, 9701, 21, 20],
            [2007, 9702, 55, 37],
            [2007, 9704, 50, 32],
            [2007, 9705, 31, 37],
            [2007, 9706, 65, 47],
            [2007, 9709, 26, 21],
            [2007, 9710, 25, 21],
            [2007, 9711, 17, 22],
            [2007, 9712, 18, 25],
            [2007, 9713, 31, 35],
            [2007, 9714, 37, 45],
            [2007, 9715, 60, 49],
            [2007, 9716, 46, 45],
            [2007, 9717, 38, 37],
            [2007, 9718, 20, 24],
            [2007, 9720, 85, 75],
            [2007, 9721, 75, 41],
            [2007, 9722, 25, 39],
            [2007, 9723, 70, 45],
            [2007, 9724, 55, 50],
            [2007, 9725, 75, 47],
            [2007, 9726, 26, 26],
            [2007, 9727, 41, 41],
            [2007, 9728, 31, 25],
            [2007, 9729, 31, 30],
            [2007, 9730, 29, 43],
            [2007, 9731, 71, 61],
            [2007, 9735, 34, 36],
            [2007, 9736, 34, 35],
            [2007, 9737, 31, 21],
            [2007, 9738, 43, 43],
            [2007, 9739, 25, 34],
            [2007, 9740, 98, 90],
            [2007, 9741, 77, 78],
            [2007, 9742, 40, 52],
            [2007, 9743, 43, 35],
            [2007, 9744, 65, 47],
            [2007, 9745, 35, 28],
            [2007, 9746, 41, 28],
            [2007, 9747, 35, 39],
            [2007, 9748, 40, 45],
            [2007, 9751, 31, 27],
            [2007, 9752, 36, 35],
            [2007, 9755, 26, 33],
            [2007, 9756, 33, 38],
            [2007, 9757, 27, 21],
            [2007, 9758, 25, 21],
            [2007, 9759, 14, 14],
            [2007, 9760, 35, 26],
            [2007, 9761, 40, 31],
            [2007, 9762, 33, 24],
            [2007, 9763, 25, 18],
            [2007, 9764, 28, 20],
            [2007, 9765, 33, 25],
            [2007, 9766, 25, 20],
            [2007, 9767, 46, 27],
            [2007, 9768, 26, 21],
            [2007, 9769, 18, 18],
            [2007, 9770, 39, 29],
            [2007, 9771, 44, 33],
            [2007, 9772, 35, 28],
            [2007, 9773, 35, 26],
            [2007, 9774, 28, 18],
            [2007, 9775, 24, 19],
            [2007, 9776, 38, 25],
            [2007, 9777, 35, 26],
            [2007, 9778, 37, 29],
            [2007, 9779, 33, 29],
            [2007, 9780, 34, 26],
            [2007, 9781, 38, 26],
            [2007, 9782, 54, 33],
            [2007, 9783, 54, 38],
            [2007, 9784, 24, 19],
            [2007, 9785, 25, 19],
            [2007, 9786, 16, 13],
            [2007, 9787, 29, 24],
            [2007, 9788, 40, 28],
            [2007, 9789, 30, 24],
            [2007, 9790, 29, 23],
            [2007, 9791, 60, 33],
            [2007, 9792, 45, 35],
            [2007, 9793, 14, 12],
            [2007, 9794, 13, 11],
            [2007, 9795, 12, 12],
            [2007, 9796, 17, 15],
            [2007, 9797, 14, 11],
            [2007, 9798, 13, 13],
            [2007, 9799, 43, 38],
            [2007, 9800, 19, 18],
            [2007, 9801, 18, 14],
            [2007, 9802, 16, 14],
            [2007, 9803, 9, 9],
            [2007, 9804, 15, 12],
            [2007, 9805, 28, 22],
            [2007, 9806, 20, 16],
            [2007, 9807, 23, 15],
            [2007, 9808, 75, 50],
            [2007, 9809, 40, 22],
            [2007, 9811, 37, 23],
            [2007, 9812, 44, 28],
            [2007, 9813, 60, 35],
            [2007, 9814, 19, 13],
            [2007, 9815, 35, 22],
            [2007, 9816, 46, 23],
            [2007, 9817, 25, 14],
            [2007, 9818, 50, 23],
            [2007, 9819, 60, 46],
            [2007, 9820, 70, 47],
            [2007, 9821, 37, 31],
            [2007, 9822, 21, 18],
            [2007, 9823, 27, 20],
            [2007, 9824, 32, 33],
            [2007, 9825, 17, 14],
            [2007, 9826, 39, 28],
            [2007, 9827, 38, 27],
            [2007, 9828, 37, 27],
            [2007, 9829, 32, 23],
            [2007, 9830, 30, 23],
            [2007, 9831, 33, 22],
            [2007, 9832, 39, 24],
            [2007, 9833, 27, 22],
            [2007, 9834, 62, 41],
            [2007, 9835, 28, 26],
            [2007, 9836, 51, 44],
            [2007, 9837, 27, 23],
            [2007, 9838, 49, 37],
            [2007, 9839, 15, 15],
            [2007, 9840, 67, 41],
            [2007, 9841, 58, 37],
            [2007, 9842, 27, 19],
            [2007, 9843, 26, 23],
            [2007, 9844, 30, 25],
            [2007, 9845, 29, 24],
            [2007, 9846, 24, 17],
            [2007, 9847, 13, 11],
            [2007, 9848, 25, 17],
            [2007, 9849, 27, 22],
            [2007, 9850, 22, 15],
            [2007, 9851, 22, 16],
            [2007, 9852, 19, 16],
            [2007, 9853, 23, 17],
            [2007, 9854, 13, 11],
            [2007, 9855, 33, 27],
            [2007, 9856, 16, 17],
            [2007, 9857, 14, 11],
            [2007, 9858, 33, 31],
            [2007, 9859, 49, 33],
            [2007, 9860, 60, 34],
            [2007, 9861, 45, 41],
            [2007, 9862, 26, 24],
            [2007, 9863, 34, 24],
            [2007, 9864, 49, 27],
            [2007, 9865, 34, 24],
            [2007, 9866, 48, 32],
            [2007, 9867, 18, 16],
            [2007, 9868, 37, 25],
            [2007, 9869, 37, 29],
            [2007, 9870, 36, 35],
            [2007, 9871, 36, 25],
            [2007, 9872, 26, 22],
            [2007, 9873, 41, 34],
            [2007, 9874, 36, 30],
            [2007, 9875, 24, 21],
            [2007, 9876, 24, 20],
            [2007, 9877, 33, 35],
            [2007, 9878, 32, 25],
            [2007, 9879, 33, 29],
            [2007, 9880, 34, 36],
            [2007, 9881, 53, 40],
            [2007, 9882, 44, 37],
            [2007, 9883, 29, 20],
            [2007, 9884, 29, 30],
            [2007, 9885, 34, 23],
            [2007, 9886, 33, 22],
            [2007, 9887, 32, 23],
            [2007, 9888, 40, 30],
            [2007, 9889, 38, 27],
            [2007, 9890, 34, 27],
            [2007, 9891, 27, 20],
            [2007, 9892, 29, 23],
            [2007, 9893, 31, 17],
            [2007, 9894, 38, 26],
            [2007, 9895, 25, 16],
            [2007, 9896, 10, 11],
            [2007, 9897, 32, 26],
            [2007, 9898, 30, 24],
            [2007, 9899, 23, 18],
            [2007, 9900, 45, 42],
            [2007, 9901, 39, 32],
            [2007, 9902, 62, 49],
            [2007, 9903, 50, 40],
            [2007, 9904, 45, 34],
            [2007, 9905, 46, 40],
            [2007, 9906, 34, 22],
            [2007, 9907, 26, 24],
            [2007, 9908, 48, 33],
            [2007, 9909, 16, 14],
            [2007, 9910, 42, 37],
            [2007, 9911, 52, 38],
            [2007, 9912, 40, 36],
            [2007, 9913, 20, 19],
            [2007, 9914, 28, 22],
            [2007, 9915, 26, 23],
            [2007, 9916, 34, 25],
            [2007, 9917, 29, 30],
            [2007, 9918, 60, 36],
            [2007, 9919, 40, 36],
            [2007, 9920, 67, 56],
            [2007, 9921, 24, 22],
            [2007, 9922, 21, 14],
            [2007, 9923, 29, 17],
            [2007, 9924, 36, 24],
            [2007, 9925, 42, 48],
            [2007, 9926, 47, 39],
            [2007, 9927, 28, 28],
            [2007, 9928, 45, 29],
            [2007, 9929, 42, 33],
            [2007, 9930, 33, 24],
            [2007, 9931, 51, 33],
            [2007, 9932, 72, 58],
            [2007, 9933, 43, 44],
            [2007, 9934, 39, 30],
            [2007, 9935, 33, 31],
            [2007, 9936, 31, 29],
            [2007, 9937, 26, 36],
            [2007, 9938, 15, 13],
            [2007, 9939, 41, 40],
            [2007, 9940, 33, 33],
            [2007, 9941, 33, 21],
            [2007, 9942, 19, 17],
            [2007, 9943, 45, 36],
            [2007, 9944, 36, 33],
            [2007, 9945, 50, 30],
            [2007, 9946, 37, 24],
            [2007, 9947, 40, 25],
            [2007, 9948, 85, 58],
            [2007, 9949, 59, 39],
            [2007, 9950, 44, 31],
            [2007, 9951, 29, 28],
            [2007, 9952, 41, 24],
            [2007, 9953, 20, 18],
            [2007, 9954, 85, 59],
            [2007, 9955, 21, 18],
            [2007, 9956, 38, 28],
            [2007, 9957, 64, 36],
            [2007, 9958, 30, 21],
            [2007, 9959, 75, 40],
            [2007, 9960, 40, 22],
            [2007, 9961, 35, 29],
            [2007, 9962, 28, 27],
            [2007, 9963, 64, 33],
            [2007, 9964, 37, 27],
            [2007, 9965, 33, 17],
            [2007, 9966, 52, 29],
            [2007, 9967, 67, 29],
            [2007, 9968, 33, 28],
            [2007, 9969, 22, 17],
            [2007, 9970, 48, 27],
            [2007, 9971, 32, 22],
            [2007, 9972, 75, 36],
            [2007, 9973, 41, 29],
            [2007, 9974, 32, 19],
            [2007, 9975, 70, 32],
            [2007, 9976, 60, 35],
            [2007, 9977, 30, 18],
            [2007, 9978, 48, 22],
            [2007, 9979, 65, 33],
            [2007, 9980, 43, 22],
            [2007, 9981, 24, 15],
            [2007, 9982, 15, 12],
            [2007, 9983, 50, 26],
            [2007, 9984, 32, 22],
            [2007, 9985, 32, 20],
            [2007, 9986, 34, 22],
            [2007, 9987, 39, 32],
            [2007, 9988, 60, 40],
            [2007, 9989, 31, 25],
            [2007, 9990, 28, 23],
            [2007, 9991, 35, 28],
            [2007, 9992, 35, 35],
            [2007, 9993, 29, 28],
            [2007, 9994, 23, 20],
            [2007, 9995, 35, 29],
            [2007, 9996, 30, 26],
            [2007, 9997, 15, 23],
            [2007, 9998, 16, 14],
            [2007, 9999, 24, 26],
            [2007, 10000, 22, 17],
            [2007, 10001, 16, 14],
            [2007, 10002, 15, 12],
            [2007, 10003, 42, 25],
            [2007, 10004, 31, 21],
            [2007, 10005, 21, 17],
            [2007, 10006, 27, 19],
            [2007, 10007, 45, 38],
            [2007, 10008, 43, 39],
            [2007, 10009, 43, 27],
            [2007, 10017, 35, 26],
            [2007, 10018, 50, 30],
            [2007, 10032, 70, 42],
            [2007, 10037, 69, 35],
            [2007, 10038, 38, 24],
            [2007, 10046, 48, 33],
            [2007, 10047, 40, 25],
            [2007, 10049, 33, 30],
            [2007, 10056, 45, 50],
            [2007, 10057, 58, 49],
            [2007, 10058, 25, 29],
            [2007, 10059, 48, 29],
            [2007, 10065, 33, 48],
            [2007, 10066, 50, 65],
            [2007, 10071, 43, 33],
            [2007, 10076, 43, 27],
            [2007, 10091, 44, 30],
            [2007, 10094, 50, 42],
            [2007, 10098, 52, 37],
            [2007, 10101, 67, 50],
            [2007, 10102, 58, 38],
            [2007, 10103, 60, 48],
            [2007, 10109, 147, 57],
            [2007, 10110, 48, 45],
            [2007, 10111, 90, 48],
            [2007, 10112, 85, 44],
            [2007, 10113, 95, 61],
            [2007, 10114, 70, 38],
            [2007, 10117, 63, 45],
            [2007, 10122, 77, 57],
            [2007, 10125, 65, 44],
            [2007, 10127, 40, 28],
            [2007, 10128, 48, 38],
            [2007, 10131, 50, 38],
            [2007, 10132, 48, 30],
            [2007, 10133, 68, 38],
            [2007, 10139, 53, 41],
            [2007, 10144, 48, 27],
            [2007, 10180, 38, 24],
            [2007, 10183, 34, 23],
            [2007, 10184, 43, 27],
            [2007, 10185, 24, 19],
            [2007, 10186, 24, 20],
            [2007, 10187, 16, 14],
            [2007, 10188, 44, 25],
            [2007, 10189, 41, 27],
            [2007, 10190, 17, 13],
            [2007, 10191, 37, 23],
            [2007, 10192, 27, 19],
            [2007, 10193, 17, 16],
            [2007, 10194, 13, 10],
            [2007, 10195, 13, 11],
            [2007, 10514, 15, 19],
            [2007, 10515, 15, 20],
            [2007, 10516, 14, 18],
            [2007, 10518, 13, 13],
            [2007, 10519, 16, 14],
            [2007, 10520, 9, 9],
            [2007, 10521, 14, 17],
            [2007, 10522, 15, 17],
            [2007, 10523, 14, 17],
            [2007, 10524, 21, 19],
            [2007, 10525, 14, 17],
            [2007, 10526, 14, 17],
            [2007, 10527, 11, 13],
            [2007, 10528, 16, 17],
            [2007, 10529, 16, 17],
            [2007, 10530, 14, 17],
            [2007, 10531, 13, 16],
            [2007, 10532, 22, 21],
            [2007, 10533, 31, 26],
            [2007, 10534, 20, 13],
            [2007, 10535, 31, 25],
            [2007, 10536, 16, 19],
            [2007, 10537, 22, 20],
            [2007, 10538, 28, 24],
            [2007, 10539, 17, 17],
            [2007, 10540, 31, 25],
            [2007, 10541, 32, 27],
            [2007, 10542, 33, 26],
            [2007, 10543, 7, 7],
            [2007, 10544, 11, 9],
            [2007, 10545, 7, 7],
            [2007, 10546, 10, 8],
            [2007, 10547, 8, 8],
            [2007, 10548, 12, 9],
            [2007, 10549, 8, 8],
            [2007, 10550, 9, 11],
            [2007, 10551, 9, 8],
            [2007, 10552, 7, 7],
            [2007, 10553, 24, 16],
            [2007, 10554, 19, 13],
            [2007, 10555, 11, 8],
            [2007, 10556, 19, 13],
            [2007, 10557, 10, 10],
            [2007, 10558, 28, 20],
            [2007, 10559, 12, 9],
            [2007, 10560, 19, 13],
            [2007, 10577, 19, 13],
            [2007, 10578, 33, 31],
            [2007, 10579, 32, 33],
            [2007, 10580, 60, 41],
            [2007, 10605, 13, 10],
            [2007, 10606, 12, 10],
            [2007, 10607, 13, 11],
            [2007, 10608, 14, 10],
            [2007, 10609, 12, 10],
            [2007, 10610, 19, 11],
            [2007, 10611, 19, 14],
            [2007, 10612, 16, 14],
            [2007, 10613, 38, 26],
            [2007, 10614, 36, 22],
            [2007, 10615, 41, 28],
            [2007, 10616, 28, 20],
            [2007, 10617, 41, 28],
            [2007, 10618, 39, 25],
            [2007, 10619, 24, 20],
            [2007, 10620, 28, 19],
            [2007, 10621, 27, 22],
            [2007, 10622, 28, 18],
            [2007, 10623, 38, 25],
            [2007, 10624, 35, 24],
            [2007, 10625, 27, 20],
            [2007, 10626, 32, 22],
            [2007, 10627, 37, 28],
            [2007, 10628, 39, 26],
            [2007, 10629, 42, 26],
            [2007, 10630, 31, 22],
            [2007, 10631, 31, 22],
            [2007, 10632, 33, 21],
            [2007, 10633, 42, 28],
            [2007, 10634, 41, 26],
            [2007, 10635, 41, 27],
            [2007, 10636, 34, 23],
            [2007, 10637, 38, 27],
            [2007, 10638, 20, 14],
            [2007, 10639, 43, 27],
            [2007, 10640, 42, 25],
            [2007, 10641, 35, 26],
            [2007, 10642, 44, 26],
            [2007, 10643, 38, 25],
            [2007, 10644, 41, 27],
            [2007, 10645, 28, 27],
            [2007, 10646, 38, 26],
            [2007, 10647, 42, 28],
            [2007, 10648, 40, 30],
            [2007, 10649, 39, 25],
            [2007, 10650, 38, 27],
            [2007, 10651, 35, 29],
            [2007, 10652, 29, 21],
            [2007, 10653, 39, 26],
            [2007, 10654, 33, 28],
            [2007, 10655, 42, 30],
            [2007, 10656, 40, 28],
            [2007, 10657, 37, 25],
            [2007, 10658, 43, 25],
            [2007, 10659, 17, 15],
            [2007, 10660, 43, 27],
            [2007, 10661, 43, 26],
            [2007, 10662, 42, 26],
            [2007, 10663, 27, 22],
            [2007, 10664, 27, 23],
            [2007, 10665, 40, 30],
            [2007, 10666, 44, 27],
            [2007, 10667, 40, 29],
            [2007, 10668, 31, 23],
            [2007, 10669, 20, 15],
            [2007, 10670, 26, 21],
            [2007, 10671, 39, 26],
            [2007, 10672, 43, 24],
            [2007, 10673, 27, 20],
            [2007, 10674, 28, 19],
            [2007, 10675, 35, 28],
            [2007, 10676, 39, 29],
            [2007, 10677, 29, 21],
            [2007, 10678, 34, 22],
            [2007, 10679, 42, 25],
            [2007, 10680, 33, 26],
            [2007, 10681, 41, 30],
            [2007, 10682, 39, 24],
            [2007, 10683, 29, 21],
            [2007, 10684, 26, 19],
            [2007, 10685, 66, 37],
            [2007, 10686, 34, 28],
            [2007, 10687, 39, 27],
            [2007, 10688, 44, 32],
            [2007, 10689, 44, 27],
            [2007, 10690, 45, 28],
            [2007, 10691, 45, 28],
            [2007, 10692, 29, 24],
            [2007, 10693, 48, 27],
            [2007, 10694, 42, 27],
            [2007, 10695, 41, 26],
            [2007, 10696, 43, 25],
            [2007, 10697, 29, 21],
            [2007, 10698, 29, 23],
            [2007, 10699, 34, 31],
            [2007, 10700, 19, 15],
            [2007, 10701, 41, 27],
            [2007, 10702, 45, 26],
            [2007, 10703, 45, 25],
            [2007, 10704, 39, 25],
            [2007, 10705, 33, 21],
            [2007, 10706, 39, 27],
            [2007, 10707, 36, 31],
            [2007, 10708, 44, 28],
            [2007, 10709, 41, 32],
            [2007, 10710, 45, 26],
            [2007, 10711, 41, 26],
            [2007, 10712, 41, 31],
            [2007, 10713, 45, 29],
            [2007, 10714, 38, 25],
            [2007, 10715, 45, 27],
            [2007, 10716, 39, 28],
            [2007, 10717, 42, 28],
            [2007, 10718, 37, 30],
            [2007, 10719, 42, 28],
            [2007, 10720, 45, 28],
            [2007, 10721, 25, 18],
            [2007, 10722, 45, 28],
            [2007, 10723, 42, 27],
            [2007, 10724, 43, 28],
            [2007, 10725, 40, 32],
            [2007, 10726, 32, 24],
            [2007, 10727, 42, 25],
            [2007, 10728, 39, 25],
            [2007, 10729, 38, 28],
            [2007, 10730, 44, 27],
            [2007, 10731, 37, 27],
            [2007, 10732, 45, 28],
            [2007, 10733, 40, 30],
            [2007, 10734, 43, 26],
            [2007, 10735, 40, 26],
            [2007, 10736, 43, 30],
            [2007, 10737, 47, 31],
            [2007, 10738, 43, 26],
            [2007, 10739, 25, 15],
            [2007, 10740, 41, 26],
            [2007, 10741, 38, 30],
            [2007, 10742, 41, 26],
            [2007, 10743, 40, 25],
            [2007, 10744, 39, 24],
            [2007, 10745, 40, 25],
            [2007, 10746, 42, 24],
            [2007, 10747, 24, 16],
            [2007, 10748, 30, 22],
            [2007, 10749, 38, 26],
            [2007, 10750, 42, 26],
            [2007, 10751, 42, 26],
            [2007, 10752, 41, 30],
            [2007, 10753, 40, 27],
            [2007, 10754, 30, 22],
            [2007, 10755, 17, 15],
            [2007, 10756, 66, 45],
            [2007, 10757, 19, 14],
            [2007, 10758, 26, 18],
            [2007, 10759, 42, 26],
            [2007, 10760, 42, 26],
            [2007, 10761, 38, 26],
            [2007, 10762, 42, 31],
            [2007, 10763, 34, 25],
            [2007, 10764, 22, 19],
            [2007, 10765, 33, 23],
            [2007, 10766, 45, 27],
            [2007, 10767, 43, 26],
            [2007, 10768, 37, 28],
            [2007, 10769, 38, 25],
            [2007, 10770, 42, 28],
            [2007, 10771, 43, 27],
            [2007, 10772, 29, 30],
            [2007, 10773, 40, 33],
            [2007, 10774, 38, 23],
            [2007, 10775, 42, 23],
            [2007, 10776, 33, 22],
            [2007, 10777, 22, 18],
            [2007, 10778, 46, 27],
            [2007, 10779, 28, 23],
            [2007, 10780, 42, 25],
            [2007, 10781, 40, 25],
            [2007, 10782, 35, 28],
            [2007, 10783, 36, 31],
            [2007, 10784, 38, 26],
            [2007, 10785, 43, 25],
            [2007, 10786, 38, 26],
            [2007, 10787, 43, 28],
            [2007, 10788, 38, 27],
            [2007, 10789, 41, 25],
            [2007, 10790, 43, 25],
            [2007, 10791, 43, 25],
            [2007, 10792, 35, 26],
            [2007, 10793, 40, 28],
            [2007, 10794, 41, 30],
            [2007, 10795, 39, 26],
            [2007, 10796, 35, 30],
            [2007, 10797, 38, 26],
            [2007, 10798, 38, 28],
            [2007, 10799, 17, 15],
            [2007, 10800, 37, 28],
            [2007, 10801, 45, 27],
            [2007, 10802, 39, 25],
            [2007, 10803, 33, 20],
            [2007, 10804, 43, 26],
            [2007, 10805, 47, 26],
            [2007, 10806, 39, 27],
            [2007, 10807, 42, 23],
            [2007, 10808, 32, 20],
            [2007, 10809, 27, 22],
            [2007, 10810, 42, 26],
            [2007, 10811, 31, 22],
            [2007, 10812, 100, 42],
            [2007, 10814, 34, 23],
            [2007, 10815, 42, 26],
            [2007, 10816, 41, 26],
            [2007, 10817, 42, 30],
            [2007, 10818, 43, 27],
            [2007, 10819, 42, 26],
            [2007, 10820, 39, 25],
            [2007, 10821, 35, 28],
            [2007, 10822, 38, 26],
            [2007, 10823, 39, 25],
            [2007, 10824, 37, 25],
            [2007, 10825, 38, 30],
            [2007, 10826, 35, 22],
            [2007, 10827, 34, 27],
            [2007, 10828, 33, 26],
            [2007, 10829, 39, 26],
            [2007, 10830, 42, 25],
            [2007, 10831, 42, 26],
            [2007, 10832, 42, 26],
            [2007, 10833, 42, 26],
            [2007, 10834, 42, 25],
            [2007, 10835, 42, 28],
            [2007, 10836, 38, 25],
            [2007, 10837, 43, 25],
            [2007, 10838, 38, 25],
            [2007, 10839, 32, 26],
            [2007, 10840, 25, 18],
            [2007, 10841, 60, 30],
            [2007, 10842, 31, 30],
            [2007, 10843, 38, 26],
            [2007, 10844, 33, 23],
            [2007, 10845, 29, 21],
            [2007, 10846, 28, 23],
            [2007, 10847, 40, 28],
            [2007, 10848, 38, 26],
            [2007, 10849, 42, 26],
            [2007, 10850, 36, 27],
            [2007, 10851, 38, 26],
            [2007, 10852, 42, 28],
            [2007, 10853, 44, 28],
            [2007, 10854, 38, 29],
            [2007, 10855, 43, 25],
            [2007, 10856, 39, 26],
            [2007, 10857, 43, 29],
            [2007, 10858, 38, 25],
            [2007, 10859, 43, 25],
            [2007, 10860, 43, 26],
            [2007, 10861, 40, 26],
            [2007, 10862, 43, 25],
            [2007, 10863, 22, 19],
            [2007, 10864, 46, 25],
            [2007, 10865, 38, 26],
            [2007, 10866, 36, 22],
            [2007, 10867, 38, 25],
            [2007, 10868, 42, 25],
            [2007, 10869, 47, 30],
            [2007, 10870, 43, 27],
            [2007, 10871, 41, 25],
            [2007, 10872, 39, 24],
            [2007, 10873, 40, 29],
            [2007, 10874, 42, 30],
            [2007, 10875, 43, 26],
            [2007, 10876, 43, 25],
            [2007, 10877, 34, 27],
            [2007, 10878, 41, 25],
            [2007, 10879, 43, 26],
            [2007, 10880, 42, 26],
            [2007, 10881, 26, 22],
            [2007, 10882, 45, 26],
            [2007, 10883, 47, 27],
            [2007, 10884, 48, 26],
            [2007, 10885, 43, 27],
            [2007, 10886, 36, 22],
            [2007, 10887, 34, 23],
            [2007, 10888, 45, 26],
            [2007, 10889, 41, 28],
            [2007, 10890, 30, 22],
            [2007, 10891, 29, 21],
            [2007, 10892, 27, 18],
            [2007, 10893, 39, 28],
            [2007, 10894, 42, 28],
            [2007, 10895, 64, 35],
            [2007, 10896, 42, 27],
            [2007, 10897, 43, 31],
            [2007, 10898, 42, 27],
            [2007, 10899, 44, 28],
            [2007, 10900, 38, 26],
            [2007, 10901, 37, 26],
            [2007, 10902, 27, 21],
            [2007, 10903, 43, 30],
            [2007, 10904, 39, 26],
            [2007, 10905, 34, 23],
            [2007, 10906, 43, 29],
            [2007, 10907, 39, 27],
            [2007, 10908, 42, 25],
            [2007, 10909, 43, 28],
            [2007, 10910, 36, 27],
            [2007, 10911, 41, 29],
            [2007, 10912, 43, 31],
            [2007, 10913, 34, 25],
            [2007, 10914, 46, 27],
            [2007, 10915, 43, 32],
            [2007, 10916, 44, 30],
            [2007, 10917, 44, 28],
            [2007, 10918, 33, 27],
            [2007, 10978, 38, 26],
            [2007, 10979, 41, 24],
            [2007, 10980, 30, 22],
            [2007, 11091, 8, 5],
            [2007, 11092, 10, 8],
            [2007, 11093, 11, 7],
            [2007, 11094, 12, 10],
            [2007, 11095, 10, 7],
            [2007, 11096, 16, 12],
            [2007, 11097, 10, 8],
            [2007, 11098, 9, 7],
            [2007, 11099, 32, 18],
            [2007, 11100, 11, 10],
            [2007, 11101, 11, 9],
            [2007, 11102, 11, 9],
            [2007, 11103, 12, 10],
            [2007, 11104, 34, 22],
            [2007, 11105, 28, 22],
            [2007, 11106, 23, 15],
            [2007, 11107, 13, 10],
            [2007, 11108, 9, 6],
            [2007, 11109, 16, 12],
            [2007, 11110, 12, 9],
            [2007, 11111, 10, 7],
            [2007, 11112, 21, 14],
            [2007, 11113, 21, 14],
            [2007, 11114, 33, 23],
            [2007, 11115, 7, 6],
            [2007, 11116, 8, 6],
            [2007, 11117, 8, 5],
            [2007, 11118, 12, 9],
            [2007, 11119, 32, 22],
            [2007, 11120, 25, 16],
            [2007, 11121, 9, 6],
            [2007, 11122, 12, 8],
            [2007, 11123, 13, 10],
            [2007, 11124, 9, 8],
            [2007, 11125, 21, 14],
            [2007, 11126, 11, 10],
            [2007, 11127, 7, 7],
            [2007, 11128, 11, 7],
            [2007, 11129, 7, 6],
            [2007, 11130, 15, 10],
            [2007, 11131, 7, 6],
            [2007, 11132, 24, 14],
            [2007, 11133, 11, 8],
            [2007, 11134, 6, 4],
            [2007, 11135, 34, 22],
            [2007, 11136, 10, 8],
            [2007, 11137, 6, 5],
            [2007, 11138, 19, 11],
            [2007, 11139, 10, 6],
            [2007, 11140, 10, 9],
            [2007, 11141, 8, 6],
            [2007, 11142, 9, 7],
            [2007, 11143, 7, 6],
            [2007, 11144, 9, 8],
            [2007, 11145, 28, 19],
            [2007, 11146, 7, 6],
            [2007, 11147, 5, 3],
            [2007, 11148, 27, 21],
            [2007, 11149, 16, 11],
            [2007, 11150, 18, 14],
            [2007, 11151, 21, 13],
            [2007, 11152, 16, 11],
            [2007, 11153, 13, 9],
            [2007, 11154, 25, 17],
            [2007, 11155, 16, 10],
            [2007, 11156, 11, 10],
            [2007, 11157, 14, 10],
            [2007, 11158, 12, 10],
            [2007, 11159, 19, 10],
            [2007, 11160, 26, 15],
            [2007, 11161, 12, 9],
            [2007, 11162, 18, 12],
            [2007, 11163, 12, 12],
            [2007, 11164, 16, 14],
            [2007, 11165, 17, 12],
            [2007, 11166, 31, 22],
            [2007, 11168, 22, 16],
            [2007, 11169, 8, 8],
            [2007, 11170, 10, 9],
            [2007, 11171, 11, 9],
            [2007, 11172, 10, 9],
            [2007, 11173, 12, 9],
            [2007, 11174, 6, 6],
            [2007, 11175, 6, 6],
            [2007, 11176, 6, 6],
            [2007, 11177, 20, 16],
            [2007, 11178, 7, 7],
            [2007, 11179, 12, 12],
            [2007, 11180, 12, 10],
            [2007, 11181, 16, 13],
            [2007, 11182, 14, 10],
            [2007, 11183, 12, 13],
            [2007, 11184, 65, 67],
            [2007, 11185, 65, 67],
            [2007, 11186, 65, 67],
            [2007, 11187, 65, 67],
            [2007, 11188, 65, 67],
            [2007, 11189, 67, 60],
            [2007, 11195, 16, 13],
            [2007, 11197, 87, 43],
            [2007, 11199, 61, 36],
            [2007, 11201, 10, 11],
            [2007, 11202, 39, 24],
            [2007, 11203, 11, 12],
            [2007, 11204, 70, 46],
            [2007, 11205, 106, 74],
            [2007, 11206, 56, 49],
            [2007, 11207, 10, 11],
            [2007, 11209, 150, 160],
            [2007, 11210, 240, 180],
            [2007, 11211, 95, 90],
            [2007, 11212, 240, 180],
            [2007, 11215, 150, 160],
            [2007, 11216, 240, 180],
            [2007, 11217, 150, 160],
            [2007, 11218, 240, 180],
            [2007, 11219, 95, 90],
            [2007, 11220, 240, 180],
            [2007, 11221, 95, 90],
            [2007, 11222, 95, 90],
            [2007, 11223, 95, 90],
            [2007, 11224, 95, 90],
            [2007, 11228, 150, 160],
            [2007, 11229, 150, 160],
            [2007, 11230, 95, 90],
            [2007, 11231, 95, 90],
            [2007, 11232, 95, 90],
            [2007, 11233, 95, 90],
            [2007, 11234, 95, 90],
            [2007, 11235, 95, 90],
            [2007, 11236, 95, 90],
            [2007, 11239, 95, 90],
            [2007, 11240, 95, 90],
            [2007, 11241, 95, 90],
            [2007, 11242, 95, 90],
            [2007, 11245, 95, 90],
            [2007, 11246, 150, 160],
            [2007, 11247, 150, 160],
            [2007, 11248, 150, 160],
            [2007, 11249, 95, 90],
            [2007, 11250, 95, 90],
            [2007, 11251, 95, 90],
            [2007, 11252, 150, 160],
            [2007, 11253, 95, 90],
            [2007, 11254, 95, 90],
            [2007, 11255, 95, 90],
            [2007, 11256, 95, 90],
            [2007, 11262, 95, 90],
            [2007, 11263, 95, 90],
            [2007, 11264, 150, 160],
            [2007, 11265, 95, 90],
            [2007, 11266, 95, 90],
            [2007, 11267, 95, 90],
            [2007, 11268, 95, 90],
            [2007, 11269, 95, 90],
            [2007, 11270, 150, 160],
            [2007, 11274, 150, 160],
            [2007, 11275, 95, 90],
            [2007, 11276, 95, 90],
            [2007, 11277, 95, 90],
            [2007, 11278, 95, 90],
            [2007, 11279, 150, 160],
            [2007, 11283, 95, 90],
            [2007, 11284, 95, 90],
            [2007, 11285, 95, 90],
            [2007, 11286, 95, 90],
            [2007, 11287, 95, 90],
            [2007, 11288, 95, 90],
            [2007, 11289, 95, 90],
            [2007, 11292, 10, 8],
            [2007, 11293, 5, 5],
            [2007, 11294, 7, 7],
            [2007, 11295, 13, 7],
            [2007, 11296, 21, 45],
            [2007, 11298, 21, 19],
            [2007, 11300, 38, 33],
            [2007, 11303, 19, 17],
            [2007, 11304, 28, 20],
            [2007, 11305, 38, 41],
            [2007, 11306, 37, 31],
            [2007, 11307, 36, 29],
            [2007, 11308, 16, 23],
            [2007, 11309, 26, 24],
            [2007, 11310, 19, 20],
            [2007, 11311, 16, 20],
            [2007, 11312, 21, 20],
            [2007, 11313, 14, 19],
            [2007, 11314, 32, 31],
            [2007, 11315, 31, 27],
            [2007, 11316, 27, 28],
            [2007, 11317, 32, 29],
            [2007, 11318, 18, 19],
            [2007, 11319, 19, 17],
            [2007, 11320, 19, 15],
            [2007, 11321, 40, 27],
            [2007, 11322, 43, 27],
            [2007, 11323, 25, 23],
            [2007, 11324, 26, 18],
            [2007, 11325, 29, 21],
            [2007, 11326, 26, 27],
            [2007, 11327, 28, 21],
            [2007, 11328, 27, 28],
            [2007, 11329, 20, 21],
            [2007, 11330, 32, 31],
            [2007, 11331, 31, 28],
            [2007, 11332, 19, 15],
            [2007, 11333, 36, 25],
            [2007, 11334, 39, 26],
            [2007, 11335, 27, 21],
            [2007, 11336, 12, 14],
            [2007, 11337, 23, 22],
            [2007, 11338, 26, 27],
            [2007, 11339, 31, 26],
            [2007, 11340, 31, 30],
            [2007, 11341, 35, 28],
            [2007, 11342, 32, 28],
            [2007, 11343, 32, 30],
            [2007, 11344, 31, 28],
            [2007, 11345, 27, 28],
            [2007, 11346, 36, 28],
            [2007, 11347, 31, 26],
            [2007, 11348, 40, 32],
            [2007, 11349, 19, 17],
            [2007, 11350, 31, 30],
            [2007, 11351, 27, 28],
            [2007, 11352, 27, 28],
            [2007, 11353, 36, 30],
            [2007, 11354, 27, 21],
            [2007, 11355, 31, 26],
            [2007, 11356, 31, 26],
            [2007, 11357, 26, 22],
            [2007, 11358, 23, 22],
            [2007, 11359, 38, 32],
            [2007, 11360, 29, 22],
            [2007, 11361, 40, 32],
            [2007, 11362, 26, 23],
            [2007, 11363, 9, 10],
            [2007, 11364, 11, 11],
            [2007, 11365, 28, 22],
            [2007, 11366, 21, 20],
            [2007, 11367, 40, 31],
            [2007, 11368, 19, 20],
            [2007, 11369, 43, 42],
            [2007, 11370, 21, 25],
            [2007, 11371, 27, 25],
            [2007, 11372, 32, 31],
            [2007, 11373, 40, 30],
            [2007, 11374, 51, 33],
            [2007, 11375, 39, 35],
            [2007, 11376, 19, 18],
            [2007, 11377, 35, 28],
            [2007, 11378, 24, 22],
            [2007, 11384, 56, 46],
            [2007, 11385, 63, 55],
            [2007, 11386, 63, 65],
            [2007, 11387, 69, 55],
            [2007, 11388, 60, 50],
            [2007, 11389, 41, 31],
            [2007, 11390, 50, 31],
            [2007, 11391, 36, 30],
            [2007, 11392, 60, 55],
            [2007, 11393, 106, 67],
            [2007, 11394, 60, 60],
            [2007, 11395, 65, 67],
            [2007, 11396, 69, 55],
            [2007, 11397, 73, 55],
            [2007, 11398, 35, 31],
            [2007, 11399, 72, 55],
            [2007, 11400, 90, 67],
            [2007, 11401, 46, 22],
            [2007, 11402, 48, 60],
            [2007, 11403, 42, 50],
            [2007, 11404, 120, 68],
            [2007, 11405, 43, 36],
            [2007, 11406, 67, 66],
            [2007, 11407, 57, 30],
            [2007, 11408, 93, 50],
            [2007, 11409, 38, 29],
            [2007, 11410, 48, 55],
            [2007, 11411, 56, 30],
            [2007, 11412, 96, 70],
            [2007, 11413, 68, 55],
            [2007, 11414, 50, 59],
            [2007, 11415, 50, 50],
            [2007, 11416, 38, 29],
            [2007, 11417, 61, 60],
            [2007, 11418, 60, 60],
            [2007, 11419, 40, 39],
            [2007, 11420, 87, 43],
            [2007, 11421, 86, 55],
            [2007, 11422, 48, 34],
            [2007, 11423, 59, 33],
            [2007, 11424, 38, 29],
            [2007, 11425, 22, 18],
            [2007, 11426, 9, 7],
            [2007, 11427, 8, 8],
            [2007, 11428, 50, 24],
            [2007, 11429, 15, 12],
            [2007, 11430, 9, 10],
            [2007, 11431, 12, 10],
            [2007, 11432, 8, 8],
            [2007, 11433, 10, 12],
            [2007, 11434, 10, 9],
            [2007, 11435, 7, 8],
            [2007, 11436, 20, 19],
            [2007, 11437, 12, 11],
            [2007, 11438, 10, 9],
            [2007, 11439, 11, 9],
            [2007, 11440, 16, 14],
            [2007, 11441, 43, 26],
            [2007, 11442, 9, 8],
            [2007, 11443, 11, 11],
            [2007, 11444, 13, 9],
            [2007, 11445, 8, 8],
            [2007, 11446, 11, 9],
            [2007, 11447, 17, 14],
            [2007, 11448, 12, 10],
            [2007, 11449, 12, 8],
            [2007, 11450, 12, 10],
            [2007, 11451, 9, 7],
            [2007, 11452, 10, 9],
            [2007, 11453, 30, 19],
            [2007, 11454, 12, 11],
            [2007, 11455, 8, 8],
            [2007, 11456, 8, 8],
            [2007, 11457, 9, 9],
            [2007, 11458, 6, 7],
            [2007, 11459, 6, 6],
            [2007, 11460, 7, 6],
            [2007, 11461, 9, 8],
            [2007, 11462, 7, 7],
            [2007, 11463, 10, 9],
            [2007, 11464, 9, 7],
            [2007, 11465, 17, 14],
            [2007, 11466, 14, 9],
            [2007, 11467, 15, 11],
            [2007, 11468, 36, 23],
            [2007, 11469, 15, 11],
            [2007, 11470, 19, 16],
            [2007, 11471, 15, 14],
            [2007, 11472, 26, 16],
            [2007, 11473, 10, 9],
            [2007, 11474, 8, 9],
            [2007, 11475, 9, 9],
            [2007, 11476, 11, 9],
            [2007, 11477, 23, 18],
            [2007, 11478, 28, 17],
            [2007, 11479, 11, 9],
            [2007, 11480, 20, 17],
            [2007, 11481, 13, 12],
            [2007, 11482, 16, 13],
            [2007, 11483, 19, 15],
            [2007, 11484, 19, 15],
            [2007, 11485, 24, 17],
            [2007, 11486, 20, 15],
            [2007, 11487, 16, 12],
            [2007, 11488, 23, 17],
            [2007, 11489, 12, 10],
            [2007, 11490, 13, 12],
            [2007, 11491, 11, 9],
            [2007, 11492, 8, 7],
            [2007, 11493, 8, 8],
            [2007, 11494, 6, 7],
            [2007, 11495, 6, 6],
            [2007, 11496, 7, 8],
            [2007, 11497, 9, 8],
            [2007, 11498, 9, 8],
            [2007, 11499, 9, 9],
            [2007, 11500, 21, 19],
            [2007, 11501, 8, 8],
            [2007, 11502, 11, 10],
            [2007, 11503, 7, 8],
            [2007, 11504, 9, 9],
            [2007, 11505, 14, 11],
            [2007, 11506, 10, 10],
            [2007, 11507, 11, 12],
            [2007, 11508, 7, 8],
            [2007, 11509, 25, 16],
            [2007, 11510, 11, 9],
            [2007, 11511, 11, 9],
            [2007, 11512, 19, 12],
            [2007, 11513, 13, 11],
            [2007, 11514, 9, 9],
            [2007, 11515, 9, 9],
            [2007, 11516, 14, 11],
            [2007, 11517, 19, 17],
            [2007, 11518, 10, 15],
            [2007, 11519, 21, 13],
            [2007, 11520, 31, 19],
            [2007, 11521, 8, 6],
            [2007, 11522, 10, 10],
            [2007, 11523, 11, 9],
            [2007, 11524, 8, 7],
            [2007, 11525, 11, 8],
            [2007, 11526, 16, 11],
            [2007, 11527, 10, 10],
            [2007, 11528, 8, 7],
            [2007, 11529, 55, 50],
            [2007, 11530, 55, 70],
            [2007, 11531, 77, 33],
            [2007, 11532, 65, 60],
            [2007, 11533, 31, 31],
            [2007, 11534, 101, 55],
            [2007, 11535, 65, 68],
            [2007, 11536, 36, 36],
            [2007, 11537, 55, 47],
            [2007, 11538, 77, 68],
            [2007, 11539, 92, 68],
            [2007, 11540, 41, 31],
            [2007, 11541, 75, 55],
            [2007, 11542, 69, 60],
            [2007, 11543, 80, 79],
            [2007, 11544, 42, 38],
            [2007, 11545, 80, 90],
            [2007, 11546, 96, 55],
            [2007, 11547, 65, 67],
            [2007, 11548, 90, 55],
            [2007, 11549, 35, 32],
            [2007, 11550, 75, 55],
            [2007, 11551, 44, 50],
            [2007, 11552, 94, 70],
            [2007, 11553, 86, 65],
            [2007, 11554, 52, 59],
            [2007, 11555, 69, 62],
            [2007, 11556, 65, 55],
            [2007, 11557, 65, 66],
            [2007, 11558, 59, 85],
            [2007, 11559, 65, 66],
            [2007, 11560, 46, 90],
            [2007, 11561, 120, 90],
            [2007, 11562, 65, 95],
            [2007, 11563, 120, 55],
            [2007, 11564, 67, 75],
            [2007, 11565, 110, 60],
            [2007, 11566, 88, 90],
            [2007, 11567, 65, 66],
            [2007, 11568, 65, 65],
            [2007, 11569, 102, 90],
            [2007, 11570, 65, 66],
            [2007, 11571, 10, 11],
            [2007, 11572, 15, 14],
            [2007, 11573, 118, 80],
            [2007, 11574, 12, 12],
            [2007, 11576, 14, 14],
            [2007, 11577, 13, 13],
            [2007, 11578, 18, 18],
            [2007, 11579, 17, 23],
            [2007, 11580, 11, 12],
            [2007, 11581, 13, 16],
            [2007, 11582, 17, 19],
            [2007, 11583, 48, 32],
            [2007, 11585, 41, 27],
            [2007, 11586, 48, 26],
            [2007, 11588, 88, 30],
            [2007, 11590, 29, 21],
            [2007, 11592, 60, 28],
            [2007, 11593, 34, 19],
            [2007, 11594, 104, 52],
            [2007, 11596, 37, 31],
            [2007, 11598, 23, 20],
            [2007, 11601, 57, 43],
            [2007, 11604, 14, 16],
            [2007, 11605, 21, 18],
            [2007, 11606, 38, 25],
            [2007, 11607, 33, 26],
            [2007, 11614, 23, 19],
            [2007, 11648, 22, 17],
            [2007, 11665, 47, 33],
            [2007, 11694, 15, 22],
            [2007, 11698, 19, 18],
            [2007, 11703, 18, 19],
            [2007, 11705, 50, 37],
            [2007, 11706, 136, 51],
            [2007, 11709, 65, 30],
            [2007, 11710, 70, 30],
            [2007, 11714, 10, 11],
            [2007, 11717, 26, 30],
            [2007, 11721, 19, 19],
            [2007, 11722, 54, 50],
            [2007, 11724, 52, 45],
            [2007, 11728, 53, 43],
            [2007, 11730, 25, 19],
            [2007, 11731, 79, 46],
            [2007, 11737, 46, 45],
            [2007, 11738, 153, 74],
            [2007, 11739, 19, 19],
            [2007, 11741, 18, 19],
            [2007, 11745, 71, 29],
            [2007, 11746, 31, 19],
            [2007, 11755, 14, 15],
            [2007, 11759, 18, 20],
            [2007, 11760, 100, 65],
            [2007, 11763, 18, 20],
            [2007, 11766, 40, 35],
            [2007, 11776, 60, 48],
            [2007, 11777, 27, 22],
            [2007, 11780, 30, 19],
            [2007, 11781, 20, 22],
            [2007, 11782, 15, 18],
            [2007, 11783, 34, 25],
            [2007, 11784, 24, 21],
            [2007, 11785, 30, 28],
            [2007, 11786, 63, 40],
            [2007, 11787, 37, 36],
            [2007, 11788, 41, 34],
            [2007, 11789, 39, 33],
            [2007, 11790, 14, 17],
            [2007, 11791, 42, 21],
            [2007, 11792, 59, 56],
            [2007, 11794, 27, 22],
            [2007, 11795, 21, 22],
            [2007, 11796, 36, 33],
            [2007, 11797, 42, 31],
            [2007, 11798, 36, 26],
            [2007, 11799, 36, 27],
            [2007, 11800, 29, 24],
            [2007, 11801, 31, 24],
            [2007, 11802, 36, 30],
            [2007, 11803, 35, 27],
            [2007, 11804, 29, 26],
            [2007, 11805, 36, 28],
            [2007, 11806, 41, 33],
            [2007, 11807, 25, 23],
            [2007, 11808, 26, 18],
            [2007, 11809, 20, 13],
            [2007, 11810, 22, 16],
            [2007, 11811, 20, 16],
            [2007, 11812, 28, 21],
            [2007, 11813, 11, 12],
            [2007, 11814, 21, 19],
            [2007, 11815, 20, 17],
            [2007, 11816, 22, 19],
            [2007, 11817, 17, 11],
            [2007, 11818, 18, 19],
            [2007, 11819, 24, 15],
            [2007, 11820, 17, 14],
            [2007, 11821, 22, 17],
            [2007, 11822, 22, 16],
            [2007, 11823, 37, 20],
            [2007, 11824, 20, 17],
            [2007, 11825, 22, 18],
            [2007, 11826, 19, 17],
            [2007, 11827, 19, 17],
            [2007, 11828, 15, 13],
            [2007, 11829, 22, 21],
            [2007, 11830, 13, 11],
            [2007, 11831, 17, 17],
            [2007, 11832, 27, 19],
            [2007, 11833, 23, 15],
            [2007, 11834, 6, 6],
            [2007, 11835, 23, 13],
            [2007, 11836, 23, 17],
            [2007, 11837, 11, 11],
            [2007, 11838, 7, 6],
            [2007, 11839, 12, 10],
            [2007, 11840, 8, 7],
            [2007, 11841, 6, 5],
            [2007, 11842, 20, 17],
            [2007, 11843, 22, 20],
            [2007, 11844, 19, 19],
            [2007, 11845, 23, 19],
            [2007, 11846, 29, 19],
            [2007, 11847, 20, 17],
            [2007, 11848, 15, 12],
            [2007, 11849, 20, 17],
            [2007, 11850, 17, 13],
            [2007, 11851, 24, 17],
            [2007, 11852, 19, 17],
            [2007, 11853, 19, 15],
            [2007, 11854, 18, 19],
            [2007, 11855, 16, 15],
            [2007, 11858, 16, 35],
            [2007, 11859, 21, 37],
            [2007, 11860, 25, 35],
            [2007, 11865, 35, 34],
            [2007, 11866, 37, 32],
            [2007, 11867, 53, 47],
            [2007, 11868, 52, 66],
            [2007, 11869, 26, 25],
            [2007, 11870, 49, 37],
            [2007, 11871, 58, 44],
            [2007, 11872, 29, 28],
            [2007, 11873, 34, 42],
            [2007, 11874, 44, 34],
            [2007, 11875, 33, 27],
            [2007, 11876, 39, 56],
            [2007, 11877, 50, 30],
            [2007, 11878, 23, 19],
            [2007, 11879, 38, 38],
            [2007, 11880, 52, 47],
            [2007, 11881, 54, 41],
            [2007, 11882, 34, 31],
            [2007, 11883, 47, 33],
            [2007, 11884, 59, 39],
            [2007, 11885, 34, 35],
            [2007, 11886, 29, 29],
            [2007, 11887, 39, 32],
            [2007, 11888, 29, 26],
            [2007, 11889, 28, 33],
            [2007, 11890, 28, 30],
            [2007, 11891, 34, 28],
            [2007, 11892, 32, 35],
            [2007, 11893, 38, 30],
            [2007, 11894, 29, 32],
            [2007, 11895, 42, 41],
            [2007, 11896, 38, 36],
            [2007, 11897, 45, 33],
            [2007, 11898, 35, 35],
            [2007, 11899, 42, 59],
            [2007, 11900, 22, 21],
            [2007, 11901, 44, 53],
            [2007, 11902, 29, 46],
            [2007, 11903, 39, 36],
            [2007, 11904, 34, 33],
            [2007, 11905, 50, 48],
            [2007, 11906, 43, 36],
            [2007, 11907, 57, 38],
            [2007, 11908, 31, 30],
            [2007, 11909, 30, 30],
            [2007, 11910, 45, 43],
            [2007, 11911, 26, 29],
            [2007, 11912, 35, 36],
            [2007, 11913, 37, 27],
            [2007, 11914, 24, 22],
            [2007, 11915, 25, 26],
            [2007, 11916, 40, 55],
            [2007, 11917, 36, 34],
            [2007, 11918, 27, 26],
            [2007, 11919, 19, 23],
            [2007, 11920, 28, 25],
            [2007, 11921, 27, 26],
            [2007, 11922, 24, 28],
            [2007, 11923, 20, 25],
            [2007, 11924, 20, 20],
            [2007, 11925, 25, 21],
            [2007, 11926, 19, 16],
            [2007, 11927, 30, 32],
            [2007, 11928, 19, 16],
            [2007, 11929, 17, 13],
            [2007, 11930, 15, 14],
            [2007, 11931, 33, 31],
            [2007, 11932, 50, 32],
            [2007, 11933, 37, 29],
            [2007, 11934, 25, 22],
            [2007, 11935, 31, 28],
            [2007, 11936, 26, 23],
            [2007, 11937, 36, 28],
            [2007, 11938, 32, 27],
            [2007, 11939, 49, 31],
            [2007, 11940, 58, 37],
            [2007, 11941, 38, 30],
            [2007, 11942, 44, 30],
            [2007, 11943, 20, 17],
            [2007, 11944, 41, 29],
            [2007, 11945, 28, 26],
            [2007, 11946, 75, 48],
            [2007, 11947, 33, 26],
            [2007, 11948, 50, 47],
            [2007, 11949, 47, 33],
            [2007, 11950, 32, 31],
            [2007, 11951, 50, 38],
            [2007, 11952, 58, 48],
            [2007, 11953, 49, 41],
            [2007, 11954, 27, 28],
            [2007, 11955, 50, 38],
            [2007, 11956, 56, 38],
            [2007, 11957, 28, 25],
            [2007, 11958, 42, 22],
            [2007, 11959, 25, 18],
            [2007, 11960, 28, 25],
            [2007, 11961, 28, 26],
            [2007, 11962, 26, 27],
            [2007, 11963, 46, 25],
            [2007, 11964, 28, 19],
            [2007, 11965, 60, 45],
            [2007, 11966, 37, 29],
            [2007, 11967, 39, 24],
            [2007, 11968, 60, 48],
            [2007, 11969, 14, 18],
            [2007, 11970, 32, 22],
            [2007, 11971, 43, 37],
            [2007, 11972, 44, 37],
            [2007, 11973, 42, 27],
            [2007, 11974, 64, 48],
            [2007, 11975, 90, 62],
            [2007, 11976, 42, 30],
            [2007, 11977, 51, 47],
            [2007, 11978, 35, 30],
            [2007, 11979, 40, 30],
            [2007, 11980, 77, 59],
            [2007, 11981, 43, 30],
            [2007, 11982, 41, 29],
            [2007, 11983, 25, 23],
            [2007, 11984, 67, 47],
            [2007, 11985, 43, 21],
            [2007, 11986, 45, 38],
            [2007, 11987, 41, 25],
            [2007, 11988, 49, 26],
            [2007, 11989, 35, 30],
            [2007, 11990, 38, 27],
            [2007, 11991, 63, 33],
            [2007, 11992, 47, 43],
            [2007, 11993, 22, 20],
            [2007, 11994, 23, 20],
            [2007, 11995, 25, 25],
            [2007, 11996, 63, 50],
            [2007, 11997, 37, 23],
            [2007, 11998, 53, 50],
            [2007, 11999, 28, 25],
            [2007, 12000, 20, 26],
            [2007, 12001, 32, 21],
            [2007, 12002, 26, 27],
            [2007, 12003, 32, 30],
            [2007, 12004, 12, 15],
            [2007, 12005, 25, 26],
            [2007, 12006, 15, 16],
            [2007, 12007, 36, 19],
            [2007, 12008, 27, 30],
            [2007, 12009, 27, 21],
            [2007, 12010, 27, 22],
            [2007, 12011, 16, 16],
            [2007, 12012, 18, 16],
            [2007, 12013, 13, 12],
            [2007, 12014, 26, 27],
            [2007, 12015, 18, 16],
            [2007, 12016, 27, 27],
            [2007, 12017, 32, 21],
            [2007, 12018, 21, 21],
            [2007, 12019, 29, 23],
            [2007, 12020, 18, 18],
            [2007, 12021, 25, 22],
            [2007, 12022, 27, 22],
            [2007, 12023, 13, 13],
            [2007, 12024, 21, 21],
            [2007, 12025, 47, 36],
            [2007, 12026, 23, 20],
            [2007, 12027, 13, 14],
            [2007, 12028, 14, 17],
            [2007, 12029, 16, 13],
            [2007, 12030, 15, 16],
            [2007, 12031, 25, 20],
            [2007, 12032, 13, 15],
            [2007, 12033, 20, 17],
            [2007, 12034, 23, 16],
            [2007, 12035, 16, 18],
            [2007, 12036, 18, 17],
            [2007, 12037, 21, 17],
            [2007, 12038, 24, 27],
            [2007, 12039, 19, 20],
            [2007, 12040, 74, 26],
            [2007, 12041, 57, 29],
            [2007, 12042, 14, 16],
            [2007, 12043, 26, 21],
            [2007, 12044, 21, 19],
            [2007, 12045, 37, 31],
            [2007, 12046, 38, 25],
            [2007, 12047, 19, 21],
            [2007, 12048, 22, 19],
            [2007, 12049, 12, 17],
            [2007, 12050, 24, 23],
            [2007, 12051, 14, 16],
            [2007, 12052, 32, 20],
            [2007, 12053, 30, 30],
            [2007, 12054, 13, 14],
            [2007, 12055, 32, 18],
            [2007, 12056, 26, 20],
            [2007, 12057, 25, 28],
            [2007, 12058, 22, 20],
            [2007, 12059, 19, 15],
            [2007, 12060, 27, 23],
            [2007, 12061, 14, 15],
            [2007, 12062, 19, 20],
            [2007, 12063, 10, 10],
            [2007, 12064, 24, 20],
            [2007, 12065, 33, 25],
            [2007, 12066, 27, 20],
            [2007, 12067, 18, 16],
            [2007, 12068, 15, 14],
            [2007, 12069, 36, 28],
            [2007, 12070, 16, 19],
            [2007, 12071, 25, 23],
            [2007, 12072, 30, 21],
            [2007, 12073, 13, 16],
            [2007, 12074, 20, 23],
            [2007, 12075, 14, 13],
            [2007, 12076, 16, 14],
            [2007, 12077, 16, 17],
            [2007, 12078, 27, 24],
            [2007, 12079, 30, 22],
            [2007, 12080, 13, 19],
            [2007, 12081, 16, 18],
            [2007, 12082, 29, 29],
            [2007, 12083, 36, 31],
            [2007, 12084, 18, 18],
            [2007, 12085, 28, 24],
            [2007, 12086, 31, 25],
            [2007, 12087, 48, 31],
            [2007, 12088, 15, 14],
            [2007, 12089, 32, 20],
            [2007, 12090, 19, 16],
            [2007, 12091, 33, 17],
            [2007, 12092, 50, 26],
            [2007, 12093, 10, 12],
            [2007, 12094, 31, 21],
            [2007, 12095, 67, 42],
            [2007, 12096, 34, 27],
            [2007, 12097, 36, 26],
            [2007, 12098, 34, 21],
            [2007, 12099, 72, 34],
            [2007, 12100, 11, 9],
            [2007, 12101, 16, 12],
            [2007, 12102, 10, 12],
            [2007, 12103, 37, 21],
            [2007, 12104, 57, 29],
            [2007, 12105, 26, 16],
            [2007, 12106, 13, 12],
            [2007, 12107, 24, 19],
            [2007, 12108, 26, 21],
            [2007, 12109, 31, 24],
            [2007, 12110, 20, 17],
            [2007, 12111, 36, 24],
            [2007, 12112, 38, 25],
            [2007, 12113, 19, 15],
            [2007, 12114, 27, 17],
            [2007, 12115, 11, 13],
            [2007, 12116, 14, 14],
            [2007, 12117, 32, 25],
            [2007, 12118, 25, 20],
            [2007, 12119, 78, 33],
            [2007, 12120, 23, 19],
            [2007, 12121, 23, 17],
            [2007, 12122, 9, 19],
            [2007, 12123, 13, 20],
            [2007, 12124, 13, 24],
            [2007, 12125, 14, 32],
            [2007, 12126, 14, 26],
            [2007, 12127, 10, 15],
            [2007, 12128, 76, 58],
            [2007, 12129, 80, 65],
            [2007, 12130, 110, 90],
            [2007, 12131, 90, 65],
            [2007, 12132, 71, 70],
            [2007, 12133, 75, 74],
            [2007, 12134, 75, 70],
            [2007, 12135, 73, 55],
            [2007, 12136, 47, 40],
            [2007, 12137, 70, 55],
            [2007, 12138, 72, 43],
            [2007, 12139, 51, 60],
            [2007, 12140, 90, 73],
            [2007, 12141, 85, 74],
            [2007, 12142, 100, 50],
            [2007, 12143, 100, 85],
            [2007, 12144, 75, 52],
            [2007, 12145, 90, 70],
            [2007, 12146, 105, 90],
            [2007, 12147, 50, 42],
            [2007, 12148, 120, 67],
            [2007, 12149, 93, 65],
            [2007, 12150, 50, 35],
            [2007, 12151, 55, 45],
            [2007, 12152, 90, 60],
            [2007, 12153, 85, 56],
            [2007, 12154, 120, 59],
            [2007, 12155, 71, 50],
            [2007, 12156, 65, 46],
            [2007, 12157, 60, 47],
            [2007, 12158, 46, 40],
            [2007, 12159, 60, 54],
            [2007, 12160, 22, 26],
            [2007, 12161, 11, 12],
            [2007, 12162, 15, 20],
            [2007, 12163, 24, 27],
            [2007, 12164, 11, 21],
            [2007, 12165, 15, 18],
            [2007, 12166, 15, 17],
            [2007, 12167, 16, 20],
            [2007, 12168, 21, 26],
            [2007, 12169, 14, 14],
            [2007, 12170, 11, 16],
            [2007, 12171, 61, 39],
            [2007, 12172, 56, 33],
            [2007, 12173, 21, 17],
            [2007, 12174, 65, 32],
            [2007, 12175, 58, 36],
            [2007, 12176, 240, 180],
            [2007, 12177, 240, 180],
            [2007, 12178, 240, 180],
            [2007, 12179, 240, 180],
            [2007, 12180, 240, 180],
            [2007, 12181, 240, 180],
            [2007, 12182, 240, 180],
            [2007, 12183, 240, 180],
            [2007, 12184, 240, 180],
            [2007, 12185, 240, 180],
            [2007, 12186, 240, 180],
            [2007, 12187, 240, 180],
            [2007, 12188, 240, 180],
            [2007, 12189, 240, 180],
            [2007, 12190, 240, 180],
            [2007, 12191, 58, 32],
            [2007, 12192, 21, 26],
            [2007, 12193, 63, 45],
            [2007, 12194, 39, 33],
            [2007, 12195, 21, 26],
            [2007, 12196, 21, 26],
            [2007, 12197, 21, 26],
            [2007, 12198, 21, 26],
            [2007, 12199, 52, 42],
            [2007, 12200, 48, 36],
            [2007, 12201, 35, 33],
            [2007, 12202, 36, 33],
            [2007, 12203, 59, 37],
            [2007, 12204, 42, 31],
            [2007, 12205, 74, 31],
            [2007, 12206, 68, 35],
            [2007, 12207, 39, 36],
            [2007, 12208, 22, 39],
            [2007, 12209, 36, 34],
            [2007, 12210, 36, 31],
            [2007, 12211, 53, 37],
            [2007, 12212, 47, 37],
            [2007, 12213, 55, 42],
            [2007, 12214, 35, 38],
            [2007, 12215, 38, 40],
            [2007, 12216, 49, 34],
            [2007, 12217, 39, 35],
            [2007, 12218, 65, 33],
            [2007, 12219, 93, 35],
            [2007, 12220, 38, 35],
            [2007, 12221, 34, 37],
            [2007, 12222, 32, 31],
            [2007, 12223, 83, 36],
            [2007, 12224, 36, 32],
            [2007, 12225, 34, 32],
            [2007, 12226, 43, 35],
            [2007, 12227, 58, 32],
            [2007, 12228, 70, 37],
            [2007, 12229, 49, 39],
            [2007, 12230, 55, 37],
            [2007, 12231, 30, 34],
            [2007, 12232, 55, 39],
            [2007, 12233, 41, 40],
            [2007, 12234, 55, 34],
            [2007, 12235, 48, 32],
            [2007, 12236, 46, 34],
            [2007, 12237, 37, 43],
            [2007, 12238, 39, 37],
            [2007, 12239, 56, 31],
            [2008, 25, 12, 9],
            [2008, 48, 38, 26],
            [2008, 49, 25, 17],
            [2008, 65, 17, 16],
            [2008, 82, 15, 16],
            [2008, 83, 24, 24],
            [2008, 101, 36, 29],
            [2008, 119, 28, 21],
            [2008, 163, 29, 27],
            [2008, 200, 28, 21],
            [2008, 204, 15, 19],
            [2008, 220, 10, 12],
            [2008, 226, 19, 18],
            [2008, 231, 41, 26],
            [2008, 234, 12, 12],
            [2008, 240, 61, 35],
            [2008, 246, 25, 16],
            [2008, 282, 36, 25],
            [2008, 310, 11, 12],
            [2008, 314, 17, 21],
            [2008, 324, 27, 23],
            [2008, 327, 33, 28],
            [2008, 346, 40, 32],
            [2008, 355, 32, 26],
            [2008, 379, 13, 12],
            [2008, 389, 23, 20],
            [2008, 399, 38, 25],
            [2008, 425, 11, 15],
            [2008, 430, 17, 18],
            [2008, 436, 38, 32],
            [2008, 479, 39, 31],
            [2008, 480, 50, 28],
            [2008, 503, 89, 26],
            [2008, 504, 8, 10],
            [2008, 541, 74, 33],
            [2008, 585, 41, 26],
            [2008, 590, 41, 46],
            [2008, 593, 39, 32],
            [2008, 597, 29, 14],
            [2008, 604, 90, 49],
            [2008, 612, 26, 26],
            [2008, 618, 18, 14],
            [2008, 662, 43, 36],
            [2008, 663, 50, 26],
            [2008, 669, 24, 16],
            [2008, 686, 16, 17],
            [2008, 694, 28, 22],
            [2008, 700, 39, 30],
            [2008, 703, 15, 15],
            [2008, 716, 36, 29],
            [2008, 734, 17, 17],
            [2008, 751, 22, 19],
            [2008, 766, 75, 41],
            [2008, 769, 43, 27],
            [2008, 803, 23, 22],
            [2008, 805, 17, 17],
            [2008, 820, 47, 28],
            [2008, 822, 12, 16],
            [2008, 827, 11, 13],
            [2008, 845, 36, 33],
            [2008, 865, 66, 26],
            [2008, 871, 27, 19],
            [2008, 878, 7, 6],
            [2008, 882, 33, 27],
            [2008, 894, 17, 13],
            [2008, 913, 16, 16],
            [2008, 922, 23, 25],
            [2008, 938, 11, 12],
            [2008, 940, 11, 13],
            [2008, 941, 31, 33],
            [2008, 964, 11, 13],
            [2008, 969, 38, 31],
            [2008, 971, 10, 10],
            [2008, 985, 44, 29],
            [2008, 998, 33, 28],
            [2008, 1003, 8, 6],
            [2008, 1008, 30, 28],
            [2008, 1016, 8, 9],
            [2008, 1030, 9, 11],
            [2008, 1048, 33, 29],
            [2008, 1059, 43, 42],
            [2008, 1106, 41, 26],
            [2008, 1111, 35, 35],
            [2008, 1132, 11, 12],
            [2008, 1136, 30, 28],
            [2008, 1145, 24, 19],
            [2008, 1150, 22, 20],
            [2008, 1156, 21, 17],
            [2008, 1157, 32, 31],
            [2008, 1159, 69, 26],
            [2008, 1174, 21, 25],
            [2008, 1186, 15, 15],
            [2008, 1203, 11, 17],
            [2008, 1213, 16, 15],
            [2008, 1221, 13, 16],
            [2008, 1226, 28, 23],
            [2008, 1234, 14, 15],
            [2008, 1235, 23, 18],
            [2008, 1238, 14, 19],
            [2008, 1247, 27, 22],
            [2008, 1254, 41, 23],
            [2008, 1268, 23, 21],
            [2008, 1275, 25, 16],
            [2008, 1281, 10, 9],
            [2008, 1295, 33, 30],
            [2008, 1302, 35, 35],
            [2008, 1303, 40, 30],
            [2008, 1320, 30, 33],
            [2008, 1396, 13, 16],
            [2008, 1420, 35, 37],
            [2008, 1445, 59, 22],
            [2008, 1456, 19, 20],
            [2008, 1466, 22, 19],
            [2008, 1473, 12, 8],
            [2008, 1481, 28, 21],
            [2008, 1491, 10, 8],
            [2008, 1507, 33, 28],
            [2008, 1515, 16, 15],
            [2008, 1525, 28, 25],
            [2008, 1530, 61, 39],
            [2008, 1536, 17, 21],
            [2008, 1557, 37, 25],
            [2008, 1577, 21, 17],
            [2008, 1580, 32, 28],
            [2008, 1587, 14, 15],
            [2008, 1589, 34, 22],
            [2008, 1598, 11, 8],
            [2008, 1628, 25, 17],
            [2008, 1635, 17, 13],
            [2008, 1638, 37, 28],
            [2008, 1645, 48, 30],
            [2008, 1673, 55, 32],
            [2008, 1685, 26, 24],
            [2008, 1704, 16, 14],
            [2008, 1717, 41, 30],
            [2008, 1730, 14, 11],
            [2008, 1769, 41, 34],
            [2008, 1772, 10, 12],
            [2008, 1774, 20, 16],
            [2008, 1794, 26, 24],
            [2008, 1795, 12, 9],
            [2008, 1797, 40, 25],
            [2008, 1798, 33, 31],
            [2008, 1824, 57, 32],
            [2008, 1841, 32, 31],
            [2008, 1845, 17, 18],
            [2008, 1864, 92, 55],
            [2008, 1866, 29, 21],
            [2008, 1891, 27, 21],
            [2008, 1894, 22, 15],
            [2008, 1903, 43, 26],
            [2008, 1921, 12, 11],
            [2008, 1930, 10, 8],
            [2008, 1952, 98, 40],
            [2008, 1962, 11, 12],
            [2008, 1965, 55, 33],
            [2008, 2011, 19, 18],
            [2008, 2017, 25, 25],
            [2008, 2023, 7, 7],
            [2008, 2035, 32, 28],
            [2008, 2056, 20, 36],
            [2008, 2064, 37, 24],
            [2008, 2098, 12, 15],
            [2008, 2142, 9, 10],
            [2008, 2178, 15, 14],
            [2008, 2190, 25, 19],
            [2008, 2198, 14, 14],
            [2008, 2208, 57, 35],
            [2008, 2213, 33, 26],
            [2008, 2227, 13, 15],
            [2008, 2244, 18, 18],
            [2008, 2250, 33, 25],
            [2008, 2277, 23, 17],
            [2008, 2280, 11, 9],
            [2008, 2282, 17, 30],
            [2008, 2300, 39, 31],
            [2008, 2311, 23, 22],
            [2008, 2316, 39, 30],
            [2008, 2343, 33, 25],
            [2008, 2352, 36, 25],
            [2008, 2371, 41, 28],
            [2008, 2384, 20, 20],
            [2008, 2429, 15, 16],
            [2008, 2435, 13, 16],
            [2008, 2443, 37, 25],
            [2008, 2458, 26, 20],
            [2008, 2459, 15, 17],
            [2008, 2467, 14, 14],
            [2008, 2483, 36, 40],
            [2008, 2485, 18, 14],
            [2008, 2500, 23, 17],
            [2008, 2501, 39, 30],
            [2008, 2505, 38, 25],
            [2008, 2524, 10, 9],
            [2008, 2533, 10, 16],
            [2008, 2539, 69, 22],
            [2008, 2547, 15, 28],
            [2008, 2554, 11, 20],
            [2008, 2576, 43, 26],
            [2008, 2585, 37, 26],
            [2008, 2595, 31, 29],
            [2008, 2606, 13, 13],
            [2008, 2627, 29, 21],
            [2008, 2635, 14, 15],
            [2008, 2670, 33, 22],
            [2008, 2671, 34, 29],
            [2008, 2692, 21, 20],
            [2008, 2695, 17, 13],
            [2008, 2723, 34, 31],
            [2008, 2758, 30, 25],
            [2008, 2775, 41, 28],
            [2008, 2785, 9, 10],
            [2008, 2798, 16, 17],
            [2008, 2822, 21, 18],
            [2008, 2835, 20, 18],
            [2008, 2836, 15, 17],
            [2008, 2879, 19, 17],
            [2008, 2883, 31, 34],
            [2008, 2914, 39, 25],
            [2008, 2922, 12, 13],
            [2008, 2991, 33, 23],
            [2008, 3019, 38, 21],
            [2008, 3033, 54, 40],
            [2008, 3046, 44, 22],
            [2008, 3053, 43, 26],
            [2008, 3066, 38, 28],
            [2008, 3086, 87, 40],
            [2008, 3091, 12, 14],
            [2008, 3092, 34, 26],
            [2008, 3119, 11, 15],
            [2008, 3126, 27, 22],
            [2008, 3134, 25, 25],
            [2008, 3142, 24, 29],
            [2008, 3158, 18, 18],
            [2008, 3164, 36, 28],
            [2008, 3171, 25, 17],
            [2008, 3182, 67, 32],
            [2008, 3221, 38, 26],
            [2008, 3246, 58, 33],
            [2008, 3252, 36, 25],
            [2008, 3254, 19, 24],
            [2008, 3273, 40, 27],
            [2008, 3274, 19, 17],
            [2008, 3301, 32, 26],
            [2008, 3308, 42, 28],
            [2008, 3309, 28, 26],
            [2008, 3321, 28, 21],
            [2008, 3327, 34, 26],
            [2008, 3348, 37, 25],
            [2008, 3364, 11, 14],
            [2008, 3372, 37, 25],
            [2008, 3382, 22, 16],
            [2008, 3434, 7, 7],
            [2008, 3438, 41, 25],
            [2008, 3451, 55, 38],
            [2008, 3454, 10, 11],
            [2008, 3462, 34, 22],
            [2008, 3494, 11, 10],
            [2008, 3503, 83, 40],
            [2008, 3515, 12, 29],
            [2008, 3517, 32, 26],
            [2008, 3559, 31, 26],
            [2008, 3569, 36, 37],
            [2008, 3579, 14, 22],
            [2008, 3590, 16, 20],
            [2008, 3593, 45, 49],
            [2008, 3659, 36, 26],
            [2008, 3669, 14, 16],
            [2008, 3700, 18, 14],
            [2008, 3718, 41, 30],
            [2008, 3726, 13, 12],
            [2008, 3729, 103, 40],
            [2008, 3765, 12, 17],
            [2008, 3859, 11, 15],
            [2008, 3884, 37, 25],
            [2008, 3889, 37, 24],
            [2008, 3915, 21, 33],
            [2008, 3925, 42, 28],
            [2008, 3943, 20, 20],
            [2008, 3956, 34, 42],
            [2008, 3972, 126, 60],
            [2008, 3976, 16, 17],
            [2008, 3985, 19, 18],
            [2008, 3993, 15, 15],
            [2008, 4015, 37, 25],
            [2008, 4022, 41, 24],
            [2008, 4026, 23, 16],
            [2008, 4027, 38, 25],
            [2008, 4028, 19, 19],
            [2008, 4043, 16, 15],
            [2008, 4074, 17, 20],
            [2008, 4091, 28, 27],
            [2008, 4107, 40, 25],
            [2008, 4125, 15, 16],
            [2008, 4165, 32, 29],
            [2008, 4173, 15, 16],
            [2008, 4176, 10, 10],
            [2008, 4209, 34, 31],
            [2008, 4246, 12, 19],
            [2008, 4285, 22, 27],
            [2008, 4299, 31, 21],
            [2008, 4301, 42, 43],
            [2008, 4310, 25, 25],
            [2008, 4312, 32, 26],
            [2008, 4325, 31, 20],
            [2008, 4353, 20, 13],
            [2008, 4358, 12, 13],
            [2008, 4362, 49, 31],
            [2008, 4380, 16, 18],
            [2008, 4382, 78, 27],
            [2008, 4386, 16, 17],
            [2008, 4413, 11, 11],
            [2008, 4414, 16, 19],
            [2008, 4426, 15, 15],
            [2008, 4440, 32, 26],
            [2008, 4442, 16, 18],
            [2008, 4454, 10, 10],
            [2008, 4464, 33, 22],
            [2008, 4470, 23, 21],
            [2008, 4477, 24, 24],
            [2008, 4487, 18, 22],
            [2008, 4491, 35, 27],
            [2008, 4518, 40, 28],
            [2008, 4536, 17, 17],
            [2008, 4545, 34, 26],
            [2008, 4610, 42, 28],
            [2008, 4617, 78, 34],
            [2008, 4618, 20, 18],
            [2008, 4623, 17, 18],
            [2008, 4626, 25, 17],
            [2008, 4634, 21, 20],
            [2008, 4638, 50, 25],
            [2008, 4644, 13, 16],
            [2008, 4648, 29, 21],
            [2008, 4660, 37, 25],
            [2008, 4670, 37, 25],
            [2008, 4676, 12, 14],
            [2008, 4689, 35, 25],
            [2008, 4710, 8, 6],
            [2008, 4724, 22, 16],
            [2008, 4732, 45, 54],
            [2008, 4734, 12, 12],
            [2008, 4738, 30, 32],
            [2008, 4745, 20, 19],
            [2008, 4749, 31, 26],
            [2008, 4762, 32, 26],
            [2008, 4764, 19, 25],
            [2008, 4789, 41, 25],
            [2008, 4794, 18, 16],
            [2008, 4801, 14, 16],
            [2008, 4805, 12, 17],
            [2008, 4820, 36, 29],
            [2008, 4828, 56, 44],
            [2008, 4832, 17, 18],
            [2008, 4840, 41, 25],
            [2008, 4849, 16, 16],
            [2008, 4863, 35, 28],
            [2008, 4865, 25, 18],
            [2008, 4871, 11, 14],
            [2008, 4888, 36, 30],
            [2008, 4897, 12, 15],
            [2008, 4912, 10, 18],
            [2008, 4914, 21, 17],
            [2008, 4918, 17, 14],
            [2008, 4926, 46, 42],
            [2008, 4939, 19, 16],
            [2008, 4944, 15, 14],
            [2008, 4951, 27, 26],
            [2008, 4973, 27, 27],
            [2008, 4976, 11, 10],
            [2008, 4978, 45, 34],
            [2008, 4983, 13, 11],
            [2008, 4992, 17, 16],
            [2008, 5006, 67, 31],
            [2008, 5019, 52, 35],
            [2008, 5031, 10, 10],
            [2008, 5038, 14, 16],
            [2008, 5048, 28, 25],
            [2008, 5050, 22, 17],
            [2008, 5051, 12, 15],
            [2008, 5062, 33, 21],
            [2008, 5063, 18, 23],
            [2008, 5073, 48, 31],
            [2008, 5081, 26, 21],
            [2008, 5091, 66, 29],
            [2008, 5092, 11, 14],
            [2008, 5095, 14, 15],
            [2008, 5107, 80, 26],
            [2008, 5108, 17, 20],
            [2008, 5130, 39, 31],
            [2008, 5149, 19, 17],
            [2008, 5159, 40, 29],
            [2008, 5184, 24, 19],
            [2008, 5185, 20, 15],
            [2008, 5186, 14, 15],
            [2008, 5187, 14, 16],
            [2008, 5188, 16, 18],
            [2008, 5217, 36, 27],
            [2008, 5219, 17, 26],
            [2008, 5220, 15, 29],
            [2008, 5221, 11, 18],
            [2008, 5222, 15, 20],
            [2008, 5223, 11, 21],
            [2008, 5224, 16, 29],
            [2008, 5225, 15, 27],
            [2008, 5226, 12, 27],
            [2008, 5227, 26, 34],
            [2008, 5228, 18, 32],
            [2008, 5229, 11, 25],
            [2008, 5230, 15, 23],
            [2008, 5231, 12, 22],
            [2008, 5232, 17, 29],
            [2008, 5233, 22, 35],
            [2008, 5234, 10, 16],
            [2008, 5235, 26, 25],
            [2008, 5236, 15, 23],
            [2008, 5237, 20, 29],
            [2008, 5238, 14, 19],
            [2008, 5239, 20, 31],
            [2008, 5240, 18, 35],
            [2008, 5241, 21, 32],
            [2008, 5242, 17, 24],
            [2008, 5243, 21, 35],
            [2008, 5244, 20, 35],
            [2008, 5245, 22, 35],
            [2008, 5273, 19, 15],
            [2008, 5375, 12, 8],
            [2008, 5434, 8, 8],
            [2008, 5472, 20, 18],
            [2008, 5473, 24, 20],
            [2008, 5495, 16, 14],
            [2008, 5528, 11, 8],
            [2008, 5944, 7, 7],
            [2008, 5945, 8, 8],
            [2008, 5946, 6, 5],
            [2008, 5962, 68, 67],
            [2008, 5989, 150, 160],
            [2008, 5990, 150, 160],
            [2008, 5991, 150, 160],
            [2008, 5992, 150, 160],
            [2008, 5993, 150, 160],
            [2008, 5996, 34, 25],
            [2008, 6068, 32, 27],
            [2008, 6069, 34, 29],
            [2008, 6070, 33, 31],
            [2008, 6071, 26, 23],
            [2008, 6073, 21, 23],
            [2008, 6074, 29, 26],
            [2008, 6075, 20, 28],
            [2008, 6076, 19, 22],
            [2008, 6077, 26, 24],
            [2008, 6078, 25, 24],
            [2008, 6079, 30, 26],
            [2008, 6080, 18, 26],
            [2008, 6081, 18, 19],
            [2008, 6082, 29, 26],
            [2008, 6083, 27, 24],
            [2008, 6084, 32, 24],
            [2008, 6085, 30, 25],
            [2008, 6087, 25, 22],
            [2008, 6088, 21, 22],
            [2008, 6089, 24, 22],
            [2008, 6090, 34, 26],
            [2008, 6091, 18, 22],
            [2008, 6092, 27, 26],
            [2008, 6093, 34, 29],
            [2008, 6094, 29, 26],
            [2008, 6095, 12, 18],
            [2008, 6096, 27, 23],
            [2008, 6097, 36, 23],
            [2008, 6098, 27, 23],
            [2008, 6099, 24, 24],
            [2008, 6100, 21, 26],
            [2008, 6101, 21, 23],
            [2008, 6102, 19, 20],
            [2008, 6103, 27, 24],
            [2008, 6104, 30, 22],
            [2008, 6105, 24, 24],
            [2008, 6106, 23, 21],
            [2008, 6108, 27, 23],
            [2008, 6109, 13, 20],
            [2008, 6110, 27, 26],
            [2008, 6111, 13, 16],
            [2008, 6112, 21, 25],
            [2008, 6113, 21, 21],
            [2008, 6114, 24, 21],
            [2008, 6115, 14, 20],
            [2008, 6116, 23, 23],
            [2008, 6117, 24, 24],
            [2008, 6118, 33, 26],
            [2008, 6119, 26, 25],
            [2008, 6120, 17, 19],
            [2008, 6121, 14, 23],
            [2008, 6122, 26, 23],
            [2008, 6123, 21, 21],
            [2008, 6124, 27, 24],
            [2008, 6125, 24, 27],
            [2008, 6126, 25, 24],
            [2008, 6127, 23, 26],
            [2008, 6128, 23, 26],
            [2008, 6130, 25, 24],
            [2008, 6131, 27, 24],
            [2008, 6132, 29, 26],
            [2008, 6133, 27, 24],
            [2008, 6134, 27, 24],
            [2008, 6135, 41, 30],
            [2008, 6136, 41, 36],
            [2008, 6137, 15, 17],
            [2008, 6138, 16, 21],
            [2008, 6139, 24, 23],
            [2008, 6140, 16, 19],
            [2008, 6141, 20, 22],
            [2008, 6142, 15, 22],
            [2008, 6143, 24, 24],
            [2008, 6145, 25, 24],
            [2008, 6146, 13, 16],
            [2008, 6147, 17, 22],
            [2008, 6148, 16, 19],
            [2008, 6149, 25, 26],
            [2008, 6150, 16, 18],
            [2008, 6151, 18, 18],
            [2008, 6152, 15, 19],
            [2008, 6153, 15, 19],
            [2008, 6154, 20, 23],
            [2008, 6155, 16, 19],
            [2008, 6156, 21, 19],
            [2008, 6157, 24, 21],
            [2008, 6158, 20, 19],
            [2008, 6159, 23, 21],
            [2008, 6160, 20, 20],
            [2008, 6161, 14, 15],
            [2008, 6162, 18, 18],
            [2008, 6163, 28, 24],
            [2008, 6164, 25, 23],
            [2008, 6165, 21, 19],
            [2008, 6166, 39, 25],
            [2008, 6167, 27, 29],
            [2008, 6244, 35, 28],
            [2008, 6353, 35, 29],
            [2008, 6358, 34, 23],
            [2008, 6391, 45, 29],
            [2008, 6433, 24, 26],
            [2008, 6438, 65, 54],
            [2008, 6442, 27, 22],
            [2008, 6463, 63, 65],
            [2008, 6471, 43, 31],
            [2008, 6492, 25, 26],
            [2008, 6494, 26, 22],
            [2008, 6495, 45, 31],
            [2008, 6502, 24, 24],
            [2008, 6614, 18, 17],
            [2008, 6631, 29, 29],
            [2008, 6633, 20, 23],
            [2008, 6634, 25, 23],
            [2008, 6635, 24, 25],
            [2008, 6636, 32, 31],
            [2008, 6637, 26, 24],
            [2008, 6638, 42, 27],
            [2008, 6639, 26, 28],
            [2008, 6640, 25, 45],
            [2008, 6643, 37, 25],
            [2008, 6649, 32, 24],
            [2008, 6650, 32, 24],
            [2008, 6651, 26, 20],
            [2008, 6652, 24, 25],
            [2008, 6653, 31, 28],
            [2008, 6654, 30, 24],
            [2008, 6655, 25, 21],
            [2008, 6656, 27, 25],
            [2008, 6657, 23, 27],
            [2008, 6660, 29, 22],
            [2008, 6661, 24, 24],
            [2008, 6662, 24, 25],
            [2008, 6663, 25, 24],
            [2008, 6664, 32, 27],
            [2008, 6665, 25, 26],
            [2008, 6666, 25, 24],
            [2008, 6667, 26, 25],
            [2008, 6668, 30, 21],
            [2008, 6669, 21, 27],
            [2008, 6670, 26, 24],
            [2008, 6671, 32, 25],
            [2008, 6672, 27, 23],
            [2008, 6673, 29, 24],
            [2008, 6674, 27, 26],
            [2008, 6675, 24, 22],
            [2008, 6676, 32, 27],
            [2008, 6677, 25, 26],
            [2008, 6678, 24, 22],
            [2008, 6679, 48, 36],
            [2008, 6680, 23, 21],
            [2008, 6682, 24, 23],
            [2008, 6683, 20, 22],
            [2008, 6684, 23, 24],
            [2008, 6685, 19, 19],
            [2008, 6686, 17, 19],
            [2008, 6687, 18, 22],
            [2008, 6688, 18, 19],
            [2008, 6689, 15, 20],
            [2008, 6690, 18, 20],
            [2008, 6697, 21, 24],
            [2008, 6699, 24, 65],
            [2008, 6700, 70, 46],
            [2008, 6701, 48, 34],
            [2008, 6702, 55, 45],
            [2008, 6704, 50, 39],
            [2008, 6715, 55, 31],
            [2008, 6716, 52, 31],
            [2008, 6718, 21, 35],
            [2008, 6722, 47, 31],
            [2008, 6723, 85, 55],
            [2008, 6726, 18, 50],
            [2008, 6728, 55, 38],
            [2008, 6734, 52, 32],
            [2008, 6737, 27, 75],
            [2008, 6738, 46, 41],
            [2008, 6741, 14, 15],
            [2008, 6748, 24, 23],
            [2008, 6749, 18, 22],
            [2008, 6750, 29, 29],
            [2008, 6752, 14, 20],
            [2008, 6753, 27, 25],
            [2008, 6754, 27, 26],
            [2008, 6755, 34, 30],
            [2008, 6756, 26, 26],
            [2008, 6757, 24, 23],
            [2008, 6758, 19, 29],
            [2008, 6759, 16, 20],
            [2008, 6760, 35, 30],
            [2008, 6761, 27, 30],
            [2008, 6762, 28, 28],
            [2008, 6763, 14, 18],
            [2008, 6764, 27, 28],
            [2008, 6766, 34, 30],
            [2008, 6767, 27, 25],
            [2008, 6768, 26, 25],
            [2008, 6769, 30, 32],
            [2008, 6770, 28, 30],
            [2008, 6771, 23, 29],
            [2008, 6772, 19, 22],
            [2008, 6773, 31, 30],
            [2008, 6777, 33, 31],
            [2008, 6778, 14, 22],
            [2008, 6779, 26, 27],
            [2008, 6780, 31, 30],
            [2008, 6781, 31, 29],
            [2008, 6782, 47, 33],
            [2008, 6783, 28, 31],
            [2008, 6784, 24, 28],
            [2008, 6785, 32, 28],
            [2008, 6786, 22, 30],
            [2008, 6787, 27, 29],
            [2008, 6789, 29, 27],
            [2008, 6790, 21, 65],
            [2008, 6791, 65, 71],
            [2008, 6794, 18, 47],
            [2008, 6795, 32, 41],
            [2008, 6798, 60, 32],
            [2008, 6803, 24, 80],
            [2008, 6804, 50, 75],
            [2008, 6805, 52, 65],
            [2008, 6806, 24, 55],
            [2008, 6807, 48, 51],
            [2008, 6808, 19, 40],
            [2008, 6812, 181, 85],
            [2008, 6813, 20, 56],
            [2008, 6814, 148, 100],
            [2008, 6816, 48, 86],
            [2008, 6818, 16, 16],
            [2008, 6819, 27, 32],
            [2008, 6820, 28, 28],
            [2008, 6821, 44, 36],
            [2008, 6822, 41, 38],
            [2008, 6823, 27, 29],
            [2008, 6833, 32, 35],
            [2008, 6834, 92, 95],
            [2008, 6835, 135, 115],
            [2008, 6836, 40, 45],
            [2008, 6837, 16, 28],
            [2008, 6838, 129, 86],
            [2008, 6841, 26, 21],
            [2008, 6845, 21, 53],
            [2008, 6846, 16, 41],
            [2008, 6847, 21, 45],
            [2008, 6848, 21, 30],
            [2008, 6849, 56, 41],
            [2008, 6850, 21, 35],
            [2008, 6851, 38, 46],
            [2008, 6852, 92, 100],
            [2008, 6853, 22, 55],
            [2008, 6854, 95, 77],
            [2008, 6855, 21, 40],
            [2008, 6856, 17, 52],
            [2008, 6857, 28, 61],
            [2008, 6858, 21, 40],
            [2008, 6859, 32, 27],
            [2008, 6860, 18, 45],
            [2008, 6861, 21, 45],
            [2008, 6862, 32, 35],
            [2008, 6867, 14, 18],
            [2008, 6868, 15, 15],
            [2008, 6869, 15, 15],
            [2008, 6870, 15, 17],
            [2008, 6871, 16, 17],
            [2008, 6872, 15, 17],
            [2008, 6873, 20, 16],
            [2008, 6874, 11, 16],
            [2008, 6875, 14, 17],
            [2008, 6876, 11, 15],
            [2008, 6877, 16, 19],
            [2008, 6878, 14, 16],
            [2008, 6879, 16, 20],
            [2008, 6880, 19, 19],
            [2008, 6881, 11, 13],
            [2008, 6882, 15, 17],
            [2008, 6883, 19, 21],
            [2008, 6910, 39, 32],
            [2008, 6912, 15, 11],
            [2008, 6914, 11, 11],
            [2008, 6918, 23, 21],
            [2008, 6920, 19, 18],
            [2008, 6922, 11, 11],
            [2008, 6928, 17, 15],
            [2008, 6930, 16, 14],
            [2008, 6931, 31, 29],
            [2008, 6934, 12, 13],
            [2008, 6938, 14, 13],
            [2008, 6940, 11, 11],
            [2008, 6942, 15, 16],
            [2008, 6944, 10, 10],
            [2008, 6948, 11, 10],
            [2008, 6950, 12, 11],
            [2008, 6952, 41, 21],
            [2008, 6954, 16, 15],
            [2008, 6957, 60, 44],
            [2008, 6958, 11, 11],
            [2008, 6960, 15, 15],
            [2008, 6962, 13, 11],
            [2008, 6965, 9, 10],
            [2008, 6966, 20, 30],
            [2008, 6967, 14, 28],
            [2008, 6968, 29, 45],
            [2008, 6969, 19, 30],
            [2008, 6970, 19, 30],
            [2008, 7007, 40, 23],
            [2008, 7008, 57, 28],
            [2008, 7011, 10, 10],
            [2008, 7013, 21, 16],
            [2008, 7014, 14, 9],
            [2008, 7015, 8, 8],
            [2008, 7019, 10, 9],
            [2008, 7021, 10, 11],
            [2008, 7027, 14, 15],
            [2008, 7029, 29, 23],
            [2008, 7031, 14, 19],
            [2008, 7033, 20, 17],
            [2008, 7035, 11, 11],
            [2008, 7039, 20, 14],
            [2008, 7050, 11, 12],
            [2008, 7052, 13, 17],
            [2008, 7054, 13, 14],
            [2008, 7056, 11, 13],
            [2008, 7057, 49, 31],
            [2008, 7058, 22, 15],
            [2008, 7062, 12, 12],
            [2008, 7063, 42, 29],
            [2008, 7066, 10, 11],
            [2008, 7068, 50, 24],
            [2008, 7070, 26, 28],
            [2008, 7072, 9, 10],
            [2008, 7074, 14, 14],
            [2008, 7076, 21, 18],
            [2008, 7078, 11, 11],
            [2008, 7080, 32, 29],
            [2008, 7082, 13, 16],
            [2008, 7084, 25, 21],
            [2008, 7086, 11, 13],
            [2008, 7088, 34, 24],
            [2008, 7090, 13, 11],
            [2008, 7091, 46, 31],
            [2008, 7092, 35, 30],
            [2008, 7093, 63, 45],
            [2008, 7094, 38, 27],
            [2008, 7098, 16, 21],
            [2008, 7156, 16, 17],
            [2008, 7259, 61, 42],
            [2008, 7260, 85, 65],
            [2008, 7261, 71, 55],
            [2008, 7262, 66, 61],
            [2008, 7263, 80, 64],
            [2008, 7264, 73, 68],
            [2008, 7265, 88, 72],
            [2008, 7266, 96, 72],
            [2008, 7267, 73, 58],
            [2008, 7268, 108, 82],
            [2008, 7269, 96, 72],
            [2008, 7270, 58, 40],
            [2008, 7271, 49, 45],
            [2008, 7272, 94, 70],
            [2008, 7273, 63, 59],
            [2008, 7274, 84, 62],
            [2008, 7275, 83, 67],
            [2008, 7276, 50, 40],
            [2008, 7277, 86, 69],
            [2008, 7278, 71, 68],
            [2008, 7279, 57, 45],
            [2008, 7280, 97, 73],
            [2008, 7281, 83, 66],
            [2008, 7282, 69, 66],
            [2008, 7283, 10, 17],
            [2008, 7284, 16, 18],
            [2008, 7285, 17, 20],
            [2008, 7286, 10, 18],
            [2008, 7287, 18, 22],
            [2008, 7288, 34, 30],
            [2008, 7289, 26, 25],
            [2008, 7290, 37, 33],
            [2008, 7291, 38, 32],
            [2008, 7292, 26, 31],
            [2008, 7293, 20, 24],
            [2008, 7294, 21, 26],
            [2008, 7295, 12, 14],
            [2008, 7296, 23, 20],
            [2008, 7297, 25, 22],
            [2008, 7298, 15, 16],
            [2008, 7299, 16, 17],
            [2008, 7300, 17, 21],
            [2008, 7301, 13, 19],
            [2008, 7302, 30, 33],
            [2008, 7303, 68, 60],
            [2008, 7304, 27, 29],
            [2008, 7305, 32, 33],
            [2008, 7306, 27, 29],
            [2008, 7307, 47, 50],
            [2008, 7308, 36, 37],
            [2008, 7309, 27, 29],
            [2008, 7310, 76, 62],
            [2008, 7311, 66, 61],
            [2008, 7312, 29, 30],
            [2008, 7313, 120, 35],
            [2008, 7314, 25, 16],
            [2008, 7315, 16, 12],
            [2008, 7316, 36, 60],
            [2008, 7317, 40, 31],
            [2008, 7318, 120, 81],
            [2008, 7319, 41, 31],
            [2008, 7320, 74, 57],
            [2008, 7321, 81, 90],
            [2008, 7322, 71, 39],
            [2008, 7323, 86, 70],
            [2008, 7324, 68, 54],
            [2008, 7325, 104, 40],
            [2008, 7326, 26, 16],
            [2008, 7327, 181, 108],
            [2008, 7328, 19, 22],
            [2008, 7329, 33, 31],
            [2008, 7330, 21, 16],
            [2008, 7337, 14, 12],
            [2008, 7342, 12, 9],
            [2008, 7343, 15, 8],
            [2008, 7344, 11, 8],
            [2008, 7348, 15, 8],
            [2008, 7352, 12, 11],
            [2008, 7354, 25, 15],
            [2008, 7356, 14, 8],
            [2008, 7357, 24, 15],
            [2008, 7358, 14, 10],
            [2008, 7359, 24, 15],
            [2008, 7360, 13, 10],
            [2008, 7362, 17, 12],
            [2008, 7363, 12, 8],
            [2008, 7364, 12, 11],
            [2008, 7367, 15, 12],
            [2008, 7370, 11, 10],
            [2008, 7371, 12, 8],
            [2008, 7372, 12, 8],
            [2008, 7373, 13, 8],
            [2008, 7374, 9, 8],
            [2008, 7375, 11, 8],
            [2008, 7376, 7, 7],
            [2008, 7377, 9, 8],
            [2008, 7378, 20, 18],
            [2008, 7379, 30, 23],
            [2008, 7398, 24, 33],
            [2008, 7399, 27, 29],
            [2008, 7401, 22, 30],
            [2008, 7403, 17, 24],
            [2008, 7405, 21, 26],
            [2008, 7406, 29, 31],
            [2008, 7407, 31, 40],
            [2008, 7410, 17, 22],
            [2008, 7411, 43, 30],
            [2008, 7413, 11, 13],
            [2008, 7414, 16, 23],
            [2008, 7415, 11, 13],
            [2008, 7416, 28, 30],
            [2008, 7417, 22, 20],
            [2008, 7420, 26, 27],
            [2008, 7421, 26, 25],
            [2008, 7423, 62, 51],
            [2008, 7433, 74, 53],
            [2008, 7434, 95, 86],
            [2008, 7435, 35, 41],
            [2008, 7436, 45, 45],
            [2008, 7437, 25, 22],
            [2008, 7438, 75, 35],
            [2008, 7441, 37, 27],
            [2008, 7442, 42, 23],
            [2008, 7443, 34, 45],
            [2008, 7444, 52, 75],
            [2008, 7445, 35, 57],
            [2008, 7446, 43, 61],
            [2008, 7447, 20, 22],
            [2008, 7448, 51, 36],
            [2008, 7451, 12, 11],
            [2008, 7454, 27, 21],
            [2008, 7456, 30, 35],
            [2008, 7457, 37, 34],
            [2008, 7458, 28, 27],
            [2008, 7459, 47, 34],
            [2008, 7460, 54, 40],
            [2008, 7461, 31, 27],
            [2008, 7462, 39, 34],
            [2008, 7463, 51, 32],
            [2008, 7464, 81, 37],
            [2008, 7465, 38, 29],
            [2008, 7466, 44, 32],
            [2008, 7467, 39, 36],
            [2008, 7468, 33, 29],
            [2008, 7469, 52, 31],
            [2008, 7470, 52, 39],
            [2008, 7471, 55, 38],
            [2008, 7472, 66, 38],
            [2008, 7473, 33, 29],
            [2008, 7474, 46, 34],
            [2008, 7475, 49, 34],
            [2008, 7476, 44, 30],
            [2008, 7477, 30, 28],
            [2008, 7478, 47, 30],
            [2008, 7479, 33, 29],
            [2008, 7480, 45, 37],
            [2008, 7481, 32, 30],
            [2008, 7482, 44, 29],
            [2008, 7483, 37, 34],
            [2008, 7484, 35, 32],
            [2008, 7485, 66, 44],
            [2008, 7486, 41, 32],
            [2008, 7487, 50, 30],
            [2008, 7488, 38, 29],
            [2008, 7489, 63, 36],
            [2008, 7490, 30, 26],
            [2008, 7491, 41, 30],
            [2008, 7492, 51, 38],
            [2008, 7493, 42, 31],
            [2008, 7494, 59, 31],
            [2008, 7495, 39, 34],
            [2008, 7496, 78, 46],
            [2008, 7497, 37, 29],
            [2008, 7498, 32, 31],
            [2008, 7499, 33, 27],
            [2008, 7500, 44, 37],
            [2008, 7501, 53, 37],
            [2008, 7502, 43, 34],
            [2008, 7503, 44, 31],
            [2008, 7504, 30, 31],
            [2008, 7505, 52, 31],
            [2008, 7506, 67, 37],
            [2008, 7507, 44, 30],
            [2008, 7508, 46, 32],
            [2008, 7509, 46, 34],
            [2008, 7510, 37, 34],
            [2008, 7511, 41, 32],
            [2008, 7512, 37, 34],
            [2008, 7513, 38, 29],
            [2008, 7514, 63, 49],
            [2008, 7515, 47, 36],
            [2008, 7516, 37, 34],
            [2008, 7517, 80, 44],
            [2008, 7518, 51, 37],
            [2008, 7519, 30, 29],
            [2008, 7520, 40, 31],
            [2008, 7521, 29, 29],
            [2008, 7522, 54, 40],
            [2008, 7523, 40, 30],
            [2008, 7524, 45, 39],
            [2008, 7525, 37, 34],
            [2008, 7526, 38, 30],
            [2008, 7527, 37, 29],
            [2008, 7528, 46, 35],
            [2008, 7529, 62, 52],
            [2008, 7530, 46, 39],
            [2008, 7531, 34, 26],
            [2008, 7532, 50, 34],
            [2008, 7533, 50, 41],
            [2008, 7534, 56, 43],
            [2008, 7535, 42, 37],
            [2008, 7536, 37, 33],
            [2008, 7537, 59, 37],
            [2008, 7538, 39, 36],
            [2008, 7539, 53, 32],
            [2008, 7540, 46, 30],
            [2008, 7541, 47, 36],
            [2008, 7542, 74, 35],
            [2008, 7543, 39, 30],
            [2008, 7544, 41, 31],
            [2008, 7545, 42, 30],
            [2008, 7546, 37, 29],
            [2008, 7547, 37, 29],
            [2008, 7548, 47, 32],
            [2008, 7549, 44, 34],
            [2008, 7550, 31, 29],
            [2008, 7551, 39, 34],
            [2008, 7552, 58, 35],
            [2008, 7553, 42, 32],
            [2008, 7554, 48, 43],
            [2008, 7555, 84, 42],
            [2008, 7556, 45, 34],
            [2008, 7557, 72, 38],
            [2008, 7558, 36, 27],
            [2008, 7559, 42, 29],
            [2008, 7560, 39, 34],
            [2008, 7561, 65, 38],
            [2008, 7562, 54, 44],
            [2008, 7563, 52, 39],
            [2008, 7564, 50, 31],
            [2008, 7565, 39, 32],
            [2008, 7566, 35, 31],
            [2008, 7567, 80, 34],
            [2008, 7568, 42, 31],
            [2008, 7569, 38, 32],
            [2008, 7570, 33, 31],
            [2008, 7571, 33, 31],
            [2008, 7572, 27, 35],
            [2008, 7573, 37, 26],
            [2008, 7574, 35, 31],
            [2008, 7575, 41, 32],
            [2008, 7576, 50, 37],
            [2008, 7577, 52, 39],
            [2008, 7578, 54, 32],
            [2008, 7579, 44, 33],
            [2008, 7580, 52, 39],
            [2008, 7581, 41, 31],
            [2008, 7582, 47, 39],
            [2008, 7583, 53, 34],
            [2008, 7584, 42, 30],
            [2008, 7585, 41, 36],
            [2008, 7586, 61, 46],
            [2008, 7587, 42, 32],
            [2008, 7588, 42, 32],
            [2008, 7589, 61, 46],
            [2008, 7590, 46, 39],
            [2008, 7591, 38, 29],
            [2008, 7592, 42, 39],
            [2008, 7593, 46, 37],
            [2008, 7594, 38, 31],
            [2008, 7595, 51, 32],
            [2008, 7596, 44, 29],
            [2008, 7597, 49, 32],
            [2008, 7598, 50, 37],
            [2008, 7599, 49, 34],
            [2008, 7600, 37, 34],
            [2008, 7601, 34, 29],
            [2008, 7602, 48, 28],
            [2008, 7603, 48, 39],
            [2008, 7604, 57, 35],
            [2008, 7605, 44, 34],
            [2008, 7606, 44, 32],
            [2008, 7607, 46, 39],
            [2008, 7608, 39, 34],
            [2008, 7609, 26, 34],
            [2008, 7610, 43, 30],
            [2008, 7611, 32, 33],
            [2008, 7612, 47, 39],
            [2008, 7613, 46, 32],
            [2008, 7614, 37, 31],
            [2008, 7615, 52, 39],
            [2008, 7616, 40, 30],
            [2008, 7617, 42, 29],
            [2008, 7618, 45, 36],
            [2008, 7619, 39, 34],
            [2008, 7620, 41, 32],
            [2008, 7621, 51, 34],
            [2008, 7622, 44, 33],
            [2008, 7623, 35, 31],
            [2008, 7624, 60, 35],
            [2008, 7625, 33, 30],
            [2008, 7626, 47, 36],
            [2008, 7627, 41, 35],
            [2008, 7628, 52, 39],
            [2008, 7629, 30, 35],
            [2008, 7630, 46, 30],
            [2008, 7631, 42, 33],
            [2008, 7632, 49, 30],
            [2008, 7633, 41, 30],
            [2008, 7634, 12, 16],
            [2008, 7635, 11, 15],
            [2008, 7636, 14, 19],
            [2008, 7639, 10, 11],
            [2008, 7649, 8, 8],
            [2008, 7661, 10, 10],
            [2008, 7662, 17, 14],
            [2008, 7663, 12, 12],
            [2008, 7668, 13, 12],
            [2008, 7669, 10, 8],
            [2008, 7672, 9, 9],
            [2008, 7673, 8, 7],
            [2008, 7674, 20, 16],
            [2008, 7676, 6, 8],
            [2008, 7677, 5, 6],
            [2008, 7678, 10, 8],
            [2008, 7679, 11, 9],
            [2008, 7680, 26, 17],
            [2008, 7681, 5, 3],
            [2008, 7682, 16, 13],
            [2008, 7683, 3, 3],
            [2008, 7684, 17, 14],
            [2008, 7685, 11, 10],
            [2008, 7686, 19, 17],
            [2008, 7687, 5, 4],
            [2008, 7688, 14, 13],
            [2008, 7690, 7, 8],
            [2008, 7691, 24, 20],
            [2008, 7692, 10, 8],
            [2008, 7693, 9, 9],
            [2008, 7694, 9, 9],
            [2008, 7695, 25, 19],
            [2008, 7696, 3, 3],
            [2008, 7697, 16, 12],
            [2008, 7698, 9, 8],
            [2008, 7699, 12, 14],
            [2008, 7700, 12, 10],
            [2008, 7701, 9, 8],
            [2008, 7702, 22, 13],
            [2008, 7703, 11, 12],
            [2008, 7705, 23, 13],
            [2008, 7706, 11, 10],
            [2008, 7707, 11, 10],
            [2008, 7708, 9, 7],
            [2008, 7709, 11, 13],
            [2008, 7710, 6, 5],
            [2008, 7711, 14, 10],
            [2008, 7713, 25, 12],
            [2008, 7714, 10, 9],
            [2008, 7716, 16, 21],
            [2008, 7717, 35, 28],
            [2008, 7718, 25, 35],
            [2008, 7719, 16, 23],
            [2008, 7722, 26, 32],
            [2008, 7723, 18, 40],
            [2008, 7725, 20, 19],
            [2008, 7726, 23, 20],
            [2008, 7729, 25, 27],
            [2008, 7730, 18, 22],
            [2008, 7731, 29, 25],
            [2008, 7734, 25, 29],
            [2008, 7736, 15, 25],
            [2008, 7737, 30, 27],
            [2008, 7738, 16, 21],
            [2008, 7739, 58, 35],
            [2008, 7740, 40, 37],
            [2008, 7741, 72, 45],
            [2008, 7743, 23, 31],
            [2008, 7744, 53, 42],
            [2008, 7749, 26, 26],
            [2008, 7753, 33, 31],
            [2008, 7754, 25, 32],
            [2008, 7755, 18, 29],
            [2008, 7757, 32, 87],
            [2008, 7758, 60, 101],
            [2008, 7759, 28, 29],
            [2008, 7760, 75, 49],
            [2008, 7761, 18, 37],
            [2008, 7762, 60, 65],
            [2008, 7763, 10, 15],
            [2008, 7764, 12, 13],
            [2008, 7765, 12, 16],
            [2008, 7766, 9, 12],
            [2008, 7796, 80, 40],
            [2008, 7797, 94, 53],
            [2008, 7798, 71, 33],
            [2008, 7799, 66, 47],
            [2008, 7800, 70, 31],
            [2008, 7801, 98, 45],
            [2008, 7802, 23, 28],
            [2008, 7803, 169, 80],
            [2008, 7804, 93, 44],
            [2008, 7805, 72, 39],
            [2008, 7806, 92, 55],
            [2008, 7807, 75, 54],
            [2008, 7808, 92, 30],
            [2008, 7809, 83, 52],
            [2008, 7810, 88, 75],
            [2008, 7811, 150, 92],
            [2008, 7812, 41, 35],
            [2008, 7813, 60, 35],
            [2008, 7815, 57, 37],
            [2008, 7816, 98, 65],
            [2008, 7817, 35, 43],
            [2008, 7818, 48, 42],
            [2008, 7819, 47, 65],
            [2008, 7820, 58, 39],
            [2008, 7821, 121, 56],
            [2008, 7822, 51, 46],
            [2008, 7823, 34, 21],
            [2008, 7824, 158, 92],
            [2008, 7825, 77, 37],
            [2008, 7826, 53, 44],
            [2008, 7827, 98, 36],
            [2008, 7828, 95, 111],
            [2008, 7829, 58, 45],
            [2008, 7830, 67, 49],
            [2008, 7831, 65, 39],
            [2008, 7832, 105, 62],
            [2008, 7833, 48, 36],
            [2008, 7834, 94, 61],
            [2008, 7835, 58, 35],
            [2008, 7836, 90, 67],
            [2008, 7837, 40, 35],
            [2008, 7838, 100, 29],
            [2008, 7839, 88, 63],
            [2008, 7840, 135, 73],
            [2008, 7841, 65, 36],
            [2008, 7842, 31, 29],
            [2008, 7843, 39, 23],
            [2008, 7844, 100, 44],
            [2008, 7845, 30, 31],
            [2008, 7846, 99, 48],
            [2008, 7847, 75, 35],
            [2008, 7848, 99, 51],
            [2008, 7849, 198, 81],
            [2008, 7850, 58, 70],
            [2008, 7851, 77, 54],
            [2008, 7852, 48, 32],
            [2008, 7853, 33, 38],
            [2008, 7854, 24, 29],
            [2008, 7855, 43, 29],
            [2008, 7856, 131, 55],
            [2008, 7857, 72, 35],
            [2008, 7858, 29, 29],
            [2008, 7859, 88, 50],
            [2008, 7860, 89, 51],
            [2008, 7861, 45, 32],
            [2008, 7862, 173, 65],
            [2008, 7863, 70, 62],
            [2008, 7864, 27, 31],
            [2008, 7865, 58, 35],
            [2008, 7866, 99, 51],
            [2008, 7867, 43, 35],
            [2008, 7868, 42, 35],
            [2008, 7869, 71, 52],
            [2008, 7870, 46, 34],
            [2008, 7871, 55, 36],
            [2008, 7872, 103, 73],
            [2008, 7873, 102, 54],
            [2008, 7874, 42, 35],
            [2008, 7875, 99, 50],
            [2008, 7876, 99, 65],
            [2008, 7877, 101, 50],
            [2008, 7878, 152, 41],
            [2008, 7879, 101, 60],
            [2008, 7880, 65, 40],
            [2008, 7881, 40, 44],
            [2008, 7882, 30, 21],
            [2008, 7883, 58, 45],
            [2008, 7884, 40, 45],
            [2008, 7885, 55, 40],
            [2008, 7886, 51, 35],
            [2008, 7887, 60, 30],
            [2008, 7888, 100, 39],
            [2008, 7889, 167, 68],
            [2008, 7890, 43, 55],
            [2008, 7891, 52, 31],
            [2008, 7892, 30, 35],
            [2008, 7893, 30, 30],
            [2008, 7894, 96, 60],
            [2008, 7895, 62, 36],
            [2008, 7896, 147, 57],
            [2008, 7897, 100, 47],
            [2008, 7898, 20, 32],
            [2008, 7899, 43, 64],
            [2008, 7900, 99, 58],
            [2008, 7901, 100, 44],
            [2008, 7902, 71, 47],
            [2008, 7903, 91, 50],
            [2008, 7904, 62, 46],
            [2008, 7905, 55, 53],
            [2008, 7906, 92, 62],
            [2008, 7907, 100, 51],
            [2008, 7908, 120, 51],
            [2008, 7909, 68, 43],
            [2008, 7910, 60, 45],
            [2008, 7911, 71, 50],
            [2008, 7912, 101, 78],
            [2008, 7913, 100, 47],
            [2008, 7914, 76, 55],
            [2008, 7915, 88, 71],
            [2008, 7916, 101, 46],
            [2008, 7917, 61, 43],
            [2008, 7918, 52, 36],
            [2008, 7919, 38, 33],
            [2008, 7920, 70, 44],
            [2008, 7921, 46, 15],
            [2008, 7922, 28, 36],
            [2008, 7923, 92, 35],
            [2008, 7924, 40, 40],
            [2008, 7925, 46, 36],
            [2008, 7926, 257, 45],
            [2008, 7927, 43, 47],
            [2008, 7928, 23, 38],
            [2008, 7929, 100, 49],
            [2008, 7930, 80, 54],
            [2008, 7931, 43, 35],
            [2008, 7932, 42, 35],
            [2008, 7933, 86, 44],
            [2008, 7934, 62, 45],
            [2008, 7935, 101, 55],
            [2008, 7936, 102, 49],
            [2008, 7937, 54, 45],
            [2008, 7938, 20, 16],
            [2008, 7939, 92, 65],
            [2008, 7940, 93, 55],
            [2008, 7941, 92, 63],
            [2008, 7942, 91, 54],
            [2008, 7943, 46, 30],
            [2008, 7944, 29, 33],
            [2008, 7945, 92, 36],
            [2008, 7946, 41, 53],
            [2008, 7947, 68, 44],
            [2008, 7948, 41, 30],
            [2008, 7949, 57, 65],
            [2008, 7950, 51, 43],
            [2008, 7951, 109, 49],
            [2008, 7952, 52, 34],
            [2008, 7953, 39, 16],
            [2008, 7954, 86, 26],
            [2008, 7955, 145, 40],
            [2008, 7956, 87, 35],
            [2008, 7957, 94, 40],
            [2008, 7958, 103, 44],
            [2008, 7959, 97, 36],
            [2008, 7960, 47, 38],
            [2008, 7961, 96, 57],
            [2008, 7962, 171, 65],
            [2008, 7963, 22, 22],
            [2008, 7964, 58, 65],
            [2008, 7965, 98, 37],
            [2008, 7966, 123, 91],
            [2008, 7967, 61, 30],
            [2008, 7968, 97, 71],
            [2008, 7969, 85, 68],
            [2008, 7970, 96, 51],
            [2008, 7971, 26, 33],
            [2008, 7972, 40, 37],
            [2008, 7974, 58, 29],
            [2008, 7975, 188, 92],
            [2008, 7976, 159, 52],
            [2008, 7977, 47, 48],
            [2008, 7978, 94, 53],
            [2008, 7979, 94, 50],
            [2008, 7980, 96, 49],
            [2008, 7981, 63, 29],
            [2008, 7982, 65, 38],
            [2008, 7983, 76, 29],
            [2008, 7984, 90, 65],
            [2008, 7985, 49, 45],
            [2008, 7986, 70, 36],
            [2008, 7987, 55, 43],
            [2008, 7988, 28, 41],
            [2008, 7989, 94, 36],
            [2008, 7990, 76, 36],
            [2008, 7992, 85, 45],
            [2008, 7993, 85, 52],
            [2008, 7994, 47, 38],
            [2008, 7995, 176, 74],
            [2008, 7996, 84, 49],
            [2008, 7997, 122, 55],
            [2008, 7998, 44, 23],
            [2008, 7999, 118, 53],
            [2008, 8000, 83, 32],
            [2008, 8001, 196, 89],
            [2008, 8002, 76, 43],
            [2008, 8003, 29, 28],
            [2008, 8004, 82, 58],
            [2008, 8022, 19, 19],
            [2008, 8038, 28, 38],
            [2008, 8039, 22, 31],
            [2008, 8040, 18, 31],
            [2008, 8041, 7, 10],
            [2008, 8042, 7, 9],
            [2008, 8043, 10, 12],
            [2008, 8044, 10, 13],
            [2008, 8045, 5, 3],
            [2008, 8046, 5, 3],
            [2008, 8047, 5, 5],
            [2008, 8048, 14, 19],
            [2008, 8049, 11, 15],
            [2008, 8050, 9, 10],
            [2008, 8051, 16, 17],
            [2008, 8052, 26, 37],
            [2008, 8053, 18, 29],
            [2008, 8054, 13, 24],
            [2008, 8055, 26, 36],
            [2008, 8056, 33, 39],
            [2008, 8057, 18, 25],
            [2008, 8058, 14, 19],
            [2008, 8059, 20, 22],
            [2008, 8060, 20, 19],
            [2008, 8061, 41, 44],
            [2008, 8062, 44, 53],
            [2008, 8063, 9, 11],
            [2008, 8064, 12, 15],
            [2008, 8065, 12, 12],
            [2008, 8068, 7, 9],
            [2008, 8069, 7, 9],
            [2008, 8071, 37, 19],
            [2008, 8073, 15, 12],
            [2008, 8074, 9, 9],
            [2008, 8075, 16, 12],
            [2008, 8076, 36, 20],
            [2008, 8086, 14, 24],
            [2008, 8087, 15, 22],
            [2008, 8088, 16, 23],
            [2008, 8089, 20, 27],
            [2008, 8090, 18, 23],
            [2008, 8091, 21, 32],
            [2008, 8092, 17, 25],
            [2008, 8093, 18, 31],
            [2008, 8094, 14, 31],
            [2008, 8095, 17, 20],
            [2008, 8096, 19, 24],
            [2008, 8097, 17, 20],
            [2008, 8099, 21, 25],
            [2008, 8102, 17, 17],
            [2008, 8103, 23, 30],
            [2008, 8107, 16, 20],
            [2008, 8109, 19, 24],
            [2008, 8110, 16, 20],
            [2008, 8116, 40, 55],
            [2008, 8117, 43, 58],
            [2008, 8118, 20, 27],
            [2008, 8119, 14, 27],
            [2008, 8120, 26, 25],
            [2008, 8121, 22, 23],
            [2008, 8124, 20, 29],
            [2008, 8126, 20, 20],
            [2008, 8127, 26, 28],
            [2008, 8131, 27, 34],
            [2008, 8133, 18, 22],
            [2008, 8134, 28, 30],
            [2008, 8136, 17, 21],
            [2008, 8137, 25, 29],
            [2008, 8138, 27, 27],
            [2008, 8140, 33, 47],
            [2008, 8141, 33, 42],
            [2008, 8145, 20, 28],
            [2008, 8149, 17, 22],
            [2008, 8151, 17, 21],
            [2008, 8153, 27, 28],
            [2008, 8154, 19, 25],
            [2008, 8155, 51, 40],
            [2008, 8159, 26, 26],
            [2008, 8160, 22, 25],
            [2008, 8164, 18, 23],
            [2008, 8167, 37, 39],
            [2008, 8168, 36, 54],
            [2008, 8170, 18, 31],
            [2008, 8171, 24, 21],
            [2008, 8175, 15, 20],
            [2008, 8177, 25, 25],
            [2008, 8178, 21, 22],
            [2008, 8184, 24, 22],
            [2008, 8185, 19, 18],
            [2008, 8187, 28, 32],
            [2008, 8188, 16, 18],
            [2008, 8194, 31, 30],
            [2008, 8195, 20, 24],
            [2008, 8196, 14, 18],
            [2008, 8198, 30, 35],
            [2008, 8200, 18, 27],
            [2008, 8202, 34, 63],
            [2008, 8205, 32, 28],
            [2008, 8208, 18, 27],
            [2008, 8210, 16, 27],
            [2008, 8217, 20, 32],
            [2008, 8218, 13, 18],
            [2008, 8219, 38, 29],
            [2008, 8220, 27, 23],
            [2008, 8221, 48, 28],
            [2008, 8222, 23, 16],
            [2008, 8223, 18, 28],
            [2008, 8224, 45, 37],
            [2008, 8225, 12, 18],
            [2008, 8227, 23, 26],
            [2008, 8228, 24, 48],
            [2008, 8231, 18, 22],
            [2008, 8232, 67, 42],
            [2008, 8234, 18, 24],
            [2008, 8236, 20, 20],
            [2008, 8238, 43, 34],
            [2008, 8241, 14, 20],
            [2008, 8248, 15, 19],
            [2008, 8250, 22, 20],
            [2008, 8251, 19, 23],
            [2008, 8254, 29, 30],
            [2008, 8255, 58, 42],
            [2008, 8256, 18, 24],
            [2008, 8259, 18, 24],
            [2008, 8260, 20, 24],
            [2008, 8262, 27, 29],
            [2008, 8264, 27, 33],
            [2008, 8265, 46, 39],
            [2008, 8268, 16, 27],
            [2008, 8270, 15, 25],
            [2008, 8271, 26, 32],
            [2008, 8276, 25, 22],
            [2008, 8277, 17, 19],
            [2008, 8287, 18, 23],
            [2008, 8288, 18, 20],
            [2008, 8294, 38, 55],
            [2008, 8299, 25, 18],
            [2008, 8300, 34, 28],
            [2008, 8302, 19, 17],
            [2008, 8309, 12, 18],
            [2008, 8310, 23, 25],
            [2008, 8311, 11, 12],
            [2008, 8312, 12, 13],
            [2008, 8313, 11, 12],
            [2008, 8314, 12, 12],
            [2008, 8315, 16, 14],
            [2008, 8316, 11, 11],
            [2008, 8317, 27, 20],
            [2008, 8319, 18, 16],
            [2008, 8322, 26, 21],
            [2008, 8323, 23, 20],
            [2008, 8324, 37, 28],
            [2008, 8390, 14, 12],
            [2008, 8536, 18, 24],
            [2008, 8537, 31, 21],
            [2008, 8538, 33, 23],
            [2008, 8539, 33, 27],
            [2008, 8540, 25, 31],
            [2008, 8541, 30, 38],
            [2008, 8542, 23, 29],
            [2008, 8543, 17, 30],
            [2008, 8544, 24, 43],
            [2008, 8546, 23, 32],
            [2008, 8547, 30, 43],
            [2008, 8548, 15, 17],
            [2008, 8549, 13, 23],
            [2008, 8550, 18, 22],
            [2008, 8551, 26, 25],
            [2008, 8552, 25, 29],
            [2008, 8553, 21, 30],
            [2008, 8554, 33, 26],
            [2008, 8555, 26, 24],
            [2008, 8556, 21, 29],
            [2008, 8557, 25, 32],
            [2008, 8558, 22, 23],
            [2008, 8559, 21, 26],
            [2008, 8560, 37, 28],
            [2008, 8561, 23, 25],
            [2008, 8562, 56, 30],
            [2008, 8563, 30, 32],
            [2008, 8564, 118, 80],
            [2008, 8565, 10, 11],
            [2008, 8566, 21, 14],
            [2008, 8567, 20, 18],
            [2008, 8568, 16, 16],
            [2008, 8569, 19, 15],
            [2008, 8570, 10, 10],
            [2008, 8571, 13, 10],
            [2008, 8572, 9, 10],
            [2008, 8573, 13, 11],
            [2008, 8574, 15, 13],
            [2008, 8575, 10, 10],
            [2008, 8576, 22, 19],
            [2008, 8577, 12, 13],
            [2008, 8578, 21, 19],
            [2008, 8579, 14, 17],
            [2008, 8580, 18, 17],
            [2008, 8581, 12, 10],
            [2008, 8582, 16, 15],
            [2008, 8583, 20, 18],
            [2008, 8584, 12, 14],
            [2008, 8719, 24, 22],
            [2008, 8720, 25, 22],
            [2008, 8721, 26, 22],
            [2008, 8722, 24, 22],
            [2008, 8723, 26, 24],
            [2008, 8724, 24, 24],
            [2008, 8725, 26, 21],
            [2008, 8726, 25, 22],
            [2008, 8727, 22, 22],
            [2008, 8728, 19, 21],
            [2008, 8729, 23, 21],
            [2008, 8730, 19, 20],
            [2008, 8731, 20, 20],
            [2008, 8732, 25, 22],
            [2008, 8733, 26, 22],
            [2008, 8734, 26, 22],
            [2008, 8735, 21, 20],
            [2008, 8736, 21, 21],
            [2008, 8737, 20, 20],
            [2008, 8738, 21, 20],
            [2008, 8739, 21, 21],
            [2008, 8740, 21, 20],
            [2008, 8741, 23, 21],
            [2008, 8742, 23, 21],
            [2008, 8743, 22, 21],
            [2008, 8744, 23, 21],
            [2008, 8745, 24, 22],
            [2008, 8746, 26, 22],
            [2008, 8747, 27, 23],
            [2008, 8748, 26, 23],
            [2008, 8749, 23, 22],
            [2008, 8750, 22, 21],
            [2008, 8751, 22, 21],
            [2008, 8752, 21, 20],
            [2008, 8753, 19, 20],
            [2008, 8754, 21, 21],
            [2008, 8755, 20, 21],
            [2008, 8756, 26, 22],
            [2008, 8757, 19, 20],
            [2008, 8758, 21, 20],
            [2008, 8759, 22, 21],
            [2008, 8760, 29, 30],
            [2008, 8761, 22, 21],
            [2008, 8762, 26, 22],
            [2008, 8763, 18, 18],
            [2008, 8764, 28, 21],
            [2008, 8765, 23, 20],
            [2008, 8766, 26, 22],
            [2008, 8767, 26, 22],
            [2008, 8768, 26, 22],
            [2008, 8769, 27, 22],
            [2008, 8770, 26, 22],
            [2008, 8771, 26, 22],
            [2008, 8772, 26, 22],
            [2008, 8773, 21, 20],
            [2008, 8774, 21, 20],
            [2008, 8775, 21, 20],
            [2008, 8776, 21, 20],
            [2008, 8777, 22, 22],
            [2008, 8778, 28, 22],
            [2008, 8779, 10, 9],
            [2008, 8780, 12, 9],
            [2008, 8781, 15, 12],
            [2008, 8782, 12, 9],
            [2008, 8783, 10, 8],
            [2008, 8784, 12, 9],
            [2008, 8785, 7, 7],
            [2008, 8786, 9, 10],
            [2008, 8787, 10, 10],
            [2008, 8788, 12, 9],
            [2008, 8790, 10, 8],
            [2008, 8791, 6, 6],
            [2008, 8792, 11, 9],
            [2008, 8793, 8, 8],
            [2008, 8794, 8, 7],
            [2008, 8795, 9, 7],
            [2008, 8796, 13, 9],
            [2008, 8797, 15, 9],
            [2008, 8798, 9, 8],
            [2008, 8799, 13, 13],
            [2008, 8800, 10, 8],
            [2008, 8801, 10, 9],
            [2008, 8802, 8, 7],
            [2008, 8803, 8, 8],
            [2008, 8804, 7, 8],
            [2008, 8805, 9, 8],
            [2008, 8806, 9, 10],
            [2008, 8807, 10, 11],
            [2008, 8808, 9, 8],
            [2008, 8809, 6, 8],
            [2008, 8810, 10, 10],
            [2008, 8811, 7, 9],
            [2008, 8812, 11, 9],
            [2008, 8814, 6, 7],
            [2008, 8815, 9, 9],
            [2008, 8816, 10, 7],
            [2008, 8817, 12, 9],
            [2008, 8818, 38, 30],
            [2008, 8819, 35, 30],
            [2008, 8820, 39, 31],
            [2008, 8821, 38, 26],
            [2008, 8822, 39, 31],
            [2008, 8823, 31, 25],
            [2008, 8824, 22, 18],
            [2008, 8825, 34, 26],
            [2008, 8826, 22, 21],
            [2008, 8827, 37, 26],
            [2008, 8828, 37, 26],
            [2008, 8829, 38, 30],
            [2008, 8830, 27, 27],
            [2008, 8831, 33, 25],
            [2008, 8832, 19, 11],
            [2008, 8833, 30, 24],
            [2008, 8834, 33, 29],
            [2008, 8835, 25, 19],
            [2008, 8836, 38, 30],
            [2008, 8837, 30, 21],
            [2008, 8838, 38, 28],
            [2008, 8839, 24, 13],
            [2008, 8840, 34, 24],
            [2008, 8841, 23, 13],
            [2008, 8842, 15, 18],
            [2008, 8843, 19, 12],
            [2008, 8844, 26, 22],
            [2008, 8845, 14, 15],
            [2008, 8846, 31, 26],
            [2008, 8847, 18, 19],
            [2008, 8848, 38, 30],
            [2008, 8849, 26, 21],
            [2008, 8850, 31, 26],
            [2008, 8851, 22, 21],
            [2008, 8852, 32, 25],
            [2008, 8853, 14, 17],
            [2008, 8854, 31, 26],
            [2008, 8855, 20, 14],
            [2008, 8856, 30, 25],
            [2008, 8857, 21, 13],
            [2008, 8858, 27, 14],
            [2008, 8859, 38, 30],
            [2008, 8860, 27, 12],
            [2008, 8861, 31, 26],
            [2008, 8862, 24, 21],
            [2008, 8863, 31, 26],
            [2008, 8864, 21, 21],
            [2008, 8865, 31, 25],
            [2008, 8866, 22, 21],
            [2008, 8867, 38, 31],
            [2008, 8868, 37, 30],
            [2008, 8869, 39, 31],
            [2008, 8870, 38, 30],
            [2008, 8871, 32, 27],
            [2008, 8872, 35, 28],
            [2008, 8873, 26, 22],
            [2008, 8874, 30, 25],
            [2008, 8875, 31, 26],
            [2008, 8876, 18, 18],
            [2008, 8877, 38, 26],
            [2008, 8878, 22, 19],
            [2008, 8879, 18, 11],
            [2008, 8880, 30, 25],
            [2008, 8881, 39, 31],
            [2008, 8882, 26, 22],
            [2008, 8883, 39, 30],
            [2008, 8884, 17, 15],
            [2008, 8885, 39, 30],
            [2008, 8886, 33, 25],
            [2008, 8887, 19, 11],
            [2008, 8888, 37, 30],
            [2008, 8889, 38, 30],
            [2008, 8890, 13, 16],
            [2008, 8891, 32, 28],
            [2008, 8892, 14, 11],
            [2008, 8893, 31, 26],
            [2008, 8894, 19, 18],
            [2008, 8895, 15, 11],
            [2008, 8896, 24, 20],
            [2008, 8897, 15, 10],
            [2008, 8898, 19, 18],
            [2008, 8899, 38, 31],
            [2008, 8900, 31, 26],
            [2008, 8901, 35, 28],
            [2008, 8902, 26, 22],
            [2008, 8903, 25, 21],
            [2008, 8904, 33, 26],
            [2008, 8905, 23, 19],
            [2008, 8906, 30, 24],
            [2008, 8907, 19, 19],
            [2008, 8908, 28, 24],
            [2008, 8909, 21, 18],
            [2008, 8910, 21, 12],
            [2008, 8911, 21, 13],
            [2008, 8912, 38, 30],
            [2008, 8913, 26, 22],
            [2008, 8914, 38, 26],
            [2008, 8915, 27, 21],
            [2008, 8916, 38, 30],
            [2008, 8917, 31, 22],
            [2008, 8918, 38, 30],
            [2008, 8919, 30, 26],
            [2008, 8920, 31, 26],
            [2008, 8921, 33, 26],
            [2008, 8922, 30, 24],
            [2008, 8923, 24, 20],
            [2008, 8924, 14, 13],
            [2008, 8925, 11, 10],
            [2008, 8926, 14, 12],
            [2008, 8927, 15, 15],
            [2008, 8928, 13, 12],
            [2008, 8929, 10, 10],
            [2008, 8930, 9, 10],
            [2008, 8931, 13, 14],
            [2008, 8932, 16, 18],
            [2008, 8933, 23, 21],
            [2008, 8934, 26, 22],
            [2008, 8935, 32, 27],
            [2008, 8936, 25, 17],
            [2008, 8937, 31, 26],
            [2008, 8938, 24, 17],
            [2008, 8939, 31, 24],
            [2008, 8940, 18, 16],
            [2008, 8941, 30, 24],
            [2008, 8942, 18, 16],
            [2008, 8943, 26, 19],
            [2008, 8944, 31, 25],
            [2008, 8945, 22, 19],
            [2008, 8946, 31, 25],
            [2008, 8947, 21, 18],
            [2008, 8948, 30, 25],
            [2008, 8949, 25, 20],
            [2008, 8950, 22, 19],
            [2008, 8951, 27, 25],
            [2008, 8952, 23, 19],
            [2008, 8953, 29, 22],
            [2008, 8954, 24, 17],
            [2008, 8955, 38, 30],
            [2008, 8956, 26, 22],
            [2008, 8957, 26, 18],
            [2008, 8958, 39, 31],
            [2008, 8959, 26, 19],
            [2008, 8960, 38, 30],
            [2008, 8961, 26, 19],
            [2008, 8962, 32, 30],
            [2008, 8963, 30, 26],
            [2008, 8964, 19, 12],
            [2008, 8965, 35, 28],
            [2008, 8966, 35, 28],
            [2008, 8967, 38, 30],
            [2008, 8968, 30, 25],
            [2008, 8969, 18, 13],
            [2008, 8970, 38, 30],
            [2008, 8971, 27, 23],
            [2008, 8972, 16, 13],
            [2008, 8973, 35, 28],
            [2008, 8974, 12, 15],
            [2008, 8975, 38, 30],
            [2008, 8976, 39, 31],
            [2008, 8977, 26, 21],
            [2008, 8978, 14, 11],
            [2008, 8979, 37, 30],
            [2008, 8980, 30, 25],
            [2008, 8981, 29, 23],
            [2008, 8983, 34, 28],
            [2008, 8984, 26, 20],
            [2008, 8985, 33, 26],
            [2008, 8986, 25, 20],
            [2008, 8987, 27, 25],
            [2008, 8988, 18, 26],
            [2008, 8989, 34, 28],
            [2008, 8990, 23, 20],
            [2008, 8991, 32, 26],
            [2008, 8992, 18, 18],
            [2008, 8993, 33, 28],
            [2008, 8994, 35, 28],
            [2008, 8995, 35, 26],
            [2008, 8996, 38, 27],
            [2008, 8997, 22, 21],
            [2008, 8998, 27, 20],
            [2008, 8999, 19, 11],
            [2008, 9000, 39, 31],
            [2008, 9001, 35, 28],
            [2008, 9002, 35, 28],
            [2008, 9003, 23, 21],
            [2008, 9004, 38, 27],
            [2008, 9005, 20, 17],
            [2008, 9006, 34, 27],
            [2008, 9007, 26, 19],
            [2008, 9008, 35, 24],
            [2008, 9009, 31, 24],
            [2008, 9010, 25, 20],
            [2008, 9011, 19, 11],
            [2008, 9012, 27, 25],
            [2008, 9013, 20, 21],
            [2008, 9014, 36, 28],
            [2008, 9015, 19, 14],
            [2008, 9016, 19, 14],
            [2008, 9017, 38, 30],
            [2008, 9018, 26, 26],
            [2008, 9019, 30, 26],
            [2008, 9020, 18, 18],
            [2008, 9021, 34, 28],
            [2008, 9022, 24, 21],
            [2008, 9023, 31, 25],
            [2008, 9024, 36, 28],
            [2008, 9025, 30, 25],
            [2008, 9026, 28, 18],
            [2008, 9027, 27, 17],
            [2008, 9028, 35, 28],
            [2008, 9030, 35, 28],
            [2008, 9031, 32, 26],
            [2008, 9032, 41, 26],
            [2008, 9033, 30, 26],
            [2008, 9034, 39, 27],
            [2008, 9035, 35, 28],
            [2008, 9036, 35, 28],
            [2008, 9037, 16, 14],
            [2008, 9038, 27, 22],
            [2008, 9039, 15, 17],
            [2008, 9040, 34, 28],
            [2008, 9041, 23, 19],
            [2008, 9042, 35, 28],
            [2008, 9043, 33, 28],
            [2008, 9044, 21, 14],
            [2008, 9045, 33, 25],
            [2008, 9046, 25, 19],
            [2008, 9047, 33, 27],
            [2008, 9048, 28, 21],
            [2008, 9049, 39, 30],
            [2008, 9050, 26, 20],
            [2008, 9051, 38, 26],
            [2008, 9052, 38, 26],
            [2008, 9053, 31, 30],
            [2008, 9054, 35, 27],
            [2008, 9055, 38, 21],
            [2008, 9056, 39, 25],
            [2008, 9057, 38, 29],
            [2008, 9058, 25, 17],
            [2008, 9059, 39, 30],
            [2008, 9060, 38, 28],
            [2008, 9061, 40, 31],
            [2008, 9062, 21, 21],
            [2008, 9063, 33, 24],
            [2008, 9064, 16, 18],
            [2008, 9065, 22, 21],
            [2008, 9066, 16, 17],
            [2008, 9067, 28, 21],
            [2008, 9068, 26, 18],
            [2008, 9069, 33, 29],
            [2008, 9070, 17, 17],
            [2008, 9071, 25, 26],
            [2008, 9072, 13, 16],
            [2008, 9073, 14, 16],
            [2008, 9074, 29, 27],
            [2008, 9075, 20, 19],
            [2008, 9076, 23, 25],
            [2008, 9077, 34, 22],
            [2008, 9078, 26, 16],
            [2008, 9079, 31, 26],
            [2008, 9080, 21, 18],
            [2008, 9081, 27, 21],
            [2008, 9082, 38, 30],
            [2008, 9083, 30, 24],
            [2008, 9084, 37, 27],
            [2008, 9085, 19, 19],
            [2008, 9086, 35, 28],
            [2008, 9087, 38, 27],
            [2008, 9088, 26, 17],
            [2008, 9089, 16, 14],
            [2008, 9090, 21, 18],
            [2008, 9091, 21, 15],
            [2008, 9092, 38, 25],
            [2008, 9093, 20, 19],
            [2008, 9094, 38, 31],
            [2008, 9095, 14, 12],
            [2008, 9096, 26, 29],
            [2008, 9097, 27, 21],
            [2008, 9098, 35, 23],
            [2008, 9099, 19, 13],
            [2008, 9100, 33, 22],
            [2008, 9101, 15, 17],
            [2008, 9102, 35, 28],
            [2008, 9103, 23, 21],
            [2008, 9104, 35, 28],
            [2008, 9105, 21, 14],
            [2008, 9106, 28, 15],
            [2008, 9107, 33, 25],
            [2008, 9108, 34, 25],
            [2008, 9109, 31, 26],
            [2008, 9110, 32, 28],
            [2008, 9111, 25, 13],
            [2008, 9112, 38, 30],
            [2008, 9113, 32, 27],
            [2008, 9114, 36, 25],
            [2008, 9115, 14, 14],
            [2008, 9116, 22, 15],
            [2008, 9117, 27, 12],
            [2008, 9118, 28, 26],
            [2008, 9119, 17, 12],
            [2008, 9120, 22, 19],
            [2008, 9121, 30, 25],
            [2008, 9122, 37, 26],
            [2008, 9123, 26, 18],
            [2008, 9124, 38, 30],
            [2008, 9125, 16, 23],
            [2008, 9126, 35, 29],
            [2008, 9127, 28, 25],
            [2008, 9128, 34, 26],
            [2008, 9129, 31, 26],
            [2008, 9130, 39, 27],
            [2008, 9131, 25, 25],
            [2008, 9132, 28, 27],
            [2008, 9133, 26, 18],
            [2008, 9134, 27, 26],
            [2008, 9135, 40, 28],
            [2008, 9136, 29, 28],
            [2008, 9137, 16, 11],
            [2008, 9138, 17, 15],
            [2008, 9139, 27, 24],
            [2008, 9140, 28, 27],
            [2008, 9141, 25, 23],
            [2008, 9142, 34, 30],
            [2008, 9143, 19, 19],
            [2008, 9144, 23, 26],
            [2008, 9145, 31, 26],
            [2008, 9146, 39, 30],
            [2008, 9166, 14, 14],
            [2008, 9194, 24, 24],
            [2008, 9195, 26, 25],
            [2008, 9196, 27, 20],
            [2008, 9198, 22, 19],
            [2008, 9199, 24, 20],
            [2008, 9200, 22, 19],
            [2008, 9201, 30, 23],
            [2008, 9202, 28, 24],
            [2008, 9203, 10, 10],
            [2008, 9204, 9, 10],
            [2008, 9209, 23, 20],
            [2008, 9211, 28, 26],
            [2008, 9214, 31, 26],
            [2008, 9218, 21, 18],
            [2008, 9226, 36, 24],
            [2008, 9227, 33, 26],
            [2008, 9228, 28, 28],
            [2008, 9229, 29, 27],
            [2008, 9230, 30, 23],
            [2008, 9232, 30, 24],
            [2008, 9233, 26, 25],
            [2008, 9234, 26, 25],
            [2008, 9235, 26, 25],
            [2008, 9237, 25, 17],
            [2008, 9238, 28, 25],
            [2008, 9242, 30, 25],
            [2008, 9244, 32, 26],
            [2008, 9245, 23, 22],
            [2008, 9248, 30, 23],
            [2008, 9254, 63, 58],
            [2008, 9255, 42, 31],
            [2008, 9257, 40, 35],
            [2008, 9258, 29, 68],
            [2008, 9259, 34, 35],
            [2008, 9260, 33, 30],
            [2008, 9261, 42, 48],
            [2008, 9263, 32, 32],
            [2008, 9264, 29, 30],
            [2008, 9265, 29, 29],
            [2008, 9266, 49, 48],
            [2008, 9267, 49, 44],
            [2008, 9268, 51, 47],
            [2008, 9269, 63, 55],
            [2008, 9270, 60, 58],
            [2008, 9271, 61, 56],
            [2008, 9272, 53, 55],
            [2008, 9273, 67, 64],
            [2008, 9274, 64, 54],
            [2008, 9275, 36, 37],
            [2008, 9276, 67, 55],
            [2008, 9277, 59, 45],
            [2008, 9278, 63, 56],
            [2008, 9279, 69, 63],
            [2008, 9280, 37, 38],
            [2008, 9281, 65, 50],
            [2008, 9282, 62, 54],
            [2008, 9283, 49, 45],
            [2008, 9284, 78, 69],
            [2008, 9285, 45, 43],
            [2008, 9286, 74, 69],
            [2008, 9287, 76, 68],
            [2008, 9288, 51, 34],
            [2008, 9289, 66, 61],
            [2008, 9290, 59, 66],
            [2008, 9291, 78, 71],
            [2008, 9292, 61, 56],
            [2008, 9293, 59, 42],
            [2008, 9294, 41, 85],
            [2008, 9295, 50, 69],
            [2008, 9296, 61, 79],
            [2008, 9297, 98, 92],
            [2008, 9298, 47, 47],
            [2008, 9299, 81, 86],
            [2008, 9300, 72, 65],
            [2008, 9301, 48, 47],
            [2008, 9302, 94, 87],
            [2008, 9303, 71, 71],
            [2008, 9304, 74, 125],
            [2008, 9305, 73, 73],
            [2008, 9306, 96, 90],
            [2008, 9307, 40, 46],
            [2008, 9308, 51, 61],
            [2008, 9309, 46, 103],
            [2008, 9310, 57, 98],
            [2008, 9311, 43, 43],
            [2008, 9312, 57, 58],
            [2008, 9313, 53, 58],
            [2008, 9314, 71, 70],
            [2008, 9315, 31, 31],
            [2008, 9316, 37, 25],
            [2008, 9317, 12, 14],
            [2008, 9318, 13, 15],
            [2008, 9319, 28, 32],
            [2008, 9320, 32, 31],
            [2008, 9327, 12, 14],
            [2008, 9328, 18, 18],
            [2008, 9329, 27, 27],
            [2008, 9330, 31, 31],
            [2008, 9331, 22, 21],
            [2008, 9332, 22, 25],
            [2008, 9333, 11, 14],
            [2008, 9334, 10, 12],
            [2008, 9335, 22, 21],
            [2008, 9336, 20, 19],
            [2008, 9337, 13, 16],
            [2008, 9338, 10, 11],
            [2008, 9339, 15, 17],
            [2008, 9340, 35, 29],
            [2008, 9341, 17, 18],
            [2008, 9342, 24, 24],
            [2008, 9343, 8, 9],
            [2008, 9344, 15, 15],
            [2008, 9345, 16, 20],
            [2008, 9346, 12, 13],
            [2008, 9347, 10, 11],
            [2008, 9348, 20, 19],
            [2008, 9349, 16, 19],
            [2008, 9350, 31, 31],
            [2008, 9351, 27, 21],
            [2008, 9352, 31, 27],
            [2008, 9353, 15, 17],
            [2008, 9354, 21, 20],
            [2008, 9355, 17, 15],
            [2008, 9356, 24, 22],
            [2008, 9357, 15, 17],
            [2008, 9358, 19, 18],
            [2008, 9359, 16, 17],
            [2008, 9360, 22, 26],
            [2008, 9361, 20, 18],
            [2008, 9362, 27, 26],
            [2008, 9363, 20, 19],
            [2008, 9364, 30, 22],
            [2008, 9365, 16, 17],
            [2008, 9366, 38, 31],
            [2008, 9367, 19, 20],
            [2008, 9368, 39, 32],
            [2008, 9369, 23, 22],
            [2008, 9370, 15, 16],
            [2008, 9371, 22, 21],
            [2008, 9372, 38, 30],
            [2008, 9373, 18, 18],
            [2008, 9374, 29, 28],
            [2008, 9375, 17, 19],
            [2008, 9376, 38, 31],
            [2008, 9377, 11, 12],
            [2008, 9378, 16, 17],
            [2008, 9379, 23, 28],
            [2008, 9380, 20, 23],
            [2008, 9381, 39, 31],
            [2008, 9382, 21, 26],
            [2008, 9383, 38, 30],
            [2008, 9384, 15, 15],
            [2008, 9385, 15, 16],
            [2008, 9386, 14, 14],
            [2008, 9387, 13, 13],
            [2008, 9388, 12, 14],
            [2008, 9389, 15, 14],
            [2008, 9390, 16, 18],
            [2008, 9391, 20, 20],
            [2008, 9392, 17, 17],
            [2008, 9393, 20, 18],
            [2008, 9394, 12, 11],
            [2008, 9395, 17, 18],
            [2008, 9396, 17, 20],
            [2008, 9397, 34, 29],
            [2008, 9398, 29, 35],
            [2008, 9399, 36, 29],
            [2008, 9400, 20, 19],
            [2008, 9401, 63, 64],
            [2008, 9402, 34, 25],
            [2008, 9403, 50, 65],
            [2008, 9406, 107, 66],
            [2008, 9411, 65, 64],
            [2008, 9416, 46, 45],
            [2008, 9417, 65, 65],
            [2008, 9420, 65, 46],
            [2008, 9423, 55, 55],
            [2008, 9428, 65, 65],
            [2008, 9431, 65, 65],
            [2008, 9436, 64, 66],
            [2008, 9443, 65, 65],
            [2008, 9444, 75, 55],
            [2008, 9451, 110, 66],
            [2008, 9452, 65, 83],
            [2008, 9453, 65, 63],
            [2008, 9456, 64, 66],
            [2008, 9457, 50, 82],
            [2008, 9458, 65, 65],
            [2008, 9465, 37, 31],
            [2008, 9470, 65, 65],
            [2008, 9473, 35, 31],
            [2008, 9474, 96, 67],
            [2008, 9477, 34, 33],
            [2008, 9478, 100, 60],
            [2008, 9487, 23, 25],
            [2008, 9488, 43, 34],
            [2008, 9491, 28, 27],
            [2008, 9492, 49, 46],
            [2008, 9497, 36, 25],
            [2008, 9498, 65, 43],
            [2008, 9509, 64, 55],
            [2008, 9519, 21, 15],
            [2008, 9520, 103, 75],
            [2008, 9525, 17, 16],
            [2008, 9526, 42, 29],
            [2008, 9529, 27, 20],
            [2008, 9530, 78, 34],
            [2008, 9531, 28, 26],
            [2008, 9532, 76, 60],
            [2008, 9539, 37, 26],
            [2008, 9540, 81, 60],
            [2008, 9541, 21, 25],
            [2008, 9542, 57, 30],
            [2008, 9543, 28, 25],
            [2008, 9544, 61, 39],
            [2008, 9547, 21, 21],
            [2008, 9548, 59, 31],
            [2008, 9549, 18, 15],
            [2008, 9550, 70, 30],
            [2008, 9551, 31, 27],
            [2008, 9552, 85, 65],
            [2008, 9553, 28, 26],
            [2008, 9554, 41, 35],
            [2008, 9555, 37, 76],
            [2008, 9556, 104, 88],
            [2008, 9557, 33, 28],
            [2008, 9558, 107, 67],
            [2008, 9561, 27, 15],
            [2008, 9562, 80, 60],
            [2008, 9581, 31, 31],
            [2008, 9582, 60, 45],
            [2008, 9593, 31, 29],
            [2008, 9594, 55, 66],
            [2008, 9595, 28, 18],
            [2008, 9596, 67, 53],
            [2008, 9597, 21, 13],
            [2008, 9598, 76, 35],
            [2008, 9609, 31, 30],
            [2008, 9610, 87, 36],
            [2008, 9611, 37, 29],
            [2008, 9612, 74, 45],
            [2008, 9613, 40, 83],
            [2008, 9614, 117, 88],
            [2008, 9617, 13, 12],
            [2008, 9618, 88, 45],
            [2008, 9619, 21, 16],
            [2008, 9620, 17, 15],
            [2008, 9633, 36, 31],
            [2008, 9634, 64, 60],
            [2008, 9639, 16, 17],
            [2008, 9640, 97, 53],
            [2008, 9641, 37, 26],
            [2008, 9642, 117, 65],
            [2008, 9643, 21, 21],
            [2008, 9644, 96, 49],
            [2008, 9651, 75, 55],
            [2008, 9652, 70, 55],
            [2008, 9653, 37, 35],
            [2008, 9654, 45, 31],
            [2008, 9661, 70, 45],
            [2008, 9662, 65, 51],
            [2008, 9663, 64, 51],
            [2008, 9664, 53, 42],
            [2008, 9665, 35, 41],
            [2008, 9666, 55, 38],
            [2008, 9667, 18, 18],
            [2008, 9668, 30, 26],
            [2008, 9670, 65, 47],
            [2008, 9673, 41, 31],
            [2008, 9674, 43, 33],
            [2008, 9675, 20, 24],
            [2008, 9676, 31, 31],
            [2008, 9677, 16, 21],
            [2008, 9678, 21, 25],
            [2008, 9681, 60, 45],
            [2008, 9682, 71, 45],
            [2008, 9687, 31, 35],
            [2008, 9689, 25, 21],
            [2008, 9690, 46, 30],
            [2008, 9691, 25, 24],
            [2008, 9692, 42, 30],
            [2008, 9693, 22, 25],
            [2008, 9694, 30, 31],
            [2008, 9695, 46, 45],
            [2008, 9696, 64, 35],
            [2008, 9699, 20, 23],
            [2008, 9700, 55, 35],
            [2008, 9701, 21, 20],
            [2008, 9702, 55, 37],
            [2008, 9704, 50, 32],
            [2008, 9705, 31, 37],
            [2008, 9706, 65, 47],
            [2008, 9709, 26, 21],
            [2008, 9710, 25, 21],
            [2008, 9711, 17, 22],
            [2008, 9712, 18, 25],
            [2008, 9713, 31, 35],
            [2008, 9714, 37, 45],
            [2008, 9715, 60, 49],
            [2008, 9716, 46, 45],
            [2008, 9717, 38, 37],
            [2008, 9718, 20, 24],
            [2008, 9720, 85, 75],
            [2008, 9721, 75, 41],
            [2008, 9722, 25, 39],
            [2008, 9723, 70, 45],
            [2008, 9724, 55, 50],
            [2008, 9725, 75, 47],
            [2008, 9726, 26, 26],
            [2008, 9727, 41, 41],
            [2008, 9728, 31, 25],
            [2008, 9729, 31, 30],
            [2008, 9730, 29, 43],
            [2008, 9731, 71, 61],
            [2008, 9735, 34, 36],
            [2008, 9736, 34, 35],
            [2008, 9737, 31, 21],
            [2008, 9738, 43, 43],
            [2008, 9739, 25, 34],
            [2008, 9740, 98, 90],
            [2008, 9741, 77, 78],
            [2008, 9742, 40, 52],
            [2008, 9743, 43, 35],
            [2008, 9744, 65, 47],
            [2008, 9745, 35, 28],
            [2008, 9746, 41, 28],
            [2008, 9747, 35, 39],
            [2008, 9748, 40, 45],
            [2008, 9751, 31, 27],
            [2008, 9752, 36, 35],
            [2008, 9755, 26, 33],
            [2008, 9756, 33, 38],
            [2008, 9757, 27, 21],
            [2008, 9758, 25, 21],
            [2008, 9759, 14, 14],
            [2008, 9760, 34, 24],
            [2008, 9761, 39, 30],
            [2008, 9762, 32, 21],
            [2008, 9763, 25, 18],
            [2008, 9764, 26, 18],
            [2008, 9765, 30, 22],
            [2008, 9766, 22, 18],
            [2008, 9767, 45, 27],
            [2008, 9768, 23, 20],
            [2008, 9769, 17, 16],
            [2008, 9770, 36, 27],
            [2008, 9771, 40, 28],
            [2008, 9772, 33, 26],
            [2008, 9773, 32, 25],
            [2008, 9774, 27, 17],
            [2008, 9775, 22, 18],
            [2008, 9776, 35, 23],
            [2008, 9777, 34, 24],
            [2008, 9778, 36, 28],
            [2008, 9779, 32, 28],
            [2008, 9780, 31, 24],
            [2008, 9781, 35, 24],
            [2008, 9782, 52, 32],
            [2008, 9783, 50, 33],
            [2008, 9784, 22, 18],
            [2008, 9785, 25, 19],
            [2008, 9786, 15, 12],
            [2008, 9787, 26, 22],
            [2008, 9788, 36, 27],
            [2008, 9789, 29, 22],
            [2008, 9790, 26, 21],
            [2008, 9791, 50, 26],
            [2008, 9792, 42, 32],
            [2008, 9793, 14, 11],
            [2008, 9794, 12, 11],
            [2008, 9795, 12, 12],
            [2008, 9796, 16, 14],
            [2008, 9797, 13, 11],
            [2008, 9798, 13, 12],
            [2008, 9799, 42, 36],
            [2008, 9800, 17, 17],
            [2008, 9801, 16, 14],
            [2008, 9802, 15, 14],
            [2008, 9803, 9, 8],
            [2008, 9804, 14, 11],
            [2008, 9805, 26, 21],
            [2008, 9806, 19, 16],
            [2008, 9807, 21, 15],
            [2008, 9808, 65, 47],
            [2008, 9809, 33, 18],
            [2008, 9811, 33, 22],
            [2008, 9812, 39, 27],
            [2008, 9813, 53, 33],
            [2008, 9814, 18, 12],
            [2008, 9815, 31, 21],
            [2008, 9816, 42, 21],
            [2008, 9817, 22, 13],
            [2008, 9818, 44, 22],
            [2008, 9819, 55, 42],
            [2008, 9820, 57, 44],
            [2008, 9821, 34, 29],
            [2008, 9822, 20, 17],
            [2008, 9823, 25, 19],
            [2008, 9824, 29, 31],
            [2008, 9825, 16, 13],
            [2008, 9826, 35, 27],
            [2008, 9827, 34, 25],
            [2008, 9828, 35, 26],
            [2008, 9829, 30, 21],
            [2008, 9830, 28, 22],
            [2008, 9831, 30, 21],
            [2008, 9832, 36, 23],
            [2008, 9833, 25, 21],
            [2008, 9834, 56, 38],
            [2008, 9835, 26, 25],
            [2008, 9836, 44, 40],
            [2008, 9837, 26, 22],
            [2008, 9838, 41, 34],
            [2008, 9839, 14, 14],
            [2008, 9840, 60, 37],
            [2008, 9841, 51, 33],
            [2008, 9842, 25, 18],
            [2008, 9843, 24, 22],
            [2008, 9844, 27, 24],
            [2008, 9845, 27, 23],
            [2008, 9846, 23, 17],
            [2008, 9847, 13, 10],
            [2008, 9848, 23, 16],
            [2008, 9849, 25, 22],
            [2008, 9850, 20, 15],
            [2008, 9851, 21, 15],
            [2008, 9852, 18, 16],
            [2008, 9853, 21, 17],
            [2008, 9854, 13, 11],
            [2008, 9855, 28, 26],
            [2008, 9856, 16, 16],
            [2008, 9857, 13, 11],
            [2008, 9858, 30, 27],
            [2008, 9859, 46, 32],
            [2008, 9860, 55, 32],
            [2008, 9861, 41, 38],
            [2008, 9862, 24, 22],
            [2008, 9863, 31, 22],
            [2008, 9864, 45, 26],
            [2008, 9865, 32, 24],
            [2008, 9866, 43, 31],
            [2008, 9867, 17, 15],
            [2008, 9868, 33, 24],
            [2008, 9869, 34, 27],
            [2008, 9870, 34, 32],
            [2008, 9871, 33, 24],
            [2008, 9872, 25, 21],
            [2008, 9873, 39, 30],
            [2008, 9874, 32, 26],
            [2008, 9875, 22, 20],
            [2008, 9876, 22, 20],
            [2008, 9877, 31, 32],
            [2008, 9878, 30, 23],
            [2008, 9879, 31, 27],
            [2008, 9880, 32, 31],
            [2008, 9881, 50, 35],
            [2008, 9882, 39, 34],
            [2008, 9883, 27, 19],
            [2008, 9884, 26, 25],
            [2008, 9885, 31, 22],
            [2008, 9886, 30, 21],
            [2008, 9887, 30, 22],
            [2008, 9888, 37, 28],
            [2008, 9889, 35, 26],
            [2008, 9890, 31, 25],
            [2008, 9891, 21, 19],
            [2008, 9892, 27, 22],
            [2008, 9893, 29, 16],
            [2008, 9894, 35, 23],
            [2008, 9895, 24, 15],
            [2008, 9896, 10, 10],
            [2008, 9897, 29, 24],
            [2008, 9898, 27, 22],
            [2008, 9899, 21, 18],
            [2008, 9900, 40, 38],
            [2008, 9901, 35, 27],
            [2008, 9902, 53, 42],
            [2008, 9903, 42, 35],
            [2008, 9904, 39, 33],
            [2008, 9905, 42, 35],
            [2008, 9906, 34, 22],
            [2008, 9907, 24, 23],
            [2008, 9908, 44, 31],
            [2008, 9909, 15, 14],
            [2008, 9910, 40, 34],
            [2008, 9911, 45, 32],
            [2008, 9912, 40, 32],
            [2008, 9913, 20, 18],
            [2008, 9914, 26, 22],
            [2008, 9915, 24, 21],
            [2008, 9916, 29, 23],
            [2008, 9917, 26, 27],
            [2008, 9918, 50, 35],
            [2008, 9919, 35, 30],
            [2008, 9920, 60, 47],
            [2008, 9921, 24, 22],
            [2008, 9922, 19, 13],
            [2008, 9923, 27, 17],
            [2008, 9924, 34, 23],
            [2008, 9925, 38, 42],
            [2008, 9926, 41, 33],
            [2008, 9927, 26, 25],
            [2008, 9928, 41, 26],
            [2008, 9929, 39, 30],
            [2008, 9930, 31, 23],
            [2008, 9931, 45, 31],
            [2008, 9932, 64, 49],
            [2008, 9933, 40, 39],
            [2008, 9934, 35, 28],
            [2008, 9935, 30, 27],
            [2008, 9936, 28, 26],
            [2008, 9937, 24, 33],
            [2008, 9938, 14, 13],
            [2008, 9939, 38, 35],
            [2008, 9940, 31, 30],
            [2008, 9941, 31, 20],
            [2008, 9942, 17, 14],
            [2008, 9943, 43, 35],
            [2008, 9944, 35, 30],
            [2008, 9945, 45, 29],
            [2008, 9946, 33, 22],
            [2008, 9947, 34, 24],
            [2008, 9948, 75, 52],
            [2008, 9949, 52, 35],
            [2008, 9950, 40, 30],
            [2008, 9951, 27, 26],
            [2008, 9952, 39, 23],
            [2008, 9953, 19, 17],
            [2008, 9954, 75, 53],
            [2008, 9955, 19, 16],
            [2008, 9956, 37, 26],
            [2008, 9957, 56, 34],
            [2008, 9958, 27, 19],
            [2008, 9959, 65, 37],
            [2008, 9960, 36, 21],
            [2008, 9961, 33, 28],
            [2008, 9962, 26, 24],
            [2008, 9963, 56, 31],
            [2008, 9964, 34, 24],
            [2008, 9965, 30, 17],
            [2008, 9966, 47, 28],
            [2008, 9967, 61, 29],
            [2008, 9968, 30, 26],
            [2008, 9969, 20, 16],
            [2008, 9970, 43, 26],
            [2008, 9971, 29, 21],
            [2008, 9972, 65, 34],
            [2008, 9973, 36, 27],
            [2008, 9974, 30, 19],
            [2008, 9975, 60, 30],
            [2008, 9976, 55, 33],
            [2008, 9977, 28, 18],
            [2008, 9978, 43, 21],
            [2008, 9979, 58, 30],
            [2008, 9980, 40, 21],
            [2008, 9981, 21, 14],
            [2008, 9982, 14, 12],
            [2008, 9983, 45, 24],
            [2008, 9984, 30, 21],
            [2008, 9985, 30, 19],
            [2008, 9986, 30, 21],
            [2008, 9987, 36, 29],
            [2008, 9988, 55, 38],
            [2008, 9989, 29, 24],
            [2008, 9990, 25, 21],
            [2008, 9991, 32, 26],
            [2008, 9992, 31, 32],
            [2008, 9993, 27, 26],
            [2008, 9994, 21, 18],
            [2008, 9995, 33, 27],
            [2008, 9996, 28, 24],
            [2008, 9997, 14, 21],
            [2008, 9998, 15, 12],
            [2008, 9999, 22, 24],
            [2008, 10000, 21, 16],
            [2008, 10001, 15, 12],
            [2008, 10002, 14, 12],
            [2008, 10003, 38, 24],
            [2008, 10004, 29, 20],
            [2008, 10005, 21, 17],
            [2008, 10006, 25, 16],
            [2008, 10007, 43, 36],
            [2008, 10008, 41, 37],
            [2008, 10009, 41, 26],
            [2008, 10017, 33, 25],
            [2008, 10018, 48, 30],
            [2008, 10032, 65, 40],
            [2008, 10037, 59, 35],
            [2008, 10038, 36, 23],
            [2008, 10046, 45, 31],
            [2008, 10047, 38, 25],
            [2008, 10049, 31, 29],
            [2008, 10056, 42, 48],
            [2008, 10057, 56, 47],
            [2008, 10058, 25, 28],
            [2008, 10059, 46, 28],
            [2008, 10065, 31, 46],
            [2008, 10066, 45, 63],
            [2008, 10071, 41, 31],
            [2008, 10076, 41, 27],
            [2008, 10091, 42, 30],
            [2008, 10094, 40, 41],
            [2008, 10098, 50, 35],
            [2008, 10101, 57, 50],
            [2008, 10102, 56, 36],
            [2008, 10103, 50, 47],
            [2008, 10109, 135, 57],
            [2008, 10110, 46, 43],
            [2008, 10111, 80, 46],
            [2008, 10112, 75, 44],
            [2008, 10113, 85, 59],
            [2008, 10114, 65, 36],
            [2008, 10117, 53, 43],
            [2008, 10122, 67, 55],
            [2008, 10125, 60, 43],
            [2008, 10127, 38, 28],
            [2008, 10128, 46, 36],
            [2008, 10131, 45, 37],
            [2008, 10132, 46, 30],
            [2008, 10133, 60, 36],
            [2008, 10139, 51, 40],
            [2008, 10144, 46, 25],
            [2008, 10180, 37, 23],
            [2008, 10183, 31, 22],
            [2008, 10184, 39, 24],
            [2008, 10185, 21, 17],
            [2008, 10186, 21, 18],
            [2008, 10187, 15, 14],
            [2008, 10188, 42, 22],
            [2008, 10189, 36, 26],
            [2008, 10190, 15, 12],
            [2008, 10191, 33, 22],
            [2008, 10192, 25, 18],
            [2008, 10193, 16, 15],
            [2008, 10194, 13, 10],
            [2008, 10195, 12, 10],
            [2008, 10514, 15, 18],
            [2008, 10515, 15, 19],
            [2008, 10516, 14, 17],
            [2008, 10518, 13, 13],
            [2008, 10519, 16, 13],
            [2008, 10520, 9, 9],
            [2008, 10521, 13, 16],
            [2008, 10522, 15, 17],
            [2008, 10523, 13, 17],
            [2008, 10524, 20, 19],
            [2008, 10525, 14, 17],
            [2008, 10526, 13, 16],
            [2008, 10527, 11, 12],
            [2008, 10528, 16, 17],
            [2008, 10529, 16, 17],
            [2008, 10530, 13, 17],
            [2008, 10531, 13, 15],
            [2008, 10532, 22, 21],
            [2008, 10533, 31, 26],
            [2008, 10534, 20, 13],
            [2008, 10535, 31, 25],
            [2008, 10536, 16, 19],
            [2008, 10537, 22, 20],
            [2008, 10538, 28, 24],
            [2008, 10539, 17, 17],
            [2008, 10540, 31, 25],
            [2008, 10541, 31, 26],
            [2008, 10542, 32, 26],
            [2008, 10543, 7, 7],
            [2008, 10544, 11, 9],
            [2008, 10545, 7, 7],
            [2008, 10546, 10, 8],
            [2008, 10547, 8, 8],
            [2008, 10548, 10, 9],
            [2008, 10549, 7, 8],
            [2008, 10550, 9, 10],
            [2008, 10551, 9, 8],
            [2008, 10552, 7, 7],
            [2008, 10553, 26, 15],
            [2008, 10555, 11, 8],
            [2008, 10556, 17, 13],
            [2008, 10557, 12, 10],
            [2008, 10559, 13, 9],
            [2008, 10560, 15, 12],
            [2008, 10578, 31, 28],
            [2008, 10579, 32, 33],
            [2008, 10580, 60, 41],
            [2008, 10605, 12, 10],
            [2008, 10606, 12, 10],
            [2008, 10607, 12, 10],
            [2008, 10608, 14, 10],
            [2008, 10609, 12, 10],
            [2008, 10610, 19, 11],
            [2008, 10611, 19, 14],
            [2008, 10612, 16, 14],
            [2008, 10613, 37, 25],
            [2008, 10614, 34, 22],
            [2008, 10615, 41, 28],
            [2008, 10616, 26, 18],
            [2008, 10617, 40, 27],
            [2008, 10618, 37, 25],
            [2008, 10619, 22, 20],
            [2008, 10620, 28, 19],
            [2008, 10621, 24, 21],
            [2008, 10622, 27, 18],
            [2008, 10623, 38, 25],
            [2008, 10624, 33, 24],
            [2008, 10625, 27, 20],
            [2008, 10626, 29, 21],
            [2008, 10627, 36, 28],
            [2008, 10628, 37, 25],
            [2008, 10629, 41, 25],
            [2008, 10630, 28, 21],
            [2008, 10631, 28, 21],
            [2008, 10632, 33, 21],
            [2008, 10633, 40, 26],
            [2008, 10634, 40, 25],
            [2008, 10635, 40, 26],
            [2008, 10636, 33, 22],
            [2008, 10637, 35, 26],
            [2008, 10638, 19, 14],
            [2008, 10639, 42, 26],
            [2008, 10640, 41, 25],
            [2008, 10641, 34, 26],
            [2008, 10642, 42, 25],
            [2008, 10643, 38, 25],
            [2008, 10644, 38, 26],
            [2008, 10645, 27, 27],
            [2008, 10646, 37, 25],
            [2008, 10647, 41, 28],
            [2008, 10648, 40, 30],
            [2008, 10649, 38, 25],
            [2008, 10650, 37, 26],
            [2008, 10651, 34, 28],
            [2008, 10652, 28, 21],
            [2008, 10653, 37, 25],
            [2008, 10654, 32, 28],
            [2008, 10655, 41, 30],
            [2008, 10656, 39, 28],
            [2008, 10657, 37, 25],
            [2008, 10658, 42, 24],
            [2008, 10659, 16, 15],
            [2008, 10660, 42, 26],
            [2008, 10661, 38, 25],
            [2008, 10662, 41, 25],
            [2008, 10663, 24, 21],
            [2008, 10664, 24, 22],
            [2008, 10665, 39, 30],
            [2008, 10666, 39, 26],
            [2008, 10667, 37, 28],
            [2008, 10668, 28, 22],
            [2008, 10669, 20, 15],
            [2008, 10670, 23, 20],
            [2008, 10671, 37, 25],
            [2008, 10672, 42, 24],
            [2008, 10673, 26, 20],
            [2008, 10674, 26, 18],
            [2008, 10675, 32, 27],
            [2008, 10676, 39, 28],
            [2008, 10677, 28, 21],
            [2008, 10678, 33, 22],
            [2008, 10679, 40, 25],
            [2008, 10680, 33, 26],
            [2008, 10681, 41, 30],
            [2008, 10682, 39, 24],
            [2008, 10683, 28, 21],
            [2008, 10684, 26, 19],
            [2008, 10685, 63, 37],
            [2008, 10686, 32, 27],
            [2008, 10687, 39, 26],
            [2008, 10688, 42, 31],
            [2008, 10689, 42, 26],
            [2008, 10690, 42, 26],
            [2008, 10691, 42, 26],
            [2008, 10692, 25, 22],
            [2008, 10693, 43, 26],
            [2008, 10694, 39, 26],
            [2008, 10695, 38, 25],
            [2008, 10696, 42, 24],
            [2008, 10697, 28, 21],
            [2008, 10698, 28, 22],
            [2008, 10699, 32, 30],
            [2008, 10700, 19, 15],
            [2008, 10701, 40, 26],
            [2008, 10702, 41, 26],
            [2008, 10703, 41, 25],
            [2008, 10704, 37, 25],
            [2008, 10705, 30, 21],
            [2008, 10706, 37, 26],
            [2008, 10707, 35, 29],
            [2008, 10708, 42, 26],
            [2008, 10709, 40, 31],
            [2008, 10710, 41, 25],
            [2008, 10711, 40, 25],
            [2008, 10712, 39, 30],
            [2008, 10713, 42, 28],
            [2008, 10714, 37, 25],
            [2008, 10715, 42, 26],
            [2008, 10716, 37, 26],
            [2008, 10717, 41, 26],
            [2008, 10718, 36, 29],
            [2008, 10719, 39, 27],
            [2008, 10720, 42, 26],
            [2008, 10721, 25, 18],
            [2008, 10722, 42, 26],
            [2008, 10723, 41, 26],
            [2008, 10724, 42, 26],
            [2008, 10725, 39, 31],
            [2008, 10726, 31, 24],
            [2008, 10727, 41, 25],
            [2008, 10728, 37, 25],
            [2008, 10729, 35, 27],
            [2008, 10730, 41, 26],
            [2008, 10731, 37, 26],
            [2008, 10732, 42, 27],
            [2008, 10733, 39, 30],
            [2008, 10734, 42, 25],
            [2008, 10735, 39, 26],
            [2008, 10736, 42, 30],
            [2008, 10737, 42, 29],
            [2008, 10738, 42, 25],
            [2008, 10739, 25, 15],
            [2008, 10740, 40, 25],
            [2008, 10741, 36, 29],
            [2008, 10742, 40, 25],
            [2008, 10743, 40, 25],
            [2008, 10744, 39, 24],
            [2008, 10745, 39, 25],
            [2008, 10746, 41, 24],
            [2008, 10747, 23, 16],
            [2008, 10748, 28, 21],
            [2008, 10749, 37, 25],
            [2008, 10750, 41, 25],
            [2008, 10751, 41, 25],
            [2008, 10752, 40, 30],
            [2008, 10753, 37, 26],
            [2008, 10754, 28, 21],
            [2008, 10755, 16, 15],
            [2008, 10756, 63, 45],
            [2008, 10757, 19, 14],
            [2008, 10758, 26, 18],
            [2008, 10759, 40, 26],
            [2008, 10760, 40, 25],
            [2008, 10761, 37, 25],
            [2008, 10762, 41, 30],
            [2008, 10763, 33, 25],
            [2008, 10764, 21, 19],
            [2008, 10765, 33, 23],
            [2008, 10766, 42, 26],
            [2008, 10767, 42, 25],
            [2008, 10768, 36, 28],
            [2008, 10769, 37, 25],
            [2008, 10770, 41, 27],
            [2008, 10771, 42, 26],
            [2008, 10772, 28, 28],
            [2008, 10773, 39, 31],
            [2008, 10774, 38, 23],
            [2008, 10775, 41, 23],
            [2008, 10776, 32, 22],
            [2008, 10777, 21, 18],
            [2008, 10778, 41, 26],
            [2008, 10779, 27, 22],
            [2008, 10780, 41, 25],
            [2008, 10781, 40, 24],
            [2008, 10782, 33, 28],
            [2008, 10783, 33, 30],
            [2008, 10784, 37, 25],
            [2008, 10785, 42, 25],
            [2008, 10786, 37, 25],
            [2008, 10787, 42, 28],
            [2008, 10788, 37, 26],
            [2008, 10789, 41, 25],
            [2008, 10790, 42, 25],
            [2008, 10791, 42, 25],
            [2008, 10792, 35, 26],
            [2008, 10793, 39, 28],
            [2008, 10794, 39, 30],
            [2008, 10795, 37, 25],
            [2008, 10796, 32, 30],
            [2008, 10797, 37, 25],
            [2008, 10798, 38, 28],
            [2008, 10799, 16, 15],
            [2008, 10800, 36, 28],
            [2008, 10801, 42, 26],
            [2008, 10802, 37, 25],
            [2008, 10803, 33, 20],
            [2008, 10804, 40, 25],
            [2008, 10805, 43, 25],
            [2008, 10806, 39, 26],
            [2008, 10807, 41, 23],
            [2008, 10808, 31, 20],
            [2008, 10809, 27, 21],
            [2008, 10810, 41, 25],
            [2008, 10811, 28, 21],
            [2008, 10812, 92, 41],
            [2008, 10814, 33, 22],
            [2008, 10815, 41, 25],
            [2008, 10816, 40, 25],
            [2008, 10817, 41, 30],
            [2008, 10818, 42, 26],
            [2008, 10819, 41, 25],
            [2008, 10820, 37, 25],
            [2008, 10821, 34, 28],
            [2008, 10822, 37, 25],
            [2008, 10823, 37, 25],
            [2008, 10824, 37, 25],
            [2008, 10825, 38, 30],
            [2008, 10826, 34, 22],
            [2008, 10827, 33, 26],
            [2008, 10828, 33, 26],
            [2008, 10829, 37, 25],
            [2008, 10830, 41, 25],
            [2008, 10831, 41, 25],
            [2008, 10832, 41, 26],
            [2008, 10833, 41, 26],
            [2008, 10834, 41, 25],
            [2008, 10835, 41, 28],
            [2008, 10836, 37, 25],
            [2008, 10837, 42, 25],
            [2008, 10838, 37, 25],
            [2008, 10839, 31, 26],
            [2008, 10840, 25, 18],
            [2008, 10841, 60, 30],
            [2008, 10842, 31, 30],
            [2008, 10843, 37, 25],
            [2008, 10844, 33, 22],
            [2008, 10845, 28, 21],
            [2008, 10846, 27, 22],
            [2008, 10847, 40, 28],
            [2008, 10848, 37, 25],
            [2008, 10849, 41, 25],
            [2008, 10850, 35, 27],
            [2008, 10851, 37, 25],
            [2008, 10852, 41, 28],
            [2008, 10853, 42, 26],
            [2008, 10854, 37, 29],
            [2008, 10855, 42, 25],
            [2008, 10856, 37, 25],
            [2008, 10857, 42, 28],
            [2008, 10858, 37, 25],
            [2008, 10859, 42, 24],
            [2008, 10860, 40, 25],
            [2008, 10861, 37, 25],
            [2008, 10862, 42, 25],
            [2008, 10863, 21, 19],
            [2008, 10864, 43, 24],
            [2008, 10865, 37, 25],
            [2008, 10866, 36, 22],
            [2008, 10867, 37, 25],
            [2008, 10868, 41, 25],
            [2008, 10869, 43, 30],
            [2008, 10870, 40, 26],
            [2008, 10871, 40, 25],
            [2008, 10872, 35, 23],
            [2008, 10873, 37, 28],
            [2008, 10874, 39, 30],
            [2008, 10875, 42, 25],
            [2008, 10876, 40, 25],
            [2008, 10877, 29, 27],
            [2008, 10878, 40, 25],
            [2008, 10879, 42, 25],
            [2008, 10880, 40, 25],
            [2008, 10881, 24, 21],
            [2008, 10882, 42, 25],
            [2008, 10883, 43, 26],
            [2008, 10884, 43, 25],
            [2008, 10885, 42, 26],
            [2008, 10886, 34, 22],
            [2008, 10887, 33, 22],
            [2008, 10888, 42, 25],
            [2008, 10889, 40, 28],
            [2008, 10890, 29, 21],
            [2008, 10891, 29, 21],
            [2008, 10892, 26, 18],
            [2008, 10893, 37, 26],
            [2008, 10894, 41, 26],
            [2008, 10895, 63, 35],
            [2008, 10896, 41, 26],
            [2008, 10897, 42, 30],
            [2008, 10898, 41, 26],
            [2008, 10899, 42, 28],
            [2008, 10900, 37, 25],
            [2008, 10901, 36, 25],
            [2008, 10902, 24, 21],
            [2008, 10903, 42, 30],
            [2008, 10904, 37, 25],
            [2008, 10905, 33, 23],
            [2008, 10906, 42, 28],
            [2008, 10907, 37, 26],
            [2008, 10908, 41, 25],
            [2008, 10909, 40, 27],
            [2008, 10910, 34, 26],
            [2008, 10911, 38, 29],
            [2008, 10912, 40, 29],
            [2008, 10913, 33, 23],
            [2008, 10914, 41, 26],
            [2008, 10915, 42, 31],
            [2008, 10916, 42, 29],
            [2008, 10917, 41, 26],
            [2008, 10918, 33, 27],
            [2008, 10978, 37, 25],
            [2008, 10979, 41, 24],
            [2008, 10980, 27, 22],
            [2008, 11091, 8, 5],
            [2008, 11092, 10, 8],
            [2008, 11093, 11, 7],
            [2008, 11094, 13, 10],
            [2008, 11095, 11, 7],
            [2008, 11096, 15, 11],
            [2008, 11097, 10, 8],
            [2008, 11098, 9, 7],
            [2008, 11099, 28, 17],
            [2008, 11100, 9, 10],
            [2008, 11101, 10, 8],
            [2008, 11102, 10, 8],
            [2008, 11103, 11, 10],
            [2008, 11104, 38, 24],
            [2008, 11105, 24, 19],
            [2008, 11106, 18, 14],
            [2008, 11107, 15, 10],
            [2008, 11108, 8, 6],
            [2008, 11109, 13, 11],
            [2008, 11110, 10, 9],
            [2008, 11111, 9, 8],
            [2008, 11112, 18, 13],
            [2008, 11113, 19, 13],
            [2008, 11114, 38, 21],
            [2008, 11115, 7, 6],
            [2008, 11116, 8, 6],
            [2008, 11117, 8, 5],
            [2008, 11118, 11, 9],
            [2008, 11119, 32, 19],
            [2008, 11120, 21, 14],
            [2008, 11121, 8, 6],
            [2008, 11122, 12, 9],
            [2008, 11123, 10, 10],
            [2008, 11124, 10, 9],
            [2008, 11125, 16, 12],
            [2008, 11126, 11, 9],
            [2008, 11127, 7, 7],
            [2008, 11128, 11, 7],
            [2008, 11129, 7, 6],
            [2008, 11130, 17, 14],
            [2008, 11131, 7, 6],
            [2008, 11132, 20, 13],
            [2008, 11133, 10, 8],
            [2008, 11134, 6, 5],
            [2008, 11135, 34, 22],
            [2008, 11136, 9, 8],
            [2008, 11137, 6, 5],
            [2008, 11138, 17, 10],
            [2008, 11139, 6, 6],
            [2008, 11140, 10, 9],
            [2008, 11141, 8, 6],
            [2008, 11142, 8, 7],
            [2008, 11143, 7, 6],
            [2008, 11144, 8, 8],
            [2008, 11145, 19, 15],
            [2008, 11146, 7, 6],
            [2008, 11147, 5, 3],
            [2008, 11148, 30, 20],
            [2008, 11149, 16, 11],
            [2008, 11150, 18, 13],
            [2008, 11151, 21, 12],
            [2008, 11152, 16, 11],
            [2008, 11153, 13, 9],
            [2008, 11154, 25, 16],
            [2008, 11155, 16, 10],
            [2008, 11156, 11, 10],
            [2008, 11157, 14, 10],
            [2008, 11158, 12, 10],
            [2008, 11159, 19, 10],
            [2008, 11160, 25, 15],
            [2008, 11161, 12, 8],
            [2008, 11162, 18, 12],
            [2008, 11163, 12, 12],
            [2008, 11164, 16, 14],
            [2008, 11165, 17, 12],
            [2008, 11166, 28, 21],
            [2008, 11168, 21, 15],
            [2008, 11169, 8, 8],
            [2008, 11170, 11, 10],
            [2008, 11171, 11, 9],
            [2008, 11172, 9, 8],
            [2008, 11173, 14, 10],
            [2008, 11174, 6, 6],
            [2008, 11175, 6, 6],
            [2008, 11176, 6, 6],
            [2008, 11177, 19, 14],
            [2008, 11178, 7, 7],
            [2008, 11179, 10, 11],
            [2008, 11180, 10, 10],
            [2008, 11181, 15, 12],
            [2008, 11182, 13, 10],
            [2008, 11183, 11, 12],
            [2008, 11184, 65, 65],
            [2008, 11185, 65, 65],
            [2008, 11186, 65, 65],
            [2008, 11187, 65, 65],
            [2008, 11188, 65, 65],
            [2008, 11189, 65, 55],
            [2008, 11195, 15, 13],
            [2008, 11197, 73, 37],
            [2008, 11199, 56, 34],
            [2008, 11201, 10, 11],
            [2008, 11202, 36, 22],
            [2008, 11203, 11, 12],
            [2008, 11204, 68, 44],
            [2008, 11205, 104, 74],
            [2008, 11206, 54, 48],
            [2008, 11207, 10, 11],
            [2008, 11209, 150, 160],
            [2008, 11210, 240, 180],
            [2008, 11211, 95, 90],
            [2008, 11212, 240, 180],
            [2008, 11215, 150, 160],
            [2008, 11216, 240, 180],
            [2008, 11217, 150, 160],
            [2008, 11218, 240, 180],
            [2008, 11219, 95, 90],
            [2008, 11220, 240, 180],
            [2008, 11221, 95, 90],
            [2008, 11222, 95, 90],
            [2008, 11223, 95, 90],
            [2008, 11224, 95, 90],
            [2008, 11228, 150, 160],
            [2008, 11229, 150, 160],
            [2008, 11230, 95, 90],
            [2008, 11231, 95, 90],
            [2008, 11232, 95, 90],
            [2008, 11233, 95, 90],
            [2008, 11234, 95, 90],
            [2008, 11235, 95, 90],
            [2008, 11236, 95, 90],
            [2008, 11239, 95, 90],
            [2008, 11240, 95, 90],
            [2008, 11241, 95, 90],
            [2008, 11242, 95, 90],
            [2008, 11245, 95, 90],
            [2008, 11246, 150, 160],
            [2008, 11247, 150, 160],
            [2008, 11248, 150, 160],
            [2008, 11249, 95, 90],
            [2008, 11250, 95, 90],
            [2008, 11251, 95, 90],
            [2008, 11252, 150, 160],
            [2008, 11253, 95, 90],
            [2008, 11254, 95, 90],
            [2008, 11255, 95, 90],
            [2008, 11256, 95, 90],
            [2008, 11262, 95, 90],
            [2008, 11263, 95, 90],
            [2008, 11264, 150, 160],
            [2008, 11265, 95, 90],
            [2008, 11266, 95, 90],
            [2008, 11267, 95, 90],
            [2008, 11268, 95, 90],
            [2008, 11269, 95, 90],
            [2008, 11270, 150, 160],
            [2008, 11274, 150, 160],
            [2008, 11275, 95, 90],
            [2008, 11276, 95, 90],
            [2008, 11277, 95, 90],
            [2008, 11278, 95, 90],
            [2008, 11279, 150, 160],
            [2008, 11283, 95, 90],
            [2008, 11284, 95, 90],
            [2008, 11285, 95, 90],
            [2008, 11286, 95, 90],
            [2008, 11287, 95, 90],
            [2008, 11288, 95, 90],
            [2008, 11289, 95, 90],
            [2008, 11292, 10, 8],
            [2008, 11293, 5, 5],
            [2008, 11294, 7, 7],
            [2008, 11295, 13, 7],
            [2008, 11296, 21, 45],
            [2008, 11298, 18, 17],
            [2008, 11300, 33, 29],
            [2008, 11303, 18, 16],
            [2008, 11304, 26, 19],
            [2008, 11305, 38, 41],
            [2008, 11306, 35, 30],
            [2008, 11307, 35, 29],
            [2008, 11308, 14, 20],
            [2008, 11309, 25, 23],
            [2008, 11310, 18, 20],
            [2008, 11311, 15, 19],
            [2008, 11312, 19, 19],
            [2008, 11313, 13, 18],
            [2008, 11314, 30, 26],
            [2008, 11315, 26, 22],
            [2008, 11316, 24, 24],
            [2008, 11317, 28, 25],
            [2008, 11318, 18, 18],
            [2008, 11319, 18, 16],
            [2008, 11320, 18, 14],
            [2008, 11321, 34, 23],
            [2008, 11322, 38, 24],
            [2008, 11323, 23, 20],
            [2008, 11324, 23, 17],
            [2008, 11325, 25, 19],
            [2008, 11326, 24, 24],
            [2008, 11327, 25, 19],
            [2008, 11328, 25, 25],
            [2008, 11329, 18, 18],
            [2008, 11330, 30, 28],
            [2008, 11331, 28, 25],
            [2008, 11332, 17, 14],
            [2008, 11333, 32, 23],
            [2008, 11334, 34, 23],
            [2008, 11335, 25, 20],
            [2008, 11336, 11, 13],
            [2008, 11337, 22, 20],
            [2008, 11338, 25, 24],
            [2008, 11339, 28, 23],
            [2008, 11340, 29, 27],
            [2008, 11341, 31, 25],
            [2008, 11342, 29, 25],
            [2008, 11343, 29, 26],
            [2008, 11344, 28, 25],
            [2008, 11345, 24, 24],
            [2008, 11346, 32, 25],
            [2008, 11347, 28, 23],
            [2008, 11348, 35, 28],
            [2008, 11349, 17, 16],
            [2008, 11350, 28, 26],
            [2008, 11351, 25, 25],
            [2008, 11352, 25, 25],
            [2008, 11353, 32, 26],
            [2008, 11354, 27, 20],
            [2008, 11355, 27, 23],
            [2008, 11356, 28, 23],
            [2008, 11357, 25, 21],
            [2008, 11358, 23, 20],
            [2008, 11359, 34, 28],
            [2008, 11360, 25, 20],
            [2008, 11361, 34, 27],
            [2008, 11362, 24, 21],
            [2008, 11363, 9, 10],
            [2008, 11364, 11, 11],
            [2008, 11365, 27, 22],
            [2008, 11366, 21, 20],
            [2008, 11367, 40, 31],
            [2008, 11368, 19, 20],
            [2008, 11369, 43, 42],
            [2008, 11370, 21, 25],
            [2008, 11371, 27, 25],
            [2008, 11372, 32, 31],
            [2008, 11373, 40, 30],
            [2008, 11374, 51, 33],
            [2008, 11375, 39, 35],
            [2008, 11376, 19, 18],
            [2008, 11377, 35, 28],
            [2008, 11378, 24, 22],
            [2008, 11384, 54, 42],
            [2008, 11385, 62, 55],
            [2008, 11386, 62, 65],
            [2008, 11387, 66, 55],
            [2008, 11388, 60, 50],
            [2008, 11389, 40, 31],
            [2008, 11390, 50, 28],
            [2008, 11391, 36, 29],
            [2008, 11392, 64, 55],
            [2008, 11393, 103, 65],
            [2008, 11394, 60, 55],
            [2008, 11395, 64, 66],
            [2008, 11396, 66, 55],
            [2008, 11397, 71, 46],
            [2008, 11398, 35, 27],
            [2008, 11399, 70, 55],
            [2008, 11400, 90, 66],
            [2008, 11401, 41, 22],
            [2008, 11402, 48, 58],
            [2008, 11403, 42, 49],
            [2008, 11404, 117, 66],
            [2008, 11405, 41, 36],
            [2008, 11406, 64, 65],
            [2008, 11407, 55, 29],
            [2008, 11408, 91, 45],
            [2008, 11409, 37, 28],
            [2008, 11410, 46, 53],
            [2008, 11411, 54, 29],
            [2008, 11412, 94, 67],
            [2008, 11413, 64, 55],
            [2008, 11414, 49, 54],
            [2008, 11415, 50, 50],
            [2008, 11416, 38, 28],
            [2008, 11417, 59, 53],
            [2008, 11418, 60, 60],
            [2008, 11419, 37, 38],
            [2008, 11420, 85, 42],
            [2008, 11421, 84, 50],
            [2008, 11422, 47, 33],
            [2008, 11423, 57, 32],
            [2008, 11424, 37, 26],
            [2008, 11425, 20, 17],
            [2008, 11426, 9, 7],
            [2008, 11427, 8, 8],
            [2008, 11428, 47, 24],
            [2008, 11429, 15, 12],
            [2008, 11430, 9, 10],
            [2008, 11431, 12, 10],
            [2008, 11432, 8, 8],
            [2008, 11433, 10, 12],
            [2008, 11434, 10, 9],
            [2008, 11435, 7, 8],
            [2008, 11436, 19, 18],
            [2008, 11437, 12, 11],
            [2008, 11438, 10, 9],
            [2008, 11439, 11, 9],
            [2008, 11440, 16, 14],
            [2008, 11441, 43, 26],
            [2008, 11442, 9, 8],
            [2008, 11443, 11, 11],
            [2008, 11444, 12, 9],
            [2008, 11445, 8, 8],
            [2008, 11446, 11, 9],
            [2008, 11447, 17, 14],
            [2008, 11448, 12, 10],
            [2008, 11449, 12, 8],
            [2008, 11450, 12, 10],
            [2008, 11451, 9, 7],
            [2008, 11452, 10, 9],
            [2008, 11453, 29, 18],
            [2008, 11454, 12, 11],
            [2008, 11455, 8, 8],
            [2008, 11456, 8, 8],
            [2008, 11457, 9, 9],
            [2008, 11458, 6, 7],
            [2008, 11459, 6, 6],
            [2008, 11460, 7, 6],
            [2008, 11461, 9, 8],
            [2008, 11462, 7, 7],
            [2008, 11463, 10, 9],
            [2008, 11464, 9, 7],
            [2008, 11465, 16, 13],
            [2008, 11466, 14, 9],
            [2008, 11467, 15, 11],
            [2008, 11468, 33, 21],
            [2008, 11469, 15, 11],
            [2008, 11470, 18, 15],
            [2008, 11471, 15, 13],
            [2008, 11472, 24, 15],
            [2008, 11473, 10, 9],
            [2008, 11474, 8, 9],
            [2008, 11475, 9, 9],
            [2008, 11476, 11, 9],
            [2008, 11477, 21, 17],
            [2008, 11478, 26, 16],
            [2008, 11479, 11, 9],
            [2008, 11480, 19, 16],
            [2008, 11481, 13, 12],
            [2008, 11482, 16, 13],
            [2008, 11483, 18, 15],
            [2008, 11484, 17, 14],
            [2008, 11485, 22, 16],
            [2008, 11486, 18, 14],
            [2008, 11487, 15, 12],
            [2008, 11488, 21, 16],
            [2008, 11489, 11, 10],
            [2008, 11490, 12, 11],
            [2008, 11491, 11, 9],
            [2008, 11492, 8, 7],
            [2008, 11493, 8, 8],
            [2008, 11494, 6, 7],
            [2008, 11495, 6, 6],
            [2008, 11496, 7, 8],
            [2008, 11497, 9, 8],
            [2008, 11498, 9, 8],
            [2008, 11499, 9, 9],
            [2008, 11500, 20, 18],
            [2008, 11501, 8, 8],
            [2008, 11502, 11, 10],
            [2008, 11503, 7, 8],
            [2008, 11504, 9, 9],
            [2008, 11505, 14, 11],
            [2008, 11506, 10, 10],
            [2008, 11507, 11, 12],
            [2008, 11508, 7, 8],
            [2008, 11509, 23, 15],
            [2008, 11510, 11, 9],
            [2008, 11511, 11, 9],
            [2008, 11512, 18, 12],
            [2008, 11513, 13, 11],
            [2008, 11514, 9, 9],
            [2008, 11515, 9, 9],
            [2008, 11516, 14, 11],
            [2008, 11517, 18, 16],
            [2008, 11518, 10, 15],
            [2008, 11519, 20, 13],
            [2008, 11520, 29, 18],
            [2008, 11521, 8, 6],
            [2008, 11522, 10, 10],
            [2008, 11523, 11, 9],
            [2008, 11524, 8, 7],
            [2008, 11525, 11, 8],
            [2008, 11526, 16, 11],
            [2008, 11527, 10, 10],
            [2008, 11528, 8, 7],
            [2008, 11529, 55, 50],
            [2008, 11530, 55, 67],
            [2008, 11531, 75, 32],
            [2008, 11532, 65, 60],
            [2008, 11533, 31, 30],
            [2008, 11534, 98, 55],
            [2008, 11535, 65, 65],
            [2008, 11536, 36, 35],
            [2008, 11537, 55, 46],
            [2008, 11538, 75, 66],
            [2008, 11539, 90, 66],
            [2008, 11540, 40, 29],
            [2008, 11541, 75, 55],
            [2008, 11542, 66, 60],
            [2008, 11543, 80, 77],
            [2008, 11544, 41, 37],
            [2008, 11545, 78, 88],
            [2008, 11546, 94, 55],
            [2008, 11547, 65, 65],
            [2008, 11548, 88, 55],
            [2008, 11549, 35, 30],
            [2008, 11550, 75, 55],
            [2008, 11551, 44, 49],
            [2008, 11552, 92, 65],
            [2008, 11553, 84, 65],
            [2008, 11554, 50, 57],
            [2008, 11555, 67, 60],
            [2008, 11556, 65, 55],
            [2008, 11557, 65, 65],
            [2008, 11558, 59, 83],
            [2008, 11559, 65, 65],
            [2008, 11560, 45, 88],
            [2008, 11561, 117, 88],
            [2008, 11562, 65, 90],
            [2008, 11563, 117, 55],
            [2008, 11564, 64, 70],
            [2008, 11565, 107, 60],
            [2008, 11566, 86, 88],
            [2008, 11567, 65, 65],
            [2008, 11568, 65, 64],
            [2008, 11569, 99, 88],
            [2008, 11570, 65, 65],
            [2008, 11571, 10, 11],
            [2008, 11572, 13, 12],
            [2008, 11573, 96, 70],
            [2008, 11574, 11, 12],
            [2008, 11576, 13, 14],
            [2008, 11577, 13, 13],
            [2008, 11578, 17, 18],
            [2008, 11579, 16, 21],
            [2008, 11580, 11, 12],
            [2008, 11581, 13, 15],
            [2008, 11582, 16, 18],
            [2008, 11583, 43, 29],
            [2008, 11585, 41, 27],
            [2008, 11586, 43, 25],
            [2008, 11588, 75, 27],
            [2008, 11590, 26, 19],
            [2008, 11592, 50, 25],
            [2008, 11593, 30, 19],
            [2008, 11594, 88, 44],
            [2008, 11596, 37, 30],
            [2008, 11598, 22, 20],
            [2008, 11601, 53, 41],
            [2008, 11604, 14, 16],
            [2008, 11605, 21, 18],
            [2008, 11606, 35, 23],
            [2008, 11607, 32, 25],
            [2008, 11614, 21, 18],
            [2008, 11648, 21, 17],
            [2008, 11665, 41, 33],
            [2008, 11694, 14, 18],
            [2008, 11698, 19, 16],
            [2008, 11703, 17, 18],
            [2008, 11705, 45, 35],
            [2008, 11706, 108, 43],
            [2008, 11709, 61, 29],
            [2008, 11710, 58, 27],
            [2008, 11714, 10, 11],
            [2008, 11717, 23, 26],
            [2008, 11721, 16, 17],
            [2008, 11722, 49, 45],
            [2008, 11724, 46, 40],
            [2008, 11728, 47, 38],
            [2008, 11730, 22, 17],
            [2008, 11731, 71, 42],
            [2008, 11737, 41, 40],
            [2008, 11738, 137, 67],
            [2008, 11739, 17, 17],
            [2008, 11741, 17, 17],
            [2008, 11745, 69, 28],
            [2008, 11746, 31, 19],
            [2008, 11755, 13, 13],
            [2008, 11759, 17, 17],
            [2008, 11760, 90, 58],
            [2008, 11763, 17, 18],
            [2008, 11766, 36, 32],
            [2008, 11776, 54, 43],
            [2008, 11777, 24, 20],
            [2008, 11780, 29, 19],
            [2008, 11781, 20, 21],
            [2008, 11782, 15, 17],
            [2008, 11783, 33, 24],
            [2008, 11784, 23, 20],
            [2008, 11785, 29, 27],
            [2008, 11786, 61, 39],
            [2008, 11787, 35, 35],
            [2008, 11788, 40, 33],
            [2008, 11789, 38, 32],
            [2008, 11790, 14, 16],
            [2008, 11791, 41, 21],
            [2008, 11792, 53, 50],
            [2008, 11794, 24, 21],
            [2008, 11795, 20, 20],
            [2008, 11796, 31, 29],
            [2008, 11797, 40, 30],
            [2008, 11798, 35, 26],
            [2008, 11799, 35, 27],
            [2008, 11800, 25, 22],
            [2008, 11801, 28, 23],
            [2008, 11802, 35, 29],
            [2008, 11803, 32, 26],
            [2008, 11804, 26, 24],
            [2008, 11805, 34, 27],
            [2008, 11806, 39, 31],
            [2008, 11807, 23, 22],
            [2008, 11808, 23, 18],
            [2008, 11809, 16, 12],
            [2008, 11810, 21, 16],
            [2008, 11811, 20, 16],
            [2008, 11812, 27, 21],
            [2008, 11813, 11, 11],
            [2008, 11814, 20, 18],
            [2008, 11815, 19, 14],
            [2008, 11816, 21, 19],
            [2008, 11817, 17, 11],
            [2008, 11818, 17, 18],
            [2008, 11819, 21, 15],
            [2008, 11820, 17, 12],
            [2008, 11821, 21, 16],
            [2008, 11822, 21, 16],
            [2008, 11823, 36, 19],
            [2008, 11824, 18, 17],
            [2008, 11825, 21, 15],
            [2008, 11826, 18, 17],
            [2008, 11827, 19, 16],
            [2008, 11828, 16, 13],
            [2008, 11829, 21, 21],
            [2008, 11830, 15, 15],
            [2008, 11831, 17, 16],
            [2008, 11832, 24, 14],
            [2008, 11833, 21, 15],
            [2008, 11834, 6, 6],
            [2008, 11835, 22, 13],
            [2008, 11836, 21, 17],
            [2008, 11837, 11, 11],
            [2008, 11838, 7, 6],
            [2008, 11839, 11, 10],
            [2008, 11840, 8, 7],
            [2008, 11841, 6, 5],
            [2008, 11842, 19, 13],
            [2008, 11843, 21, 19],
            [2008, 11844, 18, 18],
            [2008, 11845, 22, 16],
            [2008, 11846, 25, 18],
            [2008, 11847, 19, 15],
            [2008, 11848, 15, 11],
            [2008, 11849, 19, 16],
            [2008, 11850, 17, 11],
            [2008, 11851, 23, 17],
            [2008, 11852, 18, 16],
            [2008, 11853, 12, 12],
            [2008, 11854, 18, 19],
            [2008, 11855, 16, 15],
            [2008, 11858, 16, 35],
            [2008, 11859, 21, 37],
            [2008, 11860, 25, 35],
            [2008, 11865, 34, 32],
            [2008, 11866, 36, 30],
            [2008, 11867, 52, 45],
            [2008, 11868, 49, 64],
            [2008, 11869, 26, 24],
            [2008, 11870, 46, 35],
            [2008, 11871, 56, 42],
            [2008, 11872, 28, 27],
            [2008, 11873, 32, 40],
            [2008, 11874, 42, 32],
            [2008, 11875, 32, 26],
            [2008, 11876, 38, 55],
            [2008, 11877, 47, 29],
            [2008, 11878, 22, 19],
            [2008, 11879, 37, 37],
            [2008, 11880, 49, 45],
            [2008, 11881, 52, 40],
            [2008, 11882, 33, 30],
            [2008, 11883, 45, 32],
            [2008, 11884, 57, 37],
            [2008, 11885, 32, 33],
            [2008, 11886, 28, 29],
            [2008, 11887, 37, 30],
            [2008, 11888, 28, 25],
            [2008, 11889, 26, 30],
            [2008, 11890, 26, 29],
            [2008, 11891, 33, 27],
            [2008, 11892, 30, 33],
            [2008, 11893, 37, 29],
            [2008, 11894, 28, 30],
            [2008, 11895, 40, 39],
            [2008, 11896, 37, 35],
            [2008, 11897, 43, 31],
            [2008, 11898, 33, 33],
            [2008, 11899, 39, 56],
            [2008, 11900, 20, 19],
            [2008, 11901, 42, 51],
            [2008, 11902, 28, 43],
            [2008, 11903, 38, 34],
            [2008, 11904, 33, 32],
            [2008, 11905, 46, 45],
            [2008, 11906, 40, 34],
            [2008, 11907, 55, 36],
            [2008, 11908, 28, 27],
            [2008, 11909, 28, 28],
            [2008, 11910, 42, 40],
            [2008, 11911, 23, 27],
            [2008, 11912, 33, 34],
            [2008, 11913, 35, 26],
            [2008, 11914, 22, 20],
            [2008, 11915, 25, 25],
            [2008, 11916, 38, 51],
            [2008, 11917, 35, 33],
            [2008, 11918, 27, 26],
            [2008, 11919, 19, 23],
            [2008, 11920, 28, 24],
            [2008, 11921, 26, 25],
            [2008, 11922, 24, 27],
            [2008, 11923, 20, 25],
            [2008, 11924, 20, 19],
            [2008, 11925, 25, 20],
            [2008, 11926, 19, 15],
            [2008, 11927, 28, 30],
            [2008, 11928, 19, 16],
            [2008, 11929, 17, 13],
            [2008, 11930, 15, 14],
            [2008, 11931, 32, 29],
            [2008, 11932, 50, 30],
            [2008, 11933, 36, 28],
            [2008, 11934, 24, 16],
            [2008, 11935, 29, 26],
            [2008, 11936, 25, 22],
            [2008, 11937, 33, 25],
            [2008, 11938, 32, 25],
            [2008, 11939, 49, 28],
            [2008, 11940, 58, 36],
            [2008, 11941, 35, 29],
            [2008, 11942, 40, 26],
            [2008, 11943, 20, 17],
            [2008, 11944, 39, 27],
            [2008, 11945, 26, 25],
            [2008, 11946, 65, 46],
            [2008, 11947, 31, 25],
            [2008, 11948, 45, 45],
            [2008, 11949, 40, 32],
            [2008, 11950, 30, 30],
            [2008, 11951, 48, 38],
            [2008, 11952, 44, 46],
            [2008, 11953, 47, 40],
            [2008, 11954, 25, 26],
            [2008, 11955, 45, 36],
            [2008, 11956, 50, 36],
            [2008, 11957, 26, 25],
            [2008, 11958, 40, 20],
            [2008, 11959, 23, 18],
            [2008, 11960, 26, 23],
            [2008, 11961, 26, 25],
            [2008, 11962, 24, 26],
            [2008, 11963, 44, 25],
            [2008, 11964, 26, 19],
            [2008, 11965, 50, 43],
            [2008, 11966, 35, 27],
            [2008, 11967, 37, 23],
            [2008, 11968, 50, 46],
            [2008, 11969, 14, 18],
            [2008, 11970, 30, 22],
            [2008, 11971, 41, 35],
            [2008, 11972, 42, 35],
            [2008, 11973, 40, 27],
            [2008, 11974, 60, 45],
            [2008, 11975, 80, 60],
            [2008, 11976, 40, 30],
            [2008, 11977, 49, 45],
            [2008, 11978, 33, 28],
            [2008, 11979, 38, 30],
            [2008, 11980, 67, 57],
            [2008, 11981, 41, 30],
            [2008, 11982, 39, 27],
            [2008, 11983, 23, 23],
            [2008, 11984, 57, 47],
            [2008, 11985, 41, 21],
            [2008, 11986, 40, 37],
            [2008, 11987, 39, 25],
            [2008, 11988, 47, 25],
            [2008, 11989, 33, 28],
            [2008, 11990, 36, 27],
            [2008, 11991, 53, 31],
            [2008, 11992, 45, 41],
            [2008, 11993, 22, 20],
            [2008, 11994, 23, 20],
            [2008, 11995, 25, 25],
            [2008, 11996, 53, 48],
            [2008, 11997, 35, 23],
            [2008, 11998, 43, 48],
            [2008, 11999, 27, 25],
            [2008, 12000, 15, 20],
            [2008, 12001, 29, 20],
            [2008, 12002, 25, 25],
            [2008, 12003, 29, 29],
            [2008, 12004, 11, 14],
            [2008, 12005, 23, 23],
            [2008, 12006, 14, 14],
            [2008, 12007, 31, 17],
            [2008, 12008, 26, 27],
            [2008, 12009, 25, 20],
            [2008, 12010, 25, 20],
            [2008, 12011, 15, 15],
            [2008, 12012, 17, 15],
            [2008, 12013, 12, 11],
            [2008, 12014, 24, 24],
            [2008, 12015, 16, 16],
            [2008, 12016, 25, 25],
            [2008, 12017, 30, 20],
            [2008, 12018, 20, 20],
            [2008, 12019, 27, 22],
            [2008, 12020, 16, 16],
            [2008, 12021, 23, 21],
            [2008, 12022, 25, 21],
            [2008, 12023, 11, 12],
            [2008, 12024, 20, 20],
            [2008, 12025, 45, 34],
            [2008, 12026, 22, 19],
            [2008, 12027, 12, 13],
            [2008, 12028, 13, 15],
            [2008, 12029, 15, 12],
            [2008, 12030, 15, 15],
            [2008, 12031, 24, 19],
            [2008, 12032, 13, 13],
            [2008, 12033, 19, 16],
            [2008, 12034, 21, 14],
            [2008, 12035, 15, 16],
            [2008, 12036, 17, 15],
            [2008, 12037, 19, 15],
            [2008, 12038, 22, 25],
            [2008, 12039, 17, 17],
            [2008, 12040, 70, 26],
            [2008, 12041, 49, 26],
            [2008, 12042, 13, 16],
            [2008, 12043, 24, 21],
            [2008, 12044, 21, 18],
            [2008, 12045, 33, 28],
            [2008, 12046, 26, 24],
            [2008, 12047, 19, 20],
            [2008, 12048, 19, 18],
            [2008, 12049, 12, 15],
            [2008, 12050, 22, 18],
            [2008, 12051, 13, 15],
            [2008, 12052, 28, 19],
            [2008, 12053, 28, 28],
            [2008, 12054, 12, 12],
            [2008, 12055, 28, 16],
            [2008, 12056, 24, 19],
            [2008, 12057, 24, 27],
            [2008, 12058, 21, 17],
            [2008, 12059, 18, 14],
            [2008, 12060, 25, 22],
            [2008, 12061, 13, 13],
            [2008, 12062, 19, 20],
            [2008, 12063, 9, 9],
            [2008, 12064, 22, 17],
            [2008, 12065, 32, 24],
            [2008, 12066, 25, 18],
            [2008, 12067, 16, 15],
            [2008, 12068, 14, 12],
            [2008, 12069, 30, 25],
            [2008, 12070, 15, 18],
            [2008, 12071, 23, 22],
            [2008, 12072, 27, 19],
            [2008, 12073, 12, 15],
            [2008, 12074, 19, 20],
            [2008, 12075, 13, 12],
            [2008, 12076, 15, 13],
            [2008, 12077, 15, 17],
            [2008, 12078, 26, 23],
            [2008, 12079, 28, 21],
            [2008, 12080, 12, 17],
            [2008, 12081, 15, 17],
            [2008, 12082, 28, 28],
            [2008, 12083, 33, 28],
            [2008, 12084, 17, 15],
            [2008, 12085, 25, 23],
            [2008, 12086, 29, 25],
            [2008, 12087, 40, 27],
            [2008, 12088, 14, 12],
            [2008, 12089, 30, 18],
            [2008, 12090, 18, 15],
            [2008, 12091, 30, 16],
            [2008, 12092, 46, 25],
            [2008, 12093, 10, 11],
            [2008, 12094, 29, 20],
            [2008, 12095, 60, 39],
            [2008, 12096, 32, 26],
            [2008, 12097, 32, 24],
            [2008, 12098, 31, 20],
            [2008, 12099, 64, 33],
            [2008, 12100, 11, 9],
            [2008, 12101, 16, 12],
            [2008, 12102, 10, 12],
            [2008, 12103, 32, 21],
            [2008, 12104, 53, 26],
            [2008, 12105, 23, 16],
            [2008, 12106, 13, 12],
            [2008, 12107, 22, 18],
            [2008, 12108, 25, 21],
            [2008, 12109, 29, 24],
            [2008, 12110, 18, 17],
            [2008, 12111, 33, 23],
            [2008, 12112, 34, 24],
            [2008, 12113, 19, 14],
            [2008, 12114, 26, 17],
            [2008, 12115, 11, 13],
            [2008, 12116, 14, 13],
            [2008, 12117, 30, 24],
            [2008, 12118, 25, 20],
            [2008, 12119, 66, 32],
            [2008, 12120, 22, 19],
            [2008, 12121, 22, 17],
            [2008, 12122, 9, 17],
            [2008, 12123, 13, 18],
            [2008, 12124, 13, 22],
            [2008, 12125, 14, 29],
            [2008, 12126, 13, 23],
            [2008, 12127, 10, 13],
            [2008, 12128, 68, 52],
            [2008, 12129, 72, 58],
            [2008, 12130, 83, 71],
            [2008, 12131, 79, 56],
            [2008, 12132, 63, 61],
            [2008, 12133, 65, 64],
            [2008, 12134, 67, 63],
            [2008, 12135, 65, 50],
            [2008, 12136, 42, 36],
            [2008, 12137, 63, 49],
            [2008, 12138, 64, 39],
            [2008, 12139, 45, 54],
            [2008, 12140, 80, 64],
            [2008, 12141, 76, 65],
            [2008, 12142, 85, 45],
            [2008, 12143, 85, 70],
            [2008, 12144, 67, 47],
            [2008, 12145, 81, 63],
            [2008, 12146, 79, 70],
            [2008, 12147, 45, 38],
            [2008, 12148, 100, 60],
            [2008, 12149, 83, 58],
            [2008, 12150, 45, 32],
            [2008, 12151, 49, 40],
            [2008, 12152, 79, 54],
            [2008, 12153, 76, 50],
            [2008, 12154, 108, 53],
            [2008, 12155, 63, 45],
            [2008, 12156, 58, 41],
            [2008, 12157, 54, 42],
            [2008, 12158, 41, 36],
            [2008, 12159, 54, 49],
            [2008, 12160, 21, 26],
            [2008, 12161, 11, 11],
            [2008, 12162, 13, 19],
            [2008, 12163, 23, 27],
            [2008, 12164, 11, 21],
            [2008, 12165, 14, 18],
            [2008, 12166, 14, 17],
            [2008, 12167, 14, 18],
            [2008, 12168, 21, 26],
            [2008, 12169, 14, 12],
            [2008, 12170, 11, 15],
            [2008, 12171, 60, 39],
            [2008, 12172, 56, 33],
            [2008, 12173, 21, 17],
            [2008, 12174, 65, 32],
            [2008, 12175, 52, 32],
            [2008, 12176, 240, 180],
            [2008, 12177, 240, 180],
            [2008, 12178, 240, 180],
            [2008, 12179, 240, 180],
            [2008, 12180, 240, 180],
            [2008, 12181, 240, 180],
            [2008, 12182, 240, 180],
            [2008, 12183, 240, 180],
            [2008, 12184, 240, 180],
            [2008, 12185, 240, 180],
            [2008, 12186, 240, 180],
            [2008, 12187, 240, 180],
            [2008, 12188, 240, 180],
            [2008, 12189, 240, 180],
            [2008, 12190, 240, 180],
            [2008, 12191, 57, 32],
            [2008, 12192, 21, 26],
            [2008, 12193, 62, 44],
            [2008, 12194, 39, 32],
            [2008, 12195, 20, 26],
            [2008, 12196, 20, 26],
            [2008, 12197, 20, 26],
            [2008, 12198, 20, 26],
            [2008, 12199, 51, 40],
            [2008, 12200, 48, 34],
            [2008, 12201, 35, 32],
            [2008, 12202, 35, 31],
            [2008, 12203, 58, 36],
            [2008, 12204, 42, 31],
            [2008, 12205, 73, 31],
            [2008, 12206, 67, 35],
            [2008, 12207, 38, 35],
            [2008, 12208, 22, 38],
            [2008, 12209, 36, 34],
            [2008, 12210, 36, 31],
            [2008, 12211, 52, 37],
            [2008, 12212, 46, 36],
            [2008, 12213, 55, 40],
            [2008, 12214, 34, 36],
            [2008, 12215, 37, 38],
            [2008, 12216, 48, 33],
            [2008, 12217, 38, 34],
            [2008, 12218, 64, 31],
            [2008, 12219, 88, 30],
            [2008, 12220, 37, 32],
            [2008, 12221, 34, 25],
            [2008, 12222, 28, 30],
            [2008, 12223, 81, 36],
            [2008, 12224, 35, 32],
            [2008, 12225, 34, 32],
            [2008, 12226, 43, 35],
            [2008, 12227, 57, 32],
            [2008, 12228, 69, 37],
            [2008, 12229, 48, 38],
            [2008, 12230, 54, 36],
            [2008, 12231, 30, 33],
            [2008, 12232, 55, 37],
            [2008, 12233, 40, 39],
            [2008, 12234, 54, 33],
            [2008, 12235, 47, 30],
            [2008, 12236, 45, 32],
            [2008, 12237, 37, 41],
            [2008, 12238, 38, 35],
            [2008, 12239, 55, 30],
            [2008, 12240, 84, 50],
            [2008, 12241, 14, 14],
            [2008, 12242, 40, 29],
            [2008, 12243, 11, 11],
            [2008, 12244, 13, 13],
            [2008, 12245, 14, 14],
            [2008, 12246, 13, 14],
            [2008, 12247, 20, 16],
            [2008, 12248, 14, 14],
            [2008, 12249, 9, 9],
            [2008, 12250, 13, 13],
            [2008, 12251, 15, 17],
            [2008, 12253, 14, 14],
            [2008, 12254, 21, 19],
            [2008, 12255, 15, 17],
            [2008, 12256, 17, 16],
            [2008, 12257, 27, 21],
            [2008, 12258, 15, 14],
            [2008, 12259, 6, 5],
            [2008, 12260, 9, 10],
            [2008, 12261, 8, 9],
            [2008, 12262, 16, 14],
            [2008, 12263, 13, 14],
            [2008, 12264, 15, 14],
            [2008, 12265, 18, 19],
            [2008, 12266, 19, 21],
            [2008, 12267, 9, 11],
            [2008, 12268, 20, 19],
            [2008, 12269, 18, 17],
            [2008, 12270, 19, 18],
            [2008, 12271, 15, 14],
            [2008, 12272, 13, 12],
            [2008, 12273, 20, 18],
            [2008, 12274, 18, 16],
            [2008, 12275, 18, 14],
            [2008, 12276, 23, 20],
            [2008, 12277, 16, 14],
            [2008, 12278, 9, 9],
            [2008, 12279, 15, 15],
            [2008, 12280, 15, 15],
            [2008, 12281, 9, 7],
            [2008, 12282, 15, 16],
            [2008, 12283, 13, 14],
            [2008, 12284, 14, 16],
            [2008, 12285, 16, 11],
            [2008, 12286, 17, 15],
            [2008, 12287, 12, 12],
            [2008, 12288, 17, 16],
            [2008, 12289, 11, 11],
            [2008, 12290, 13, 13],
            [2008, 12291, 15, 16],
            [2008, 12292, 11, 13],
            [2008, 12293, 18, 16],
            [2008, 12294, 15, 15],
            [2008, 12295, 18, 16],
            [2008, 12296, 26, 24],
            [2008, 12297, 12, 14],
            [2008, 12298, 16, 17],
            [2008, 12299, 22, 29],
            [2008, 12300, 17, 19],
            [2008, 12301, 16, 11],
            [2008, 12302, 32, 23],
            [2008, 12303, 33, 17],
            [2008, 12304, 25, 24],
            [2008, 12305, 16, 9],
            [2008, 12306, 14, 10],
            [2008, 12307, 33, 25],
            [2008, 12308, 29, 18],
            [2008, 12309, 28, 19],
            [2008, 12310, 29, 19],
            [2008, 12311, 33, 25],
            [2009, 25, 12, 9],
            [2009, 48, 33, 23],
            [2009, 49, 24, 16],
            [2009, 65, 21, 17],
            [2009, 82, 15, 16],
            [2009, 83, 21, 21],
            [2009, 101, 30, 25],
            [2009, 119, 26, 19],
            [2009, 163, 21, 21],
            [2009, 200, 25, 19],
            [2009, 204, 15, 18],
            [2009, 220, 10, 12],
            [2009, 226, 18, 16],
            [2009, 231, 40, 23],
            [2009, 234, 12, 12],
            [2009, 240, 61, 36],
            [2009, 246, 23, 15],
            [2009, 282, 33, 23],
            [2009, 314, 16, 19],
            [2009, 324, 24, 19],
            [2009, 327, 32, 28],
            [2009, 346, 26, 33],
            [2009, 355, 29, 24],
            [2009, 379, 13, 12],
            [2009, 389, 22, 18],
            [2009, 399, 32, 23],
            [2009, 425, 11, 14],
            [2009, 430, 16, 17],
            [2009, 436, 41, 31],
            [2009, 480, 39, 23],
            [2009, 503, 91, 27],
            [2009, 504, 8, 10],
            [2009, 541, 128, 38],
            [2009, 585, 34, 22],
            [2009, 590, 41, 46],
            [2009, 593, 31, 31],
            [2009, 597, 21, 14],
            [2009, 604, 76, 51],
            [2009, 612, 26, 27],
            [2009, 662, 41, 41],
            [2009, 663, 51, 27],
            [2009, 669, 16, 17],
            [2009, 686, 11, 17],
            [2009, 694, 26, 21],
            [2009, 700, 39, 29],
            [2009, 703, 14, 14],
            [2009, 716, 34, 26],
            [2009, 751, 20, 17],
            [2009, 766, 76, 41],
            [2009, 769, 51, 31],
            [2009, 803, 22, 20],
            [2009, 805, 16, 15],
            [2009, 820, 46, 31],
            [2009, 827, 11, 13],
            [2009, 845, 33, 29],
            [2009, 865, 56, 27],
            [2009, 871, 26, 18],
            [2009, 878, 7, 6],
            [2009, 882, 26, 24],
            [2009, 894, 17, 13],
            [2009, 913, 16, 16],
            [2009, 922, 21, 23],
            [2009, 938, 11, 11],
            [2009, 940, 11, 12],
            [2009, 941, 31, 36],
            [2009, 964, 13, 14],
            [2009, 969, 36, 32],
            [2009, 971, 10, 10],
            [2009, 985, 44, 29],
            [2009, 998, 35, 26],
            [2009, 1003, 8, 6],
            [2009, 1008, 27, 24],
            [2009, 1016, 8, 9],
            [2009, 1030, 9, 10],
            [2009, 1059, 31, 31],
            [2009, 1106, 45, 22],
            [2009, 1111, 26, 33],
            [2009, 1132, 11, 11],
            [2009, 1136, 26, 27],
            [2009, 1150, 21, 19],
            [2009, 1156, 20, 16],
            [2009, 1157, 31, 33],
            [2009, 1159, 71, 27],
            [2009, 1174, 21, 31],
            [2009, 1186, 15, 14],
            [2009, 1203, 11, 17],
            [2009, 1213, 16, 14],
            [2009, 1221, 13, 15],
            [2009, 1226, 16, 22],
            [2009, 1234, 13, 15],
            [2009, 1235, 20, 17],
            [2009, 1238, 14, 18],
            [2009, 1247, 25, 19],
            [2009, 1254, 38, 20],
            [2009, 1268, 22, 20],
            [2009, 1275, 26, 16],
            [2009, 1281, 9, 9],
            [2009, 1295, 29, 26],
            [2009, 1303, 38, 30],
            [2009, 1320, 28, 32],
            [2009, 1396, 13, 15],
            [2009, 1420, 33, 35],
            [2009, 1445, 61, 21],
            [2009, 1466, 20, 17],
            [2009, 1473, 11, 8],
            [2009, 1481, 30, 18],
            [2009, 1491, 10, 8],
            [2009, 1507, 29, 25],
            [2009, 1515, 14, 12],
            [2009, 1525, 24, 21],
            [2009, 1530, 61, 40],
            [2009, 1536, 16, 19],
            [2009, 1557, 36, 21],
            [2009, 1577, 18, 14],
            [2009, 1580, 26, 24],
            [2009, 1587, 13, 15],
            [2009, 1589, 31, 20],
            [2009, 1598, 11, 8],
            [2009, 1628, 21, 16],
            [2009, 1635, 17, 13],
            [2009, 1638, 51, 26],
            [2009, 1645, 44, 27],
            [2009, 1673, 49, 30],
            [2009, 1685, 23, 21],
            [2009, 1704, 11, 16],
            [2009, 1717, 37, 26],
            [2009, 1730, 14, 11],
            [2009, 1769, 36, 36],
            [2009, 1772, 9, 12],
            [2009, 1774, 19, 15],
            [2009, 1794, 21, 26],
            [2009, 1795, 10, 8],
            [2009, 1797, 38, 23],
            [2009, 1798, 30, 27],
            [2009, 1824, 56, 31],
            [2009, 1864, 91, 46],
            [2009, 1866, 28, 21],
            [2009, 1891, 26, 22],
            [2009, 1894, 20, 14],
            [2009, 1903, 40, 24],
            [2009, 1921, 21, 12],
            [2009, 1930, 10, 7],
            [2009, 1952, 86, 38],
            [2009, 1962, 11, 11],
            [2009, 1965, 56, 34],
            [2009, 2011, 14, 16],
            [2009, 2017, 21, 20],
            [2009, 2023, 7, 7],
            [2009, 2035, 38, 25],
            [2009, 2056, 21, 31],
            [2009, 2064, 35, 22],
            [2009, 2142, 9, 10],
            [2009, 2178, 11, 13],
            [2009, 2190, 23, 17],
            [2009, 2198, 13, 12],
            [2009, 2208, 51, 30],
            [2009, 2213, 27, 23],
            [2009, 2227, 12, 14],
            [2009, 2244, 18, 17],
            [2009, 2250, 30, 22],
            [2009, 2277, 26, 26],
            [2009, 2280, 11, 9],
            [2009, 2282, 15, 31],
            [2009, 2311, 22, 20],
            [2009, 2316, 37, 27],
            [2009, 2343, 36, 26],
            [2009, 2352, 31, 21],
            [2009, 2371, 37, 25],
            [2009, 2429, 15, 16],
            [2009, 2435, 11, 12],
            [2009, 2443, 35, 23],
            [2009, 2458, 26, 21],
            [2009, 2459, 15, 16],
            [2009, 2467, 14, 11],
            [2009, 2483, 36, 42],
            [2009, 2485, 11, 16],
            [2009, 2500, 21, 15],
            [2009, 2501, 35, 25],
            [2009, 2505, 38, 23],
            [2009, 2524, 10, 9],
            [2009, 2533, 10, 15],
            [2009, 2539, 91, 27],
            [2009, 2547, 16, 26],
            [2009, 2554, 11, 12],
            [2009, 2576, 39, 23],
            [2009, 2585, 51, 31],
            [2009, 2595, 29, 26],
            [2009, 2606, 13, 13],
            [2009, 2627, 31, 20],
            [2009, 2635, 14, 15],
            [2009, 2670, 30, 20],
            [2009, 2671, 30, 25],
            [2009, 2692, 20, 19],
            [2009, 2695, 17, 12],
            [2009, 2723, 32, 25],
            [2009, 2758, 28, 23],
            [2009, 2775, 36, 25],
            [2009, 2785, 9, 10],
            [2009, 2798, 14, 17],
            [2009, 2822, 17, 16],
            [2009, 2835, 18, 16],
            [2009, 2836, 29, 20],
            [2009, 2879, 16, 16],
            [2009, 2883, 31, 36],
            [2009, 2914, 40, 23],
            [2009, 2922, 10, 12],
            [2009, 2991, 29, 21],
            [2009, 3019, 29, 19],
            [2009, 3033, 56, 42],
            [2009, 3046, 61, 24],
            [2009, 3053, 45, 24],
            [2009, 3066, 34, 24],
            [2009, 3086, 65, 38],
            [2009, 3091, 11, 13],
            [2009, 3092, 30, 23],
            [2009, 3119, 11, 12],
            [2009, 3126, 35, 22],
            [2009, 3134, 22, 21],
            [2009, 3158, 21, 18],
            [2009, 3164, 35, 23],
            [2009, 3171, 20, 16],
            [2009, 3182, 55, 31],
            [2009, 3221, 34, 24],
            [2009, 3246, 56, 32],
            [2009, 3252, 30, 20],
            [2009, 3254, 26, 31],
            [2009, 3273, 47, 22],
            [2009, 3274, 11, 16],
            [2009, 3301, 46, 27],
            [2009, 3308, 41, 25],
            [2009, 3309, 24, 22],
            [2009, 3321, 26, 21],
            [2009, 3327, 36, 36],
            [2009, 3348, 33, 22],
            [2009, 3364, 11, 14],
            [2009, 3372, 30, 23],
            [2009, 3382, 21, 15],
            [2009, 3434, 7, 7],
            [2009, 3438, 37, 23],
            [2009, 3451, 31, 41],
            [2009, 3454, 11, 11],
            [2009, 3462, 35, 22],
            [2009, 3494, 11, 11],
            [2009, 3503, 81, 41],
            [2009, 3515, 12, 27],
            [2009, 3517, 30, 23],
            [2009, 3559, 24, 23],
            [2009, 3569, 33, 34],
            [2009, 3590, 21, 26],
            [2009, 3593, 46, 51],
            [2009, 3659, 36, 26],
            [2009, 3669, 14, 16],
            [2009, 3700, 14, 13],
            [2009, 3718, 39, 30],
            [2009, 3726, 13, 12],
            [2009, 3729, 92, 38],
            [2009, 3765, 12, 16],
            [2009, 3859, 11, 13],
            [2009, 3884, 32, 23],
            [2009, 3889, 32, 22],
            [2009, 3915, 20, 33],
            [2009, 3925, 41, 31],
            [2009, 3943, 20, 19],
            [2009, 3956, 29, 34],
            [2009, 3972, 126, 63],
            [2009, 3976, 16, 17],
            [2009, 3985, 18, 17],
            [2009, 3993, 15, 14],
            [2009, 4015, 34, 23],
            [2009, 4022, 38, 22],
            [2009, 4026, 21, 26],
            [2009, 4027, 38, 23],
            [2009, 4028, 11, 21],
            [2009, 4043, 16, 14],
            [2009, 4074, 17, 19],
            [2009, 4091, 26, 22],
            [2009, 4107, 38, 25],
            [2009, 4125, 14, 16],
            [2009, 4173, 14, 16],
            [2009, 4176, 11, 11],
            [2009, 4209, 51, 32],
            [2009, 4246, 10, 17],
            [2009, 4285, 16, 21],
            [2009, 4299, 36, 21],
            [2009, 4301, 46, 46],
            [2009, 4310, 20, 20],
            [2009, 4312, 33, 24],
            [2009, 4325, 28, 19],
            [2009, 4353, 19, 13],
            [2009, 4358, 12, 13],
            [2009, 4362, 46, 28],
            [2009, 4380, 11, 11],
            [2009, 4382, 76, 31],
            [2009, 4386, 16, 16],
            [2009, 4413, 11, 11],
            [2009, 4414, 16, 18],
            [2009, 4426, 14, 15],
            [2009, 4440, 29, 23],
            [2009, 4442, 16, 18],
            [2009, 4454, 9, 10],
            [2009, 4464, 25, 21],
            [2009, 4477, 22, 21],
            [2009, 4487, 16, 22],
            [2009, 4491, 32, 24],
            [2009, 4518, 40, 21],
            [2009, 4536, 16, 16],
            [2009, 4545, 30, 23],
            [2009, 4610, 38, 23],
            [2009, 4617, 112, 34],
            [2009, 4623, 21, 16],
            [2009, 4626, 18, 14],
            [2009, 4634, 20, 18],
            [2009, 4638, 46, 23],
            [2009, 4644, 13, 15],
            [2009, 4648, 27, 19],
            [2009, 4660, 40, 23],
            [2009, 4670, 34, 23],
            [2009, 4676, 11, 13],
            [2009, 4689, 29, 25],
            [2009, 4710, 8, 6],
            [2009, 4724, 21, 26],
            [2009, 4734, 12, 12],
            [2009, 4738, 31, 29],
            [2009, 4749, 27, 23],
            [2009, 4762, 27, 23],
            [2009, 4764, 21, 21],
            [2009, 4789, 38, 23],
            [2009, 4794, 18, 15],
            [2009, 4801, 13, 16],
            [2009, 4805, 12, 15],
            [2009, 4820, 33, 25],
            [2009, 4828, 56, 42],
            [2009, 4832, 17, 17],
            [2009, 4840, 32, 23],
            [2009, 4849, 16, 16],
            [2009, 4863, 30, 25],
            [2009, 4865, 19, 16],
            [2009, 4871, 11, 13],
            [2009, 4888, 36, 31],
            [2009, 4897, 12, 14],
            [2009, 4912, 11, 16],
            [2009, 4914, 21, 17],
            [2009, 4918, 13, 13],
            [2009, 4926, 46, 41],
            [2009, 4939, 18, 16],
            [2009, 4944, 13, 14],
            [2009, 4951, 26, 26],
            [2009, 4973, 31, 31],
            [2009, 4976, 11, 11],
            [2009, 4983, 13, 11],
            [2009, 4992, 15, 15],
            [2009, 5006, 46, 38],
            [2009, 5019, 51, 31],
            [2009, 5031, 11, 11],
            [2009, 5038, 14, 15],
            [2009, 5048, 26, 26],
            [2009, 5050, 31, 16],
            [2009, 5051, 12, 15],
            [2009, 5062, 46, 22],
            [2009, 5063, 21, 26],
            [2009, 5073, 91, 36],
            [2009, 5081, 24, 19],
            [2009, 5091, 66, 31],
            [2009, 5092, 11, 11],
            [2009, 5095, 14, 14],
            [2009, 5107, 81, 31],
            [2009, 5108, 16, 18],
            [2009, 5149, 19, 17],
            [2009, 5159, 35, 26],
            [2009, 5184, 23, 18],
            [2009, 5185, 18, 15],
            [2009, 5186, 14, 15],
            [2009, 5187, 14, 15],
            [2009, 5188, 16, 17],
            [2009, 5217, 33, 23],
            [2009, 5219, 17, 23],
            [2009, 5220, 15, 26],
            [2009, 5221, 11, 15],
            [2009, 5222, 15, 21],
            [2009, 5223, 11, 19],
            [2009, 5224, 16, 26],
            [2009, 5225, 15, 23],
            [2009, 5226, 12, 23],
            [2009, 5227, 26, 33],
            [2009, 5228, 18, 31],
            [2009, 5229, 11, 22],
            [2009, 5230, 15, 21],
            [2009, 5231, 12, 20],
            [2009, 5232, 17, 28],
            [2009, 5233, 22, 34],
            [2009, 5234, 10, 15],
            [2009, 5235, 28, 24],
            [2009, 5236, 14, 20],
            [2009, 5237, 20, 26],
            [2009, 5238, 13, 16],
            [2009, 5239, 21, 30],
            [2009, 5240, 18, 34],
            [2009, 5241, 22, 31],
            [2009, 5242, 17, 22],
            [2009, 5243, 21, 34],
            [2009, 5244, 21, 34],
            [2009, 5245, 22, 34],
            [2009, 5273, 18, 14],
            [2009, 5375, 11, 6],
            [2009, 5434, 6, 6],
            [2009, 5472, 21, 21],
            [2009, 5473, 26, 26],
            [2009, 5495, 31, 26],
            [2009, 5528, 11, 11],
            [2009, 5944, 7, 7],
            [2009, 5945, 8, 8],
            [2009, 5946, 6, 5],
            [2009, 5989, 145, 155],
            [2009, 5990, 145, 155],
            [2009, 5991, 145, 155],
            [2009, 5992, 145, 155],
            [2009, 5993, 145, 155],
            [2009, 5996, 32, 23],
            [2009, 6068, 29, 26],
            [2009, 6069, 30, 27],
            [2009, 6070, 30, 30],
            [2009, 6071, 25, 22],
            [2009, 6073, 19, 22],
            [2009, 6074, 27, 25],
            [2009, 6075, 19, 26],
            [2009, 6076, 18, 19],
            [2009, 6077, 25, 24],
            [2009, 6078, 22, 21],
            [2009, 6079, 28, 25],
            [2009, 6080, 17, 24],
            [2009, 6081, 16, 17],
            [2009, 6082, 27, 25],
            [2009, 6083, 26, 23],
            [2009, 6084, 29, 23],
            [2009, 6085, 27, 24],
            [2009, 6087, 23, 21],
            [2009, 6088, 19, 19],
            [2009, 6089, 23, 21],
            [2009, 6090, 30, 24],
            [2009, 6091, 17, 21],
            [2009, 6092, 26, 25],
            [2009, 6093, 32, 27],
            [2009, 6094, 27, 25],
            [2009, 6095, 11, 16],
            [2009, 6096, 26, 22],
            [2009, 6097, 35, 22],
            [2009, 6098, 25, 22],
            [2009, 6099, 23, 23],
            [2009, 6100, 20, 25],
            [2009, 6101, 19, 22],
            [2009, 6102, 17, 20],
            [2009, 6103, 26, 23],
            [2009, 6104, 27, 21],
            [2009, 6105, 23, 23],
            [2009, 6106, 22, 20],
            [2009, 6108, 25, 22],
            [2009, 6109, 12, 18],
            [2009, 6110, 26, 25],
            [2009, 6111, 11, 14],
            [2009, 6112, 20, 24],
            [2009, 6113, 20, 20],
            [2009, 6114, 21, 20],
            [2009, 6115, 13, 18],
            [2009, 6116, 22, 23],
            [2009, 6117, 23, 23],
            [2009, 6118, 30, 25],
            [2009, 6119, 25, 24],
            [2009, 6120, 15, 18],
            [2009, 6121, 13, 22],
            [2009, 6122, 25, 23],
            [2009, 6123, 20, 20],
            [2009, 6124, 25, 23],
            [2009, 6125, 23, 25],
            [2009, 6126, 24, 24],
            [2009, 6127, 22, 25],
            [2009, 6128, 22, 25],
            [2009, 6130, 24, 23],
            [2009, 6131, 26, 23],
            [2009, 6132, 27, 25],
            [2009, 6133, 26, 23],
            [2009, 6134, 26, 23],
            [2009, 6135, 40, 28],
            [2009, 6136, 35, 33],
            [2009, 6137, 14, 16],
            [2009, 6138, 14, 19],
            [2009, 6139, 23, 22],
            [2009, 6140, 15, 17],
            [2009, 6141, 19, 19],
            [2009, 6142, 14, 20],
            [2009, 6143, 23, 23],
            [2009, 6145, 23, 23],
            [2009, 6146, 11, 14],
            [2009, 6147, 15, 20],
            [2009, 6148, 14, 18],
            [2009, 6149, 24, 25],
            [2009, 6150, 15, 16],
            [2009, 6151, 17, 17],
            [2009, 6152, 15, 18],
            [2009, 6153, 14, 17],
            [2009, 6154, 18, 22],
            [2009, 6155, 15, 17],
            [2009, 6156, 19, 18],
            [2009, 6157, 21, 19],
            [2009, 6158, 19, 17],
            [2009, 6159, 21, 19],
            [2009, 6160, 19, 20],
            [2009, 6161, 12, 14],
            [2009, 6162, 16, 16],
            [2009, 6163, 26, 21],
            [2009, 6164, 23, 22],
            [2009, 6165, 19, 17],
            [2009, 6166, 38, 24],
            [2009, 6167, 26, 28],
            [2009, 6244, 33, 26],
            [2009, 6353, 29, 25],
            [2009, 6358, 29, 20],
            [2009, 6391, 46, 42],
            [2009, 6433, 23, 27],
            [2009, 6438, 56, 44],
            [2009, 6442, 27, 17],
            [2009, 6463, 57, 35],
            [2009, 6471, 56, 33],
            [2009, 6492, 33, 40],
            [2009, 6494, 30, 30],
            [2009, 6495, 33, 20],
            [2009, 6502, 20, 15],
            [2009, 6614, 17, 18],
            [2009, 6631, 26, 26],
            [2009, 6633, 18, 22],
            [2009, 6634, 23, 22],
            [2009, 6635, 23, 24],
            [2009, 6636, 29, 28],
            [2009, 6637, 25, 23],
            [2009, 6638, 41, 25],
            [2009, 6639, 25, 26],
            [2009, 6640, 23, 43],
            [2009, 6643, 35, 23],
            [2009, 6649, 29, 23],
            [2009, 6650, 29, 23],
            [2009, 6651, 24, 20],
            [2009, 6652, 23, 23],
            [2009, 6653, 29, 26],
            [2009, 6654, 27, 23],
            [2009, 6655, 24, 21],
            [2009, 6656, 25, 24],
            [2009, 6657, 22, 26],
            [2009, 6660, 27, 22],
            [2009, 6661, 22, 23],
            [2009, 6662, 23, 23],
            [2009, 6663, 24, 23],
            [2009, 6664, 29, 26],
            [2009, 6665, 24, 25],
            [2009, 6666, 24, 23],
            [2009, 6667, 25, 24],
            [2009, 6668, 29, 21],
            [2009, 6669, 17, 26],
            [2009, 6670, 25, 24],
            [2009, 6671, 29, 24],
            [2009, 6672, 26, 23],
            [2009, 6673, 27, 23],
            [2009, 6674, 25, 25],
            [2009, 6675, 23, 21],
            [2009, 6676, 29, 25],
            [2009, 6677, 24, 25],
            [2009, 6678, 23, 21],
            [2009, 6679, 41, 33],
            [2009, 6680, 22, 20],
            [2009, 6682, 23, 23],
            [2009, 6683, 19, 21],
            [2009, 6684, 22, 23],
            [2009, 6685, 18, 18],
            [2009, 6686, 16, 17],
            [2009, 6687, 17, 21],
            [2009, 6688, 17, 17],
            [2009, 6689, 14, 18],
            [2009, 6690, 16, 19],
            [2009, 6697, 20, 24],
            [2009, 6699, 22, 63],
            [2009, 6700, 68, 44],
            [2009, 6701, 46, 32],
            [2009, 6702, 53, 43],
            [2009, 6704, 48, 37],
            [2009, 6715, 53, 29],
            [2009, 6716, 50, 29],
            [2009, 6718, 19, 33],
            [2009, 6722, 45, 29],
            [2009, 6723, 83, 53],
            [2009, 6726, 16, 48],
            [2009, 6728, 53, 36],
            [2009, 6734, 50, 30],
            [2009, 6737, 25, 73],
            [2009, 6738, 44, 39],
            [2009, 6741, 14, 15],
            [2009, 6748, 23, 23],
            [2009, 6749, 17, 21],
            [2009, 6750, 26, 27],
            [2009, 6752, 13, 19],
            [2009, 6753, 25, 24],
            [2009, 6754, 26, 25],
            [2009, 6755, 32, 28],
            [2009, 6756, 25, 24],
            [2009, 6757, 22, 22],
            [2009, 6758, 18, 26],
            [2009, 6759, 15, 19],
            [2009, 6760, 34, 28],
            [2009, 6761, 26, 28],
            [2009, 6762, 26, 27],
            [2009, 6763, 13, 16],
            [2009, 6764, 25, 27],
            [2009, 6766, 30, 27],
            [2009, 6767, 26, 24],
            [2009, 6768, 24, 23],
            [2009, 6769, 27, 29],
            [2009, 6770, 27, 28],
            [2009, 6771, 22, 27],
            [2009, 6772, 17, 20],
            [2009, 6773, 28, 27],
            [2009, 6777, 30, 29],
            [2009, 6778, 13, 20],
            [2009, 6779, 24, 25],
            [2009, 6780, 30, 28],
            [2009, 6781, 29, 28],
            [2009, 6782, 42, 29],
            [2009, 6783, 27, 29],
            [2009, 6784, 23, 27],
            [2009, 6785, 28, 26],
            [2009, 6786, 21, 28],
            [2009, 6787, 25, 28],
            [2009, 6789, 27, 25],
            [2009, 6790, 19, 63],
            [2009, 6791, 63, 69],
            [2009, 6794, 16, 45],
            [2009, 6795, 30, 39],
            [2009, 6798, 58, 30],
            [2009, 6803, 22, 78],
            [2009, 6804, 48, 73],
            [2009, 6805, 50, 63],
            [2009, 6806, 22, 53],
            [2009, 6807, 46, 49],
            [2009, 6808, 17, 38],
            [2009, 6812, 179, 83],
            [2009, 6813, 18, 54],
            [2009, 6814, 146, 98],
            [2009, 6816, 46, 84],
            [2009, 6818, 15, 15],
            [2009, 6819, 25, 31],
            [2009, 6820, 26, 27],
            [2009, 6821, 42, 35],
            [2009, 6822, 40, 35],
            [2009, 6823, 26, 27],
            [2009, 6833, 30, 33],
            [2009, 6834, 90, 93],
            [2009, 6835, 133, 113],
            [2009, 6836, 38, 43],
            [2009, 6837, 14, 26],
            [2009, 6838, 127, 84],
            [2009, 6841, 25, 21],
            [2009, 6845, 19, 51],
            [2009, 6846, 14, 39],
            [2009, 6847, 19, 43],
            [2009, 6848, 19, 28],
            [2009, 6849, 54, 39],
            [2009, 6850, 19, 33],
            [2009, 6851, 36, 44],
            [2009, 6852, 90, 98],
            [2009, 6853, 20, 53],
            [2009, 6854, 93, 75],
            [2009, 6855, 19, 38],
            [2009, 6856, 15, 50],
            [2009, 6857, 26, 59],
            [2009, 6858, 19, 38],
            [2009, 6859, 30, 25],
            [2009, 6860, 16, 43],
            [2009, 6861, 19, 43],
            [2009, 6862, 30, 33],
            [2009, 6867, 14, 18],
            [2009, 6868, 15, 13],
            [2009, 6869, 14, 14],
            [2009, 6870, 11, 15],
            [2009, 6871, 15, 17],
            [2009, 6872, 15, 16],
            [2009, 6873, 21, 15],
            [2009, 6874, 11, 16],
            [2009, 6875, 14, 17],
            [2009, 6876, 11, 15],
            [2009, 6877, 16, 19],
            [2009, 6878, 14, 16],
            [2009, 6879, 16, 20],
            [2009, 6880, 21, 19],
            [2009, 6881, 11, 13],
            [2009, 6882, 15, 16],
            [2009, 6883, 21, 21],
            [2009, 6910, 18, 18],
            [2009, 6912, 11, 10],
            [2009, 6914, 11, 11],
            [2009, 6918, 15, 16],
            [2009, 6920, 13, 16],
            [2009, 6922, 11, 11],
            [2009, 6928, 12, 14],
            [2009, 6930, 16, 17],
            [2009, 6931, 37, 28],
            [2009, 6934, 13, 13],
            [2009, 6938, 12, 12],
            [2009, 6940, 11, 10],
            [2009, 6942, 11, 16],
            [2009, 6944, 9, 10],
            [2009, 6948, 11, 10],
            [2009, 6950, 11, 10],
            [2009, 6952, 26, 20],
            [2009, 6954, 14, 13],
            [2009, 6957, 63, 40],
            [2009, 6958, 12, 11],
            [2009, 6960, 11, 13],
            [2009, 6962, 13, 10],
            [2009, 6965, 9, 10],
            [2009, 6966, 20, 38],
            [2009, 6967, 13, 21],
            [2009, 6968, 32, 45],
            [2009, 6969, 13, 20],
            [2009, 6970, 19, 38],
            [2009, 7007, 35, 21],
            [2009, 7008, 58, 27],
            [2009, 7011, 11, 11],
            [2009, 7013, 15, 15],
            [2009, 7014, 14, 9],
            [2009, 7015, 9, 8],
            [2009, 7019, 9, 9],
            [2009, 7021, 11, 11],
            [2009, 7027, 11, 12],
            [2009, 7029, 36, 23],
            [2009, 7031, 12, 14],
            [2009, 7033, 19, 14],
            [2009, 7035, 11, 10],
            [2009, 7039, 15, 14],
            [2009, 7050, 11, 11],
            [2009, 7052, 11, 14],
            [2009, 7054, 15, 12],
            [2009, 7056, 11, 13],
            [2009, 7057, 48, 28],
            [2009, 7058, 16, 14],
            [2009, 7062, 11, 11],
            [2009, 7063, 40, 27],
            [2009, 7066, 10, 10],
            [2009, 7068, 44, 22],
            [2009, 7070, 37, 28],
            [2009, 7072, 11, 10],
            [2009, 7074, 12, 13],
            [2009, 7076, 14, 16],
            [2009, 7078, 11, 11],
            [2009, 7080, 31, 25],
            [2009, 7082, 11, 13],
            [2009, 7084, 25, 21],
            [2009, 7086, 11, 15],
            [2009, 7088, 31, 22],
            [2009, 7090, 11, 11],
            [2009, 7091, 48, 28],
            [2009, 7092, 40, 31],
            [2009, 7093, 67, 45],
            [2009, 7094, 29, 26],
            [2009, 7098, 11, 18],
            [2009, 7156, 16, 17],
            [2009, 7283, 10, 17],
            [2009, 7284, 16, 18],
            [2009, 7285, 17, 20],
            [2009, 7286, 10, 18],
            [2009, 7287, 17, 22],
            [2009, 7288, 33, 30],
            [2009, 7289, 26, 25],
            [2009, 7290, 37, 33],
            [2009, 7291, 38, 32],
            [2009, 7292, 26, 31],
            [2009, 7293, 20, 24],
            [2009, 7294, 21, 26],
            [2009, 7295, 11, 12],
            [2009, 7296, 21, 18],
            [2009, 7297, 24, 21],
            [2009, 7298, 15, 15],
            [2009, 7299, 16, 16],
            [2009, 7300, 16, 19],
            [2009, 7301, 13, 18],
            [2009, 7302, 27, 30],
            [2009, 7303, 66, 56],
            [2009, 7304, 26, 28],
            [2009, 7305, 30, 31],
            [2009, 7306, 26, 28],
            [2009, 7307, 47, 50],
            [2009, 7308, 35, 35],
            [2009, 7309, 26, 28],
            [2009, 7310, 75, 60],
            [2009, 7311, 66, 59],
            [2009, 7312, 26, 28],
            [2009, 7313, 118, 35],
            [2009, 7314, 24, 16],
            [2009, 7315, 14, 12],
            [2009, 7316, 35, 60],
            [2009, 7317, 39, 31],
            [2009, 7318, 119, 81],
            [2009, 7319, 40, 31],
            [2009, 7320, 73, 57],
            [2009, 7321, 80, 90],
            [2009, 7322, 70, 38],
            [2009, 7323, 85, 70],
            [2009, 7324, 67, 54],
            [2009, 7325, 103, 40],
            [2009, 7326, 25, 16],
            [2009, 7327, 175, 107],
            [2009, 7328, 18, 20],
            [2009, 7329, 31, 28],
            [2009, 7330, 21, 16],
            [2009, 7337, 13, 10],
            [2009, 7342, 13, 9],
            [2009, 7343, 15, 8],
            [2009, 7344, 10, 8],
            [2009, 7348, 15, 9],
            [2009, 7352, 12, 10],
            [2009, 7354, 23, 13],
            [2009, 7356, 15, 10],
            [2009, 7357, 24, 13],
            [2009, 7358, 17, 11],
            [2009, 7359, 24, 14],
            [2009, 7360, 13, 10],
            [2009, 7362, 15, 11],
            [2009, 7363, 13, 9],
            [2009, 7364, 15, 10],
            [2009, 7367, 13, 11],
            [2009, 7370, 12, 10],
            [2009, 7371, 13, 8],
            [2009, 7372, 13, 10],
            [2009, 7373, 13, 9],
            [2009, 7374, 10, 8],
            [2009, 7375, 12, 10],
            [2009, 7376, 7, 7],
            [2009, 7377, 11, 8],
            [2009, 7378, 11, 14],
            [2009, 7379, 21, 17],
            [2009, 7398, 24, 31],
            [2009, 7399, 27, 28],
            [2009, 7401, 21, 27],
            [2009, 7403, 15, 22],
            [2009, 7405, 20, 23],
            [2009, 7406, 27, 28],
            [2009, 7407, 29, 36],
            [2009, 7410, 15, 20],
            [2009, 7411, 41, 28],
            [2009, 7413, 9, 11],
            [2009, 7414, 14, 21],
            [2009, 7415, 9, 11],
            [2009, 7416, 26, 28],
            [2009, 7417, 20, 18],
            [2009, 7420, 24, 25],
            [2009, 7421, 24, 23],
            [2009, 7423, 60, 49],
            [2009, 7433, 72, 51],
            [2009, 7434, 93, 84],
            [2009, 7435, 33, 39],
            [2009, 7436, 43, 43],
            [2009, 7437, 23, 20],
            [2009, 7438, 73, 33],
            [2009, 7441, 35, 25],
            [2009, 7442, 40, 21],
            [2009, 7443, 32, 43],
            [2009, 7444, 50, 73],
            [2009, 7445, 33, 55],
            [2009, 7446, 41, 59],
            [2009, 7447, 18, 20],
            [2009, 7448, 49, 34],
            [2009, 7451, 16, 11],
            [2009, 7454, 31, 26],
            [2009, 7456, 28, 31],
            [2009, 7457, 32, 31],
            [2009, 7458, 26, 25],
            [2009, 7459, 44, 30],
            [2009, 7460, 51, 35],
            [2009, 7461, 28, 25],
            [2009, 7462, 38, 32],
            [2009, 7463, 50, 28],
            [2009, 7464, 80, 35],
            [2009, 7465, 33, 26],
            [2009, 7466, 42, 31],
            [2009, 7467, 35, 32],
            [2009, 7468, 30, 26],
            [2009, 7469, 47, 28],
            [2009, 7470, 48, 36],
            [2009, 7471, 50, 33],
            [2009, 7472, 62, 33],
            [2009, 7473, 30, 27],
            [2009, 7474, 42, 30],
            [2009, 7475, 48, 30],
            [2009, 7476, 43, 27],
            [2009, 7477, 27, 26],
            [2009, 7478, 46, 27],
            [2009, 7479, 30, 26],
            [2009, 7480, 41, 35],
            [2009, 7481, 28, 27],
            [2009, 7482, 42, 26],
            [2009, 7483, 32, 30],
            [2009, 7484, 31, 29],
            [2009, 7485, 62, 39],
            [2009, 7486, 36, 28],
            [2009, 7487, 49, 27],
            [2009, 7488, 33, 26],
            [2009, 7489, 53, 34],
            [2009, 7490, 27, 22],
            [2009, 7491, 39, 27],
            [2009, 7492, 48, 35],
            [2009, 7493, 40, 28],
            [2009, 7494, 58, 28],
            [2009, 7495, 35, 30],
            [2009, 7496, 77, 42],
            [2009, 7497, 33, 27],
            [2009, 7498, 31, 28],
            [2009, 7499, 30, 25],
            [2009, 7500, 42, 35],
            [2009, 7501, 50, 33],
            [2009, 7502, 40, 32],
            [2009, 7503, 40, 28],
            [2009, 7504, 29, 30],
            [2009, 7505, 48, 28],
            [2009, 7506, 66, 35],
            [2009, 7507, 42, 27],
            [2009, 7508, 45, 29],
            [2009, 7509, 43, 30],
            [2009, 7510, 32, 30],
            [2009, 7511, 36, 28],
            [2009, 7512, 32, 30],
            [2009, 7513, 33, 26],
            [2009, 7514, 53, 42],
            [2009, 7515, 44, 34],
            [2009, 7516, 32, 30],
            [2009, 7517, 79, 39],
            [2009, 7518, 48, 35],
            [2009, 7519, 25, 25],
            [2009, 7520, 37, 28],
            [2009, 7521, 26, 27],
            [2009, 7522, 50, 38],
            [2009, 7523, 37, 26],
            [2009, 7524, 39, 33],
            [2009, 7525, 32, 30],
            [2009, 7526, 34, 27],
            [2009, 7527, 36, 26],
            [2009, 7528, 39, 31],
            [2009, 7529, 55, 46],
            [2009, 7530, 42, 36],
            [2009, 7531, 29, 21],
            [2009, 7532, 49, 30],
            [2009, 7533, 42, 38],
            [2009, 7534, 50, 36],
            [2009, 7535, 40, 34],
            [2009, 7536, 32, 29],
            [2009, 7537, 56, 34],
            [2009, 7538, 35, 35],
            [2009, 7539, 50, 28],
            [2009, 7540, 39, 28],
            [2009, 7541, 44, 34],
            [2009, 7542, 73, 31],
            [2009, 7543, 35, 27],
            [2009, 7544, 36, 28],
            [2009, 7545, 39, 27],
            [2009, 7546, 33, 27],
            [2009, 7547, 33, 27],
            [2009, 7548, 46, 28],
            [2009, 7549, 40, 30],
            [2009, 7550, 28, 26],
            [2009, 7551, 38, 32],
            [2009, 7552, 57, 32],
            [2009, 7553, 39, 28],
            [2009, 7554, 40, 36],
            [2009, 7555, 83, 39],
            [2009, 7556, 42, 30],
            [2009, 7557, 71, 33],
            [2009, 7558, 34, 25],
            [2009, 7559, 39, 27],
            [2009, 7560, 38, 32],
            [2009, 7561, 61, 33],
            [2009, 7562, 50, 39],
            [2009, 7563, 48, 36],
            [2009, 7564, 49, 28],
            [2009, 7565, 34, 28],
            [2009, 7566, 32, 28],
            [2009, 7567, 79, 30],
            [2009, 7568, 41, 28],
            [2009, 7569, 36, 28],
            [2009, 7570, 29, 28],
            [2009, 7571, 29, 28],
            [2009, 7572, 26, 34],
            [2009, 7573, 33, 22],
            [2009, 7574, 32, 28],
            [2009, 7575, 36, 28],
            [2009, 7576, 47, 35],
            [2009, 7577, 48, 36],
            [2009, 7578, 53, 28],
            [2009, 7579, 38, 29],
            [2009, 7580, 48, 36],
            [2009, 7581, 39, 28],
            [2009, 7582, 44, 36],
            [2009, 7583, 50, 30],
            [2009, 7584, 41, 27],
            [2009, 7585, 39, 34],
            [2009, 7586, 55, 42],
            [2009, 7587, 40, 28],
            [2009, 7588, 40, 28],
            [2009, 7589, 55, 42],
            [2009, 7590, 39, 36],
            [2009, 7591, 33, 26],
            [2009, 7592, 40, 36],
            [2009, 7593, 42, 34],
            [2009, 7594, 36, 28],
            [2009, 7595, 48, 28],
            [2009, 7596, 43, 26],
            [2009, 7597, 48, 28],
            [2009, 7598, 45, 35],
            [2009, 7599, 47, 30],
            [2009, 7600, 32, 30],
            [2009, 7601, 32, 26],
            [2009, 7602, 45, 26],
            [2009, 7603, 44, 36],
            [2009, 7604, 56, 30],
            [2009, 7605, 38, 30],
            [2009, 7606, 40, 29],
            [2009, 7607, 44, 36],
            [2009, 7608, 38, 32],
            [2009, 7609, 25, 30],
            [2009, 7610, 42, 27],
            [2009, 7611, 28, 32],
            [2009, 7612, 44, 36],
            [2009, 7613, 42, 28],
            [2009, 7614, 33, 28],
            [2009, 7615, 48, 36],
            [2009, 7616, 35, 27],
            [2009, 7617, 39, 26],
            [2009, 7618, 42, 34],
            [2009, 7619, 35, 30],
            [2009, 7620, 36, 28],
            [2009, 7621, 50, 30],
            [2009, 7622, 38, 29],
            [2009, 7623, 32, 28],
            [2009, 7624, 56, 31],
            [2009, 7625, 30, 27],
            [2009, 7626, 44, 34],
            [2009, 7627, 39, 33],
            [2009, 7628, 48, 36],
            [2009, 7629, 28, 33],
            [2009, 7630, 45, 27],
            [2009, 7631, 35, 29],
            [2009, 7632, 47, 27],
            [2009, 7633, 39, 27],
            [2009, 7634, 11, 15],
            [2009, 7635, 11, 14],
            [2009, 7636, 12, 17],
            [2009, 7639, 6, 11],
            [2009, 7649, 6, 6],
            [2009, 7661, 8, 10],
            [2009, 7662, 14, 13],
            [2009, 7663, 10, 12],
            [2009, 7668, 12, 11],
            [2009, 7669, 10, 8],
            [2009, 7672, 9, 9],
            [2009, 7673, 8, 7],
            [2009, 7674, 18, 14],
            [2009, 7676, 6, 8],
            [2009, 7677, 5, 6],
            [2009, 7678, 10, 8],
            [2009, 7679, 11, 9],
            [2009, 7680, 17, 16],
            [2009, 7681, 5, 3],
            [2009, 7682, 14, 13],
            [2009, 7683, 3, 3],
            [2009, 7684, 15, 13],
            [2009, 7685, 9, 10],
            [2009, 7686, 18, 16],
            [2009, 7687, 5, 4],
            [2009, 7688, 14, 13],
            [2009, 7690, 7, 8],
            [2009, 7691, 15, 18],
            [2009, 7692, 10, 8],
            [2009, 7693, 8, 9],
            [2009, 7694, 9, 9],
            [2009, 7695, 14, 17],
            [2009, 7696, 3, 3],
            [2009, 7697, 12, 12],
            [2009, 7698, 9, 8],
            [2009, 7699, 11, 13],
            [2009, 7700, 11, 10],
            [2009, 7701, 7, 8],
            [2009, 7702, 17, 13],
            [2009, 7703, 11, 11],
            [2009, 7705, 17, 13],
            [2009, 7706, 11, 10],
            [2009, 7707, 11, 10],
            [2009, 7708, 9, 7],
            [2009, 7709, 11, 12],
            [2009, 7710, 6, 5],
            [2009, 7711, 12, 10],
            [2009, 7713, 20, 12],
            [2009, 7714, 10, 9],
            [2009, 7716, 16, 20],
            [2009, 7717, 34, 26],
            [2009, 7718, 24, 32],
            [2009, 7719, 16, 21],
            [2009, 7722, 25, 30],
            [2009, 7723, 17, 36],
            [2009, 7725, 20, 19],
            [2009, 7726, 23, 19],
            [2009, 7729, 24, 25],
            [2009, 7730, 18, 21],
            [2009, 7731, 27, 22],
            [2009, 7734, 24, 27],
            [2009, 7736, 14, 23],
            [2009, 7737, 30, 26],
            [2009, 7738, 16, 20],
            [2009, 7739, 57, 32],
            [2009, 7740, 37, 34],
            [2009, 7741, 70, 42],
            [2009, 7743, 22, 28],
            [2009, 7744, 50, 39],
            [2009, 7749, 24, 23],
            [2009, 7753, 32, 28],
            [2009, 7754, 24, 30],
            [2009, 7755, 17, 27],
            [2009, 7757, 30, 85],
            [2009, 7758, 58, 99],
            [2009, 7759, 26, 27],
            [2009, 7760, 73, 47],
            [2009, 7761, 16, 35],
            [2009, 7762, 58, 63],
            [2009, 7763, 9, 14],
            [2009, 7764, 11, 12],
            [2009, 7765, 11, 14],
            [2009, 7766, 9, 12],
            [2009, 7796, 69, 38],
            [2009, 7797, 78, 45],
            [2009, 7798, 59, 28],
            [2009, 7799, 50, 43],
            [2009, 7800, 57, 26],
            [2009, 7801, 82, 38],
            [2009, 7802, 20, 24],
            [2009, 7803, 136, 67],
            [2009, 7804, 78, 37],
            [2009, 7805, 58, 35],
            [2009, 7806, 77, 47],
            [2009, 7807, 63, 46],
            [2009, 7808, 78, 29],
            [2009, 7809, 69, 44],
            [2009, 7810, 73, 63],
            [2009, 7811, 121, 78],
            [2009, 7812, 34, 30],
            [2009, 7813, 43, 26],
            [2009, 7815, 48, 31],
            [2009, 7816, 82, 55],
            [2009, 7817, 29, 36],
            [2009, 7818, 40, 36],
            [2009, 7819, 39, 55],
            [2009, 7820, 48, 31],
            [2009, 7821, 80, 47],
            [2009, 7822, 43, 39],
            [2009, 7823, 30, 21],
            [2009, 7824, 128, 78],
            [2009, 7825, 64, 31],
            [2009, 7826, 44, 37],
            [2009, 7827, 82, 31],
            [2009, 7828, 81, 86],
            [2009, 7829, 49, 38],
            [2009, 7830, 51, 32],
            [2009, 7831, 54, 33],
            [2009, 7832, 87, 52],
            [2009, 7833, 40, 31],
            [2009, 7834, 78, 52],
            [2009, 7835, 50, 26],
            [2009, 7836, 75, 57],
            [2009, 7837, 33, 32],
            [2009, 7838, 83, 25],
            [2009, 7839, 73, 53],
            [2009, 7840, 110, 62],
            [2009, 7841, 54, 31],
            [2009, 7842, 26, 25],
            [2009, 7843, 33, 20],
            [2009, 7844, 83, 37],
            [2009, 7845, 25, 26],
            [2009, 7846, 82, 41],
            [2009, 7847, 63, 30],
            [2009, 7848, 82, 43],
            [2009, 7849, 100, 68],
            [2009, 7850, 47, 59],
            [2009, 7851, 64, 46],
            [2009, 7852, 38, 27],
            [2009, 7853, 29, 34],
            [2009, 7854, 20, 25],
            [2009, 7855, 36, 25],
            [2009, 7856, 90, 47],
            [2009, 7857, 60, 30],
            [2009, 7858, 25, 25],
            [2009, 7859, 73, 42],
            [2009, 7860, 74, 43],
            [2009, 7861, 38, 27],
            [2009, 7862, 140, 55],
            [2009, 7863, 58, 52],
            [2009, 7864, 21, 30],
            [2009, 7865, 49, 30],
            [2009, 7866, 82, 43],
            [2009, 7867, 36, 30],
            [2009, 7868, 35, 30],
            [2009, 7869, 59, 44],
            [2009, 7870, 39, 29],
            [2009, 7871, 46, 31],
            [2009, 7872, 86, 62],
            [2009, 7873, 85, 46],
            [2009, 7874, 35, 30],
            [2009, 7875, 82, 42],
            [2009, 7876, 82, 55],
            [2009, 7877, 84, 42],
            [2009, 7878, 126, 35],
            [2009, 7879, 85, 52],
            [2009, 7880, 54, 34],
            [2009, 7881, 34, 37],
            [2009, 7882, 25, 18],
            [2009, 7883, 49, 38],
            [2009, 7884, 34, 38],
            [2009, 7885, 46, 34],
            [2009, 7886, 43, 30],
            [2009, 7887, 50, 26],
            [2009, 7888, 83, 33],
            [2009, 7889, 90, 57],
            [2009, 7890, 35, 44],
            [2009, 7891, 44, 26],
            [2009, 7892, 25, 30],
            [2009, 7893, 25, 26],
            [2009, 7894, 70, 51],
            [2009, 7895, 51, 34],
            [2009, 7896, 118, 48],
            [2009, 7897, 83, 40],
            [2009, 7898, 20, 32],
            [2009, 7899, 36, 54],
            [2009, 7900, 82, 49],
            [2009, 7901, 83, 37],
            [2009, 7902, 59, 40],
            [2009, 7903, 76, 42],
            [2009, 7904, 52, 39],
            [2009, 7905, 46, 45],
            [2009, 7906, 74, 50],
            [2009, 7907, 83, 43],
            [2009, 7908, 100, 43],
            [2009, 7909, 57, 36],
            [2009, 7910, 50, 38],
            [2009, 7911, 59, 42],
            [2009, 7912, 84, 66],
            [2009, 7913, 83, 40],
            [2009, 7914, 63, 47],
            [2009, 7915, 73, 60],
            [2009, 7916, 66, 39],
            [2009, 7917, 50, 37],
            [2009, 7918, 44, 31],
            [2009, 7919, 32, 28],
            [2009, 7920, 55, 37],
            [2009, 7921, 36, 15],
            [2009, 7922, 24, 31],
            [2009, 7923, 71, 31],
            [2009, 7924, 35, 31],
            [2009, 7925, 39, 31],
            [2009, 7926, 242, 37],
            [2009, 7927, 36, 40],
            [2009, 7928, 21, 31],
            [2009, 7929, 83, 42],
            [2009, 7930, 67, 46],
            [2009, 7931, 35, 30],
            [2009, 7932, 35, 30],
            [2009, 7933, 72, 37],
            [2009, 7934, 52, 38],
            [2009, 7935, 84, 47],
            [2009, 7936, 85, 42],
            [2009, 7937, 45, 38],
            [2009, 7938, 19, 15],
            [2009, 7939, 77, 55],
            [2009, 7940, 78, 47],
            [2009, 7941, 77, 53],
            [2009, 7942, 76, 46],
            [2009, 7943, 39, 26],
            [2009, 7944, 25, 28],
            [2009, 7945, 80, 33],
            [2009, 7946, 32, 46],
            [2009, 7947, 57, 37],
            [2009, 7948, 34, 26],
            [2009, 7949, 48, 55],
            [2009, 7950, 43, 36],
            [2009, 7951, 91, 42],
            [2009, 7952, 44, 29],
            [2009, 7953, 33, 14],
            [2009, 7954, 72, 22],
            [2009, 7955, 128, 37],
            [2009, 7956, 73, 33],
            [2009, 7957, 82, 37],
            [2009, 7958, 85, 37],
            [2009, 7959, 82, 34],
            [2009, 7960, 39, 32],
            [2009, 7961, 80, 48],
            [2009, 7962, 159, 54],
            [2009, 7963, 21, 21],
            [2009, 7964, 49, 55],
            [2009, 7965, 82, 31],
            [2009, 7966, 102, 77],
            [2009, 7967, 57, 27],
            [2009, 7968, 81, 60],
            [2009, 7969, 71, 57],
            [2009, 7970, 78, 45],
            [2009, 7971, 22, 28],
            [2009, 7972, 34, 31],
            [2009, 7974, 49, 25],
            [2009, 7975, 156, 78],
            [2009, 7976, 147, 41],
            [2009, 7977, 39, 41],
            [2009, 7978, 78, 45],
            [2009, 7979, 78, 42],
            [2009, 7980, 80, 42],
            [2009, 7981, 53, 25],
            [2009, 7982, 54, 32],
            [2009, 7983, 63, 25],
            [2009, 7984, 75, 55],
            [2009, 7985, 41, 38],
            [2009, 7986, 58, 31],
            [2009, 7987, 50, 37],
            [2009, 7988, 25, 36],
            [2009, 7989, 76, 34],
            [2009, 7990, 63, 31],
            [2009, 7992, 71, 38],
            [2009, 7993, 71, 44],
            [2009, 7994, 39, 32],
            [2009, 7995, 146, 62],
            [2009, 7996, 70, 42],
            [2009, 7997, 100, 47],
            [2009, 7998, 42, 22],
            [2009, 7999, 91, 45],
            [2009, 8000, 69, 27],
            [2009, 8001, 163, 75],
            [2009, 8002, 63, 36],
            [2009, 8003, 25, 24],
            [2009, 8004, 68, 49],
            [2009, 8022, 16, 21],
            [2009, 8038, 28, 36],
            [2009, 8039, 21, 21],
            [2009, 8040, 21, 22],
            [2009, 8041, 7, 9],
            [2009, 8045, 5, 3],
            [2009, 8046, 5, 3],
            [2009, 8047, 5, 4],
            [2009, 8048, 13, 16],
            [2009, 8049, 11, 14],
            [2009, 8050, 8, 9],
            [2009, 8052, 20, 28],
            [2009, 8053, 17, 25],
            [2009, 8054, 12, 24],
            [2009, 8055, 22, 29],
            [2009, 8056, 25, 32],
            [2009, 8057, 17, 22],
            [2009, 8059, 16, 19],
            [2009, 8060, 19, 17],
            [2009, 8061, 39, 40],
            [2009, 8062, 37, 42],
            [2009, 8063, 8, 10],
            [2009, 8064, 11, 14],
            [2009, 8065, 11, 11],
            [2009, 8068, 7, 9],
            [2009, 8069, 7, 9],
            [2009, 8071, 33, 18],
            [2009, 8073, 12, 12],
            [2009, 8074, 11, 12],
            [2009, 8075, 12, 12],
            [2009, 8076, 32, 19],
            [2009, 8086, 21, 24],
            [2009, 8087, 14, 21],
            [2009, 8088, 13, 21],
            [2009, 8089, 18, 21],
            [2009, 8090, 21, 31],
            [2009, 8091, 21, 23],
            [2009, 8092, 15, 21],
            [2009, 8093, 21, 21],
            [2009, 8094, 14, 21],
            [2009, 8095, 15, 21],
            [2009, 8096, 17, 21],
            [2009, 8097, 16, 24],
            [2009, 8099, 20, 23],
            [2009, 8102, 16, 16],
            [2009, 8103, 22, 28],
            [2009, 8107, 16, 20],
            [2009, 8109, 18, 22],
            [2009, 8110, 15, 17],
            [2009, 8116, 39, 51],
            [2009, 8117, 42, 53],
            [2009, 8118, 19, 24],
            [2009, 8119, 14, 24],
            [2009, 8120, 24, 23],
            [2009, 8121, 21, 21],
            [2009, 8124, 18, 26],
            [2009, 8126, 19, 19],
            [2009, 8127, 24, 25],
            [2009, 8131, 26, 31],
            [2009, 8133, 18, 21],
            [2009, 8134, 27, 27],
            [2009, 8136, 17, 20],
            [2009, 8137, 24, 27],
            [2009, 8138, 25, 25],
            [2009, 8140, 32, 44],
            [2009, 8141, 32, 40],
            [2009, 8145, 19, 25],
            [2009, 8149, 17, 21],
            [2009, 8151, 15, 20],
            [2009, 8153, 25, 26],
            [2009, 8154, 18, 23],
            [2009, 8155, 47, 37],
            [2009, 8159, 25, 23],
            [2009, 8160, 21, 23],
            [2009, 8164, 18, 22],
            [2009, 8167, 36, 37],
            [2009, 8168, 34, 51],
            [2009, 8170, 17, 29],
            [2009, 8171, 22, 19],
            [2009, 8175, 14, 18],
            [2009, 8177, 24, 23],
            [2009, 8178, 20, 20],
            [2009, 8184, 23, 20],
            [2009, 8185, 18, 18],
            [2009, 8187, 27, 30],
            [2009, 8188, 15, 17],
            [2009, 8194, 30, 28],
            [2009, 8195, 20, 23],
            [2009, 8196, 13, 16],
            [2009, 8198, 27, 31],
            [2009, 8200, 17, 26],
            [2009, 8202, 32, 59],
            [2009, 8205, 30, 26],
            [2009, 8208, 17, 25],
            [2009, 8210, 15, 25],
            [2009, 8217, 18, 28],
            [2009, 8218, 13, 18],
            [2009, 8219, 37, 27],
            [2009, 8220, 25, 22],
            [2009, 8221, 46, 26],
            [2009, 8222, 21, 15],
            [2009, 8223, 17, 25],
            [2009, 8224, 43, 34],
            [2009, 8225, 12, 17],
            [2009, 8227, 22, 23],
            [2009, 8228, 22, 45],
            [2009, 8231, 18, 21],
            [2009, 8232, 66, 40],
            [2009, 8234, 18, 23],
            [2009, 8236, 20, 20],
            [2009, 8238, 41, 32],
            [2009, 8241, 14, 20],
            [2009, 8248, 15, 19],
            [2009, 8250, 21, 19],
            [2009, 8251, 19, 21],
            [2009, 8254, 27, 27],
            [2009, 8255, 56, 38],
            [2009, 8256, 18, 23],
            [2009, 8259, 18, 23],
            [2009, 8260, 18, 23],
            [2009, 8262, 26, 27],
            [2009, 8264, 27, 32],
            [2009, 8265, 44, 37],
            [2009, 8268, 15, 24],
            [2009, 8270, 15, 24],
            [2009, 8271, 25, 28],
            [2009, 8276, 25, 21],
            [2009, 8277, 16, 19],
            [2009, 8287, 17, 21],
            [2009, 8288, 18, 20],
            [2009, 8294, 36, 51],
            [2009, 8299, 24, 17],
            [2009, 8300, 34, 27],
            [2009, 8302, 19, 15],
            [2009, 8309, 12, 18],
            [2009, 8310, 22, 22],
            [2009, 8311, 11, 12],
            [2009, 8312, 12, 13],
            [2009, 8313, 11, 12],
            [2009, 8314, 12, 12],
            [2009, 8315, 16, 14],
            [2009, 8316, 11, 11],
            [2009, 8317, 26, 18],
            [2009, 8319, 18, 16],
            [2009, 8322, 26, 20],
            [2009, 8323, 23, 20],
            [2009, 8324, 36, 25],
            [2009, 8390, 16, 16],
            [2009, 8536, 18, 23],
            [2009, 8537, 30, 20],
            [2009, 8538, 31, 22],
            [2009, 8539, 31, 25],
            [2009, 8540, 24, 29],
            [2009, 8541, 28, 34],
            [2009, 8542, 21, 27],
            [2009, 8543, 17, 27],
            [2009, 8544, 22, 40],
            [2009, 8546, 22, 30],
            [2009, 8547, 30, 40],
            [2009, 8548, 15, 16],
            [2009, 8549, 12, 21],
            [2009, 8550, 18, 20],
            [2009, 8551, 24, 24],
            [2009, 8552, 23, 27],
            [2009, 8553, 18, 26],
            [2009, 8554, 32, 25],
            [2009, 8555, 23, 22],
            [2009, 8556, 18, 24],
            [2009, 8557, 20, 28],
            [2009, 8558, 21, 21],
            [2009, 8559, 20, 24],
            [2009, 8560, 36, 26],
            [2009, 8561, 23, 24],
            [2009, 8562, 52, 27],
            [2009, 8563, 27, 29],
            [2009, 8564, 108, 71],
            [2009, 8565, 10, 11],
            [2009, 8566, 20, 14],
            [2009, 8567, 19, 17],
            [2009, 8568, 16, 15],
            [2009, 8569, 15, 14],
            [2009, 8570, 10, 10],
            [2009, 8571, 10, 10],
            [2009, 8572, 9, 10],
            [2009, 8573, 13, 11],
            [2009, 8574, 16, 13],
            [2009, 8575, 12, 10],
            [2009, 8576, 20, 17],
            [2009, 8577, 7, 13],
            [2009, 8578, 20, 17],
            [2009, 8579, 15, 16],
            [2009, 8580, 18, 16],
            [2009, 8581, 13, 10],
            [2009, 8582, 13, 14],
            [2009, 8583, 18, 17],
            [2009, 8584, 14, 13],
            [2009, 8719, 24, 21],
            [2009, 8720, 25, 21],
            [2009, 8721, 26, 21],
            [2009, 8722, 23, 21],
            [2009, 8723, 26, 21],
            [2009, 8724, 24, 22],
            [2009, 8725, 25, 21],
            [2009, 8726, 25, 22],
            [2009, 8727, 21, 22],
            [2009, 8728, 19, 21],
            [2009, 8729, 23, 21],
            [2009, 8730, 19, 20],
            [2009, 8731, 20, 20],
            [2009, 8732, 25, 22],
            [2009, 8733, 26, 22],
            [2009, 8734, 26, 21],
            [2009, 8735, 21, 19],
            [2009, 8736, 21, 21],
            [2009, 8737, 19, 19],
            [2009, 8738, 21, 19],
            [2009, 8739, 21, 20],
            [2009, 8740, 21, 19],
            [2009, 8741, 23, 20],
            [2009, 8742, 23, 20],
            [2009, 8743, 22, 20],
            [2009, 8744, 23, 20],
            [2009, 8745, 24, 21],
            [2009, 8746, 26, 22],
            [2009, 8747, 27, 20],
            [2009, 8748, 26, 21],
            [2009, 8749, 22, 21],
            [2009, 8750, 22, 21],
            [2009, 8751, 22, 21],
            [2009, 8752, 21, 19],
            [2009, 8753, 19, 20],
            [2009, 8754, 21, 21],
            [2009, 8755, 20, 21],
            [2009, 8756, 26, 22],
            [2009, 8757, 19, 19],
            [2009, 8758, 21, 19],
            [2009, 8759, 21, 21],
            [2009, 8760, 27, 28],
            [2009, 8761, 22, 21],
            [2009, 8762, 26, 21],
            [2009, 8763, 17, 18],
            [2009, 8764, 28, 21],
            [2009, 8765, 23, 19],
            [2009, 8766, 26, 22],
            [2009, 8767, 26, 22],
            [2009, 8768, 26, 22],
            [2009, 8769, 25, 22],
            [2009, 8770, 26, 21],
            [2009, 8771, 26, 21],
            [2009, 8772, 26, 21],
            [2009, 8773, 21, 19],
            [2009, 8774, 21, 19],
            [2009, 8775, 21, 19],
            [2009, 8776, 21, 19],
            [2009, 8777, 22, 21],
            [2009, 8778, 28, 21],
            [2009, 8779, 10, 9],
            [2009, 8780, 12, 9],
            [2009, 8781, 12, 11],
            [2009, 8782, 11, 10],
            [2009, 8783, 10, 8],
            [2009, 8784, 11, 10],
            [2009, 8785, 7, 6],
            [2009, 8786, 9, 10],
            [2009, 8787, 10, 10],
            [2009, 8788, 12, 9],
            [2009, 8790, 10, 8],
            [2009, 8791, 7, 6],
            [2009, 8792, 11, 9],
            [2009, 8793, 8, 7],
            [2009, 8794, 8, 7],
            [2009, 8795, 9, 7],
            [2009, 8796, 12, 9],
            [2009, 8797, 14, 9],
            [2009, 8798, 9, 8],
            [2009, 8799, 14, 13],
            [2009, 8800, 8, 7],
            [2009, 8801, 10, 9],
            [2009, 8802, 7, 7],
            [2009, 8803, 8, 7],
            [2009, 8804, 7, 8],
            [2009, 8805, 9, 9],
            [2009, 8806, 9, 11],
            [2009, 8807, 11, 10],
            [2009, 8808, 9, 8],
            [2009, 8809, 8, 8],
            [2009, 8810, 11, 11],
            [2009, 8811, 7, 8],
            [2009, 8812, 11, 10],
            [2009, 8814, 9, 9],
            [2009, 8815, 9, 9],
            [2009, 8816, 10, 7],
            [2009, 8817, 11, 9],
            [2009, 8818, 55, 30],
            [2009, 8819, 37, 29],
            [2009, 8820, 37, 25],
            [2009, 8821, 26, 19],
            [2009, 8822, 35, 25],
            [2009, 8823, 29, 25],
            [2009, 8824, 18, 14],
            [2009, 8825, 31, 21],
            [2009, 8826, 21, 22],
            [2009, 8827, 30, 19],
            [2009, 8828, 32, 19],
            [2009, 8829, 24, 21],
            [2009, 8830, 18, 20],
            [2009, 8831, 38, 22],
            [2009, 8832, 23, 15],
            [2009, 8833, 28, 18],
            [2009, 8834, 33, 21],
            [2009, 8835, 23, 16],
            [2009, 8836, 54, 29],
            [2009, 8837, 31, 17],
            [2009, 8838, 29, 23],
            [2009, 8839, 22, 15],
            [2009, 8840, 24, 20],
            [2009, 8841, 21, 15],
            [2009, 8842, 18, 19],
            [2009, 8843, 25, 14],
            [2009, 8844, 35, 23],
            [2009, 8845, 27, 19],
            [2009, 8846, 26, 20],
            [2009, 8847, 18, 16],
            [2009, 8848, 36, 21],
            [2009, 8849, 26, 17],
            [2009, 8850, 32, 27],
            [2009, 8851, 28, 23],
            [2009, 8852, 24, 18],
            [2009, 8853, 8, 13],
            [2009, 8854, 28, 21],
            [2009, 8855, 22, 15],
            [2009, 8856, 36, 21],
            [2009, 8857, 17, 12],
            [2009, 8858, 41, 23],
            [2009, 8859, 36, 25],
            [2009, 8860, 25, 13],
            [2009, 8861, 22, 20],
            [2009, 8862, 9, 8],
            [2009, 8863, 29, 20],
            [2009, 8864, 20, 16],
            [2009, 8865, 28, 25],
            [2009, 8866, 23, 22],
            [2009, 8867, 19, 22],
            [2009, 8868, 37, 29],
            [2009, 8869, 59, 32],
            [2009, 8870, 34, 24],
            [2009, 8871, 31, 22],
            [2009, 8872, 59, 29],
            [2009, 8873, 17, 16],
            [2009, 8874, 40, 21],
            [2009, 8875, 36, 26],
            [2009, 8876, 18, 19],
            [2009, 8877, 39, 22],
            [2009, 8878, 22, 20],
            [2009, 8879, 18, 13],
            [2009, 8880, 25, 19],
            [2009, 8881, 51, 30],
            [2009, 8882, 14, 16],
            [2009, 8883, 21, 14],
            [2009, 8884, 17, 16],
            [2009, 8885, 37, 22],
            [2009, 8886, 30, 18],
            [2009, 8887, 18, 13],
            [2009, 8888, 23, 21],
            [2009, 8889, 35, 30],
            [2009, 8890, 10, 14],
            [2009, 8891, 11, 13],
            [2009, 8892, 30, 21],
            [2009, 8893, 61, 27],
            [2009, 8894, 48, 21],
            [2009, 8895, 35, 19],
            [2009, 8896, 38, 25],
            [2009, 8897, 20, 16],
            [2009, 8898, 10, 13],
            [2009, 8899, 48, 26],
            [2009, 8900, 28, 19],
            [2009, 8901, 33, 22],
            [2009, 8902, 31, 23],
            [2009, 8903, 38, 22],
            [2009, 8904, 26, 20],
            [2009, 8905, 23, 19],
            [2009, 8906, 28, 18],
            [2009, 8907, 19, 19],
            [2009, 8908, 26, 18],
            [2009, 8909, 24, 19],
            [2009, 8910, 20, 12],
            [2009, 8911, 19, 15],
            [2009, 8912, 33, 22],
            [2009, 8913, 23, 23],
            [2009, 8914, 22, 20],
            [2009, 8915, 18, 16],
            [2009, 8916, 36, 22],
            [2009, 8917, 26, 16],
            [2009, 8918, 34, 24],
            [2009, 8919, 23, 21],
            [2009, 8920, 28, 21],
            [2009, 8921, 25, 21],
            [2009, 8922, 27, 24],
            [2009, 8923, 38, 28],
            [2009, 8924, 16, 15],
            [2009, 8925, 11, 12],
            [2009, 8926, 14, 14],
            [2009, 8927, 15, 16],
            [2009, 8928, 16, 15],
            [2009, 8929, 13, 12],
            [2009, 8930, 9, 12],
            [2009, 8931, 8, 13],
            [2009, 8932, 9, 9],
            [2009, 8933, 18, 17],
            [2009, 8934, 23, 23],
            [2009, 8935, 32, 20],
            [2009, 8936, 23, 15],
            [2009, 8937, 36, 27],
            [2009, 8938, 22, 15],
            [2009, 8939, 27, 25],
            [2009, 8940, 17, 17],
            [2009, 8941, 27, 20],
            [2009, 8942, 12, 12],
            [2009, 8943, 25, 19],
            [2009, 8944, 35, 18],
            [2009, 8945, 32, 14],
            [2009, 8946, 31, 12],
            [2009, 8947, 28, 14],
            [2009, 8948, 38, 20],
            [2009, 8949, 24, 15],
            [2009, 8950, 21, 19],
            [2009, 8951, 25, 20],
            [2009, 8952, 18, 19],
            [2009, 8953, 27, 23],
            [2009, 8954, 22, 19],
            [2009, 8955, 30, 22],
            [2009, 8956, 20, 18],
            [2009, 8957, 35, 24],
            [2009, 8958, 39, 30],
            [2009, 8959, 32, 20],
            [2009, 8960, 34, 24],
            [2009, 8961, 25, 18],
            [2009, 8962, 41, 22],
            [2009, 8963, 30, 22],
            [2009, 8964, 25, 18],
            [2009, 8965, 38, 25],
            [2009, 8966, 31, 20],
            [2009, 8967, 33, 24],
            [2009, 8968, 28, 19],
            [2009, 8969, 18, 15],
            [2009, 8970, 69, 30],
            [2009, 8971, 17, 17],
            [2009, 8972, 17, 13],
            [2009, 8973, 12, 13],
            [2009, 8974, 5, 12],
            [2009, 8975, 36, 22],
            [2009, 8976, 55, 26],
            [2009, 8977, 46, 23],
            [2009, 8978, 15, 13],
            [2009, 8979, 19, 21],
            [2009, 8980, 32, 26],
            [2009, 8981, 28, 19],
            [2009, 8983, 34, 23],
            [2009, 8984, 26, 21],
            [2009, 8985, 32, 26],
            [2009, 8986, 37, 23],
            [2009, 8987, 27, 20],
            [2009, 8988, 18, 17],
            [2009, 8989, 31, 23],
            [2009, 8990, 22, 17],
            [2009, 8991, 22, 20],
            [2009, 8992, 16, 19],
            [2009, 8993, 31, 24],
            [2009, 8994, 39, 27],
            [2009, 8995, 30, 26],
            [2009, 8996, 35, 22],
            [2009, 8997, 30, 16],
            [2009, 8998, 21, 22],
            [2009, 8999, 17, 13],
            [2009, 9000, 39, 32],
            [2009, 9001, 31, 22],
            [2009, 9002, 27, 23],
            [2009, 9003, 21, 22],
            [2009, 9004, 30, 20],
            [2009, 9005, 18, 15],
            [2009, 9006, 33, 27],
            [2009, 9007, 24, 19],
            [2009, 9008, 11, 17],
            [2009, 9009, 24, 24],
            [2009, 9010, 26, 22],
            [2009, 9011, 21, 15],
            [2009, 9012, 18, 18],
            [2009, 9013, 14, 16],
            [2009, 9014, 41, 21],
            [2009, 9015, 39, 18],
            [2009, 9016, 20, 15],
            [2009, 9017, 19, 21],
            [2009, 9018, 20, 19],
            [2009, 9019, 29, 23],
            [2009, 9020, 17, 19],
            [2009, 9021, 33, 28],
            [2009, 9022, 25, 22],
            [2009, 9023, 25, 18],
            [2009, 9024, 44, 33],
            [2009, 9025, 28, 21],
            [2009, 9026, 37, 19],
            [2009, 9027, 36, 21],
            [2009, 9028, 35, 28],
            [2009, 9030, 27, 23],
            [2009, 9031, 16, 19],
            [2009, 9032, 26, 19],
            [2009, 9033, 29, 20],
            [2009, 9034, 47, 27],
            [2009, 9035, 33, 21],
            [2009, 9036, 30, 20],
            [2009, 9037, 16, 15],
            [2009, 9038, 26, 24],
            [2009, 9039, 15, 18],
            [2009, 9040, 28, 21],
            [2009, 9041, 6, 7],
            [2009, 9042, 34, 28],
            [2009, 9043, 40, 23],
            [2009, 9044, 29, 19],
            [2009, 9045, 30, 26],
            [2009, 9046, 23, 14],
            [2009, 9047, 31, 22],
            [2009, 9048, 14, 16],
            [2009, 9049, 49, 30],
            [2009, 9050, 9, 9],
            [2009, 9051, 44, 32],
            [2009, 9052, 45, 35],
            [2009, 9053, 65, 36],
            [2009, 9054, 43, 27],
            [2009, 9055, 42, 17],
            [2009, 9056, 45, 21],
            [2009, 9057, 34, 28],
            [2009, 9058, 17, 18],
            [2009, 9059, 30, 24],
            [2009, 9060, 33, 27],
            [2009, 9061, 48, 31],
            [2009, 9062, 25, 21],
            [2009, 9063, 30, 20],
            [2009, 9064, 14, 13],
            [2009, 9065, 23, 17],
            [2009, 9066, 16, 18],
            [2009, 9067, 33, 18],
            [2009, 9068, 24, 16],
            [2009, 9069, 25, 20],
            [2009, 9070, 9, 8],
            [2009, 9071, 17, 20],
            [2009, 9072, 12, 12],
            [2009, 9073, 11, 14],
            [2009, 9074, 29, 20],
            [2009, 9075, 11, 14],
            [2009, 9076, 22, 21],
            [2009, 9077, 28, 23],
            [2009, 9078, 24, 17],
            [2009, 9079, 35, 26],
            [2009, 9080, 22, 19],
            [2009, 9081, 25, 22],
            [2009, 9082, 38, 22],
            [2009, 9083, 27, 24],
            [2009, 9084, 29, 22],
            [2009, 9085, 16, 14],
            [2009, 9086, 22, 20],
            [2009, 9087, 38, 23],
            [2009, 9088, 32, 20],
            [2009, 9089, 13, 12],
            [2009, 9090, 30, 21],
            [2009, 9091, 14, 14],
            [2009, 9092, 25, 19],
            [2009, 9093, 25, 18],
            [2009, 9094, 30, 23],
            [2009, 9095, 5, 10],
            [2009, 9096, 31, 31],
            [2009, 9097, 14, 16],
            [2009, 9098, 25, 17],
            [2009, 9099, 20, 16],
            [2009, 9100, 32, 21],
            [2009, 9101, 11, 8],
            [2009, 9102, 20, 14],
            [2009, 9103, 12, 16],
            [2009, 9104, 34, 28],
            [2009, 9105, 17, 12],
            [2009, 9106, 30, 17],
            [2009, 9107, 30, 25],
            [2009, 9108, 25, 20],
            [2009, 9109, 16, 12],
            [2009, 9110, 22, 14],
            [2009, 9111, 25, 15],
            [2009, 9112, 38, 25],
            [2009, 9113, 30, 24],
            [2009, 9114, 31, 25],
            [2009, 9115, 22, 16],
            [2009, 9116, 30, 18],
            [2009, 9117, 32, 21],
            [2009, 9118, 33, 27],
            [2009, 9119, 18, 13],
            [2009, 9120, 21, 20],
            [2009, 9121, 15, 18],
            [2009, 9122, 40, 26],
            [2009, 9123, 34, 19],
            [2009, 9124, 35, 22],
            [2009, 9125, 13, 24],
            [2009, 9126, 35, 24],
            [2009, 9127, 28, 25],
            [2009, 9128, 46, 28],
            [2009, 9129, 22, 17],
            [2009, 9130, 42, 28],
            [2009, 9131, 11, 9],
            [2009, 9132, 29, 23],
            [2009, 9133, 19, 19],
            [2009, 9134, 27, 22],
            [2009, 9135, 41, 25],
            [2009, 9136, 19, 20],
            [2009, 9137, 16, 10],
            [2009, 9138, 33, 22],
            [2009, 9139, 15, 17],
            [2009, 9140, 19, 19],
            [2009, 9141, 18, 19],
            [2009, 9142, 26, 20],
            [2009, 9143, 19, 18],
            [2009, 9144, 16, 18],
            [2009, 9145, 30, 21],
            [2009, 9146, 71, 40],
            [2009, 9166, 21, 16],
            [2009, 9194, 22, 21],
            [2009, 9195, 25, 22],
            [2009, 9196, 24, 18],
            [2009, 9198, 20, 17],
            [2009, 9199, 23, 18],
            [2009, 9200, 20, 17],
            [2009, 9201, 28, 21],
            [2009, 9202, 25, 21],
            [2009, 9203, 9, 9],
            [2009, 9204, 9, 9],
            [2009, 9209, 22, 18],
            [2009, 9211, 25, 23],
            [2009, 9214, 26, 22],
            [2009, 9218, 21, 17],
            [2009, 9226, 36, 23],
            [2009, 9227, 28, 22],
            [2009, 9228, 23, 23],
            [2009, 9229, 26, 23],
            [2009, 9230, 28, 21],
            [2009, 9232, 29, 21],
            [2009, 9233, 23, 22],
            [2009, 9234, 24, 22],
            [2009, 9235, 23, 22],
            [2009, 9238, 25, 22],
            [2009, 9242, 29, 22],
            [2009, 9244, 28, 23],
            [2009, 9245, 23, 22],
            [2009, 9248, 28, 21],
            [2009, 9254, 56, 51],
            [2009, 9255, 41, 31],
            [2009, 9257, 35, 31],
            [2009, 9258, 27, 68],
            [2009, 9259, 30, 31],
            [2009, 9260, 31, 29],
            [2009, 9261, 37, 42],
            [2009, 9263, 29, 31],
            [2009, 9264, 26, 26],
            [2009, 9265, 25, 25],
            [2009, 9266, 44, 41],
            [2009, 9267, 46, 40],
            [2009, 9268, 50, 45],
            [2009, 9269, 60, 50],
            [2009, 9270, 58, 54],
            [2009, 9271, 58, 50],
            [2009, 9272, 47, 48],
            [2009, 9273, 65, 59],
            [2009, 9274, 59, 48],
            [2009, 9275, 33, 34],
            [2009, 9276, 63, 50],
            [2009, 9277, 58, 43],
            [2009, 9278, 60, 50],
            [2009, 9279, 69, 63],
            [2009, 9280, 34, 35],
            [2009, 9281, 62, 46],
            [2009, 9282, 57, 48],
            [2009, 9283, 43, 38],
            [2009, 9284, 71, 59],
            [2009, 9285, 40, 37],
            [2009, 9286, 69, 62],
            [2009, 9287, 71, 61],
            [2009, 9288, 50, 35],
            [2009, 9289, 60, 53],
            [2009, 9290, 59, 66],
            [2009, 9291, 77, 67],
            [2009, 9292, 55, 50],
            [2009, 9293, 59, 42],
            [2009, 9294, 38, 84],
            [2009, 9295, 44, 69],
            [2009, 9296, 60, 79],
            [2009, 9297, 98, 90],
            [2009, 9298, 41, 39],
            [2009, 9299, 81, 86],
            [2009, 9300, 67, 58],
            [2009, 9301, 42, 40],
            [2009, 9302, 94, 84],
            [2009, 9303, 71, 68],
            [2009, 9304, 74, 124],
            [2009, 9305, 72, 69],
            [2009, 9306, 95, 90],
            [2009, 9307, 40, 43],
            [2009, 9308, 51, 59],
            [2009, 9309, 46, 102],
            [2009, 9310, 57, 97],
            [2009, 9311, 39, 38],
            [2009, 9312, 57, 57],
            [2009, 9313, 53, 57],
            [2009, 9314, 71, 66],
            [2009, 9403, 26, 26],
            [2009, 9406, 86, 46],
            [2009, 9411, 56, 90],
            [2009, 9416, 41, 26],
            [2009, 9417, 51, 46],
            [2009, 9420, 46, 86],
            [2009, 9423, 46, 36],
            [2009, 9428, 26, 46],
            [2009, 9431, 31, 41],
            [2009, 9436, 41, 51],
            [2009, 9443, 41, 81],
            [2009, 9444, 46, 46],
            [2009, 9451, 81, 71],
            [2009, 9452, 36, 56],
            [2009, 9453, 46, 66],
            [2009, 9456, 76, 90],
            [2009, 9457, 36, 51],
            [2009, 9458, 61, 56],
            [2009, 9465, 41, 31],
            [2009, 9470, 36, 61],
            [2009, 9473, 26, 21],
            [2009, 9474, 111, 56],
            [2009, 9477, 41, 41],
            [2009, 9478, 120, 71],
            [2009, 9487, 16, 26],
            [2009, 9488, 61, 41],
            [2009, 9491, 26, 21],
            [2009, 9492, 81, 56],
            [2009, 9497, 36, 26],
            [2009, 9498, 96, 46],
            [2009, 9509, 76, 49],
            [2009, 9519, 16, 13],
            [2009, 9520, 91, 46],
            [2009, 9525, 21, 16],
            [2009, 9526, 46, 21],
            [2009, 9529, 21, 16],
            [2009, 9530, 86, 46],
            [2009, 9531, 16, 16],
            [2009, 9532, 66, 41],
            [2009, 9539, 16, 11],
            [2009, 9540, 91, 66],
            [2009, 9541, 11, 26],
            [2009, 9542, 96, 51],
            [2009, 9543, 21, 16],
            [2009, 9544, 86, 51],
            [2009, 9547, 21, 19],
            [2009, 9548, 61, 36],
            [2009, 9549, 16, 16],
            [2009, 9550, 81, 36],
            [2009, 9551, 26, 21],
            [2009, 9552, 86, 51],
            [2009, 9553, 21, 26],
            [2009, 9554, 71, 41],
            [2009, 9555, 31, 66],
            [2009, 9556, 101, 90],
            [2009, 9557, 46, 31],
            [2009, 9558, 111, 61],
            [2009, 9561, 21, 21],
            [2009, 9562, 71, 51],
            [2009, 9581, 41, 31],
            [2009, 9582, 111, 61],
            [2009, 9593, 44, 26],
            [2009, 9594, 91, 51],
            [2009, 9595, 26, 26],
            [2009, 9596, 120, 56],
            [2009, 9597, 31, 16],
            [2009, 9598, 76, 36],
            [2009, 9609, 16, 16],
            [2009, 9610, 81, 41],
            [2009, 9611, 16, 21],
            [2009, 9612, 86, 51],
            [2009, 9613, 46, 51],
            [2009, 9614, 120, 90],
            [2009, 9617, 11, 11],
            [2009, 9618, 100, 51],
            [2009, 9619, 21, 16],
            [2009, 9620, 21, 16],
            [2009, 9633, 21, 34],
            [2009, 9634, 61, 46],
            [2009, 9639, 16, 11],
            [2009, 9640, 91, 46],
            [2009, 9641, 31, 16],
            [2009, 9642, 105, 51],
            [2009, 9643, 21, 16],
            [2009, 9644, 91, 36],
            [2009, 9651, 73, 53],
            [2009, 9652, 68, 53],
            [2009, 9653, 35, 33],
            [2009, 9654, 43, 29],
            [2009, 9661, 68, 43],
            [2009, 9662, 63, 49],
            [2009, 9663, 62, 49],
            [2009, 9664, 51, 40],
            [2009, 9665, 33, 39],
            [2009, 9666, 53, 36],
            [2009, 9667, 16, 16],
            [2009, 9668, 28, 24],
            [2009, 9670, 63, 45],
            [2009, 9673, 39, 29],
            [2009, 9674, 41, 31],
            [2009, 9675, 18, 22],
            [2009, 9676, 29, 29],
            [2009, 9677, 14, 19],
            [2009, 9678, 19, 23],
            [2009, 9681, 58, 43],
            [2009, 9682, 69, 43],
            [2009, 9687, 29, 33],
            [2009, 9689, 23, 19],
            [2009, 9690, 44, 28],
            [2009, 9691, 23, 22],
            [2009, 9692, 40, 28],
            [2009, 9693, 20, 23],
            [2009, 9694, 28, 29],
            [2009, 9695, 44, 43],
            [2009, 9696, 62, 33],
            [2009, 9699, 18, 21],
            [2009, 9700, 53, 33],
            [2009, 9701, 19, 18],
            [2009, 9702, 53, 35],
            [2009, 9704, 48, 30],
            [2009, 9705, 29, 35],
            [2009, 9706, 63, 45],
            [2009, 9709, 24, 19],
            [2009, 9710, 23, 19],
            [2009, 9711, 15, 20],
            [2009, 9712, 16, 23],
            [2009, 9713, 29, 33],
            [2009, 9714, 35, 43],
            [2009, 9715, 58, 47],
            [2009, 9716, 44, 43],
            [2009, 9717, 36, 35],
            [2009, 9718, 18, 22],
            [2009, 9720, 83, 73],
            [2009, 9721, 73, 39],
            [2009, 9722, 23, 37],
            [2009, 9723, 68, 43],
            [2009, 9724, 53, 48],
            [2009, 9725, 73, 45],
            [2009, 9726, 24, 24],
            [2009, 9727, 39, 39],
            [2009, 9728, 29, 23],
            [2009, 9729, 29, 28],
            [2009, 9730, 27, 41],
            [2009, 9731, 69, 59],
            [2009, 9735, 32, 34],
            [2009, 9736, 32, 33],
            [2009, 9737, 29, 19],
            [2009, 9738, 41, 41],
            [2009, 9739, 23, 32],
            [2009, 9740, 96, 88],
            [2009, 9741, 75, 76],
            [2009, 9742, 38, 50],
            [2009, 9743, 41, 33],
            [2009, 9744, 63, 45],
            [2009, 9745, 33, 26],
            [2009, 9746, 39, 26],
            [2009, 9747, 33, 37],
            [2009, 9748, 38, 43],
            [2009, 9751, 29, 25],
            [2009, 9752, 34, 33],
            [2009, 9755, 24, 31],
            [2009, 9756, 31, 36],
            [2009, 9757, 25, 19],
            [2009, 9758, 23, 19],
            [2009, 9759, 15, 14],
            [2009, 9760, 32, 23],
            [2009, 9761, 40, 25],
            [2009, 9762, 30, 20],
            [2009, 9763, 24, 17],
            [2009, 9764, 24, 17],
            [2009, 9765, 28, 20],
            [2009, 9766, 21, 17],
            [2009, 9767, 40, 26],
            [2009, 9768, 22, 19],
            [2009, 9769, 16, 15],
            [2009, 9770, 35, 26],
            [2009, 9771, 38, 25],
            [2009, 9772, 31, 25],
            [2009, 9773, 29, 23],
            [2009, 9774, 26, 17],
            [2009, 9775, 22, 17],
            [2009, 9776, 32, 21],
            [2009, 9777, 32, 23],
            [2009, 9778, 35, 25],
            [2009, 9779, 30, 25],
            [2009, 9780, 29, 22],
            [2009, 9781, 32, 22],
            [2009, 9782, 46, 28],
            [2009, 9783, 44, 29],
            [2009, 9784, 21, 17],
            [2009, 9785, 24, 19],
            [2009, 9786, 14, 11],
            [2009, 9787, 25, 20],
            [2009, 9788, 33, 24],
            [2009, 9789, 28, 22],
            [2009, 9790, 25, 20],
            [2009, 9791, 43, 21],
            [2009, 9792, 38, 28],
            [2009, 9793, 14, 11],
            [2009, 9794, 12, 11],
            [2009, 9795, 12, 12],
            [2009, 9796, 15, 13],
            [2009, 9797, 13, 11],
            [2009, 9798, 12, 11],
            [2009, 9799, 40, 31],
            [2009, 9800, 22, 19],
            [2009, 9801, 16, 14],
            [2009, 9802, 15, 14],
            [2009, 9803, 9, 9],
            [2009, 9804, 14, 11],
            [2009, 9805, 31, 21],
            [2009, 9806, 20, 16],
            [2009, 9807, 21, 14],
            [2009, 9808, 85, 51],
            [2009, 9809, 57, 27],
            [2009, 9811, 54, 25],
            [2009, 9812, 64, 29],
            [2009, 9813, 68, 35],
            [2009, 9814, 20, 13],
            [2009, 9815, 42, 23],
            [2009, 9816, 51, 25],
            [2009, 9817, 24, 13],
            [2009, 9818, 60, 30],
            [2009, 9819, 58, 42],
            [2009, 9820, 70, 46],
            [2009, 9821, 45, 26],
            [2009, 9822, 20, 17],
            [2009, 9823, 23, 18],
            [2009, 9824, 33, 26],
            [2009, 9825, 15, 14],
            [2009, 9826, 36, 27],
            [2009, 9827, 39, 28],
            [2009, 9828, 33, 24],
            [2009, 9829, 26, 21],
            [2009, 9830, 28, 22],
            [2009, 9831, 28, 21],
            [2009, 9832, 33, 22],
            [2009, 9833, 24, 20],
            [2009, 9834, 42, 34],
            [2009, 9835, 25, 24],
            [2009, 9836, 70, 46],
            [2009, 9837, 25, 22],
            [2009, 9838, 43, 28],
            [2009, 9839, 14, 15],
            [2009, 9840, 54, 38],
            [2009, 9841, 46, 29],
            [2009, 9842, 26, 21],
            [2009, 9843, 24, 21],
            [2009, 9844, 36, 25],
            [2009, 9845, 27, 22],
            [2009, 9846, 24, 17],
            [2009, 9847, 12, 10],
            [2009, 9848, 22, 16],
            [2009, 9849, 25, 21],
            [2009, 9850, 20, 16],
            [2009, 9851, 20, 14],
            [2009, 9852, 22, 18],
            [2009, 9853, 20, 16],
            [2009, 9854, 13, 12],
            [2009, 9855, 26, 23],
            [2009, 9856, 17, 20],
            [2009, 9857, 13, 11],
            [2009, 9858, 28, 25],
            [2009, 9859, 42, 30],
            [2009, 9860, 48, 33],
            [2009, 9861, 37, 35],
            [2009, 9862, 23, 20],
            [2009, 9863, 29, 23],
            [2009, 9864, 43, 27],
            [2009, 9865, 30, 22],
            [2009, 9866, 46, 27],
            [2009, 9867, 16, 15],
            [2009, 9868, 30, 24],
            [2009, 9869, 32, 26],
            [2009, 9870, 32, 29],
            [2009, 9871, 31, 23],
            [2009, 9872, 22, 20],
            [2009, 9873, 35, 27],
            [2009, 9874, 30, 24],
            [2009, 9875, 20, 19],
            [2009, 9876, 21, 19],
            [2009, 9877, 29, 33],
            [2009, 9878, 28, 22],
            [2009, 9879, 28, 24],
            [2009, 9880, 29, 28],
            [2009, 9881, 44, 34],
            [2009, 9882, 35, 28],
            [2009, 9883, 25, 20],
            [2009, 9884, 25, 23],
            [2009, 9885, 29, 21],
            [2009, 9886, 28, 22],
            [2009, 9887, 28, 22],
            [2009, 9888, 34, 26],
            [2009, 9889, 32, 24],
            [2009, 9890, 28, 26],
            [2009, 9891, 22, 20],
            [2009, 9892, 30, 22],
            [2009, 9893, 27, 16],
            [2009, 9894, 32, 22],
            [2009, 9895, 23, 15],
            [2009, 9896, 10, 10],
            [2009, 9897, 27, 22],
            [2009, 9898, 25, 22],
            [2009, 9899, 19, 17],
            [2009, 9900, 36, 32],
            [2009, 9901, 32, 25],
            [2009, 9902, 54, 34],
            [2009, 9903, 38, 31],
            [2009, 9904, 35, 29],
            [2009, 9905, 37, 30],
            [2009, 9906, 31, 20],
            [2009, 9907, 23, 21],
            [2009, 9908, 39, 28],
            [2009, 9909, 14, 13],
            [2009, 9910, 35, 30],
            [2009, 9911, 39, 29],
            [2009, 9912, 37, 33],
            [2009, 9913, 19, 18],
            [2009, 9914, 25, 22],
            [2009, 9915, 23, 20],
            [2009, 9916, 26, 21],
            [2009, 9917, 24, 25],
            [2009, 9918, 70, 33],
            [2009, 9919, 42, 29],
            [2009, 9920, 55, 40],
            [2009, 9921, 22, 21],
            [2009, 9922, 17, 14],
            [2009, 9923, 24, 16],
            [2009, 9924, 32, 30],
            [2009, 9925, 35, 35],
            [2009, 9926, 37, 30],
            [2009, 9927, 24, 23],
            [2009, 9928, 44, 34],
            [2009, 9929, 35, 29],
            [2009, 9930, 29, 23],
            [2009, 9931, 47, 28],
            [2009, 9932, 59, 47],
            [2009, 9933, 36, 33],
            [2009, 9934, 32, 25],
            [2009, 9935, 34, 34],
            [2009, 9936, 27, 24],
            [2009, 9937, 23, 26],
            [2009, 9938, 14, 12],
            [2009, 9939, 50, 41],
            [2009, 9940, 29, 28],
            [2009, 9941, 29, 20],
            [2009, 9942, 16, 13],
            [2009, 9943, 54, 45],
            [2009, 9944, 30, 24],
            [2009, 9945, 39, 29],
            [2009, 9946, 31, 23],
            [2009, 9947, 31, 22],
            [2009, 9948, 70, 49],
            [2009, 9949, 46, 35],
            [2009, 9950, 69, 38],
            [2009, 9951, 34, 28],
            [2009, 9952, 52, 43],
            [2009, 9953, 18, 19],
            [2009, 9954, 63, 43],
            [2009, 9955, 18, 15],
            [2009, 9956, 33, 26],
            [2009, 9957, 56, 29],
            [2009, 9958, 35, 27],
            [2009, 9959, 60, 32],
            [2009, 9960, 45, 20],
            [2009, 9961, 31, 24],
            [2009, 9962, 24, 21],
            [2009, 9963, 53, 31],
            [2009, 9964, 41, 24],
            [2009, 9965, 32, 17],
            [2009, 9966, 46, 25],
            [2009, 9967, 57, 29],
            [2009, 9968, 35, 22],
            [2009, 9969, 18, 14],
            [2009, 9970, 65, 35],
            [2009, 9971, 27, 21],
            [2009, 9972, 77, 49],
            [2009, 9973, 38, 24],
            [2009, 9974, 42, 18],
            [2009, 9975, 79, 34],
            [2009, 9976, 60, 42],
            [2009, 9977, 29, 18],
            [2009, 9978, 48, 20],
            [2009, 9979, 57, 28],
            [2009, 9980, 45, 21],
            [2009, 9981, 20, 13],
            [2009, 9982, 13, 12],
            [2009, 9983, 39, 21],
            [2009, 9984, 29, 21],
            [2009, 9985, 27, 17],
            [2009, 9986, 29, 20],
            [2009, 9987, 43, 33],
            [2009, 9988, 53, 36],
            [2009, 9989, 33, 23],
            [2009, 9990, 42, 29],
            [2009, 9991, 34, 29],
            [2009, 9992, 29, 28],
            [2009, 9993, 24, 26],
            [2009, 9994, 19, 17],
            [2009, 9995, 31, 30],
            [2009, 9996, 31, 23],
            [2009, 9997, 14, 19],
            [2009, 9998, 15, 15],
            [2009, 9999, 24, 24],
            [2009, 10000, 21, 19],
            [2009, 10001, 14, 13],
            [2009, 10002, 13, 11],
            [2009, 10003, 80, 42],
            [2009, 10004, 51, 44],
            [2009, 10005, 27, 19],
            [2009, 10006, 35, 30],
            [2009, 10007, 41, 35],
            [2009, 10008, 39, 37],
            [2009, 10009, 39, 25],
            [2009, 10017, 31, 24],
            [2009, 10018, 46, 28],
            [2009, 10032, 55, 38],
            [2009, 10037, 49, 33],
            [2009, 10038, 34, 22],
            [2009, 10046, 40, 30],
            [2009, 10047, 36, 24],
            [2009, 10049, 30, 28],
            [2009, 10056, 40, 46],
            [2009, 10057, 54, 45],
            [2009, 10058, 25, 27],
            [2009, 10059, 44, 27],
            [2009, 10065, 29, 45],
            [2009, 10066, 40, 60],
            [2009, 10071, 39, 30],
            [2009, 10076, 39, 25],
            [2009, 10091, 40, 30],
            [2009, 10094, 35, 40],
            [2009, 10098, 48, 34],
            [2009, 10101, 50, 48],
            [2009, 10102, 54, 35],
            [2009, 10103, 40, 45],
            [2009, 10109, 125, 55],
            [2009, 10110, 44, 41],
            [2009, 10111, 70, 44],
            [2009, 10112, 60, 42],
            [2009, 10113, 75, 58],
            [2009, 10114, 55, 35],
            [2009, 10117, 50, 40],
            [2009, 10122, 60, 53],
            [2009, 10125, 55, 41],
            [2009, 10127, 36, 26],
            [2009, 10128, 44, 35],
            [2009, 10131, 40, 37],
            [2009, 10132, 44, 30],
            [2009, 10133, 50, 35],
            [2009, 10139, 49, 37],
            [2009, 10144, 44, 25],
            [2009, 10180, 35, 21],
            [2009, 10183, 38, 25],
            [2009, 10184, 79, 44],
            [2009, 10185, 21, 22],
            [2009, 10186, 21, 18],
            [2009, 10187, 15, 16],
            [2009, 10188, 40, 32],
            [2009, 10189, 33, 24],
            [2009, 10190, 15, 12],
            [2009, 10191, 41, 25],
            [2009, 10192, 23, 18],
            [2009, 10193, 22, 18],
            [2009, 10194, 12, 11],
            [2009, 10195, 12, 10],
            [2009, 10514, 14, 17],
            [2009, 10515, 14, 17],
            [2009, 10516, 14, 16],
            [2009, 10518, 11, 14],
            [2009, 10519, 11, 13],
            [2009, 10520, 4, 6],
            [2009, 10521, 11, 11],
            [2009, 10522, 11, 16],
            [2009, 10523, 11, 16],
            [2009, 10524, 21, 31],
            [2009, 10525, 11, 11],
            [2009, 10526, 11, 17],
            [2009, 10527, 11, 12],
            [2009, 10528, 16, 21],
            [2009, 10529, 11, 21],
            [2009, 10530, 11, 21],
            [2009, 10531, 11, 17],
            [2009, 10532, 21, 22],
            [2009, 10533, 30, 23],
            [2009, 10534, 20, 15],
            [2009, 10535, 30, 20],
            [2009, 10536, 26, 19],
            [2009, 10537, 29, 20],
            [2009, 10538, 39, 23],
            [2009, 10539, 13, 15],
            [2009, 10540, 16, 11],
            [2009, 10541, 21, 12],
            [2009, 10542, 30, 26],
            [2009, 10543, 9, 9],
            [2009, 10544, 11, 9],
            [2009, 10545, 7, 7],
            [2009, 10546, 10, 8],
            [2009, 10547, 8, 8],
            [2009, 10548, 10, 9],
            [2009, 10549, 7, 8],
            [2009, 10550, 9, 9],
            [2009, 10551, 8, 8],
            [2009, 10552, 7, 7],
            [2009, 10553, 25, 14],
            [2009, 10555, 11, 8],
            [2009, 10556, 16, 13],
            [2009, 10557, 11, 9],
            [2009, 10559, 13, 9],
            [2009, 10560, 15, 11],
            [2009, 10578, 30, 25],
            [2009, 10579, 30, 31],
            [2009, 10580, 58, 39],
            [2009, 10605, 11, 10],
            [2009, 10606, 11, 10],
            [2009, 10607, 11, 10],
            [2009, 10608, 11, 10],
            [2009, 10609, 11, 10],
            [2009, 10610, 15, 10],
            [2009, 10611, 17, 13],
            [2009, 10612, 14, 13],
            [2009, 10613, 33, 23],
            [2009, 10614, 30, 20],
            [2009, 10615, 38, 25],
            [2009, 10616, 35, 21],
            [2009, 10617, 38, 24],
            [2009, 10618, 34, 22],
            [2009, 10619, 20, 17],
            [2009, 10620, 26, 17],
            [2009, 10621, 22, 19],
            [2009, 10622, 25, 17],
            [2009, 10623, 34, 23],
            [2009, 10624, 35, 21],
            [2009, 10625, 20, 18],
            [2009, 10626, 27, 19],
            [2009, 10627, 40, 25],
            [2009, 10628, 37, 23],
            [2009, 10629, 41, 23],
            [2009, 10630, 25, 19],
            [2009, 10631, 25, 19],
            [2009, 10632, 28, 19],
            [2009, 10633, 38, 24],
            [2009, 10634, 45, 27],
            [2009, 10635, 38, 24],
            [2009, 10636, 31, 20],
            [2009, 10637, 30, 24],
            [2009, 10638, 20, 14],
            [2009, 10639, 44, 24],
            [2009, 10640, 41, 23],
            [2009, 10641, 35, 24],
            [2009, 10642, 47, 28],
            [2009, 10643, 34, 22],
            [2009, 10644, 45, 30],
            [2009, 10645, 25, 24],
            [2009, 10646, 40, 23],
            [2009, 10647, 36, 25],
            [2009, 10648, 38, 28],
            [2009, 10649, 33, 23],
            [2009, 10650, 41, 31],
            [2009, 10651, 37, 27],
            [2009, 10652, 27, 18],
            [2009, 10653, 37, 23],
            [2009, 10654, 29, 25],
            [2009, 10655, 38, 27],
            [2009, 10656, 37, 24],
            [2009, 10657, 35, 23],
            [2009, 10658, 45, 22],
            [2009, 10659, 15, 14],
            [2009, 10660, 39, 24],
            [2009, 10661, 36, 23],
            [2009, 10662, 37, 23],
            [2009, 10663, 23, 19],
            [2009, 10664, 36, 19],
            [2009, 10665, 36, 24],
            [2009, 10666, 37, 24],
            [2009, 10667, 33, 25],
            [2009, 10668, 27, 20],
            [2009, 10669, 18, 14],
            [2009, 10670, 28, 20],
            [2009, 10671, 41, 23],
            [2009, 10672, 35, 20],
            [2009, 10673, 24, 18],
            [2009, 10674, 28, 17],
            [2009, 10675, 33, 24],
            [2009, 10676, 35, 22],
            [2009, 10677, 28, 19],
            [2009, 10678, 30, 20],
            [2009, 10679, 38, 23],
            [2009, 10680, 29, 23],
            [2009, 10681, 35, 26],
            [2009, 10682, 34, 22],
            [2009, 10683, 26, 19],
            [2009, 10684, 20, 17],
            [2009, 10685, 56, 32],
            [2009, 10686, 47, 28],
            [2009, 10687, 35, 21],
            [2009, 10688, 50, 30],
            [2009, 10689, 42, 27],
            [2009, 10690, 45, 26],
            [2009, 10691, 39, 24],
            [2009, 10692, 45, 25],
            [2009, 10693, 60, 36],
            [2009, 10694, 42, 26],
            [2009, 10695, 45, 25],
            [2009, 10696, 42, 22],
            [2009, 10697, 22, 17],
            [2009, 10698, 29, 20],
            [2009, 10699, 30, 26],
            [2009, 10700, 14, 14],
            [2009, 10701, 36, 23],
            [2009, 10702, 38, 24],
            [2009, 10703, 38, 23],
            [2009, 10704, 32, 22],
            [2009, 10705, 29, 19],
            [2009, 10706, 35, 24],
            [2009, 10707, 33, 26],
            [2009, 10708, 39, 24],
            [2009, 10709, 38, 27],
            [2009, 10710, 37, 23],
            [2009, 10711, 38, 23],
            [2009, 10712, 35, 26],
            [2009, 10713, 38, 25],
            [2009, 10714, 35, 23],
            [2009, 10715, 39, 24],
            [2009, 10716, 34, 23],
            [2009, 10717, 38, 24],
            [2009, 10718, 33, 26],
            [2009, 10719, 35, 24],
            [2009, 10720, 39, 24],
            [2009, 10721, 22, 15],
            [2009, 10722, 39, 24],
            [2009, 10723, 41, 24],
            [2009, 10724, 39, 24],
            [2009, 10725, 38, 25],
            [2009, 10726, 28, 22],
            [2009, 10727, 45, 23],
            [2009, 10728, 37, 23],
            [2009, 10729, 32, 24],
            [2009, 10730, 38, 24],
            [2009, 10731, 35, 23],
            [2009, 10732, 39, 24],
            [2009, 10733, 37, 27],
            [2009, 10734, 36, 22],
            [2009, 10735, 38, 23],
            [2009, 10736, 39, 27],
            [2009, 10737, 50, 29],
            [2009, 10738, 38, 22],
            [2009, 10739, 18, 14],
            [2009, 10740, 35, 23],
            [2009, 10741, 34, 26],
            [2009, 10742, 36, 23],
            [2009, 10743, 40, 23],
            [2009, 10744, 35, 22],
            [2009, 10745, 35, 21],
            [2009, 10746, 45, 22],
            [2009, 10747, 20, 15],
            [2009, 10748, 26, 19],
            [2009, 10749, 35, 23],
            [2009, 10750, 41, 25],
            [2009, 10751, 37, 23],
            [2009, 10752, 36, 26],
            [2009, 10753, 33, 23],
            [2009, 10754, 26, 19],
            [2009, 10755, 16, 14],
            [2009, 10756, 50, 37],
            [2009, 10757, 16, 13],
            [2009, 10758, 24, 17],
            [2009, 10759, 37, 24],
            [2009, 10760, 37, 23],
            [2009, 10761, 34, 23],
            [2009, 10762, 37, 26],
            [2009, 10763, 29, 22],
            [2009, 10764, 19, 18],
            [2009, 10765, 29, 21],
            [2009, 10766, 37, 24],
            [2009, 10767, 32, 23],
            [2009, 10768, 31, 25],
            [2009, 10769, 33, 22],
            [2009, 10770, 35, 22],
            [2009, 10771, 35, 24],
            [2009, 10772, 26, 24],
            [2009, 10773, 36, 27],
            [2009, 10774, 36, 21],
            [2009, 10775, 38, 21],
            [2009, 10776, 28, 20],
            [2009, 10777, 20, 16],
            [2009, 10778, 38, 24],
            [2009, 10779, 35, 22],
            [2009, 10780, 37, 23],
            [2009, 10781, 35, 22],
            [2009, 10782, 37, 25],
            [2009, 10783, 32, 27],
            [2009, 10784, 31, 20],
            [2009, 10785, 39, 23],
            [2009, 10786, 33, 23],
            [2009, 10787, 38, 23],
            [2009, 10788, 31, 22],
            [2009, 10789, 35, 23],
            [2009, 10790, 36, 23],
            [2009, 10791, 36, 23],
            [2009, 10792, 35, 22],
            [2009, 10793, 35, 24],
            [2009, 10794, 36, 26],
            [2009, 10795, 33, 23],
            [2009, 10796, 30, 24],
            [2009, 10797, 33, 23],
            [2009, 10798, 34, 23],
            [2009, 10799, 15, 14],
            [2009, 10800, 33, 25],
            [2009, 10801, 38, 22],
            [2009, 10802, 34, 25],
            [2009, 10803, 30, 18],
            [2009, 10804, 38, 23],
            [2009, 10805, 40, 23],
            [2009, 10806, 37, 24],
            [2009, 10807, 35, 21],
            [2009, 10808, 24, 19],
            [2009, 10809, 24, 20],
            [2009, 10810, 38, 23],
            [2009, 10811, 45, 28],
            [2009, 10812, 77, 35],
            [2009, 10814, 30, 20],
            [2009, 10815, 38, 23],
            [2009, 10816, 38, 21],
            [2009, 10817, 37, 26],
            [2009, 10818, 37, 24],
            [2009, 10819, 38, 23],
            [2009, 10820, 35, 23],
            [2009, 10821, 38, 23],
            [2009, 10822, 33, 23],
            [2009, 10823, 33, 23],
            [2009, 10824, 37, 23],
            [2009, 10825, 35, 26],
            [2009, 10826, 30, 20],
            [2009, 10827, 26, 23],
            [2009, 10828, 29, 23],
            [2009, 10829, 33, 23],
            [2009, 10830, 36, 23],
            [2009, 10831, 37, 23],
            [2009, 10832, 38, 24],
            [2009, 10833, 38, 24],
            [2009, 10834, 38, 23],
            [2009, 10835, 35, 25],
            [2009, 10836, 34, 23],
            [2009, 10837, 39, 23],
            [2009, 10838, 33, 23],
            [2009, 10839, 26, 23],
            [2009, 10840, 19, 16],
            [2009, 10841, 50, 25],
            [2009, 10842, 28, 26],
            [2009, 10843, 34, 23],
            [2009, 10844, 29, 20],
            [2009, 10845, 20, 18],
            [2009, 10846, 25, 20],
            [2009, 10847, 35, 25],
            [2009, 10848, 30, 23],
            [2009, 10849, 37, 23],
            [2009, 10850, 30, 24],
            [2009, 10851, 35, 23],
            [2009, 10852, 35, 25],
            [2009, 10853, 40, 24],
            [2009, 10854, 35, 28],
            [2009, 10855, 45, 23],
            [2009, 10856, 32, 21],
            [2009, 10857, 37, 24],
            [2009, 10858, 32, 23],
            [2009, 10859, 39, 24],
            [2009, 10860, 37, 23],
            [2009, 10861, 33, 23],
            [2009, 10862, 36, 22],
            [2009, 10863, 17, 17],
            [2009, 10864, 38, 20],
            [2009, 10865, 33, 23],
            [2009, 10866, 30, 20],
            [2009, 10867, 34, 23],
            [2009, 10868, 36, 23],
            [2009, 10869, 39, 26],
            [2009, 10870, 38, 24],
            [2009, 10871, 37, 23],
            [2009, 10872, 32, 21],
            [2009, 10873, 35, 25],
            [2009, 10874, 33, 26],
            [2009, 10875, 39, 27],
            [2009, 10876, 45, 24],
            [2009, 10877, 39, 25],
            [2009, 10878, 40, 28],
            [2009, 10879, 38, 27],
            [2009, 10880, 46, 30],
            [2009, 10881, 23, 19],
            [2009, 10882, 41, 23],
            [2009, 10883, 43, 24],
            [2009, 10884, 40, 23],
            [2009, 10885, 60, 27],
            [2009, 10886, 34, 24],
            [2009, 10887, 30, 20],
            [2009, 10888, 41, 23],
            [2009, 10889, 38, 24],
            [2009, 10890, 28, 19],
            [2009, 10891, 29, 19],
            [2009, 10892, 22, 16],
            [2009, 10893, 33, 23],
            [2009, 10894, 38, 24],
            [2009, 10895, 50, 30],
            [2009, 10896, 36, 24],
            [2009, 10897, 38, 27],
            [2009, 10898, 37, 24],
            [2009, 10899, 40, 25],
            [2009, 10900, 34, 21],
            [2009, 10901, 30, 23],
            [2009, 10902, 23, 19],
            [2009, 10903, 39, 27],
            [2009, 10904, 35, 23],
            [2009, 10905, 30, 21],
            [2009, 10906, 39, 25],
            [2009, 10907, 35, 24],
            [2009, 10908, 38, 23],
            [2009, 10909, 36, 25],
            [2009, 10910, 31, 24],
            [2009, 10911, 40, 26],
            [2009, 10912, 43, 26],
            [2009, 10913, 37, 21],
            [2009, 10914, 40, 26],
            [2009, 10915, 39, 25],
            [2009, 10916, 39, 26],
            [2009, 10917, 38, 24],
            [2009, 10918, 32, 23],
            [2009, 10978, 33, 23],
            [2009, 10979, 37, 20],
            [2009, 10980, 26, 20],
            [2009, 11091, 7, 5],
            [2009, 11092, 9, 8],
            [2009, 11093, 10, 7],
            [2009, 11094, 13, 9],
            [2009, 11095, 10, 7],
            [2009, 11096, 13, 9],
            [2009, 11097, 9, 8],
            [2009, 11098, 9, 7],
            [2009, 11099, 26, 14],
            [2009, 11100, 9, 8],
            [2009, 11101, 9, 8],
            [2009, 11102, 10, 7],
            [2009, 11103, 10, 9],
            [2009, 11104, 36, 22],
            [2009, 11105, 23, 17],
            [2009, 11106, 17, 12],
            [2009, 11107, 14, 9],
            [2009, 11108, 8, 6],
            [2009, 11109, 12, 10],
            [2009, 11110, 10, 8],
            [2009, 11111, 9, 8],
            [2009, 11112, 16, 12],
            [2009, 11113, 18, 11],
            [2009, 11114, 36, 20],
            [2009, 11115, 7, 6],
            [2009, 11116, 8, 6],
            [2009, 11117, 8, 5],
            [2009, 11118, 9, 8],
            [2009, 11119, 30, 17],
            [2009, 11120, 18, 13],
            [2009, 11121, 7, 6],
            [2009, 11122, 11, 8],
            [2009, 11123, 10, 9],
            [2009, 11124, 9, 8],
            [2009, 11125, 15, 10],
            [2009, 11126, 10, 8],
            [2009, 11127, 6, 7],
            [2009, 11128, 10, 7],
            [2009, 11129, 6, 6],
            [2009, 11130, 16, 13],
            [2009, 11131, 7, 6],
            [2009, 11132, 20, 13],
            [2009, 11133, 10, 8],
            [2009, 11134, 6, 5],
            [2009, 11135, 32, 19],
            [2009, 11136, 9, 8],
            [2009, 11137, 6, 5],
            [2009, 11138, 15, 9],
            [2009, 11139, 6, 6],
            [2009, 11140, 9, 8],
            [2009, 11141, 7, 6],
            [2009, 11142, 7, 7],
            [2009, 11143, 7, 6],
            [2009, 11144, 7, 8],
            [2009, 11145, 18, 13],
            [2009, 11146, 7, 6],
            [2009, 11147, 5, 3],
            [2009, 11148, 27, 18],
            [2009, 11149, 15, 10],
            [2009, 11150, 16, 14],
            [2009, 11151, 18, 11],
            [2009, 11152, 15, 10],
            [2009, 11153, 14, 10],
            [2009, 11154, 20, 14],
            [2009, 11155, 15, 11],
            [2009, 11156, 11, 10],
            [2009, 11157, 16, 10],
            [2009, 11158, 15, 10],
            [2009, 11159, 19, 11],
            [2009, 11160, 25, 15],
            [2009, 11161, 13, 9],
            [2009, 11162, 16, 11],
            [2009, 11163, 13, 11],
            [2009, 11164, 17, 13],
            [2009, 11165, 15, 11],
            [2009, 11166, 31, 19],
            [2009, 11168, 20, 14],
            [2009, 11169, 8, 8],
            [2009, 11170, 11, 9],
            [2009, 11171, 10, 8],
            [2009, 11172, 9, 8],
            [2009, 11173, 13, 10],
            [2009, 11174, 6, 6],
            [2009, 11175, 5, 6],
            [2009, 11176, 5, 5],
            [2009, 11177, 17, 12],
            [2009, 11178, 7, 7],
            [2009, 11179, 9, 10],
            [2009, 11180, 9, 9],
            [2009, 11181, 12, 11],
            [2009, 11182, 12, 9],
            [2009, 11183, 10, 11],
            [2009, 11184, 36, 56],
            [2009, 11185, 31, 71],
            [2009, 11186, 26, 56],
            [2009, 11187, 56, 90],
            [2009, 11188, 31, 86],
            [2009, 11189, 71, 31],
            [2009, 11195, 14, 13],
            [2009, 11197, 58, 34],
            [2009, 11199, 48, 30],
            [2009, 11201, 11, 12],
            [2009, 11202, 32, 20],
            [2009, 11203, 11, 11],
            [2009, 11204, 71, 43],
            [2009, 11205, 90, 75],
            [2009, 11206, 41, 46],
            [2009, 11207, 7, 11],
            [2009, 11209, 145, 155],
            [2009, 11210, 230, 175],
            [2009, 11211, 90, 85],
            [2009, 11212, 230, 175],
            [2009, 11215, 145, 155],
            [2009, 11216, 230, 175],
            [2009, 11217, 145, 155],
            [2009, 11218, 230, 175],
            [2009, 11219, 90, 85],
            [2009, 11220, 230, 175],
            [2009, 11221, 90, 85],
            [2009, 11222, 90, 85],
            [2009, 11223, 90, 85],
            [2009, 11224, 90, 85],
            [2009, 11228, 145, 155],
            [2009, 11229, 145, 155],
            [2009, 11230, 90, 85],
            [2009, 11231, 90, 85],
            [2009, 11232, 90, 85],
            [2009, 11233, 90, 85],
            [2009, 11234, 90, 85],
            [2009, 11235, 90, 85],
            [2009, 11236, 90, 85],
            [2009, 11239, 90, 85],
            [2009, 11240, 90, 85],
            [2009, 11241, 90, 85],
            [2009, 11242, 90, 85],
            [2009, 11245, 90, 85],
            [2009, 11246, 145, 155],
            [2009, 11247, 145, 155],
            [2009, 11248, 145, 155],
            [2009, 11249, 90, 85],
            [2009, 11250, 90, 85],
            [2009, 11251, 90, 85],
            [2009, 11252, 145, 155],
            [2009, 11253, 90, 85],
            [2009, 11254, 90, 85],
            [2009, 11255, 90, 85],
            [2009, 11256, 90, 85],
            [2009, 11262, 90, 85],
            [2009, 11263, 90, 85],
            [2009, 11264, 145, 155],
            [2009, 11265, 90, 85],
            [2009, 11266, 90, 85],
            [2009, 11267, 90, 85],
            [2009, 11268, 90, 85],
            [2009, 11269, 90, 85],
            [2009, 11270, 145, 155],
            [2009, 11274, 145, 155],
            [2009, 11275, 90, 85],
            [2009, 11276, 90, 85],
            [2009, 11277, 90, 85],
            [2009, 11278, 90, 85],
            [2009, 11279, 145, 155],
            [2009, 11283, 90, 85],
            [2009, 11284, 90, 85],
            [2009, 11285, 90, 85],
            [2009, 11286, 90, 85],
            [2009, 11287, 90, 85],
            [2009, 11288, 90, 85],
            [2009, 11289, 90, 85],
            [2009, 11292, 10, 8],
            [2009, 11293, 5, 5],
            [2009, 11294, 7, 7],
            [2009, 11295, 13, 7],
            [2009, 11296, 19, 43],
            [2009, 11298, 15, 14],
            [2009, 11300, 28, 24],
            [2009, 11304, 24, 17],
            [2009, 11305, 36, 39],
            [2009, 11306, 34, 30],
            [2009, 11307, 32, 29],
            [2009, 11308, 12, 17],
            [2009, 11309, 24, 23],
            [2009, 11310, 17, 19],
            [2009, 11311, 14, 18],
            [2009, 11312, 17, 19],
            [2009, 11313, 12, 16],
            [2009, 11314, 24, 22],
            [2009, 11315, 21, 18],
            [2009, 11316, 21, 21],
            [2009, 11318, 17, 16],
            [2009, 11319, 16, 14],
            [2009, 11320, 16, 13],
            [2009, 11322, 33, 22],
            [2009, 11323, 20, 18],
            [2009, 11324, 21, 15],
            [2009, 11325, 21, 17],
            [2009, 11326, 22, 21],
            [2009, 11327, 23, 18],
            [2009, 11328, 23, 22],
            [2009, 11329, 15, 15],
            [2009, 11330, 27, 24],
            [2009, 11331, 25, 22],
            [2009, 11333, 28, 20],
            [2009, 11334, 30, 20],
            [2009, 11335, 24, 18],
            [2009, 11336, 10, 11],
            [2009, 11338, 23, 22],
            [2009, 11339, 25, 20],
            [2009, 11340, 26, 23],
            [2009, 11341, 27, 22],
            [2009, 11342, 26, 22],
            [2009, 11343, 26, 23],
            [2009, 11344, 25, 22],
            [2009, 11345, 21, 21],
            [2009, 11346, 28, 22],
            [2009, 11348, 30, 24],
            [2009, 11349, 16, 14],
            [2009, 11350, 25, 23],
            [2009, 11351, 23, 22],
            [2009, 11352, 24, 22],
            [2009, 11353, 28, 23],
            [2009, 11354, 26, 18],
            [2009, 11355, 24, 19],
            [2009, 11356, 25, 20],
            [2009, 11357, 23, 19],
            [2009, 11358, 22, 18],
            [2009, 11359, 29, 24],
            [2009, 11360, 21, 17],
            [2009, 11361, 28, 23],
            [2009, 11362, 22, 19],
            [2009, 11363, 10, 10],
            [2009, 11364, 16, 10],
            [2009, 11365, 22, 20],
            [2009, 11366, 19, 18],
            [2009, 11367, 38, 29],
            [2009, 11368, 17, 18],
            [2009, 11369, 41, 40],
            [2009, 11370, 19, 23],
            [2009, 11371, 25, 23],
            [2009, 11372, 30, 29],
            [2009, 11373, 38, 28],
            [2009, 11374, 49, 31],
            [2009, 11375, 37, 33],
            [2009, 11376, 17, 16],
            [2009, 11377, 33, 26],
            [2009, 11378, 22, 20],
            [2009, 11384, 56, 36],
            [2009, 11385, 51, 36],
            [2009, 11386, 36, 41],
            [2009, 11387, 99, 71],
            [2009, 11388, 36, 36],
            [2009, 11389, 46, 41],
            [2009, 11390, 46, 26],
            [2009, 11391, 26, 26],
            [2009, 11392, 61, 36],
            [2009, 11393, 41, 26],
            [2009, 11394, 46, 56],
            [2009, 11395, 96, 66],
            [2009, 11396, 71, 56],
            [2009, 11397, 86, 56],
            [2009, 11398, 31, 31],
            [2009, 11399, 66, 41],
            [2009, 11400, 86, 36],
            [2009, 11401, 26, 16],
            [2009, 11402, 72, 56],
            [2009, 11403, 41, 46],
            [2009, 11404, 101, 66],
            [2009, 11405, 46, 56],
            [2009, 11406, 76, 61],
            [2009, 11407, 36, 31],
            [2009, 11408, 71, 41],
            [2009, 11409, 51, 41],
            [2009, 11410, 61, 46],
            [2009, 11411, 51, 36],
            [2009, 11412, 96, 56],
            [2009, 11413, 66, 46],
            [2009, 11414, 51, 46],
            [2009, 11415, 41, 36],
            [2009, 11416, 26, 16],
            [2009, 11417, 41, 41],
            [2009, 11418, 41, 31],
            [2009, 11419, 36, 31],
            [2009, 11420, 56, 41],
            [2009, 11421, 66, 66],
            [2009, 11422, 46, 36],
            [2009, 11423, 66, 31],
            [2009, 11424, 36, 26],
            [2009, 11425, 18, 15],
            [2009, 11426, 9, 7],
            [2009, 11427, 8, 8],
            [2009, 11428, 43, 23],
            [2009, 11429, 15, 12],
            [2009, 11430, 9, 10],
            [2009, 11431, 12, 10],
            [2009, 11432, 8, 8],
            [2009, 11433, 10, 12],
            [2009, 11434, 10, 9],
            [2009, 11435, 7, 8],
            [2009, 11436, 18, 16],
            [2009, 11437, 12, 10],
            [2009, 11438, 10, 9],
            [2009, 11439, 11, 9],
            [2009, 11440, 16, 13],
            [2009, 11441, 42, 25],
            [2009, 11442, 9, 8],
            [2009, 11443, 11, 11],
            [2009, 11444, 11, 8],
            [2009, 11445, 8, 8],
            [2009, 11446, 11, 9],
            [2009, 11447, 16, 13],
            [2009, 11448, 12, 10],
            [2009, 11449, 12, 8],
            [2009, 11450, 12, 10],
            [2009, 11451, 9, 7],
            [2009, 11452, 10, 9],
            [2009, 11453, 28, 17],
            [2009, 11454, 12, 11],
            [2009, 11455, 8, 8],
            [2009, 11456, 8, 8],
            [2009, 11457, 9, 9],
            [2009, 11458, 6, 7],
            [2009, 11459, 6, 6],
            [2009, 11460, 7, 6],
            [2009, 11461, 9, 8],
            [2009, 11462, 7, 7],
            [2009, 11463, 10, 9],
            [2009, 11464, 9, 7],
            [2009, 11465, 15, 12],
            [2009, 11466, 14, 9],
            [2009, 11467, 14, 11],
            [2009, 11468, 29, 19],
            [2009, 11469, 14, 10],
            [2009, 11470, 16, 14],
            [2009, 11471, 14, 12],
            [2009, 11472, 22, 14],
            [2009, 11473, 10, 9],
            [2009, 11474, 8, 8],
            [2009, 11475, 9, 9],
            [2009, 11476, 10, 8],
            [2009, 11477, 19, 15],
            [2009, 11478, 23, 15],
            [2009, 11479, 11, 9],
            [2009, 11480, 18, 15],
            [2009, 11481, 13, 11],
            [2009, 11482, 15, 12],
            [2009, 11483, 18, 14],
            [2009, 11484, 16, 13],
            [2009, 11485, 20, 14],
            [2009, 11486, 16, 13],
            [2009, 11487, 15, 11],
            [2009, 11488, 18, 14],
            [2009, 11489, 10, 9],
            [2009, 11490, 11, 10],
            [2009, 11491, 11, 9],
            [2009, 11492, 8, 7],
            [2009, 11493, 8, 8],
            [2009, 11494, 6, 7],
            [2009, 11495, 6, 6],
            [2009, 11496, 7, 8],
            [2009, 11497, 8, 8],
            [2009, 11498, 9, 8],
            [2009, 11499, 8, 8],
            [2009, 11500, 18, 16],
            [2009, 11501, 8, 8],
            [2009, 11502, 11, 10],
            [2009, 11503, 7, 8],
            [2009, 11504, 8, 8],
            [2009, 11505, 14, 11],
            [2009, 11506, 10, 10],
            [2009, 11507, 11, 12],
            [2009, 11508, 7, 8],
            [2009, 11509, 20, 14],
            [2009, 11510, 11, 9],
            [2009, 11511, 10, 8],
            [2009, 11512, 18, 12],
            [2009, 11513, 13, 11],
            [2009, 11514, 9, 9],
            [2009, 11515, 9, 9],
            [2009, 11516, 14, 11],
            [2009, 11517, 18, 15],
            [2009, 11518, 10, 14],
            [2009, 11519, 18, 12],
            [2009, 11520, 26, 17],
            [2009, 11521, 8, 6],
            [2009, 11522, 10, 10],
            [2009, 11523, 11, 9],
            [2009, 11524, 8, 7],
            [2009, 11525, 11, 8],
            [2009, 11526, 15, 11],
            [2009, 11527, 10, 10],
            [2009, 11528, 8, 7],
            [2009, 11529, 26, 36],
            [2009, 11530, 71, 56],
            [2009, 11531, 71, 41],
            [2009, 11532, 36, 41],
            [2009, 11533, 22, 16],
            [2009, 11534, 96, 56],
            [2009, 11535, 41, 26],
            [2009, 11536, 36, 26],
            [2009, 11537, 41, 21],
            [2009, 11538, 46, 41],
            [2009, 11539, 71, 61],
            [2009, 11540, 21, 16],
            [2009, 11541, 46, 41],
            [2009, 11542, 52, 36],
            [2009, 11543, 31, 62],
            [2009, 11544, 56, 31],
            [2009, 11545, 81, 86],
            [2009, 11546, 86, 56],
            [2009, 11547, 66, 90],
            [2009, 11548, 86, 56],
            [2009, 11549, 51, 31],
            [2009, 11550, 41, 46],
            [2009, 11551, 50, 36],
            [2009, 11552, 56, 41],
            [2009, 11553, 120, 61],
            [2009, 11554, 46, 51],
            [2009, 11555, 56, 61],
            [2009, 11556, 21, 26],
            [2009, 11557, 26, 61],
            [2009, 11558, 67, 61],
            [2009, 11559, 66, 81],
            [2009, 11560, 46, 66],
            [2009, 11561, 101, 90],
            [2009, 11562, 56, 76],
            [2009, 11563, 120, 76],
            [2009, 11564, 76, 96],
            [2009, 11565, 68, 41],
            [2009, 11566, 120, 90],
            [2009, 11567, 41, 41],
            [2009, 11568, 36, 61],
            [2009, 11569, 81, 81],
            [2009, 11570, 31, 41],
            [2009, 11571, 11, 11],
            [2009, 11572, 12, 13],
            [2009, 11573, 96, 70],
            [2009, 11574, 11, 12],
            [2009, 11576, 13, 13],
            [2009, 11577, 13, 12],
            [2009, 11578, 18, 18],
            [2009, 11579, 19, 21],
            [2009, 11580, 10, 12],
            [2009, 11581, 13, 14],
            [2009, 11582, 16, 17],
            [2009, 11583, 35, 25],
            [2009, 11585, 36, 24],
            [2009, 11586, 44, 25],
            [2009, 11588, 112, 34],
            [2009, 11590, 24, 16],
            [2009, 11592, 44, 23],
            [2009, 11593, 28, 18],
            [2009, 11594, 78, 41],
            [2009, 11596, 33, 27],
            [2009, 11598, 46, 22],
            [2009, 11601, 48, 35],
            [2009, 11604, 14, 15],
            [2009, 11605, 20, 17],
            [2009, 11705, 40, 30],
            [2009, 11706, 93, 38],
            [2009, 11709, 50, 26],
            [2009, 11710, 116, 34],
            [2009, 11714, 11, 11],
            [2009, 11717, 22, 20],
            [2009, 11721, 15, 17],
            [2009, 11722, 48, 37],
            [2009, 11724, 47, 40],
            [2009, 11728, 51, 34],
            [2009, 11730, 20, 14],
            [2009, 11731, 101, 40],
            [2009, 11737, 34, 32],
            [2009, 11738, 119, 63],
            [2009, 11739, 16, 19],
            [2009, 11741, 14, 14],
            [2009, 11745, 61, 29],
            [2009, 11746, 31, 16],
            [2009, 11755, 11, 11],
            [2009, 11759, 14, 16],
            [2009, 11760, 83, 76],
            [2009, 11763, 16, 16],
            [2009, 11766, 34, 23],
            [2009, 11776, 52, 35],
            [2009, 11777, 22, 16],
            [2009, 11780, 31, 17],
            [2009, 11781, 16, 21],
            [2009, 11782, 11, 16],
            [2009, 11783, 31, 25],
            [2009, 11784, 46, 21],
            [2009, 11785, 21, 26],
            [2009, 11786, 46, 41],
            [2009, 11787, 31, 31],
            [2009, 11788, 36, 34],
            [2009, 11789, 36, 33],
            [2009, 11790, 11, 11],
            [2009, 11791, 41, 24],
            [2009, 11792, 51, 35],
            [2009, 11794, 25, 20],
            [2009, 11795, 18, 18],
            [2009, 11796, 30, 25],
            [2009, 11797, 25, 18],
            [2009, 11798, 30, 21],
            [2009, 11799, 29, 27],
            [2009, 11800, 31, 31],
            [2009, 11801, 28, 21],
            [2009, 11802, 26, 27],
            [2009, 11803, 30, 26],
            [2009, 11804, 19, 19],
            [2009, 11805, 33, 23],
            [2009, 11806, 33, 25],
            [2009, 11807, 28, 21],
            [2009, 11808, 21, 16],
            [2009, 11809, 15, 12],
            [2009, 11810, 21, 12],
            [2009, 11811, 17, 13],
            [2009, 11812, 21, 21],
            [2009, 11813, 11, 11],
            [2009, 11814, 19, 14],
            [2009, 11815, 16, 11],
            [2009, 11816, 21, 13],
            [2009, 11817, 17, 11],
            [2009, 11818, 15, 16],
            [2009, 11819, 21, 14],
            [2009, 11820, 15, 12],
            [2009, 11821, 21, 15],
            [2009, 11822, 21, 15],
            [2009, 11823, 31, 17],
            [2009, 11824, 17, 14],
            [2009, 11825, 21, 14],
            [2009, 11826, 14, 14],
            [2009, 11827, 19, 14],
            [2009, 11828, 16, 12],
            [2009, 11829, 21, 21],
            [2009, 11830, 14, 14],
            [2009, 11831, 15, 14],
            [2009, 11832, 23, 12],
            [2009, 11833, 21, 14],
            [2009, 11834, 6, 6],
            [2009, 11835, 21, 12],
            [2009, 11836, 21, 15],
            [2009, 11837, 11, 11],
            [2009, 11838, 7, 6],
            [2009, 11839, 11, 10],
            [2009, 11840, 8, 7],
            [2009, 11841, 6, 5],
            [2009, 11842, 15, 11],
            [2009, 11843, 21, 17],
            [2009, 11844, 16, 16],
            [2009, 11845, 21, 14],
            [2009, 11846, 21, 14],
            [2009, 11847, 16, 14],
            [2009, 11848, 13, 11],
            [2009, 11849, 19, 14],
            [2009, 11850, 12, 11],
            [2009, 11851, 21, 16],
            [2009, 11852, 15, 14],
            [2009, 11853, 11, 11],
            [2009, 11854, 18, 18],
            [2009, 11855, 15, 14],
            [2009, 11858, 14, 33],
            [2009, 11859, 19, 35],
            [2009, 11860, 23, 33],
            [2009, 11865, 34, 31],
            [2009, 11866, 35, 28],
            [2009, 11867, 50, 42],
            [2009, 11868, 47, 60],
            [2009, 11869, 24, 22],
            [2009, 11870, 44, 32],
            [2009, 11871, 56, 39],
            [2009, 11872, 28, 26],
            [2009, 11873, 31, 38],
            [2009, 11874, 42, 30],
            [2009, 11875, 31, 25],
            [2009, 11876, 36, 52],
            [2009, 11877, 46, 28],
            [2009, 11878, 19, 17],
            [2009, 11879, 36, 35],
            [2009, 11880, 47, 41],
            [2009, 11881, 51, 38],
            [2009, 11882, 32, 27],
            [2009, 11883, 44, 30],
            [2009, 11884, 55, 34],
            [2009, 11885, 31, 31],
            [2009, 11886, 26, 27],
            [2009, 11887, 35, 27],
            [2009, 11888, 27, 23],
            [2009, 11889, 26, 29],
            [2009, 11890, 26, 28],
            [2009, 11891, 33, 25],
            [2009, 11892, 29, 31],
            [2009, 11893, 36, 28],
            [2009, 11894, 28, 30],
            [2009, 11895, 40, 36],
            [2009, 11896, 35, 33],
            [2009, 11897, 41, 29],
            [2009, 11898, 32, 30],
            [2009, 11899, 37, 52],
            [2009, 11900, 19, 19],
            [2009, 11901, 42, 48],
            [2009, 11902, 28, 40],
            [2009, 11903, 37, 32],
            [2009, 11904, 32, 30],
            [2009, 11905, 45, 42],
            [2009, 11906, 39, 32],
            [2009, 11907, 54, 33],
            [2009, 11908, 27, 25],
            [2009, 11909, 27, 26],
            [2009, 11910, 40, 36],
            [2009, 11911, 22, 24],
            [2009, 11912, 32, 31],
            [2009, 11913, 33, 23],
            [2009, 11914, 21, 19],
            [2009, 11915, 23, 24],
            [2009, 11916, 37, 47],
            [2009, 11917, 34, 31],
            [2009, 11918, 26, 24],
            [2009, 11919, 18, 21],
            [2009, 11920, 27, 23],
            [2009, 11921, 25, 24],
            [2009, 11922, 22, 25],
            [2009, 11923, 19, 24],
            [2009, 11924, 19, 17],
            [2009, 11925, 24, 20],
            [2009, 11926, 18, 15],
            [2009, 11927, 28, 27],
            [2009, 11928, 18, 15],
            [2009, 11929, 16, 12],
            [2009, 11930, 14, 13],
            [2009, 11931, 32, 28],
            [2009, 11932, 32, 30],
            [2009, 11933, 43, 28],
            [2009, 11934, 23, 16],
            [2009, 11935, 33, 22],
            [2009, 11936, 19, 21],
            [2009, 11937, 50, 26],
            [2009, 11938, 31, 22],
            [2009, 11939, 49, 28],
            [2009, 11940, 47, 29],
            [2009, 11941, 51, 26],
            [2009, 11942, 51, 31],
            [2009, 11943, 20, 17],
            [2009, 11944, 35, 25],
            [2009, 11945, 24, 25],
            [2009, 11946, 55, 45],
            [2009, 11947, 29, 24],
            [2009, 11948, 40, 45],
            [2009, 11949, 35, 31],
            [2009, 11950, 28, 30],
            [2009, 11951, 45, 36],
            [2009, 11952, 36, 44],
            [2009, 11953, 45, 38],
            [2009, 11954, 25, 25],
            [2009, 11955, 40, 35],
            [2009, 11956, 45, 35],
            [2009, 11957, 24, 24],
            [2009, 11958, 38, 20],
            [2009, 11959, 21, 18],
            [2009, 11960, 24, 21],
            [2009, 11961, 24, 25],
            [2009, 11962, 22, 25],
            [2009, 11963, 42, 25],
            [2009, 11964, 24, 19],
            [2009, 11965, 40, 40],
            [2009, 11966, 33, 26],
            [2009, 11967, 35, 22],
            [2009, 11968, 40, 44],
            [2009, 11969, 14, 18],
            [2009, 11970, 28, 22],
            [2009, 11971, 39, 35],
            [2009, 11972, 40, 33],
            [2009, 11973, 38, 22],
            [2009, 11974, 55, 43],
            [2009, 11975, 70, 57],
            [2009, 11976, 38, 28],
            [2009, 11977, 47, 44],
            [2009, 11978, 31, 28],
            [2009, 11979, 36, 28],
            [2009, 11980, 60, 54],
            [2009, 11981, 39, 27],
            [2009, 11982, 37, 25],
            [2009, 11983, 21, 21],
            [2009, 11984, 50, 45],
            [2009, 11985, 39, 21],
            [2009, 11986, 35, 37],
            [2009, 11987, 37, 24],
            [2009, 11988, 45, 25],
            [2009, 11989, 31, 28],
            [2009, 11990, 34, 25],
            [2009, 11991, 40, 30],
            [2009, 11992, 43, 40],
            [2009, 11993, 22, 20],
            [2009, 11994, 23, 20],
            [2009, 11995, 20, 25],
            [2009, 11996, 50, 46],
            [2009, 11997, 33, 23],
            [2009, 11998, 35, 46],
            [2009, 12091, 31, 16],
            [2009, 12092, 71, 28],
            [2009, 12093, 7, 11],
            [2009, 12094, 27, 19],
            [2009, 12095, 53, 33],
            [2009, 12096, 30, 23],
            [2009, 12097, 30, 22],
            [2009, 12098, 28, 19],
            [2009, 12099, 50, 31],
            [2009, 12100, 11, 9],
            [2009, 12101, 16, 12],
            [2009, 12102, 11, 12],
            [2009, 12103, 29, 19],
            [2009, 12104, 46, 24],
            [2009, 12105, 22, 15],
            [2009, 12106, 13, 12],
            [2009, 12107, 21, 17],
            [2009, 12108, 24, 20],
            [2009, 12109, 23, 22],
            [2009, 12110, 18, 16],
            [2009, 12111, 32, 21],
            [2009, 12112, 31, 19],
            [2009, 12113, 19, 14],
            [2009, 12114, 24, 16],
            [2009, 12115, 11, 13],
            [2009, 12116, 13, 13],
            [2009, 12117, 24, 22],
            [2009, 12118, 24, 19],
            [2009, 12119, 58, 29],
            [2009, 12120, 15, 17],
            [2009, 12121, 17, 16],
            [2009, 12122, 11, 16],
            [2009, 12123, 12, 16],
            [2009, 12124, 12, 21],
            [2009, 12125, 13, 24],
            [2009, 12126, 13, 21],
            [2009, 12127, 11, 13],
            [2009, 12128, 61, 48],
            [2009, 12129, 51, 51],
            [2009, 12130, 81, 65],
            [2009, 12131, 81, 65],
            [2009, 12132, 59, 48],
            [2009, 12133, 66, 48],
            [2009, 12134, 61, 60],
            [2009, 12135, 66, 45],
            [2009, 12136, 32, 25],
            [2009, 12137, 66, 61],
            [2009, 12138, 60, 47],
            [2009, 12139, 42, 43],
            [2009, 12140, 64, 44],
            [2009, 12141, 101, 56],
            [2009, 12142, 81, 44],
            [2009, 12143, 80, 67],
            [2009, 12144, 61, 41],
            [2009, 12145, 64, 54],
            [2009, 12146, 71, 50],
            [2009, 12147, 44, 37],
            [2009, 12148, 76, 51],
            [2009, 12149, 73, 55],
            [2009, 12150, 42, 18],
            [2009, 12151, 66, 61],
            [2009, 12152, 71, 40],
            [2009, 12153, 66, 33],
            [2009, 12154, 73, 57],
            [2009, 12155, 56, 50],
            [2009, 12156, 81, 39],
            [2009, 12157, 66, 31],
            [2009, 12158, 30, 16],
            [2009, 12159, 51, 62],
            [2009, 12160, 21, 23],
            [2009, 12161, 11, 11],
            [2009, 12162, 12, 18],
            [2009, 12163, 21, 21],
            [2009, 12164, 11, 21],
            [2009, 12165, 14, 17],
            [2009, 12166, 14, 16],
            [2009, 12167, 13, 17],
            [2009, 12168, 21, 22],
            [2009, 12169, 14, 12],
            [2009, 12170, 11, 14],
            [2009, 12171, 60, 39],
            [2009, 12172, 55, 33],
            [2009, 12173, 20, 17],
            [2009, 12174, 64, 32],
            [2009, 12175, 52, 31],
            [2009, 12176, 230, 175],
            [2009, 12177, 230, 175],
            [2009, 12178, 230, 175],
            [2009, 12179, 230, 175],
            [2009, 12180, 230, 175],
            [2009, 12181, 230, 175],
            [2009, 12182, 230, 175],
            [2009, 12183, 230, 175],
            [2009, 12184, 230, 175],
            [2009, 12185, 230, 175],
            [2009, 12186, 230, 175],
            [2009, 12187, 230, 175],
            [2009, 12188, 230, 175],
            [2009, 12189, 230, 175],
            [2009, 12190, 230, 175],
            [2009, 12191, 53, 29],
            [2009, 12192, 19, 21],
            [2009, 12193, 58, 38],
            [2009, 12194, 36, 28],
            [2009, 12195, 19, 22],
            [2009, 12196, 19, 22],
            [2009, 12197, 19, 22],
            [2009, 12198, 19, 22],
            [2009, 12199, 48, 34],
            [2009, 12200, 44, 32],
            [2009, 12201, 33, 31],
            [2009, 12202, 34, 31],
            [2009, 12203, 54, 33],
            [2009, 12204, 39, 28],
            [2009, 12205, 68, 28],
            [2009, 12206, 62, 29],
            [2009, 12207, 36, 32],
            [2009, 12208, 21, 36],
            [2009, 12209, 34, 31],
            [2009, 12210, 34, 28],
            [2009, 12211, 49, 33],
            [2009, 12212, 43, 33],
            [2009, 12213, 50, 39],
            [2009, 12214, 32, 34],
            [2009, 12215, 35, 36],
            [2009, 12216, 45, 31],
            [2009, 12217, 36, 32],
            [2009, 12218, 60, 30],
            [2009, 12219, 80, 31],
            [2009, 12220, 35, 31],
            [2009, 12221, 30, 33],
            [2009, 12222, 26, 28],
            [2009, 12223, 76, 31],
            [2009, 12224, 33, 30],
            [2009, 12225, 32, 30],
            [2009, 12226, 40, 32],
            [2009, 12227, 53, 30],
            [2009, 12228, 64, 35],
            [2009, 12229, 45, 35],
            [2009, 12230, 50, 33],
            [2009, 12231, 28, 29],
            [2009, 12232, 50, 34],
            [2009, 12233, 38, 37],
            [2009, 12234, 50, 30],
            [2009, 12235, 43, 29],
            [2009, 12236, 43, 31],
            [2009, 12237, 34, 40],
            [2009, 12238, 36, 34],
            [2009, 12239, 52, 28],
            [2009, 12240, 31, 41],
            [2009, 12241, 16, 16],
            [2009, 12242, 41, 31],
            [2009, 12243, 11, 16],
            [2009, 12244, 11, 11],
            [2009, 12245, 11, 11],
            [2009, 12246, 16, 11],
            [2009, 12247, 16, 16],
            [2009, 12248, 11, 11],
            [2009, 12249, 6, 6],
            [2009, 12250, 16, 11],
            [2009, 12251, 11, 16],
            [2009, 12253, 13, 11],
            [2009, 12254, 21, 21],
            [2009, 12255, 16, 21],
            [2009, 12256, 16, 16],
            [2009, 12257, 31, 26],
            [2009, 12258, 16, 11],
            [2009, 12259, 11, 4],
            [2009, 12260, 6, 6],
            [2009, 12261, 6, 11],
            [2009, 12262, 26, 21],
            [2009, 12263, 11, 16],
            [2009, 12264, 11, 11],
            [2009, 12265, 21, 21],
            [2009, 12266, 26, 26],
            [2009, 12267, 6, 11],
            [2009, 12268, 21, 20],
            [2009, 12269, 16, 16],
            [2009, 12270, 26, 26],
            [2009, 12271, 11, 11],
            [2009, 12272, 11, 11],
            [2009, 12273, 16, 16],
            [2009, 12274, 21, 16],
            [2009, 12275, 16, 16],
            [2009, 12276, 26, 21],
            [2009, 12277, 16, 16],
            [2009, 12278, 11, 11],
            [2009, 12279, 16, 11],
            [2009, 12280, 16, 16],
            [2009, 12281, 6, 6],
            [2009, 12282, 16, 21],
            [2009, 12283, 11, 11],
            [2009, 12284, 11, 16],
            [2009, 12285, 16, 16],
            [2009, 12286, 16, 11],
            [2009, 12287, 11, 11],
            [2009, 12288, 16, 16],
            [2009, 12289, 16, 16],
            [2009, 12290, 11, 11],
            [2009, 12291, 11, 16],
            [2009, 12292, 11, 11],
            [2009, 12293, 21, 16],
            [2009, 12294, 11, 16],
            [2009, 12295, 16, 16],
            [2009, 12296, 41, 36],
            [2009, 12297, 16, 16],
            [2009, 12298, 16, 16],
            [2009, 12299, 31, 36],
            [2009, 12300, 17, 18],
            [2009, 12301, 14, 11],
            [2009, 12302, 30, 21],
            [2009, 12303, 31, 15],
            [2009, 12304, 23, 23],
            [2009, 12305, 14, 9],
            [2009, 12306, 14, 10],
            [2009, 12307, 28, 21],
            [2009, 12308, 27, 15],
            [2009, 12309, 25, 15],
            [2009, 12310, 25, 15],
            [2009, 12311, 29, 22],
            [2009, 12326, 13, 14],
            [2009, 12327, 40, 33],
            [2009, 12328, 14, 15],
            [2009, 12329, 8, 10],
            [2009, 12330, 13, 15],
            [2009, 12331, 9, 11],
            [2009, 12332, 20, 20],
            [2009, 12333, 24, 20],
            [2009, 12334, 14, 14],
            [2009, 12335, 14, 13],
            [2009, 12336, 21, 16],
            [2009, 12337, 16, 14],
            [2009, 12338, 14, 13],
            [2009, 12339, 11, 13],
            [2009, 12340, 15, 13],
            [2009, 12341, 19, 16],
            [2009, 12342, 22, 16],
            [2009, 12343, 28, 24],
            [2009, 12344, 14, 12],
            [2009, 12345, 13, 12],
            [2009, 12346, 24, 20],
            [2009, 12347, 24, 20],
            [2009, 12348, 19, 16],
            [2009, 12349, 20, 16],
            [2009, 12350, 24, 18],
            [2009, 12351, 24, 17],
            [2009, 12352, 9, 9],
            [2009, 12353, 12, 13],
            [2009, 12354, 10, 10],
            [2009, 12355, 15, 14],
            [2009, 12356, 11, 12],
            [2009, 12357, 23, 26],
            [2009, 12358, 19, 17],
            [2009, 12359, 28, 25],
            [2009, 12360, 38, 38],
            [2009, 12361, 24, 19],
            [2009, 12362, 15, 19],
            [2009, 12363, 23, 20],
            [2009, 12364, 11, 12],
            [2009, 12365, 11, 12],
            [2009, 12366, 27, 27],
            [2009, 12367, 32, 26],
            [2009, 12368, 14, 14],
            [2009, 12369, 29, 30],
            [2009, 12370, 16, 17],
            [2009, 12371, 19, 19],
            [2009, 12372, 12, 13],
            [2009, 12373, 21, 25],
            [2009, 12374, 15, 16],
            [2009, 12375, 25, 24],
            [2009, 12376, 17, 17],
            [2009, 12377, 16, 19],
            [2009, 12378, 17, 16],
            [2009, 12379, 17, 18],
            [2009, 12380, 21, 22],
            [2009, 12381, 15, 17],
            [2009, 12382, 23, 24],
            [2009, 12383, 9, 9],
            [2009, 12384, 15, 14],
            [2009, 12385, 16, 18],
            [2009, 12386, 13, 15],
            [2009, 12387, 13, 12],
            [2009, 12388, 15, 17],
            [2009, 12389, 13, 13],
            [2009, 12390, 16, 18],
            [2009, 12391, 18, 20],
            [2009, 12392, 40, 43],
            [2009, 12393, 26, 25],
            [2009, 12394, 18, 17],
            [2009, 12395, 13, 13],
            [2009, 12396, 19, 17],
            [2009, 12397, 15, 16],
            [2009, 12398, 33, 28],
            [2009, 12399, 36, 28],
            [2009, 12400, 17, 15],
            [2009, 12401, 22, 15],
            [2009, 12402, 27, 19],
            [2009, 12403, 16, 16],
            [2009, 12404, 19, 16],
            [2009, 12405, 15, 12],
            [2009, 12406, 25, 22],
            [2009, 12407, 26, 22],
            [2009, 12408, 45, 39],
            [2009, 12409, 48, 59],
            [2009, 12410, 45, 50],
            [2009, 12411, 130, 64],
            [2009, 12412, 45, 37],
            [2009, 12413, 68, 65],
            [2009, 12414, 100, 64],
            [2009, 12415, 50, 64],
            [2009, 12416, 50, 60],
            [2009, 12417, 60, 55],
            [2009, 12418, 50, 60],
            [2009, 12419, 60, 64],
            [2009, 12420, 45, 37],
            [2009, 12421, 45, 40],
            [2009, 12422, 60, 60],
            [2009, 12423, 33, 31],
            [2009, 12424, 105, 69],
            [2009, 12425, 54, 58],
            [2009, 12426, 45, 55],
            [2009, 12427, 45, 38],
            [2009, 12428, 55, 69],
            [2009, 12429, 105, 65],
            [2009, 12430, 45, 39],
            [2009, 12431, 50, 69],
            [2009, 12432, 45, 37],
            [2009, 12433, 100, 64],
            [2009, 12434, 105, 69],
            [2009, 12435, 120, 60],
            [2009, 12436, 40, 38],
            [2009, 12437, 105, 51],
            [2009, 12438, 130, 70],
            [2009, 12439, 90, 64],
            [2009, 12440, 130, 69],
            [2009, 12441, 100, 64],
            [2009, 12442, 120, 64],
            [2009, 12443, 130, 82],
            [2009, 12444, 125, 65],
            [2009, 12445, 115, 65],
            [2009, 12446, 100, 60],
            [2009, 12447, 80, 64],
            [2010, 25, 11, 9],
            [2010, 48, 31, 20],
            [2010, 49, 24, 15],
            [2010, 82, 15, 16],
            [2010, 83, 19, 17],
            [2010, 101, 29, 20],
            [2010, 119, 24, 18],
            [2010, 200, 24, 18],
            [2010, 204, 15, 15],
            [2010, 220, 10, 12],
            [2010, 226, 17, 15],
            [2010, 231, 37, 21],
            [2010, 234, 11, 11],
            [2010, 246, 21, 14],
            [2010, 282, 30, 22],
            [2010, 314, 15, 18],
            [2010, 324, 20, 17],
            [2010, 327, 31, 28],
            [2010, 355, 27, 22],
            [2010, 379, 12, 11],
            [2010, 389, 22, 17],
            [2010, 399, 30, 20],
            [2010, 425, 11, 13],
            [2010, 430, 15, 15],
            [2010, 480, 38, 22],
            [2010, 504, 8, 9],
            [2010, 541, 123, 37],
            [2010, 585, 32, 19],
            [2010, 700, 38, 25],
            [2010, 703, 14, 13],
            [2010, 716, 32, 23],
            [2010, 751, 18, 16],
            [2010, 803, 21, 18],
            [2010, 805, 15, 14],
            [2010, 827, 11, 11],
            [2010, 845, 30, 28],
            [2010, 871, 24, 17],
            [2010, 878, 7, 6],
            [2010, 882, 25, 19],
            [2010, 894, 17, 13],
            [2010, 922, 20, 22],
            [2010, 938, 11, 11],
            [2010, 940, 11, 12],
            [2010, 964, 12, 13],
            [2010, 971, 10, 10],
            [2010, 985, 43, 28],
            [2010, 998, 33, 20],
            [2010, 1003, 8, 6],
            [2010, 1008, 24, 21],
            [2010, 1016, 8, 9],
            [2010, 1030, 8, 9],
            [2010, 1106, 44, 21],
            [2010, 1132, 11, 11],
            [2010, 1150, 20, 16],
            [2010, 1156, 19, 15],
            [2010, 1174, 21, 25],
            [2010, 1186, 15, 13],
            [2010, 1213, 16, 12],
            [2010, 1221, 12, 14],
            [2010, 1234, 13, 14],
            [2010, 1235, 19, 14],
            [2010, 1238, 14, 17],
            [2010, 1247, 23, 17],
            [2010, 1254, 36, 18],
            [2010, 1268, 21, 19],
            [2010, 1281, 9, 9],
            [2010, 1295, 26, 20],
            [2010, 1303, 34, 24],
            [2010, 1396, 13, 13],
            [2010, 1420, 32, 34],
            [2010, 1466, 19, 15],
            [2010, 1473, 11, 8],
            [2010, 1481, 29, 16],
            [2010, 1491, 9, 8],
            [2010, 1507, 28, 21],
            [2010, 1515, 13, 11],
            [2010, 1525, 21, 18],
            [2010, 1536, 15, 18],
            [2010, 1577, 17, 13],
            [2010, 1580, 24, 21],
            [2010, 1587, 13, 14],
            [2010, 1589, 28, 18],
            [2010, 1598, 10, 8],
            [2010, 1628, 20, 14],
            [2010, 1635, 17, 13],
            [2010, 1645, 40, 23],
            [2010, 1673, 48, 29],
            [2010, 1685, 21, 18],
            [2010, 1717, 34, 23],
            [2010, 1730, 14, 11],
            [2010, 1772, 9, 12],
            [2010, 1774, 18, 14],
            [2010, 1795, 10, 8],
            [2010, 1797, 35, 20],
            [2010, 1798, 29, 22],
            [2010, 1866, 27, 20],
            [2010, 1894, 18, 13],
            [2010, 1903, 37, 22],
            [2010, 1930, 9, 7],
            [2010, 1952, 83, 37],
            [2010, 1962, 10, 10],
            [2010, 2011, 14, 13],
            [2010, 2017, 17, 16],
            [2010, 2023, 7, 7],
            [2010, 2035, 37, 24],
            [2010, 2064, 33, 21],
            [2010, 2142, 11, 11],
            [2010, 2178, 11, 11],
            [2010, 2190, 20, 16],
            [2010, 2198, 11, 10],
            [2010, 2208, 48, 29],
            [2010, 2213, 26, 18],
            [2010, 2227, 12, 13],
            [2010, 2244, 17, 16],
            [2010, 2250, 27, 20],
            [2010, 2280, 10, 8],
            [2010, 2282, 15, 24],
            [2010, 2311, 21, 18],
            [2010, 2316, 34, 23],
            [2010, 2352, 27, 19],
            [2010, 2371, 33, 22],
            [2010, 2429, 15, 14],
            [2010, 2443, 33, 20],
            [2010, 2459, 14, 15],
            [2010, 2467, 14, 11],
            [2010, 2500, 21, 14],
            [2010, 2501, 33, 23],
            [2010, 2505, 36, 20],
            [2010, 2524, 10, 9],
            [2010, 2533, 10, 14],
            [2010, 2576, 38, 21],
            [2010, 2595, 27, 22],
            [2010, 2606, 13, 12],
            [2010, 2627, 26, 19],
            [2010, 2635, 14, 15],
            [2010, 2670, 27, 18],
            [2010, 2671, 27, 22],
            [2010, 2692, 19, 17],
            [2010, 2695, 17, 12],
            [2010, 2723, 31, 23],
            [2010, 2758, 26, 22],
            [2010, 2775, 32, 22],
            [2010, 2785, 9, 10],
            [2010, 2798, 14, 15],
            [2010, 2822, 16, 13],
            [2010, 2835, 17, 14],
            [2010, 2836, 27, 20],
            [2010, 2879, 15, 15],
            [2010, 2914, 38, 20],
            [2010, 2922, 10, 11],
            [2010, 2991, 28, 18],
            [2010, 3019, 28, 16],
            [2010, 3053, 44, 21],
            [2010, 3066, 30, 22],
            [2010, 3086, 63, 36],
            [2010, 3091, 11, 12],
            [2010, 3092, 29, 21],
            [2010, 3119, 9, 11],
            [2010, 3126, 34, 18],
            [2010, 3134, 19, 18],
            [2010, 3158, 21, 18],
            [2010, 3164, 32, 22],
            [2010, 3171, 19, 14],
            [2010, 3182, 53, 30],
            [2010, 3221, 32, 22],
            [2010, 3246, 53, 31],
            [2010, 3252, 29, 18],
            [2010, 3273, 46, 20],
            [2010, 3308, 40, 22],
            [2010, 3309, 21, 19],
            [2010, 3321, 23, 19],
            [2010, 3348, 30, 19],
            [2010, 3364, 11, 13],
            [2010, 3372, 28, 20],
            [2010, 3382, 20, 14],
            [2010, 3434, 7, 7],
            [2010, 3438, 35, 20],
            [2010, 3454, 11, 11],
            [2010, 3462, 35, 22],
            [2010, 3494, 11, 11],
            [2010, 3515, 12, 23],
            [2010, 3517, 28, 21],
            [2010, 3559, 23, 18],
            [2010, 3569, 32, 33],
            [2010, 3669, 14, 15],
            [2010, 3700, 13, 13],
            [2010, 3718, 37, 29],
            [2010, 3726, 13, 12],
            [2010, 3729, 88, 37],
            [2010, 3765, 12, 15],
            [2010, 3859, 11, 12],
            [2010, 3884, 30, 20],
            [2010, 3889, 29, 18],
            [2010, 3915, 20, 32],
            [2010, 3943, 19, 18],
            [2010, 3956, 25, 28],
            [2010, 3976, 16, 17],
            [2010, 3985, 17, 15],
            [2010, 3993, 15, 14],
            [2010, 4015, 31, 20],
            [2010, 4022, 35, 22],
            [2010, 4027, 36, 21],
            [2010, 4043, 15, 13],
            [2010, 4074, 16, 17],
            [2010, 4091, 24, 20],
            [2010, 4107, 37, 24],
            [2010, 4125, 14, 15],
            [2010, 4173, 14, 14],
            [2010, 4176, 11, 11],
            [2010, 4246, 10, 16],
            [2010, 4312, 32, 23],
            [2010, 4325, 27, 18],
            [2010, 4353, 18, 12],
            [2010, 4358, 12, 12],
            [2010, 4362, 45, 27],
            [2010, 4386, 16, 14],
            [2010, 4414, 16, 16],
            [2010, 4426, 14, 14],
            [2010, 4440, 27, 19],
            [2010, 4442, 16, 18],
            [2010, 4454, 9, 10],
            [2010, 4464, 24, 20],
            [2010, 4477, 20, 18],
            [2010, 4491, 30, 20],
            [2010, 4518, 39, 21],
            [2010, 4536, 15, 15],
            [2010, 4545, 29, 21],
            [2010, 4610, 34, 22],
            [2010, 4617, 109, 33],
            [2010, 4623, 21, 16],
            [2010, 4626, 17, 12],
            [2010, 4634, 18, 16],
            [2010, 4638, 44, 22],
            [2010, 4644, 13, 14],
            [2010, 4648, 26, 17],
            [2010, 4660, 39, 22],
            [2010, 4670, 32, 21],
            [2010, 4676, 11, 13],
            [2010, 4689, 27, 23],
            [2010, 4710, 8, 6],
            [2010, 4734, 12, 11],
            [2010, 4749, 26, 20],
            [2010, 4762, 24, 20],
            [2010, 4789, 36, 20],
            [2010, 4794, 17, 14],
            [2010, 4801, 13, 15],
            [2010, 4805, 12, 13],
            [2010, 4820, 29, 21],
            [2010, 4832, 17, 15],
            [2010, 4840, 30, 20],
            [2010, 4863, 28, 20],
            [2010, 4865, 18, 14],
            [2010, 4871, 11, 13],
            [2010, 4897, 12, 13],
            [2010, 4912, 11, 15],
            [2010, 4914, 20, 16],
            [2010, 4918, 12, 13],
            [2010, 4939, 17, 15],
            [2010, 4944, 13, 14],
            [2010, 4976, 11, 11],
            [2010, 4983, 12, 11],
            [2010, 4992, 14, 14],
            [2010, 5031, 11, 11],
            [2010, 5038, 14, 14],
            [2010, 5051, 12, 14],
            [2010, 5081, 23, 18],
            [2010, 5092, 11, 11],
            [2010, 5095, 13, 13],
            [2010, 5108, 16, 16],
            [2010, 5149, 18, 16],
            [2010, 5159, 33, 25],
            [2010, 5184, 22, 17],
            [2010, 5185, 17, 14],
            [2010, 5186, 14, 15],
            [2010, 5187, 14, 13],
            [2010, 5188, 16, 15],
            [2010, 5217, 30, 20],
            [2010, 5219, 17, 23],
            [2010, 5220, 15, 23],
            [2010, 5221, 11, 14],
            [2010, 5222, 15, 19],
            [2010, 5223, 11, 18],
            [2010, 5224, 16, 23],
            [2010, 5225, 14, 20],
            [2010, 5226, 11, 20],
            [2010, 5227, 25, 31],
            [2010, 5228, 17, 27],
            [2010, 5229, 10, 19],
            [2010, 5230, 14, 18],
            [2010, 5231, 12, 17],
            [2010, 5232, 17, 24],
            [2010, 5233, 21, 32],
            [2010, 5234, 10, 13],
            [2010, 5235, 27, 22],
            [2010, 5236, 13, 17],
            [2010, 5237, 21, 21],
            [2010, 5238, 12, 14],
            [2010, 5239, 20, 26],
            [2010, 5240, 18, 30],
            [2010, 5241, 21, 25],
            [2010, 5242, 16, 20],
            [2010, 5243, 20, 28],
            [2010, 5244, 20, 28],
            [2010, 5245, 22, 31],
            [2010, 5273, 17, 14],
            [2010, 5375, 11, 6],
            [2010, 5434, 6, 6],
            [2010, 5472, 21, 21],
            [2010, 5473, 26, 26],
            [2010, 5495, 31, 26],
            [2010, 5528, 11, 6],
            [2010, 5944, 7, 7],
            [2010, 5945, 8, 8],
            [2010, 5946, 6, 5],
            [2010, 5996, 29, 21],
            [2010, 6068, 21, 23],
            [2010, 6069, 33, 24],
            [2010, 6070, 27, 26],
            [2010, 6071, 17, 20],
            [2010, 6073, 10, 20],
            [2010, 6074, 19, 22],
            [2010, 6075, 14, 23],
            [2010, 6076, 11, 17],
            [2010, 6077, 16, 21],
            [2010, 6078, 16, 19],
            [2010, 6079, 23, 22],
            [2010, 6080, 14, 21],
            [2010, 6081, 12, 16],
            [2010, 6082, 19, 22],
            [2010, 6083, 18, 21],
            [2010, 6084, 20, 21],
            [2010, 6085, 16, 21],
            [2010, 6087, 16, 19],
            [2010, 6088, 16, 17],
            [2010, 6089, 16, 19],
            [2010, 6090, 28, 21],
            [2010, 6091, 10, 19],
            [2010, 6092, 25, 22],
            [2010, 6093, 23, 24],
            [2010, 6094, 18, 22],
            [2010, 6095, 10, 15],
            [2010, 6096, 16, 20],
            [2010, 6097, 27, 20],
            [2010, 6098, 28, 20],
            [2010, 6099, 17, 21],
            [2010, 6100, 18, 22],
            [2010, 6101, 15, 20],
            [2010, 6102, 13, 18],
            [2010, 6103, 16, 21],
            [2010, 6104, 19, 19],
            [2010, 6105, 17, 21],
            [2010, 6106, 15, 18],
            [2010, 6108, 17, 20],
            [2010, 6109, 10, 17],
            [2010, 6110, 15, 22],
            [2010, 6111, 13, 13],
            [2010, 6112, 13, 21],
            [2010, 6113, 15, 18],
            [2010, 6114, 16, 18],
            [2010, 6115, 11, 17],
            [2010, 6116, 16, 21],
            [2010, 6117, 16, 20],
            [2010, 6118, 21, 22],
            [2010, 6119, 23, 21],
            [2010, 6120, 13, 17],
            [2010, 6121, 10, 20],
            [2010, 6122, 18, 21],
            [2010, 6123, 15, 18],
            [2010, 6124, 31, 21],
            [2010, 6125, 18, 22],
            [2010, 6126, 20, 21],
            [2010, 6127, 19, 22],
            [2010, 6128, 17, 22],
            [2010, 6130, 20, 21],
            [2010, 6131, 31, 21],
            [2010, 6132, 32, 22],
            [2010, 6133, 20, 21],
            [2010, 6134, 13, 20],
            [2010, 6135, 37, 25],
            [2010, 6136, 24, 28],
            [2010, 6137, 13, 15],
            [2010, 6138, 12, 17],
            [2010, 6139, 17, 20],
            [2010, 6140, 14, 16],
            [2010, 6141, 17, 17],
            [2010, 6142, 12, 18],
            [2010, 6143, 17, 21],
            [2010, 6145, 27, 20],
            [2010, 6146, 10, 13],
            [2010, 6147, 14, 18],
            [2010, 6148, 17, 17],
            [2010, 6149, 17, 22],
            [2010, 6150, 18, 15],
            [2010, 6151, 15, 16],
            [2010, 6152, 12, 17],
            [2010, 6153, 13, 16],
            [2010, 6154, 16, 20],
            [2010, 6155, 18, 16],
            [2010, 6156, 26, 17],
            [2010, 6157, 18, 17],
            [2010, 6158, 19, 16],
            [2010, 6159, 30, 17],
            [2010, 6160, 21, 18],
            [2010, 6161, 15, 13],
            [2010, 6162, 10, 15],
            [2010, 6163, 20, 19],
            [2010, 6164, 18, 20],
            [2010, 6165, 16, 16],
            [2010, 6166, 31, 21],
            [2010, 6167, 17, 25],
            [2010, 6244, 32, 25],
            [2010, 6353, 25, 22],
            [2010, 6358, 25, 18],
            [2010, 6391, 44, 40],
            [2010, 6433, 22, 26],
            [2010, 6438, 54, 42],
            [2010, 6442, 26, 17],
            [2010, 6463, 55, 33],
            [2010, 6471, 54, 32],
            [2010, 6492, 33, 38],
            [2010, 6494, 30, 29],
            [2010, 6495, 33, 20],
            [2010, 6502, 20, 14],
            [2010, 6614, 17, 18],
            [2010, 6631, 18, 23],
            [2010, 6633, 16, 20],
            [2010, 6634, 17, 20],
            [2010, 6635, 17, 21],
            [2010, 6636, 33, 25],
            [2010, 6637, 18, 21],
            [2010, 6638, 35, 22],
            [2010, 6639, 14, 23],
            [2010, 6640, 22, 42],
            [2010, 6643, 34, 22],
            [2010, 6649, 17, 21],
            [2010, 6650, 21, 21],
            [2010, 6651, 17, 18],
            [2010, 6652, 17, 21],
            [2010, 6653, 21, 23],
            [2010, 6654, 19, 21],
            [2010, 6655, 17, 19],
            [2010, 6656, 16, 21],
            [2010, 6657, 17, 23],
            [2010, 6660, 29, 20],
            [2010, 6661, 16, 21],
            [2010, 6662, 17, 21],
            [2010, 6663, 21, 21],
            [2010, 6664, 36, 23],
            [2010, 6665, 18, 22],
            [2010, 6666, 14, 21],
            [2010, 6667, 17, 21],
            [2010, 6668, 19, 19],
            [2010, 6669, 13, 23],
            [2010, 6670, 28, 21],
            [2010, 6671, 21, 21],
            [2010, 6672, 25, 21],
            [2010, 6673, 29, 21],
            [2010, 6674, 20, 22],
            [2010, 6675, 27, 19],
            [2010, 6676, 20, 22],
            [2010, 6677, 18, 22],
            [2010, 6678, 19, 19],
            [2010, 6679, 31, 28],
            [2010, 6680, 19, 18],
            [2010, 6682, 21, 20],
            [2010, 6683, 14, 18],
            [2010, 6684, 18, 20],
            [2010, 6685, 14, 16],
            [2010, 6686, 15, 16],
            [2010, 6687, 11, 19],
            [2010, 6688, 11, 16],
            [2010, 6689, 10, 16],
            [2010, 6690, 15, 17],
            [2010, 6697, 20, 23],
            [2010, 6699, 21, 62],
            [2010, 6700, 67, 43],
            [2010, 6701, 45, 31],
            [2010, 6702, 52, 42],
            [2010, 6704, 47, 36],
            [2010, 6715, 52, 28],
            [2010, 6716, 49, 28],
            [2010, 6718, 18, 32],
            [2010, 6722, 44, 28],
            [2010, 6723, 82, 52],
            [2010, 6726, 15, 47],
            [2010, 6728, 52, 35],
            [2010, 6734, 49, 29],
            [2010, 6737, 24, 72],
            [2010, 6738, 43, 38],
            [2010, 6741, 14, 15],
            [2010, 6748, 18, 21],
            [2010, 6749, 13, 19],
            [2010, 6750, 18, 23],
            [2010, 6752, 11, 17],
            [2010, 6753, 18, 21],
            [2010, 6754, 18, 22],
            [2010, 6755, 30, 25],
            [2010, 6756, 18, 21],
            [2010, 6757, 15, 20],
            [2010, 6758, 13, 23],
            [2010, 6759, 11, 17],
            [2010, 6760, 30, 25],
            [2010, 6761, 21, 25],
            [2010, 6762, 19, 24],
            [2010, 6763, 13, 15],
            [2010, 6764, 21, 24],
            [2010, 6766, 40, 24],
            [2010, 6767, 15, 21],
            [2010, 6768, 18, 21],
            [2010, 6769, 31, 25],
            [2010, 6770, 17, 25],
            [2010, 6771, 16, 24],
            [2010, 6772, 13, 18],
            [2010, 6773, 19, 24],
            [2010, 6777, 21, 25],
            [2010, 6778, 10, 16],
            [2010, 6779, 17, 22],
            [2010, 6780, 21, 25],
            [2010, 6781, 19, 25],
            [2010, 6782, 36, 25],
            [2010, 6783, 18, 25],
            [2010, 6784, 11, 24],
            [2010, 6785, 25, 23],
            [2010, 6786, 14, 23],
            [2010, 6787, 21, 24],
            [2010, 6789, 20, 22],
            [2010, 6790, 18, 62],
            [2010, 6791, 62, 68],
            [2010, 6794, 15, 44],
            [2010, 6795, 29, 38],
            [2010, 6798, 57, 29],
            [2010, 6803, 21, 77],
            [2010, 6804, 47, 72],
            [2010, 6805, 49, 62],
            [2010, 6806, 21, 52],
            [2010, 6807, 45, 48],
            [2010, 6808, 16, 37],
            [2010, 6812, 178, 82],
            [2010, 6813, 17, 53],
            [2010, 6814, 145, 97],
            [2010, 6816, 45, 83],
            [2010, 6818, 14, 14],
            [2010, 6818, 14, 14],
            [2010, 6819, 24, 27],
            [2010, 6819, 24, 27],
            [2010, 6820, 33, 28],
            [2010, 6820, 33, 28],
            [2010, 6821, 30, 36],
            [2010, 6821, 30, 36],
            [2010, 6822, 30, 36],
            [2010, 6822, 30, 36],
            [2010, 6823, 27, 33],
            [2010, 6823, 27, 33],
            [2010, 6833, 29, 32],
            [2010, 6834, 89, 92],
            [2010, 6835, 132, 112],
            [2010, 6836, 37, 42],
            [2010, 6837, 13, 25],
            [2010, 6838, 126, 83],
            [2010, 6841, 13, 19],
            [2010, 6845, 18, 50],
            [2010, 6846, 13, 38],
            [2010, 6847, 18, 42],
            [2010, 6848, 18, 27],
            [2010, 6849, 53, 38],
            [2010, 6850, 18, 32],
            [2010, 6851, 35, 43],
            [2010, 6852, 89, 97],
            [2010, 6853, 19, 52],
            [2010, 6854, 92, 74],
            [2010, 6855, 18, 37],
            [2010, 6856, 14, 49],
            [2010, 6857, 25, 58],
            [2010, 6858, 18, 37],
            [2010, 6859, 29, 24],
            [2010, 6860, 15, 42],
            [2010, 6861, 18, 42],
            [2010, 6862, 29, 32],
            [2010, 6867, 14, 18],
            [2010, 6868, 15, 12],
            [2010, 6869, 14, 13],
            [2010, 6870, 11, 15],
            [2010, 6871, 15, 15],
            [2010, 6872, 15, 15],
            [2010, 6873, 21, 12],
            [2010, 6874, 11, 15],
            [2010, 6875, 14, 15],
            [2010, 6876, 11, 14],
            [2010, 6877, 16, 19],
            [2010, 6878, 14, 16],
            [2010, 6879, 16, 20],
            [2010, 6880, 21, 18],
            [2010, 6881, 11, 13],
            [2010, 6882, 15, 13],
            [2010, 6883, 21, 21],
            [2010, 6910, 18, 18],
            [2010, 6912, 11, 10],
            [2010, 6914, 11, 11],
            [2010, 6918, 15, 15],
            [2010, 6920, 13, 15],
            [2010, 6922, 11, 10],
            [2010, 6928, 12, 14],
            [2010, 6930, 16, 17],
            [2010, 6931, 37, 28],
            [2010, 6934, 13, 13],
            [2010, 6938, 12, 12],
            [2010, 6940, 11, 10],
            [2010, 6942, 11, 15],
            [2010, 6944, 9, 9],
            [2010, 6948, 11, 10],
            [2010, 6950, 11, 10],
            [2010, 6952, 26, 19],
            [2010, 6954, 14, 13],
            [2010, 6957, 63, 40],
            [2010, 6958, 12, 11],
            [2010, 6960, 11, 13],
            [2010, 6962, 12, 9],
            [2010, 6965, 9, 9],
            [2010, 6966, 20, 38],
            [2010, 6967, 13, 20],
            [2010, 6968, 32, 43],
            [2010, 6969, 13, 19],
            [2010, 6970, 19, 38],
            [2010, 7007, 34, 20],
            [2010, 7008, 58, 27],
            [2010, 7011, 10, 10],
            [2010, 7013, 15, 12],
            [2010, 7014, 14, 8],
            [2010, 7015, 9, 8],
            [2010, 7019, 8, 9],
            [2010, 7021, 11, 11],
            [2010, 7027, 11, 12],
            [2010, 7029, 34, 23],
            [2010, 7031, 12, 14],
            [2010, 7033, 19, 14],
            [2010, 7035, 11, 10],
            [2010, 7039, 15, 13],
            [2010, 7050, 11, 11],
            [2010, 7052, 11, 14],
            [2010, 7054, 15, 12],
            [2010, 7056, 11, 12],
            [2010, 7057, 48, 28],
            [2010, 7058, 16, 14],
            [2010, 7062, 11, 11],
            [2010, 7063, 40, 26],
            [2010, 7066, 9, 10],
            [2010, 7068, 43, 21],
            [2010, 7070, 37, 27],
            [2010, 7072, 10, 10],
            [2010, 7074, 12, 12],
            [2010, 7076, 14, 15],
            [2010, 7078, 11, 11],
            [2010, 7080, 31, 24],
            [2010, 7082, 11, 12],
            [2010, 7084, 25, 19],
            [2010, 7086, 11, 15],
            [2010, 7088, 31, 20],
            [2010, 7090, 11, 11],
            [2010, 7091, 48, 27],
            [2010, 7092, 39, 30],
            [2010, 7093, 66, 44],
            [2010, 7094, 29, 25],
            [2010, 7098, 11, 17],
            [2010, 7156, 16, 17],
            [2010, 7283, 10, 16],
            [2010, 7284, 16, 17],
            [2010, 7285, 17, 19],
            [2010, 7286, 10, 17],
            [2010, 7287, 16, 20],
            [2010, 7288, 31, 27],
            [2010, 7289, 24, 23],
            [2010, 7290, 34, 29],
            [2010, 7291, 37, 30],
            [2010, 7292, 25, 27],
            [2010, 7293, 20, 22],
            [2010, 7294, 21, 24],
            [2010, 7295, 11, 11],
            [2010, 7296, 19, 17],
            [2010, 7297, 23, 18],
            [2010, 7298, 14, 14],
            [2010, 7299, 16, 15],
            [2010, 7300, 15, 18],
            [2010, 7301, 13, 17],
            [2010, 7302, 25, 27],
            [2010, 7303, 59, 48],
            [2010, 7304, 24, 26],
            [2010, 7305, 28, 28],
            [2010, 7306, 24, 26],
            [2010, 7307, 43, 42],
            [2010, 7308, 33, 32],
            [2010, 7309, 24, 26],
            [2010, 7310, 71, 57],
            [2010, 7311, 65, 55],
            [2010, 7312, 24, 25],
            [2010, 7313, 117, 34],
            [2010, 7314, 23, 16],
            [2010, 7315, 14, 12],
            [2010, 7316, 34, 60],
            [2010, 7317, 38, 31],
            [2010, 7318, 115, 81],
            [2010, 7319, 39, 30],
            [2010, 7320, 70, 57],
            [2010, 7321, 77, 90],
            [2010, 7322, 69, 37],
            [2010, 7323, 81, 69],
            [2010, 7324, 66, 53],
            [2010, 7325, 99, 38],
            [2010, 7326, 24, 16],
            [2010, 7327, 170, 106],
            [2010, 7328, 18, 17],
            [2010, 7337, 13, 10],
            [2010, 7342, 13, 8],
            [2010, 7343, 15, 8],
            [2010, 7344, 10, 8],
            [2010, 7348, 15, 9],
            [2010, 7352, 12, 10],
            [2010, 7354, 23, 12],
            [2010, 7356, 15, 10],
            [2010, 7357, 23, 12],
            [2010, 7358, 17, 11],
            [2010, 7359, 23, 14],
            [2010, 7360, 13, 9],
            [2010, 7362, 15, 10],
            [2010, 7363, 13, 9],
            [2010, 7364, 15, 10],
            [2010, 7367, 13, 10],
            [2010, 7370, 12, 9],
            [2010, 7371, 13, 8],
            [2010, 7372, 13, 10],
            [2010, 7373, 13, 9],
            [2010, 7374, 10, 8],
            [2010, 7375, 12, 10],
            [2010, 7376, 7, 7],
            [2010, 7377, 11, 8],
            [2010, 7378, 10, 13],
            [2010, 7379, 19, 15],
            [2010, 7398, 21, 23],
            [2010, 7399, 22, 27],
            [2010, 7401, 17, 22],
            [2010, 7403, 18, 22],
            [2010, 7405, 20, 24],
            [2010, 7407, 27, 30],
            [2010, 7410, 14, 19],
            [2010, 7411, 40, 27],
            [2010, 7413, 8, 10],
            [2010, 7414, 13, 20],
            [2010, 7415, 8, 10],
            [2010, 7416, 25, 27],
            [2010, 7417, 19, 17],
            [2010, 7420, 23, 24],
            [2010, 7421, 23, 22],
            [2010, 7423, 59, 48],
            [2010, 7433, 71, 50],
            [2010, 7434, 92, 83],
            [2010, 7435, 32, 38],
            [2010, 7436, 42, 42],
            [2010, 7437, 22, 19],
            [2010, 7438, 72, 32],
            [2010, 7441, 34, 24],
            [2010, 7442, 39, 20],
            [2010, 7443, 31, 42],
            [2010, 7444, 49, 72],
            [2010, 7445, 32, 54],
            [2010, 7446, 40, 58],
            [2010, 7447, 17, 19],
            [2010, 7448, 48, 33],
            [2010, 7451, 16, 11],
            [2010, 7454, 31, 26],
            [2010, 7456, 21, 27],
            [2010, 7457, 40, 27],
            [2010, 7458, 32, 23],
            [2010, 7459, 53, 27],
            [2010, 7460, 44, 30],
            [2010, 7461, 21, 22],
            [2010, 7462, 26, 28],
            [2010, 7463, 59, 25],
            [2010, 7464, 60, 31],
            [2010, 7465, 36, 24],
            [2010, 7466, 31, 27],
            [2010, 7467, 42, 28],
            [2010, 7468, 25, 23],
            [2010, 7469, 56, 25],
            [2010, 7470, 48, 31],
            [2010, 7471, 39, 29],
            [2010, 7472, 89, 32],
            [2010, 7473, 34, 24],
            [2010, 7474, 41, 27],
            [2010, 7475, 52, 26],
            [2010, 7476, 52, 24],
            [2010, 7477, 27, 23],
            [2010, 7478, 50, 24],
            [2010, 7479, 33, 23],
            [2010, 7480, 28, 31],
            [2010, 7481, 27, 24],
            [2010, 7482, 50, 24],
            [2010, 7483, 38, 26],
            [2010, 7484, 40, 25],
            [2010, 7485, 88, 37],
            [2010, 7486, 47, 25],
            [2010, 7487, 57, 24],
            [2010, 7488, 43, 23],
            [2010, 7489, 36, 30],
            [2010, 7490, 21, 20],
            [2010, 7491, 31, 24],
            [2010, 7492, 66, 30],
            [2010, 7493, 41, 25],
            [2010, 7494, 56, 27],
            [2010, 7495, 27, 27],
            [2010, 7496, 79, 38],
            [2010, 7497, 29, 25],
            [2010, 7498, 31, 25],
            [2010, 7499, 28, 22],
            [2010, 7500, 30, 30],
            [2010, 7501, 38, 29],
            [2010, 7502, 29, 28],
            [2010, 7503, 50, 26],
            [2010, 7504, 21, 27],
            [2010, 7505, 52, 25],
            [2010, 7506, 69, 31],
            [2010, 7507, 45, 24],
            [2010, 7508, 51, 26],
            [2010, 7509, 41, 26],
            [2010, 7510, 52, 28],
            [2010, 7511, 37, 25],
            [2010, 7512, 48, 26],
            [2010, 7513, 34, 23],
            [2010, 7514, 38, 44],
            [2010, 7515, 30, 30],
            [2010, 7516, 33, 26],
            [2010, 7517, 73, 37],
            [2010, 7518, 60, 31],
            [2010, 7519, 29, 22],
            [2010, 7520, 36, 25],
            [2010, 7521, 25, 23],
            [2010, 7522, 52, 35],
            [2010, 7523, 38, 23],
            [2010, 7524, 51, 29],
            [2010, 7525, 37, 26],
            [2010, 7526, 35, 24],
            [2010, 7527, 32, 24],
            [2010, 7528, 32, 27],
            [2010, 7529, 63, 41],
            [2010, 7530, 33, 31],
            [2010, 7531, 32, 19],
            [2010, 7532, 47, 27],
            [2010, 7533, 61, 33],
            [2010, 7534, 46, 31],
            [2010, 7535, 36, 30],
            [2010, 7536, 37, 26],
            [2010, 7537, 44, 29],
            [2010, 7538, 34, 31],
            [2010, 7539, 53, 25],
            [2010, 7540, 47, 26],
            [2010, 7541, 41, 29],
            [2010, 7542, 48, 28],
            [2010, 7543, 37, 24],
            [2010, 7544, 41, 25],
            [2010, 7545, 50, 24],
            [2010, 7546, 30, 25],
            [2010, 7547, 20, 25],
            [2010, 7548, 35, 25],
            [2010, 7549, 44, 29],
            [2010, 7550, 21, 23],
            [2010, 7551, 39, 28],
            [2010, 7552, 38, 28],
            [2010, 7553, 36, 25],
            [2010, 7554, 44, 31],
            [2010, 7555, 81, 34],
            [2010, 7556, 57, 28],
            [2010, 7557, 74, 31],
            [2010, 7558, 29, 23],
            [2010, 7559, 30, 25],
            [2010, 7560, 25, 28],
            [2010, 7561, 47, 30],
            [2010, 7562, 39, 33],
            [2010, 7563, 35, 31],
            [2010, 7564, 53, 25],
            [2010, 7565, 35, 25],
            [2010, 7566, 39, 25],
            [2010, 7567, 85, 28],
            [2010, 7568, 45, 25],
            [2010, 7569, 32, 24],
            [2010, 7570, 36, 25],
            [2010, 7571, 39, 25],
            [2010, 7572, 19, 25],
            [2010, 7573, 30, 19],
            [2010, 7574, 35, 25],
            [2010, 7575, 35, 25],
            [2010, 7576, 59, 31],
            [2010, 7577, 33, 31],
            [2010, 7578, 42, 25],
            [2010, 7579, 52, 26],
            [2010, 7580, 53, 31],
            [2010, 7581, 35, 26],
            [2010, 7582, 39, 31],
            [2010, 7583, 47, 26],
            [2010, 7584, 44, 24],
            [2010, 7585, 27, 29],
            [2010, 7586, 74, 38],
            [2010, 7587, 25, 25],
            [2010, 7588, 31, 25],
            [2010, 7589, 47, 38],
            [2010, 7590, 37, 30],
            [2010, 7591, 25, 23],
            [2010, 7592, 27, 31],
            [2010, 7593, 50, 30],
            [2010, 7594, 44, 24],
            [2010, 7595, 42, 25],
            [2010, 7596, 48, 23],
            [2010, 7597, 58, 26],
            [2010, 7598, 47, 30],
            [2010, 7599, 60, 26],
            [2010, 7600, 29, 26],
            [2010, 7601, 34, 24],
            [2010, 7602, 44, 23],
            [2010, 7603, 48, 34],
            [2010, 7604, 58, 28],
            [2010, 7605, 39, 26],
            [2010, 7606, 39, 25],
            [2010, 7607, 28, 31],
            [2010, 7608, 28, 28],
            [2010, 7609, 19, 27],
            [2010, 7610, 34, 24],
            [2010, 7611, 33, 28],
            [2010, 7612, 39, 31],
            [2010, 7613, 34, 25],
            [2010, 7614, 30, 25],
            [2010, 7615, 38, 31],
            [2010, 7616, 35, 24],
            [2010, 7617, 25, 23],
            [2010, 7618, 35, 29],
            [2010, 7619, 30, 27],
            [2010, 7620, 35, 25],
            [2010, 7621, 47, 27],
            [2010, 7622, 32, 26],
            [2010, 7623, 38, 25],
            [2010, 7624, 31, 29],
            [2010, 7625, 23, 24],
            [2010, 7626, 35, 29],
            [2010, 7627, 30, 28],
            [2010, 7628, 53, 31],
            [2010, 7629, 25, 29],
            [2010, 7630, 50, 24],
            [2010, 7631, 32, 25],
            [2010, 7632, 45, 24],
            [2010, 7633, 37, 24],
            [2010, 7635, 10, 13],
            [2010, 7636, 10, 16],
            [2010, 7639, 6, 11],
            [2010, 7649, 6, 6],
            [2010, 7661, 8, 10],
            [2010, 7662, 14, 12],
            [2010, 7663, 10, 11],
            [2010, 7668, 12, 10],
            [2010, 7669, 10, 8],
            [2010, 7672, 9, 8],
            [2010, 7673, 8, 7],
            [2010, 7674, 15, 12],
            [2010, 7676, 6, 8],
            [2010, 7677, 5, 6],
            [2010, 7678, 10, 8],
            [2010, 7679, 11, 8],
            [2010, 7680, 17, 14],
            [2010, 7681, 4, 3],
            [2010, 7682, 14, 12],
            [2010, 7683, 3, 3],
            [2010, 7684, 15, 11],
            [2010, 7685, 9, 9],
            [2010, 7686, 18, 14],
            [2010, 7687, 4, 4],
            [2010, 7688, 14, 12],
            [2010, 7690, 7, 8],
            [2010, 7691, 15, 16],
            [2010, 7692, 10, 8],
            [2010, 7693, 8, 8],
            [2010, 7694, 9, 8],
            [2010, 7695, 14, 16],
            [2010, 7696, 3, 3],
            [2010, 7697, 12, 11],
            [2010, 7698, 9, 8],
            [2010, 7699, 11, 13],
            [2010, 7700, 11, 9],
            [2010, 7701, 7, 8],
            [2010, 7702, 16, 12],
            [2010, 7703, 9, 10],
            [2010, 7705, 17, 12],
            [2010, 7706, 11, 9],
            [2010, 7707, 10, 10],
            [2010, 7708, 8, 7],
            [2010, 7709, 11, 11],
            [2010, 7710, 6, 5],
            [2010, 7711, 12, 10],
            [2010, 7713, 20, 11],
            [2010, 7714, 10, 8],
            [2010, 7716, 16, 17],
            [2010, 7719, 17, 28],
            [2010, 7723, 18, 38],
            [2010, 7725, 19, 17],
            [2010, 7730, 17, 19],
            [2010, 7736, 18, 22],
            [2010, 7738, 16, 19],
            [2010, 7740, 27, 28],
            [2010, 7749, 22, 24],
            [2010, 7754, 23, 26],
            [2010, 7757, 29, 84],
            [2010, 7758, 57, 98],
            [2010, 7759, 25, 26],
            [2010, 7760, 72, 46],
            [2010, 7761, 15, 34],
            [2010, 7762, 57, 62],
            [2010, 7765, 11, 13],
            [2010, 7766, 8, 11],
            [2010, 7796, 61, 35],
            [2010, 7797, 67, 38],
            [2010, 7798, 51, 25],
            [2010, 7799, 46, 36],
            [2010, 7800, 50, 23],
            [2010, 7801, 67, 32],
            [2010, 7802, 20, 22],
            [2010, 7803, 106, 59],
            [2010, 7804, 68, 35],
            [2010, 7805, 50, 30],
            [2010, 7806, 64, 39],
            [2010, 7807, 56, 38],
            [2010, 7808, 65, 25],
            [2010, 7809, 61, 40],
            [2010, 7810, 61, 50],
            [2010, 7811, 95, 60],
            [2010, 7812, 32, 26],
            [2010, 7813, 39, 23],
            [2010, 7815, 42, 28],
            [2010, 7816, 70, 45],
            [2010, 7817, 29, 34],
            [2010, 7818, 35, 30],
            [2010, 7819, 36, 50],
            [2010, 7820, 41, 27],
            [2010, 7821, 66, 39],
            [2010, 7822, 39, 33],
            [2010, 7823, 30, 21],
            [2010, 7824, 101, 67],
            [2010, 7825, 57, 27],
            [2010, 7826, 40, 31],
            [2010, 7827, 68, 27],
            [2010, 7828, 70, 66],
            [2010, 7829, 45, 33],
            [2010, 7830, 45, 28],
            [2010, 7831, 47, 28],
            [2010, 7832, 74, 43],
            [2010, 7833, 36, 27],
            [2010, 7834, 62, 42],
            [2010, 7835, 44, 23],
            [2010, 7836, 66, 50],
            [2010, 7837, 32, 30],
            [2010, 7838, 69, 22],
            [2010, 7839, 61, 43],
            [2010, 7840, 92, 54],
            [2010, 7841, 49, 27],
            [2010, 7842, 26, 25],
            [2010, 7843, 31, 19],
            [2010, 7844, 71, 32],
            [2010, 7845, 22, 22],
            [2010, 7846, 68, 34],
            [2010, 7847, 54, 26],
            [2010, 7848, 71, 39],
            [2010, 7849, 81, 60],
            [2010, 7850, 40, 47],
            [2010, 7851, 57, 38],
            [2010, 7852, 31, 23],
            [2010, 7853, 26, 29],
            [2010, 7854, 20, 23],
            [2010, 7855, 32, 22],
            [2010, 7856, 72, 38],
            [2010, 7857, 51, 26],
            [2010, 7858, 24, 22],
            [2010, 7859, 62, 35],
            [2010, 7860, 64, 36],
            [2010, 7861, 35, 24],
            [2010, 7862, 113, 49],
            [2010, 7863, 53, 46],
            [2010, 7864, 21, 29],
            [2010, 7865, 45, 27],
            [2010, 7866, 71, 39],
            [2010, 7867, 35, 27],
            [2010, 7868, 33, 26],
            [2010, 7869, 50, 37],
            [2010, 7870, 37, 26],
            [2010, 7871, 41, 27],
            [2010, 7872, 74, 54],
            [2010, 7873, 70, 38],
            [2010, 7874, 33, 26],
            [2010, 7875, 64, 35],
            [2010, 7876, 70, 45],
            [2010, 7877, 72, 38],
            [2010, 7878, 102, 30],
            [2010, 7879, 73, 43],
            [2010, 7880, 47, 29],
            [2010, 7881, 32, 31],
            [2010, 7882, 21, 16],
            [2010, 7883, 41, 32],
            [2010, 7884, 31, 32],
            [2010, 7885, 43, 32],
            [2010, 7886, 39, 26],
            [2010, 7887, 44, 23],
            [2010, 7888, 71, 29],
            [2010, 7889, 77, 50],
            [2010, 7890, 33, 36],
            [2010, 7891, 39, 23],
            [2010, 7892, 24, 26],
            [2010, 7893, 24, 23],
            [2010, 7894, 61, 42],
            [2010, 7895, 47, 30],
            [2010, 7896, 97, 40],
            [2010, 7897, 72, 37],
            [2010, 7898, 20, 28],
            [2010, 7899, 35, 44],
            [2010, 7900, 71, 44],
            [2010, 7901, 71, 32],
            [2010, 7902, 53, 34],
            [2010, 7903, 66, 38],
            [2010, 7904, 47, 33],
            [2010, 7905, 40, 37],
            [2010, 7906, 62, 41],
            [2010, 7907, 72, 39],
            [2010, 7908, 84, 39],
            [2010, 7909, 50, 34],
            [2010, 7910, 43, 32],
            [2010, 7911, 53, 35],
            [2010, 7912, 72, 52],
            [2010, 7913, 71, 34],
            [2010, 7914, 56, 39],
            [2010, 7915, 62, 48],
            [2010, 7916, 59, 36],
            [2010, 7917, 46, 35],
            [2010, 7918, 41, 27],
            [2010, 7919, 31, 25],
            [2010, 7920, 48, 31],
            [2010, 7921, 35, 15],
            [2010, 7922, 23, 27],
            [2010, 7923, 60, 27],
            [2010, 7924, 34, 27],
            [2010, 7925, 36, 27],
            [2010, 7926, 182, 35],
            [2010, 7927, 35, 34],
            [2010, 7928, 20, 27],
            [2010, 7929, 71, 35],
            [2010, 7930, 56, 38],
            [2010, 7931, 33, 26],
            [2010, 7932, 32, 26],
            [2010, 7933, 59, 31],
            [2010, 7934, 43, 32],
            [2010, 7935, 68, 38],
            [2010, 7936, 73, 35],
            [2010, 7937, 42, 33],
            [2010, 7938, 19, 15],
            [2010, 7939, 65, 44],
            [2010, 7940, 65, 39],
            [2010, 7941, 67, 47],
            [2010, 7942, 66, 38],
            [2010, 7943, 36, 23],
            [2010, 7944, 23, 24],
            [2010, 7945, 69, 31],
            [2010, 7946, 32, 41],
            [2010, 7947, 49, 32],
            [2010, 7948, 31, 23],
            [2010, 7949, 45, 49],
            [2010, 7950, 41, 34],
            [2010, 7951, 75, 39],
            [2010, 7952, 36, 25],
            [2010, 7953, 31, 14],
            [2010, 7954, 63, 20],
            [2010, 7955, 100, 32],
            [2010, 7956, 58, 28],
            [2010, 7957, 70, 32],
            [2010, 7958, 73, 35],
            [2010, 7959, 70, 30],
            [2010, 7960, 35, 28],
            [2010, 7961, 66, 39],
            [2010, 7962, 126, 48],
            [2010, 7963, 21, 19],
            [2010, 7964, 45, 49],
            [2010, 7965, 71, 30],
            [2010, 7966, 85, 60],
            [2010, 7967, 51, 24],
            [2010, 7968, 67, 49],
            [2010, 7969, 63, 50],
            [2010, 7970, 67, 38],
            [2010, 7971, 22, 25],
            [2010, 7972, 32, 27],
            [2010, 7974, 41, 22],
            [2010, 7975, 123, 61],
            [2010, 7976, 120, 37],
            [2010, 7977, 36, 39],
            [2010, 7978, 68, 41],
            [2010, 7979, 68, 38],
            [2010, 7980, 66, 35],
            [2010, 7981, 47, 22],
            [2010, 7982, 47, 28],
            [2010, 7983, 54, 23],
            [2010, 7984, 66, 49],
            [2010, 7985, 39, 33],
            [2010, 7986, 52, 27],
            [2010, 7987, 46, 35],
            [2010, 7988, 25, 34],
            [2010, 7989, 68, 32],
            [2010, 7990, 56, 27],
            [2010, 7992, 59, 32],
            [2010, 7993, 60, 37],
            [2010, 7994, 36, 28],
            [2010, 7995, 116, 50],
            [2010, 7996, 61, 35],
            [2010, 7997, 80, 39],
            [2010, 7998, 39, 20],
            [2010, 7999, 74, 37],
            [2010, 8000, 56, 24],
            [2010, 8001, 128, 59],
            [2010, 8002, 53, 31],
            [2010, 8003, 24, 22],
            [2010, 8004, 57, 40],
            [2010, 8022, 16, 21],
            [2010, 8039, 21, 21],
            [2010, 8040, 21, 22],
            [2010, 8041, 6, 7],
            [2010, 8045, 5, 3],
            [2010, 8046, 5, 3],
            [2010, 8047, 5, 4],
            [2010, 8048, 13, 16],
            [2010, 8049, 11, 13],
            [2010, 8050, 8, 8],
            [2010, 8052, 17, 23],
            [2010, 8053, 16, 21],
            [2010, 8054, 12, 24],
            [2010, 8055, 19, 22],
            [2010, 8056, 22, 27],
            [2010, 8057, 16, 19],
            [2010, 8059, 16, 17],
            [2010, 8060, 17, 16],
            [2010, 8061, 38, 35],
            [2010, 8062, 31, 36],
            [2010, 8063, 8, 10],
            [2010, 8064, 11, 13],
            [2010, 8065, 11, 11],
            [2010, 8068, 7, 9],
            [2010, 8069, 7, 9],
            [2010, 8071, 31, 17],
            [2010, 8073, 11, 12],
            [2010, 8074, 11, 12],
            [2010, 8075, 12, 12],
            [2010, 8076, 29, 18],
            [2010, 8086, 21, 24],
            [2010, 8087, 14, 21],
            [2010, 8088, 13, 21],
            [2010, 8089, 18, 21],
            [2010, 8090, 21, 24],
            [2010, 8091, 21, 21],
            [2010, 8092, 15, 21],
            [2010, 8093, 21, 21],
            [2010, 8094, 14, 21],
            [2010, 8095, 15, 21],
            [2010, 8096, 17, 21],
            [2010, 8097, 16, 24],
            [2010, 8107, 18, 18],
            [2010, 8110, 20, 15],
            [2010, 8124, 20, 20],
            [2010, 8126, 16, 23],
            [2010, 8127, 21, 25],
            [2010, 8131, 16, 18],
            [2010, 8133, 16, 19],
            [2010, 8136, 18, 21],
            [2010, 8137, 30, 30],
            [2010, 8138, 25, 30],
            [2010, 8149, 20, 23],
            [2010, 8151, 16, 19],
            [2010, 8153, 20, 29],
            [2010, 8159, 25, 25],
            [2010, 8164, 20, 19],
            [2010, 8168, 30, 36],
            [2010, 8171, 20, 28],
            [2010, 8175, 20, 21],
            [2010, 8177, 33, 21],
            [2010, 8178, 22, 20],
            [2010, 8185, 19, 20],
            [2010, 8187, 27, 32],
            [2010, 8188, 19, 17],
            [2010, 8195, 20, 30],
            [2010, 8200, 23, 25],
            [2010, 8205, 17, 20],
            [2010, 8208, 17, 38],
            [2010, 8218, 11, 15],
            [2010, 8220, 28, 25],
            [2010, 8222, 23, 17],
            [2010, 8225, 16, 18],
            [2010, 8228, 26, 31],
            [2010, 8231, 16, 21],
            [2010, 8234, 25, 30],
            [2010, 8236, 19, 20],
            [2010, 8241, 15, 22],
            [2010, 8248, 15, 20],
            [2010, 8250, 19, 21],
            [2010, 8262, 17, 20],
            [2010, 8264, 30, 36],
            [2010, 8270, 11, 19],
            [2010, 8271, 25, 21],
            [2010, 8287, 18, 20],
            [2010, 8288, 20, 22],
            [2010, 8299, 22, 17],
            [2010, 8309, 15, 17],
            [2010, 8311, 10, 11],
            [2010, 8312, 11, 11],
            [2010, 8313, 10, 11],
            [2010, 8314, 11, 11],
            [2010, 8315, 13, 13],
            [2010, 8316, 10, 10],
            [2010, 8317, 28, 21],
            [2010, 8319, 15, 14],
            [2010, 8323, 21, 18],
            [2010, 8390, 16, 16],
            [2010, 8536, 18, 21],
            [2010, 8537, 28, 19],
            [2010, 8538, 31, 22],
            [2010, 8539, 29, 23],
            [2010, 8540, 24, 27],
            [2010, 8541, 26, 29],
            [2010, 8542, 20, 24],
            [2010, 8543, 17, 24],
            [2010, 8544, 21, 33],
            [2010, 8546, 21, 26],
            [2010, 8547, 28, 33],
            [2010, 8548, 14, 15],
            [2010, 8565, 10, 11],
            [2010, 8566, 20, 13],
            [2010, 8567, 19, 15],
            [2010, 8568, 16, 14],
            [2010, 8569, 15, 13],
            [2010, 8570, 10, 9],
            [2010, 8571, 10, 10],
            [2010, 8572, 9, 9],
            [2010, 8573, 13, 11],
            [2010, 8574, 16, 12],
            [2010, 8575, 12, 10],
            [2010, 8576, 20, 15],
            [2010, 8577, 6, 12],
            [2010, 8578, 20, 15],
            [2010, 8579, 15, 14],
            [2010, 8580, 18, 14],
            [2010, 8581, 13, 9],
            [2010, 8582, 13, 13],
            [2010, 8583, 18, 15],
            [2010, 8584, 12, 11],
            [2010, 8719, 22, 20],
            [2010, 8720, 24, 20],
            [2010, 8721, 24, 20],
            [2010, 8722, 21, 19],
            [2010, 8723, 23, 21],
            [2010, 8724, 23, 19],
            [2010, 8725, 24, 18],
            [2010, 8726, 24, 18],
            [2010, 8727, 21, 18],
            [2010, 8728, 18, 17],
            [2010, 8729, 22, 21],
            [2010, 8730, 17, 17],
            [2010, 8731, 18, 16],
            [2010, 8732, 23, 20],
            [2010, 8733, 24, 20],
            [2010, 8734, 24, 21],
            [2010, 8735, 21, 15],
            [2010, 8736, 21, 19],
            [2010, 8737, 18, 17],
            [2010, 8738, 21, 18],
            [2010, 8739, 20, 18],
            [2010, 8740, 21, 19],
            [2010, 8741, 22, 19],
            [2010, 8742, 22, 19],
            [2010, 8743, 21, 20],
            [2010, 8744, 22, 19],
            [2010, 8745, 22, 21],
            [2010, 8746, 25, 19],
            [2010, 8747, 25, 19],
            [2010, 8748, 24, 21],
            [2010, 8749, 21, 18],
            [2010, 8750, 21, 19],
            [2010, 8751, 21, 18],
            [2010, 8752, 21, 16],
            [2010, 8753, 19, 19],
            [2010, 8754, 21, 21],
            [2010, 8755, 20, 21],
            [2010, 8756, 24, 22],
            [2010, 8757, 17, 18],
            [2010, 8758, 21, 16],
            [2010, 8759, 21, 17],
            [2010, 8760, 26, 26],
            [2010, 8761, 21, 20],
            [2010, 8762, 24, 21],
            [2010, 8763, 17, 16],
            [2010, 8764, 27, 21],
            [2010, 8765, 22, 18],
            [2010, 8766, 25, 19],
            [2010, 8767, 24, 20],
            [2010, 8768, 24, 20],
            [2010, 8769, 22, 18],
            [2010, 8770, 24, 20],
            [2010, 8771, 24, 20],
            [2010, 8772, 24, 20],
            [2010, 8773, 21, 18],
            [2010, 8774, 21, 18],
            [2010, 8775, 21, 17],
            [2010, 8776, 21, 18],
            [2010, 8777, 21, 20],
            [2010, 8778, 26, 21],
            [2010, 8779, 9, 8],
            [2010, 8780, 12, 9],
            [2010, 8781, 12, 11],
            [2010, 8782, 10, 9],
            [2010, 8783, 9, 8],
            [2010, 8784, 10, 9],
            [2010, 8785, 7, 6],
            [2010, 8786, 9, 9],
            [2010, 8787, 9, 9],
            [2010, 8788, 12, 9],
            [2010, 8790, 10, 8],
            [2010, 8791, 7, 6],
            [2010, 8792, 10, 8],
            [2010, 8793, 8, 7],
            [2010, 8794, 8, 7],
            [2010, 8795, 9, 7],
            [2010, 8796, 12, 9],
            [2010, 8797, 14, 9],
            [2010, 8798, 9, 8],
            [2010, 8799, 13, 12],
            [2010, 8800, 8, 7],
            [2010, 8801, 10, 8],
            [2010, 8802, 7, 7],
            [2010, 8803, 8, 7],
            [2010, 8804, 7, 8],
            [2010, 8805, 8, 9],
            [2010, 8806, 9, 10],
            [2010, 8807, 11, 10],
            [2010, 8808, 9, 8],
            [2010, 8809, 8, 8],
            [2010, 8810, 11, 11],
            [2010, 8811, 7, 7],
            [2010, 8812, 10, 9],
            [2010, 8814, 9, 9],
            [2010, 8815, 9, 9],
            [2010, 8816, 9, 7],
            [2010, 8817, 10, 9],
            [2010, 8818, 51, 28],
            [2010, 8819, 34, 26],
            [2010, 8820, 34, 23],
            [2010, 8821, 24, 17],
            [2010, 8822, 32, 23],
            [2010, 8823, 27, 23],
            [2010, 8824, 16, 13],
            [2010, 8825, 29, 19],
            [2010, 8826, 19, 20],
            [2010, 8827, 30, 17],
            [2010, 8828, 30, 17],
            [2010, 8829, 22, 19],
            [2010, 8830, 16, 18],
            [2010, 8831, 35, 21],
            [2010, 8832, 21, 15],
            [2010, 8833, 26, 16],
            [2010, 8834, 30, 19],
            [2010, 8835, 21, 14],
            [2010, 8836, 50, 27],
            [2010, 8837, 29, 15],
            [2010, 8838, 27, 21],
            [2010, 8839, 20, 13],
            [2010, 8840, 22, 18],
            [2010, 8841, 19, 13],
            [2010, 8842, 16, 17],
            [2010, 8843, 23, 14],
            [2010, 8844, 32, 21],
            [2010, 8845, 25, 19],
            [2010, 8846, 24, 18],
            [2010, 8847, 17, 14],
            [2010, 8848, 33, 19],
            [2010, 8849, 24, 15],
            [2010, 8850, 30, 25],
            [2010, 8851, 26, 22],
            [2010, 8852, 23, 16],
            [2010, 8853, 7, 12],
            [2010, 8854, 26, 19],
            [2010, 8855, 20, 14],
            [2010, 8856, 33, 19],
            [2010, 8857, 16, 11],
            [2010, 8858, 38, 21],
            [2010, 8859, 33, 23],
            [2010, 8860, 23, 13],
            [2010, 8861, 20, 18],
            [2010, 8862, 9, 7],
            [2010, 8863, 26, 18],
            [2010, 8864, 18, 14],
            [2010, 8865, 26, 23],
            [2010, 8866, 21, 20],
            [2010, 8867, 17, 20],
            [2010, 8868, 34, 26],
            [2010, 8869, 55, 29],
            [2010, 8870, 31, 22],
            [2010, 8871, 30, 20],
            [2010, 8872, 55, 28],
            [2010, 8873, 15, 14],
            [2010, 8874, 37, 19],
            [2010, 8875, 33, 24],
            [2010, 8876, 17, 17],
            [2010, 8877, 38, 20],
            [2010, 8878, 20, 18],
            [2010, 8879, 16, 12],
            [2010, 8880, 23, 17],
            [2010, 8881, 47, 27],
            [2010, 8882, 13, 14],
            [2010, 8883, 19, 13],
            [2010, 8884, 16, 14],
            [2010, 8885, 35, 21],
            [2010, 8886, 29, 16],
            [2010, 8887, 17, 12],
            [2010, 8888, 21, 19],
            [2010, 8889, 33, 27],
            [2010, 8890, 9, 13],
            [2010, 8891, 10, 12],
            [2010, 8892, 28, 19],
            [2010, 8893, 57, 26],
            [2010, 8894, 45, 20],
            [2010, 8895, 32, 17],
            [2010, 8896, 35, 23],
            [2010, 8897, 18, 15],
            [2010, 8898, 9, 12],
            [2010, 8899, 45, 24],
            [2010, 8900, 26, 17],
            [2010, 8901, 31, 20],
            [2010, 8902, 29, 21],
            [2010, 8903, 35, 20],
            [2010, 8904, 24, 18],
            [2010, 8905, 21, 17],
            [2010, 8906, 26, 16],
            [2010, 8907, 18, 17],
            [2010, 8908, 24, 16],
            [2010, 8909, 22, 17],
            [2010, 8910, 18, 11],
            [2010, 8911, 17, 13],
            [2010, 8912, 32, 20],
            [2010, 8913, 21, 21],
            [2010, 8914, 21, 18],
            [2010, 8915, 17, 14],
            [2010, 8916, 33, 20],
            [2010, 8917, 25, 14],
            [2010, 8918, 31, 22],
            [2010, 8919, 21, 19],
            [2010, 8920, 26, 19],
            [2010, 8921, 23, 19],
            [2010, 8922, 26, 22],
            [2010, 8923, 35, 27],
            [2010, 8924, 16, 15],
            [2010, 8925, 11, 11],
            [2010, 8926, 14, 13],
            [2010, 8927, 15, 14],
            [2010, 8928, 15, 14],
            [2010, 8929, 13, 11],
            [2010, 8930, 9, 11],
            [2010, 8931, 8, 12],
            [2010, 8932, 8, 9],
            [2010, 8933, 16, 15],
            [2010, 8934, 21, 21],
            [2010, 8935, 30, 18],
            [2010, 8936, 21, 13],
            [2010, 8937, 33, 25],
            [2010, 8938, 20, 13],
            [2010, 8939, 25, 23],
            [2010, 8940, 16, 15],
            [2010, 8941, 27, 18],
            [2010, 8942, 11, 11],
            [2010, 8943, 22, 18],
            [2010, 8944, 32, 16],
            [2010, 8945, 30, 13],
            [2010, 8946, 29, 11],
            [2010, 8947, 26, 13],
            [2010, 8948, 35, 18],
            [2010, 8949, 22, 13],
            [2010, 8950, 19, 17],
            [2010, 8951, 23, 18],
            [2010, 8952, 16, 17],
            [2010, 8953, 25, 21],
            [2010, 8954, 20, 19],
            [2010, 8955, 28, 20],
            [2010, 8956, 18, 16],
            [2010, 8957, 32, 22],
            [2010, 8958, 36, 27],
            [2010, 8959, 30, 19],
            [2010, 8960, 31, 22],
            [2010, 8961, 23, 17],
            [2010, 8962, 38, 21],
            [2010, 8963, 28, 20],
            [2010, 8964, 23, 17],
            [2010, 8965, 35, 23],
            [2010, 8966, 29, 18],
            [2010, 8967, 30, 22],
            [2010, 8968, 26, 17],
            [2010, 8969, 17, 13],
            [2010, 8970, 64, 28],
            [2010, 8971, 15, 15],
            [2010, 8972, 16, 13],
            [2010, 8973, 11, 12],
            [2010, 8974, 5, 11],
            [2010, 8975, 33, 20],
            [2010, 8976, 51, 24],
            [2010, 8977, 43, 21],
            [2010, 8978, 14, 12],
            [2010, 8979, 17, 19],
            [2010, 8980, 30, 24],
            [2010, 8981, 28, 17],
            [2010, 8983, 31, 21],
            [2010, 8984, 24, 20],
            [2010, 8985, 30, 24],
            [2010, 8986, 34, 22],
            [2010, 8987, 25, 18],
            [2010, 8988, 17, 16],
            [2010, 8989, 29, 21],
            [2010, 8990, 20, 16],
            [2010, 8991, 20, 18],
            [2010, 8992, 16, 17],
            [2010, 8993, 29, 22],
            [2010, 8994, 36, 25],
            [2010, 8995, 28, 24],
            [2010, 8996, 32, 20],
            [2010, 8997, 28, 14],
            [2010, 8998, 19, 20],
            [2010, 8999, 16, 12],
            [2010, 9000, 36, 29],
            [2010, 9001, 29, 20],
            [2010, 9002, 25, 21],
            [2010, 9003, 19, 20],
            [2010, 9004, 30, 18],
            [2010, 9005, 17, 13],
            [2010, 9006, 31, 25],
            [2010, 9007, 22, 17],
            [2010, 9008, 10, 15],
            [2010, 9009, 22, 22],
            [2010, 9010, 24, 20],
            [2010, 9011, 19, 14],
            [2010, 9012, 16, 16],
            [2010, 9013, 13, 14],
            [2010, 9014, 38, 19],
            [2010, 9015, 36, 17],
            [2010, 9016, 19, 14],
            [2010, 9017, 17, 19],
            [2010, 9018, 18, 17],
            [2010, 9019, 27, 21],
            [2010, 9020, 16, 17],
            [2010, 9021, 30, 26],
            [2010, 9022, 23, 20],
            [2010, 9023, 24, 16],
            [2010, 9024, 41, 30],
            [2010, 9025, 26, 19],
            [2010, 9026, 34, 18],
            [2010, 9027, 33, 19],
            [2010, 9028, 32, 26],
            [2010, 9030, 25, 21],
            [2010, 9031, 15, 17],
            [2010, 9032, 24, 17],
            [2010, 9033, 27, 18],
            [2010, 9034, 44, 25],
            [2010, 9035, 30, 19],
            [2010, 9036, 29, 18],
            [2010, 9037, 15, 15],
            [2010, 9038, 24, 22],
            [2010, 9039, 14, 16],
            [2010, 9040, 26, 19],
            [2010, 9041, 6, 6],
            [2010, 9042, 31, 26],
            [2010, 9043, 37, 21],
            [2010, 9044, 27, 17],
            [2010, 9045, 28, 24],
            [2010, 9046, 21, 13],
            [2010, 9047, 29, 20],
            [2010, 9048, 13, 14],
            [2010, 9049, 46, 27],
            [2010, 9050, 8, 8],
            [2010, 9051, 41, 30],
            [2010, 9052, 42, 32],
            [2010, 9053, 61, 33],
            [2010, 9054, 40, 26],
            [2010, 9055, 39, 15],
            [2010, 9056, 41, 19],
            [2010, 9057, 31, 26],
            [2010, 9058, 15, 16],
            [2010, 9059, 28, 22],
            [2010, 9060, 30, 25],
            [2010, 9061, 45, 29],
            [2010, 9062, 23, 20],
            [2010, 9063, 28, 18],
            [2010, 9064, 13, 12],
            [2010, 9065, 21, 15],
            [2010, 9066, 15, 16],
            [2010, 9067, 29, 17],
            [2010, 9068, 22, 14],
            [2010, 9069, 23, 18],
            [2010, 9070, 8, 7],
            [2010, 9071, 16, 18],
            [2010, 9072, 11, 11],
            [2010, 9073, 10, 13],
            [2010, 9074, 27, 18],
            [2010, 9075, 10, 14],
            [2010, 9076, 20, 19],
            [2010, 9077, 26, 21],
            [2010, 9078, 22, 15],
            [2010, 9079, 32, 24],
            [2010, 9080, 20, 18],
            [2010, 9081, 23, 20],
            [2010, 9082, 35, 20],
            [2010, 9083, 25, 22],
            [2010, 9084, 27, 20],
            [2010, 9085, 16, 13],
            [2010, 9086, 21, 18],
            [2010, 9087, 35, 21],
            [2010, 9088, 30, 19],
            [2010, 9089, 12, 12],
            [2010, 9090, 29, 20],
            [2010, 9091, 13, 14],
            [2010, 9092, 23, 17],
            [2010, 9093, 22, 17],
            [2010, 9094, 30, 21],
            [2010, 9095, 5, 9],
            [2010, 9096, 28, 29],
            [2010, 9097, 13, 14],
            [2010, 9098, 23, 17],
            [2010, 9099, 18, 15],
            [2010, 9100, 30, 20],
            [2010, 9101, 10, 7],
            [2010, 9102, 18, 13],
            [2010, 9103, 11, 16],
            [2010, 9104, 32, 26],
            [2010, 9105, 16, 11],
            [2010, 9106, 28, 16],
            [2010, 9107, 28, 23],
            [2010, 9108, 23, 18],
            [2010, 9109, 15, 12],
            [2010, 9110, 22, 14],
            [2010, 9111, 23, 14],
            [2010, 9112, 34, 23],
            [2010, 9113, 28, 22],
            [2010, 9114, 29, 23],
            [2010, 9115, 21, 15],
            [2010, 9116, 28, 17],
            [2010, 9117, 30, 19],
            [2010, 9118, 30, 25],
            [2010, 9119, 16, 13],
            [2010, 9120, 20, 18],
            [2010, 9121, 14, 16],
            [2010, 9122, 37, 24],
            [2010, 9123, 31, 17],
            [2010, 9124, 32, 20],
            [2010, 9125, 12, 23],
            [2010, 9126, 32, 22],
            [2010, 9127, 26, 23],
            [2010, 9128, 43, 27],
            [2010, 9129, 20, 16],
            [2010, 9130, 38, 26],
            [2010, 9131, 11, 9],
            [2010, 9132, 26, 22],
            [2010, 9133, 16, 18],
            [2010, 9134, 25, 20],
            [2010, 9135, 38, 23],
            [2010, 9136, 17, 18],
            [2010, 9137, 15, 10],
            [2010, 9138, 30, 21],
            [2010, 9139, 14, 15],
            [2010, 9140, 17, 18],
            [2010, 9141, 17, 17],
            [2010, 9142, 25, 19],
            [2010, 9143, 17, 17],
            [2010, 9144, 15, 17],
            [2010, 9145, 28, 20],
            [2010, 9146, 66, 38],
            [2010, 9166, 21, 16],
            [2010, 9194, 20, 18],
            [2010, 9195, 24, 19],
            [2010, 9196, 22, 16],
            [2010, 9198, 17, 15],
            [2010, 9199, 22, 16],
            [2010, 9200, 17, 15],
            [2010, 9201, 26, 18],
            [2010, 9202, 22, 18],
            [2010, 9203, 9, 9],
            [2010, 9204, 8, 8],
            [2010, 9209, 22, 16],
            [2010, 9211, 22, 20],
            [2010, 9214, 22, 18],
            [2010, 9218, 21, 15],
            [2010, 9226, 36, 23],
            [2010, 9227, 23, 19],
            [2010, 9228, 19, 19],
            [2010, 9229, 23, 20],
            [2010, 9230, 26, 18],
            [2010, 9232, 27, 19],
            [2010, 9233, 21, 19],
            [2010, 9234, 22, 20],
            [2010, 9235, 21, 19],
            [2010, 9238, 22, 19],
            [2010, 9242, 27, 19],
            [2010, 9244, 25, 20],
            [2010, 9245, 22, 22],
            [2010, 9248, 26, 18],
            [2010, 9254, 53, 48],
            [2010, 9255, 39, 30],
            [2010, 9257, 33, 30],
            [2010, 9258, 26, 64],
            [2010, 9259, 28, 28],
            [2010, 9260, 30, 28],
            [2010, 9261, 34, 37],
            [2010, 9266, 44, 41],
            [2010, 9267, 46, 40],
            [2010, 9268, 49, 45],
            [2010, 9269, 59, 48],
            [2010, 9270, 57, 52],
            [2010, 9271, 56, 50],
            [2010, 9272, 47, 47],
            [2010, 9273, 62, 55],
            [2010, 9274, 59, 46],
            [2010, 9275, 31, 31],
            [2010, 9276, 61, 48],
            [2010, 9280, 31, 31],
            [2010, 9281, 60, 44],
            [2010, 9282, 57, 46],
            [2010, 9283, 40, 34],
            [2010, 9284, 67, 53],
            [2010, 9285, 36, 33],
            [2010, 9286, 66, 58],
            [2010, 9287, 68, 57],
            [2010, 9288, 50, 35],
            [2010, 9289, 59, 51],
            [2010, 9290, 56, 62],
            [2010, 9291, 74, 65],
            [2010, 9292, 52, 43],
            [2010, 9293, 58, 42],
            [2010, 9294, 35, 67],
            [2010, 9295, 44, 64],
            [2010, 9296, 57, 73],
            [2010, 9297, 91, 80],
            [2010, 9298, 38, 35],
            [2010, 9299, 77, 76],
            [2010, 9300, 61, 49],
            [2010, 9301, 39, 36],
            [2010, 9302, 87, 76],
            [2010, 9303, 62, 55],
            [2010, 9304, 71, 106],
            [2010, 9305, 63, 56],
            [2010, 9306, 89, 79],
            [2010, 9307, 36, 38],
            [2010, 9308, 51, 56],
            [2010, 9309, 45, 92],
            [2010, 9310, 52, 76],
            [2010, 9311, 39, 38],
            [2010, 9312, 57, 53],
            [2010, 9313, 48, 48],
            [2010, 9314, 62, 54],
            [2010, 9403, 24, 24],
            [2010, 9406, 81, 41],
            [2010, 9411, 51, 85],
            [2010, 9416, 40, 25],
            [2010, 9417, 49, 41],
            [2010, 9420, 44, 81],
            [2010, 9423, 44, 34],
            [2010, 9428, 25, 41],
            [2010, 9431, 30, 39],
            [2010, 9436, 40, 49],
            [2010, 9443, 40, 71],
            [2010, 9444, 41, 41],
            [2010, 9451, 78, 66],
            [2010, 9452, 33, 51],
            [2010, 9453, 41, 61],
            [2010, 9456, 71, 85],
            [2010, 9457, 35, 49],
            [2010, 9458, 51, 51],
            [2010, 9465, 39, 26],
            [2010, 9470, 34, 56],
            [2010, 9473, 24, 20],
            [2010, 9474, 106, 51],
            [2010, 9477, 40, 36],
            [2010, 9478, 115, 66],
            [2010, 9487, 16, 25],
            [2010, 9488, 56, 39],
            [2010, 9491, 24, 20],
            [2010, 9492, 78, 51],
            [2010, 9497, 35, 25],
            [2010, 9498, 92, 41],
            [2010, 9509, 71, 46],
            [2010, 9519, 16, 13],
            [2010, 9520, 86, 44],
            [2010, 9525, 18, 16],
            [2010, 9526, 44, 20],
            [2010, 9529, 21, 16],
            [2010, 9530, 76, 41],
            [2010, 9531, 16, 16],
            [2010, 9532, 62, 37],
            [2010, 9539, 16, 11],
            [2010, 9540, 87, 61],
            [2010, 9541, 11, 21],
            [2010, 9542, 92, 46],
            [2010, 9543, 20, 16],
            [2010, 9544, 82, 46],
            [2010, 9547, 20, 18],
            [2010, 9548, 59, 31],
            [2010, 9549, 16, 16],
            [2010, 9550, 76, 31],
            [2010, 9551, 24, 20],
            [2010, 9552, 81, 49],
            [2010, 9553, 20, 25],
            [2010, 9554, 68, 39],
            [2010, 9555, 30, 61],
            [2010, 9556, 97, 85],
            [2010, 9557, 44, 26],
            [2010, 9558, 106, 56],
            [2010, 9561, 20, 20],
            [2010, 9562, 68, 46],
            [2010, 9581, 40, 30],
            [2010, 9582, 105, 56],
            [2010, 9593, 42, 25],
            [2010, 9594, 87, 46],
            [2010, 9595, 25, 25],
            [2010, 9596, 115, 51],
            [2010, 9597, 30, 16],
            [2010, 9598, 71, 31],
            [2010, 9609, 16, 16],
            [2010, 9610, 78, 36],
            [2010, 9611, 16, 20],
            [2010, 9612, 82, 49],
            [2010, 9613, 44, 46],
            [2010, 9614, 115, 81],
            [2010, 9617, 11, 11],
            [2010, 9618, 96, 49],
            [2010, 9619, 20, 16],
            [2010, 9620, 20, 16],
            [2010, 9633, 19, 33],
            [2010, 9634, 56, 44],
            [2010, 9639, 16, 11],
            [2010, 9640, 87, 41],
            [2010, 9641, 28, 16],
            [2010, 9642, 95, 46],
            [2010, 9643, 19, 16],
            [2010, 9644, 86, 31],
            [2010, 9651, 72, 52],
            [2010, 9652, 67, 52],
            [2010, 9653, 34, 32],
            [2010, 9654, 42, 28],
            [2010, 9661, 67, 42],
            [2010, 9662, 62, 48],
            [2010, 9663, 61, 48],
            [2010, 9664, 50, 39],
            [2010, 9665, 32, 38],
            [2010, 9666, 52, 35],
            [2010, 9667, 15, 15],
            [2010, 9668, 27, 23],
            [2010, 9670, 62, 44],
            [2010, 9673, 38, 28],
            [2010, 9674, 40, 30],
            [2010, 9675, 17, 21],
            [2010, 9676, 28, 28],
            [2010, 9677, 13, 18],
            [2010, 9678, 18, 22],
            [2010, 9681, 57, 42],
            [2010, 9682, 68, 42],
            [2010, 9687, 28, 32],
            [2010, 9689, 22, 18],
            [2010, 9690, 43, 27],
            [2010, 9691, 22, 21],
            [2010, 9692, 39, 27],
            [2010, 9693, 19, 22],
            [2010, 9694, 27, 28],
            [2010, 9695, 43, 42],
            [2010, 9696, 61, 32],
            [2010, 9699, 17, 20],
            [2010, 9700, 52, 32],
            [2010, 9701, 18, 17],
            [2010, 9702, 52, 34],
            [2010, 9704, 47, 29],
            [2010, 9705, 28, 34],
            [2010, 9706, 62, 44],
            [2010, 9709, 23, 18],
            [2010, 9710, 22, 18],
            [2010, 9711, 14, 19],
            [2010, 9712, 15, 22],
            [2010, 9713, 28, 32],
            [2010, 9714, 34, 42],
            [2010, 9715, 57, 46],
            [2010, 9716, 43, 42],
            [2010, 9717, 35, 34],
            [2010, 9718, 17, 21],
            [2010, 9720, 82, 72],
            [2010, 9721, 72, 38],
            [2010, 9722, 22, 36],
            [2010, 9723, 67, 42],
            [2010, 9724, 52, 47],
            [2010, 9725, 72, 44],
            [2010, 9726, 23, 23],
            [2010, 9727, 38, 38],
            [2010, 9728, 28, 22],
            [2010, 9729, 28, 27],
            [2010, 9730, 26, 40],
            [2010, 9731, 68, 58],
            [2010, 9735, 31, 33],
            [2010, 9736, 31, 32],
            [2010, 9737, 28, 18],
            [2010, 9738, 40, 40],
            [2010, 9739, 22, 31],
            [2010, 9740, 95, 87],
            [2010, 9741, 74, 75],
            [2010, 9742, 37, 49],
            [2010, 9743, 40, 32],
            [2010, 9744, 62, 44],
            [2010, 9745, 32, 25],
            [2010, 9746, 38, 25],
            [2010, 9747, 32, 36],
            [2010, 9748, 37, 42],
            [2010, 9751, 28, 24],
            [2010, 9752, 33, 32],
            [2010, 9755, 23, 30],
            [2010, 9756, 30, 35],
            [2010, 9757, 24, 18],
            [2010, 9758, 22, 18],
            [2010, 9759, 15, 14],
            [2010, 9760, 31, 22],
            [2010, 9761, 38, 24],
            [2010, 9762, 29, 18],
            [2010, 9763, 23, 16],
            [2010, 9764, 21, 16],
            [2010, 9765, 25, 18],
            [2010, 9766, 20, 16],
            [2010, 9767, 36, 25],
            [2010, 9768, 21, 17],
            [2010, 9769, 15, 14],
            [2010, 9770, 33, 25],
            [2010, 9771, 35, 25],
            [2010, 9772, 28, 24],
            [2010, 9773, 27, 20],
            [2010, 9774, 24, 16],
            [2010, 9775, 21, 16],
            [2010, 9776, 30, 19],
            [2010, 9777, 30, 22],
            [2010, 9778, 33, 24],
            [2010, 9779, 28, 22],
            [2010, 9780, 27, 20],
            [2010, 9781, 30, 20],
            [2010, 9782, 40, 25],
            [2010, 9783, 39, 25],
            [2010, 9784, 20, 16],
            [2010, 9785, 22, 18],
            [2010, 9786, 14, 11],
            [2010, 9787, 23, 19],
            [2010, 9788, 30, 22],
            [2010, 9789, 26, 22],
            [2010, 9790, 23, 20],
            [2010, 9791, 37, 21],
            [2010, 9792, 34, 26],
            [2010, 9793, 14, 11],
            [2010, 9794, 12, 11],
            [2010, 9795, 12, 11],
            [2010, 9796, 14, 13],
            [2010, 9797, 12, 11],
            [2010, 9798, 12, 11],
            [2010, 9799, 38, 27],
            [2010, 9800, 22, 19],
            [2010, 9801, 15, 13],
            [2010, 9802, 14, 13],
            [2010, 9803, 9, 9],
            [2010, 9804, 13, 11],
            [2010, 9805, 30, 20],
            [2010, 9806, 20, 16],
            [2010, 9807, 19, 13],
            [2010, 9808, 82, 47],
            [2010, 9809, 56, 26],
            [2010, 9811, 51, 24],
            [2010, 9812, 61, 27],
            [2010, 9813, 65, 33],
            [2010, 9814, 20, 13],
            [2010, 9815, 40, 23],
            [2010, 9816, 50, 24],
            [2010, 9817, 23, 13],
            [2010, 9818, 58, 30],
            [2010, 9819, 53, 39],
            [2010, 9820, 66, 43],
            [2010, 9821, 43, 24],
            [2010, 9822, 19, 16],
            [2010, 9823, 21, 17],
            [2010, 9824, 30, 25],
            [2010, 9825, 14, 13],
            [2010, 9826, 34, 26],
            [2010, 9827, 37, 27],
            [2010, 9828, 31, 22],
            [2010, 9829, 24, 20],
            [2010, 9830, 26, 21],
            [2010, 9831, 25, 20],
            [2010, 9832, 30, 21],
            [2010, 9833, 23, 19],
            [2010, 9834, 41, 32],
            [2010, 9835, 23, 23],
            [2010, 9836, 68, 43],
            [2010, 9837, 23, 21],
            [2010, 9838, 41, 26],
            [2010, 9839, 14, 15],
            [2010, 9840, 50, 36],
            [2010, 9841, 42, 27],
            [2010, 9842, 24, 19],
            [2010, 9843, 22, 20],
            [2010, 9844, 34, 24],
            [2010, 9845, 25, 21],
            [2010, 9846, 23, 16],
            [2010, 9847, 12, 10],
            [2010, 9848, 21, 16],
            [2010, 9849, 24, 19],
            [2010, 9850, 19, 16],
            [2010, 9851, 19, 14],
            [2010, 9852, 22, 18],
            [2010, 9853, 19, 16],
            [2010, 9854, 12, 11],
            [2010, 9855, 24, 22],
            [2010, 9856, 17, 19],
            [2010, 9857, 13, 11],
            [2010, 9858, 25, 24],
            [2010, 9859, 39, 29],
            [2010, 9860, 41, 31],
            [2010, 9861, 33, 32],
            [2010, 9862, 21, 18],
            [2010, 9863, 26, 21],
            [2010, 9864, 40, 26],
            [2010, 9865, 28, 21],
            [2010, 9866, 43, 25],
            [2010, 9867, 15, 15],
            [2010, 9868, 27, 22],
            [2010, 9869, 29, 25],
            [2010, 9870, 29, 27],
            [2010, 9871, 28, 22],
            [2010, 9872, 21, 19],
            [2010, 9873, 30, 26],
            [2010, 9874, 27, 21],
            [2010, 9875, 18, 18],
            [2010, 9876, 20, 18],
            [2010, 9877, 27, 32],
            [2010, 9878, 25, 21],
            [2010, 9879, 26, 21],
            [2010, 9880, 27, 27],
            [2010, 9881, 39, 33],
            [2010, 9882, 30, 26],
            [2010, 9883, 23, 19],
            [2010, 9884, 23, 23],
            [2010, 9885, 26, 20],
            [2010, 9886, 25, 22],
            [2010, 9887, 26, 21],
            [2010, 9888, 31, 25],
            [2010, 9889, 30, 23],
            [2010, 9890, 26, 25],
            [2010, 9891, 21, 18],
            [2010, 9892, 29, 21],
            [2010, 9893, 25, 16],
            [2010, 9894, 29, 21],
            [2010, 9895, 22, 14],
            [2010, 9896, 10, 10],
            [2010, 9897, 25, 20],
            [2010, 9898, 25, 21],
            [2010, 9899, 19, 16],
            [2010, 9900, 33, 30],
            [2010, 9901, 29, 22],
            [2010, 9902, 51, 31],
            [2010, 9903, 33, 29],
            [2010, 9904, 31, 26],
            [2010, 9905, 33, 28],
            [2010, 9906, 28, 19],
            [2010, 9907, 22, 19],
            [2010, 9908, 35, 24],
            [2010, 9909, 13, 12],
            [2010, 9910, 31, 27],
            [2010, 9911, 34, 27],
            [2010, 9912, 34, 32],
            [2010, 9913, 18, 17],
            [2010, 9914, 23, 21],
            [2010, 9915, 22, 20],
            [2010, 9916, 24, 20],
            [2010, 9917, 23, 24],
            [2010, 9918, 69, 32],
            [2010, 9919, 38, 28],
            [2010, 9920, 51, 37],
            [2010, 9921, 21, 20],
            [2010, 9922, 16, 13],
            [2010, 9923, 22, 16],
            [2010, 9924, 31, 29],
            [2010, 9925, 33, 32],
            [2010, 9926, 34, 28],
            [2010, 9927, 22, 22],
            [2010, 9928, 42, 31],
            [2010, 9929, 30, 26],
            [2010, 9930, 27, 21],
            [2010, 9931, 43, 26],
            [2010, 9932, 54, 44],
            [2010, 9933, 31, 30],
            [2010, 9934, 30, 23],
            [2010, 9935, 32, 32],
            [2010, 9936, 25, 22],
            [2010, 9937, 22, 25],
            [2010, 9938, 13, 11],
            [2010, 9939, 47, 38],
            [2010, 9940, 28, 27],
            [2010, 9941, 27, 20],
            [2010, 9942, 15, 12],
            [2010, 9943, 51, 43],
            [2010, 9944, 27, 22],
            [2010, 9945, 34, 28],
            [2010, 9946, 28, 22],
            [2010, 9947, 28, 20],
            [2010, 9948, 65, 46],
            [2010, 9949, 44, 33],
            [2010, 9950, 66, 37],
            [2010, 9951, 31, 27],
            [2010, 9952, 49, 41],
            [2010, 9953, 18, 18],
            [2010, 9954, 53, 35],
            [2010, 9955, 16, 14],
            [2010, 9956, 30, 25],
            [2010, 9957, 51, 27],
            [2010, 9958, 33, 26],
            [2010, 9959, 55, 29],
            [2010, 9960, 43, 19],
            [2010, 9961, 28, 23],
            [2010, 9962, 22, 21],
            [2010, 9963, 51, 31],
            [2010, 9964, 39, 23],
            [2010, 9965, 30, 17],
            [2010, 9966, 44, 22],
            [2010, 9967, 52, 28],
            [2010, 9968, 34, 20],
            [2010, 9969, 16, 14],
            [2010, 9970, 61, 34],
            [2010, 9971, 26, 20],
            [2010, 9972, 77, 47],
            [2010, 9973, 36, 22],
            [2010, 9974, 39, 17],
            [2010, 9975, 73, 34],
            [2010, 9976, 57, 41],
            [2010, 9977, 28, 17],
            [2010, 9978, 47, 20],
            [2010, 9979, 53, 25],
            [2010, 9980, 44, 21],
            [2010, 9981, 18, 12],
            [2010, 9982, 13, 12],
            [2010, 9983, 37, 21],
            [2010, 9984, 27, 20],
            [2010, 9985, 23, 16],
            [2010, 9986, 28, 19],
            [2010, 9987, 41, 33],
            [2010, 9988, 52, 33],
            [2010, 9989, 32, 21],
            [2010, 9990, 40, 27],
            [2010, 9991, 34, 29],
            [2010, 9992, 28, 26],
            [2010, 9993, 23, 25],
            [2010, 9994, 18, 15],
            [2010, 9995, 28, 29],
            [2010, 9996, 31, 22],
            [2010, 9997, 13, 17],
            [2010, 9998, 14, 15],
            [2010, 9999, 24, 23],
            [2010, 10000, 20, 19],
            [2010, 10001, 13, 13],
            [2010, 10002, 13, 11],
            [2010, 10003, 80, 40],
            [2010, 10004, 49, 41],
            [2010, 10005, 25, 18],
            [2010, 10006, 35, 29],
            [2010, 10180, 47, 26],
            [2010, 10183, 35, 23],
            [2010, 10184, 79, 42],
            [2010, 10185, 21, 21],
            [2010, 10186, 20, 18],
            [2010, 10187, 15, 16],
            [2010, 10188, 40, 30],
            [2010, 10189, 30, 23],
            [2010, 10190, 14, 12],
            [2010, 10191, 39, 25],
            [2010, 10192, 22, 17],
            [2010, 10193, 21, 18],
            [2010, 10194, 12, 11],
            [2010, 10195, 12, 10],
            [2010, 10514, 14, 16],
            [2010, 10515, 14, 16],
            [2010, 10516, 14, 16],
            [2010, 10532, 19, 20],
            [2010, 10533, 28, 22],
            [2010, 10534, 19, 14],
            [2010, 10535, 27, 19],
            [2010, 10536, 24, 17],
            [2010, 10537, 27, 18],
            [2010, 10538, 36, 22],
            [2010, 10539, 12, 13],
            [2010, 10540, 15, 10],
            [2010, 10541, 19, 11],
            [2010, 10542, 28, 24],
            [2010, 10543, 9, 9],
            [2010, 10544, 10, 8],
            [2010, 10545, 7, 7],
            [2010, 10546, 10, 7],
            [2010, 10547, 7, 7],
            [2010, 10548, 9, 8],
            [2010, 10549, 7, 7],
            [2010, 10550, 8, 8],
            [2010, 10551, 8, 7],
            [2010, 10552, 7, 7],
            [2010, 10553, 21, 13],
            [2010, 10555, 11, 8],
            [2010, 10556, 13, 12],
            [2010, 10557, 8, 9],
            [2010, 10559, 11, 9],
            [2010, 10560, 12, 10],
            [2010, 10578, 21, 22],
            [2010, 10579, 29, 30],
            [2010, 10580, 57, 38],
            [2010, 10605, 11, 9],
            [2010, 10606, 10, 9],
            [2010, 10607, 10, 9],
            [2010, 10608, 11, 9],
            [2010, 10609, 11, 10],
            [2010, 10610, 14, 10],
            [2010, 10611, 16, 11],
            [2010, 10612, 13, 11],
            [2010, 10613, 29, 21],
            [2010, 10614, 26, 18],
            [2010, 10615, 36, 22],
            [2010, 10616, 33, 19],
            [2010, 10617, 35, 22],
            [2010, 10618, 33, 21],
            [2010, 10619, 18, 16],
            [2010, 10620, 24, 16],
            [2010, 10621, 20, 17],
            [2010, 10622, 23, 15],
            [2010, 10623, 30, 20],
            [2010, 10624, 34, 19],
            [2010, 10625, 19, 16],
            [2010, 10626, 24, 18],
            [2010, 10627, 39, 22],
            [2010, 10628, 35, 21],
            [2010, 10629, 40, 21],
            [2010, 10630, 22, 17],
            [2010, 10631, 24, 17],
            [2010, 10632, 27, 17],
            [2010, 10633, 35, 21],
            [2010, 10634, 44, 25],
            [2010, 10635, 37, 21],
            [2010, 10636, 30, 19],
            [2010, 10637, 28, 20],
            [2010, 10638, 19, 13],
            [2010, 10639, 42, 23],
            [2010, 10640, 40, 21],
            [2010, 10641, 34, 22],
            [2010, 10642, 46, 28],
            [2010, 10643, 30, 19],
            [2010, 10644, 43, 26],
            [2010, 10645, 24, 21],
            [2010, 10646, 39, 22],
            [2010, 10647, 32, 22],
            [2010, 10648, 36, 24],
            [2010, 10649, 30, 20],
            [2010, 10650, 39, 27],
            [2010, 10651, 35, 22],
            [2010, 10652, 26, 17],
            [2010, 10653, 35, 20],
            [2010, 10654, 28, 22],
            [2010, 10655, 35, 25],
            [2010, 10656, 34, 23],
            [2010, 10657, 33, 21],
            [2010, 10658, 44, 21],
            [2010, 10659, 14, 13],
            [2010, 10660, 36, 21],
            [2010, 10661, 33, 21],
            [2010, 10662, 33, 20],
            [2010, 10663, 21, 18],
            [2010, 10664, 35, 18],
            [2010, 10665, 35, 22],
            [2010, 10666, 34, 22],
            [2010, 10667, 31, 22],
            [2010, 10668, 25, 19],
            [2010, 10669, 17, 12],
            [2010, 10670, 26, 19],
            [2010, 10671, 40, 23],
            [2010, 10672, 34, 19],
            [2010, 10673, 21, 16],
            [2010, 10674, 27, 15],
            [2010, 10675, 32, 21],
            [2010, 10676, 32, 20],
            [2010, 10677, 28, 17],
            [2010, 10678, 29, 18],
            [2010, 10679, 36, 21],
            [2010, 10680, 27, 20],
            [2010, 10681, 32, 22],
            [2010, 10682, 32, 19],
            [2010, 10683, 24, 17],
            [2010, 10684, 19, 14],
            [2010, 10685, 55, 28],
            [2010, 10686, 45, 26],
            [2010, 10687, 32, 20],
            [2010, 10688, 48, 26],
            [2010, 10689, 41, 24],
            [2010, 10690, 43, 22],
            [2010, 10691, 37, 21],
            [2010, 10692, 43, 25],
            [2010, 10693, 58, 32],
            [2010, 10694, 38, 24],
            [2010, 10695, 43, 24],
            [2010, 10696, 41, 21],
            [2010, 10697, 21, 14],
            [2010, 10698, 28, 18],
            [2010, 10699, 28, 23],
            [2010, 10700, 14, 11],
            [2010, 10701, 33, 21],
            [2010, 10702, 36, 22],
            [2010, 10703, 35, 20],
            [2010, 10704, 30, 19],
            [2010, 10705, 27, 18],
            [2010, 10706, 33, 21],
            [2010, 10707, 31, 21],
            [2010, 10708, 36, 21],
            [2010, 10709, 35, 24],
            [2010, 10710, 33, 20],
            [2010, 10711, 35, 20],
            [2010, 10712, 33, 21],
            [2010, 10713, 36, 22],
            [2010, 10714, 34, 22],
            [2010, 10715, 36, 21],
            [2010, 10716, 31, 21],
            [2010, 10717, 36, 22],
            [2010, 10718, 31, 21],
            [2010, 10719, 31, 20],
            [2010, 10720, 36, 21],
            [2010, 10721, 20, 13],
            [2010, 10722, 38, 21],
            [2010, 10723, 40, 23],
            [2010, 10724, 36, 22],
            [2010, 10725, 30, 24],
            [2010, 10726, 25, 19],
            [2010, 10727, 43, 23],
            [2010, 10728, 33, 22],
            [2010, 10729, 31, 22],
            [2010, 10730, 37, 23],
            [2010, 10731, 34, 23],
            [2010, 10732, 36, 22],
            [2010, 10733, 34, 23],
            [2010, 10734, 32, 19],
            [2010, 10735, 35, 20],
            [2010, 10736, 36, 25],
            [2010, 10737, 48, 28],
            [2010, 10738, 35, 19],
            [2010, 10739, 17, 12],
            [2010, 10740, 33, 20],
            [2010, 10741, 32, 23],
            [2010, 10742, 33, 20],
            [2010, 10743, 39, 21],
            [2010, 10744, 30, 19],
            [2010, 10745, 34, 20],
            [2010, 10746, 43, 21],
            [2010, 10747, 18, 14],
            [2010, 10748, 24, 17],
            [2010, 10749, 33, 20],
            [2010, 10750, 39, 23],
            [2010, 10751, 34, 20],
            [2010, 10752, 33, 23],
            [2010, 10753, 30, 20],
            [2010, 10754, 24, 17],
            [2010, 10755, 15, 13],
            [2010, 10756, 44, 30],
            [2010, 10757, 14, 11],
            [2010, 10758, 21, 15],
            [2010, 10759, 35, 22],
            [2010, 10760, 35, 22],
            [2010, 10761, 32, 20],
            [2010, 10762, 35, 24],
            [2010, 10763, 27, 18],
            [2010, 10764, 18, 16],
            [2010, 10765, 27, 18],
            [2010, 10766, 35, 21],
            [2010, 10767, 30, 20],
            [2010, 10768, 29, 21],
            [2010, 10769, 29, 19],
            [2010, 10770, 34, 20],
            [2010, 10771, 33, 20],
            [2010, 10772, 24, 21],
            [2010, 10773, 35, 23],
            [2010, 10774, 34, 19],
            [2010, 10775, 35, 19],
            [2010, 10776, 26, 18],
            [2010, 10777, 19, 15],
            [2010, 10778, 37, 21],
            [2010, 10779, 34, 20],
            [2010, 10780, 35, 20],
            [2010, 10781, 31, 19],
            [2010, 10782, 35, 24],
            [2010, 10783, 30, 26],
            [2010, 10784, 29, 18],
            [2010, 10785, 36, 20],
            [2010, 10786, 30, 20],
            [2010, 10787, 36, 22],
            [2010, 10788, 28, 18],
            [2010, 10789, 33, 20],
            [2010, 10790, 34, 20],
            [2010, 10791, 34, 18],
            [2010, 10792, 32, 20],
            [2010, 10793, 33, 21],
            [2010, 10794, 34, 24],
            [2010, 10795, 30, 22],
            [2010, 10796, 28, 23],
            [2010, 10797, 31, 20],
            [2010, 10798, 33, 20],
            [2010, 10799, 14, 13],
            [2010, 10800, 31, 20],
            [2010, 10801, 34, 21],
            [2010, 10802, 33, 24],
            [2010, 10803, 27, 16],
            [2010, 10804, 35, 20],
            [2010, 10805, 37, 20],
            [2010, 10806, 34, 21],
            [2010, 10807, 34, 19],
            [2010, 10808, 23, 17],
            [2010, 10809, 23, 18],
            [2010, 10810, 36, 20],
            [2010, 10811, 43, 27],
            [2010, 10812, 67, 33],
            [2010, 10814, 29, 18],
            [2010, 10815, 35, 20],
            [2010, 10816, 36, 20],
            [2010, 10817, 34, 22],
            [2010, 10818, 36, 21],
            [2010, 10819, 36, 20],
            [2010, 10820, 33, 21],
            [2010, 10821, 37, 21],
            [2010, 10822, 30, 21],
            [2010, 10823, 29, 20],
            [2010, 10824, 35, 23],
            [2010, 10825, 32, 23],
            [2010, 10826, 28, 17],
            [2010, 10827, 25, 20],
            [2010, 10828, 27, 20],
            [2010, 10829, 31, 20],
            [2010, 10830, 34, 20],
            [2010, 10831, 34, 20],
            [2010, 10832, 36, 21],
            [2010, 10833, 36, 20],
            [2010, 10834, 35, 20],
            [2010, 10835, 34, 20],
            [2010, 10836, 33, 22],
            [2010, 10837, 36, 20],
            [2010, 10838, 31, 20],
            [2010, 10839, 25, 21],
            [2010, 10840, 18, 14],
            [2010, 10841, 47, 23],
            [2010, 10842, 26, 23],
            [2010, 10843, 31, 20],
            [2010, 10844, 27, 16],
            [2010, 10845, 19, 16],
            [2010, 10846, 23, 18],
            [2010, 10847, 34, 21],
            [2010, 10848, 28, 20],
            [2010, 10849, 34, 20],
            [2010, 10850, 26, 20],
            [2010, 10851, 33, 20],
            [2010, 10852, 34, 21],
            [2010, 10853, 38, 21],
            [2010, 10854, 33, 22],
            [2010, 10855, 43, 22],
            [2010, 10856, 30, 19],
            [2010, 10857, 35, 21],
            [2010, 10858, 30, 20],
            [2010, 10859, 36, 22],
            [2010, 10860, 35, 21],
            [2010, 10861, 31, 20],
            [2010, 10862, 34, 19],
            [2010, 10863, 16, 14],
            [2010, 10864, 37, 19],
            [2010, 10865, 31, 20],
            [2010, 10866, 29, 18],
            [2010, 10867, 31, 20],
            [2010, 10868, 34, 20],
            [2010, 10869, 35, 23],
            [2010, 10870, 35, 21],
            [2010, 10871, 35, 20],
            [2010, 10872, 30, 18],
            [2010, 10873, 33, 22],
            [2010, 10874, 30, 21],
            [2010, 10875, 37, 23],
            [2010, 10876, 43, 23],
            [2010, 10877, 38, 24],
            [2010, 10878, 39, 24],
            [2010, 10879, 34, 25],
            [2010, 10880, 45, 27],
            [2010, 10881, 22, 18],
            [2010, 10882, 40, 22],
            [2010, 10883, 41, 23],
            [2010, 10884, 37, 21],
            [2010, 10885, 57, 26],
            [2010, 10886, 34, 22],
            [2010, 10887, 29, 18],
            [2010, 10888, 34, 20],
            [2010, 10889, 35, 22],
            [2010, 10890, 26, 18],
            [2010, 10891, 28, 17],
            [2010, 10892, 20, 14],
            [2010, 10893, 31, 20],
            [2010, 10894, 36, 21],
            [2010, 10895, 46, 26],
            [2010, 10896, 34, 20],
            [2010, 10897, 36, 23],
            [2010, 10898, 35, 21],
            [2010, 10899, 38, 24],
            [2010, 10900, 31, 20],
            [2010, 10901, 28, 20],
            [2010, 10902, 21, 18],
            [2010, 10903, 37, 25],
            [2010, 10904, 33, 20],
            [2010, 10905, 27, 18],
            [2010, 10906, 36, 21],
            [2010, 10907, 34, 23],
            [2010, 10908, 37, 22],
            [2010, 10909, 35, 22],
            [2010, 10910, 28, 21],
            [2010, 10911, 34, 23],
            [2010, 10912, 35, 23],
            [2010, 10913, 36, 20],
            [2010, 10914, 39, 24],
            [2010, 10915, 36, 23],
            [2010, 10916, 36, 25],
            [2010, 10917, 36, 21],
            [2010, 10918, 31, 21],
            [2010, 10978, 29, 20],
            [2010, 10979, 34, 19],
            [2010, 10980, 25, 18],
            [2010, 11091, 6, 5],
            [2010, 11092, 8, 7],
            [2010, 11093, 9, 7],
            [2010, 11094, 12, 8],
            [2010, 11095, 10, 7],
            [2010, 11096, 12, 9],
            [2010, 11097, 9, 7],
            [2010, 11098, 8, 6],
            [2010, 11099, 24, 13],
            [2010, 11100, 8, 7],
            [2010, 11101, 8, 7],
            [2010, 11102, 9, 7],
            [2010, 11103, 10, 8],
            [2010, 11104, 33, 21],
            [2010, 11105, 22, 16],
            [2010, 11106, 16, 12],
            [2010, 11107, 13, 9],
            [2010, 11108, 6, 6],
            [2010, 11109, 11, 9],
            [2010, 11110, 9, 6],
            [2010, 11111, 8, 8],
            [2010, 11112, 15, 11],
            [2010, 11113, 17, 11],
            [2010, 11114, 34, 18],
            [2010, 11115, 7, 6],
            [2010, 11116, 7, 6],
            [2010, 11117, 7, 5],
            [2010, 11118, 9, 7],
            [2010, 11119, 28, 17],
            [2010, 11120, 16, 12],
            [2010, 11121, 6, 6],
            [2010, 11122, 11, 8],
            [2010, 11123, 9, 7],
            [2010, 11124, 9, 8],
            [2010, 11125, 13, 9],
            [2010, 11126, 10, 8],
            [2010, 11127, 6, 6],
            [2010, 11128, 9, 7],
            [2010, 11129, 6, 6],
            [2010, 11130, 14, 12],
            [2010, 11131, 6, 6],
            [2010, 11132, 18, 11],
            [2010, 11133, 10, 7],
            [2010, 11134, 6, 5],
            [2010, 11135, 30, 17],
            [2010, 11136, 8, 7],
            [2010, 11137, 6, 5],
            [2010, 11138, 13, 8],
            [2010, 11139, 6, 5],
            [2010, 11140, 7, 7],
            [2010, 11141, 7, 5],
            [2010, 11142, 7, 6],
            [2010, 11143, 6, 6],
            [2010, 11144, 7, 8],
            [2010, 11145, 16, 12],
            [2010, 11146, 7, 6],
            [2010, 11147, 4, 3],
            [2010, 11148, 25, 16],
            [2010, 11149, 15, 10],
            [2010, 11150, 15, 14],
            [2010, 11151, 18, 10],
            [2010, 11152, 15, 10],
            [2010, 11153, 14, 9],
            [2010, 11154, 20, 14],
            [2010, 11155, 15, 11],
            [2010, 11156, 11, 9],
            [2010, 11157, 15, 10],
            [2010, 11158, 14, 10],
            [2010, 11159, 19, 11],
            [2010, 11160, 25, 15],
            [2010, 11161, 13, 9],
            [2010, 11162, 16, 10],
            [2010, 11163, 13, 10],
            [2010, 11164, 17, 11],
            [2010, 11165, 15, 10],
            [2010, 11166, 30, 17],
            [2010, 11168, 18, 14],
            [2010, 11169, 8, 7],
            [2010, 11170, 10, 9],
            [2010, 11171, 9, 8],
            [2010, 11172, 8, 8],
            [2010, 11173, 12, 10],
            [2010, 11174, 5, 6],
            [2010, 11175, 5, 6],
            [2010, 11176, 5, 5],
            [2010, 11177, 14, 11],
            [2010, 11178, 6, 6],
            [2010, 11179, 9, 9],
            [2010, 11180, 9, 8],
            [2010, 11181, 11, 10],
            [2010, 11182, 10, 8],
            [2010, 11183, 9, 10],
            [2010, 11184, 31, 51],
            [2010, 11185, 30, 66],
            [2010, 11186, 25, 51],
            [2010, 11187, 51, 85],
            [2010, 11188, 30, 81],
            [2010, 11189, 68, 30],
            [2010, 11195, 13, 12],
            [2010, 11197, 56, 33],
            [2010, 11199, 41, 29],
            [2010, 11201, 11, 12],
            [2010, 11202, 31, 19],
            [2010, 11203, 11, 11],
            [2010, 11292, 10, 8],
            [2010, 11293, 5, 5],
            [2010, 11294, 7, 7],
            [2010, 11295, 13, 7],
            [2010, 11296, 18, 42],
            [2010, 11298, 13, 12],
            [2010, 11300, 24, 21],
            [2010, 11304, 22, 16],
            [2010, 11305, 35, 38],
            [2010, 11306, 29, 26],
            [2010, 11307, 30, 27],
            [2010, 11308, 10, 15],
            [2010, 11309, 17, 21],
            [2010, 11310, 12, 17],
            [2010, 11311, 12, 17],
            [2010, 11312, 12, 17],
            [2010, 11313, 11, 15],
            [2010, 11314, 21, 19],
            [2010, 11315, 17, 15],
            [2010, 11316, 19, 17],
            [2010, 11318, 16, 15],
            [2010, 11319, 15, 13],
            [2010, 11320, 15, 12],
            [2010, 11322, 29, 19],
            [2010, 11323, 18, 15],
            [2010, 11324, 18, 13],
            [2010, 11325, 18, 15],
            [2010, 11326, 20, 18],
            [2010, 11327, 20, 16],
            [2010, 11328, 21, 19],
            [2010, 11329, 13, 13],
            [2010, 11330, 24, 21],
            [2010, 11331, 22, 19],
            [2010, 11333, 25, 18],
            [2010, 11334, 26, 18],
            [2010, 11335, 22, 17],
            [2010, 11336, 9, 10],
            [2010, 11338, 21, 19],
            [2010, 11339, 22, 18],
            [2010, 11340, 24, 21],
            [2010, 11341, 24, 19],
            [2010, 11342, 23, 19],
            [2010, 11343, 23, 20],
            [2010, 11344, 22, 19],
            [2010, 11345, 19, 17],
            [2010, 11346, 25, 19],
            [2010, 11348, 26, 20],
            [2010, 11349, 14, 13],
            [2010, 11350, 22, 20],
            [2010, 11351, 21, 19],
            [2010, 11352, 22, 20],
            [2010, 11353, 25, 20],
            [2010, 11354, 25, 16],
            [2010, 11355, 20, 17],
            [2010, 11356, 22, 18],
            [2010, 11357, 21, 17],
            [2010, 11358, 22, 17],
            [2010, 11359, 25, 20],
            [2010, 11360, 18, 15],
            [2010, 11361, 24, 19],
            [2010, 11362, 20, 17],
            [2010, 11363, 8, 9],
            [2010, 11364, 15, 10],
            [2010, 11365, 22, 17],
            [2010, 11366, 18, 17],
            [2010, 11367, 37, 28],
            [2010, 11368, 16, 17],
            [2010, 11369, 40, 39],
            [2010, 11370, 18, 22],
            [2010, 11371, 24, 22],
            [2010, 11372, 29, 28],
            [2010, 11373, 37, 27],
            [2010, 11374, 48, 30],
            [2010, 11375, 36, 32],
            [2010, 11376, 16, 15],
            [2010, 11377, 32, 25],
            [2010, 11378, 21, 19],
            [2010, 11384, 53, 33],
            [2010, 11385, 49, 34],
            [2010, 11386, 34, 37],
            [2010, 11387, 91, 66],
            [2010, 11388, 34, 34],
            [2010, 11389, 44, 36],
            [2010, 11390, 44, 25],
            [2010, 11391, 25, 24],
            [2010, 11392, 56, 31],
            [2010, 11393, 40, 21],
            [2010, 11394, 44, 51],
            [2010, 11395, 92, 61],
            [2010, 11396, 68, 51],
            [2010, 11397, 82, 51],
            [2010, 11398, 29, 30],
            [2010, 11399, 61, 37],
            [2010, 11400, 79, 31],
            [2010, 11401, 24, 16],
            [2010, 11402, 69, 51],
            [2010, 11403, 40, 44],
            [2010, 11404, 97, 61],
            [2010, 11405, 41, 51],
            [2010, 11406, 73, 56],
            [2010, 11407, 34, 30],
            [2010, 11408, 68, 36],
            [2010, 11409, 49, 36],
            [2010, 11410, 59, 36],
            [2010, 11411, 49, 31],
            [2010, 11412, 91, 51],
            [2010, 11413, 63, 41],
            [2010, 11414, 49, 41],
            [2010, 11415, 36, 34],
            [2010, 11416, 24, 16],
            [2010, 11417, 40, 39],
            [2010, 11418, 40, 30],
            [2010, 11419, 35, 30],
            [2010, 11420, 54, 36],
            [2010, 11421, 63, 61],
            [2010, 11422, 44, 31],
            [2010, 11423, 63, 30],
            [2010, 11424, 35, 25],
            [2010, 11425, 16, 14],
            [2010, 11426, 9, 7],
            [2010, 11427, 8, 8],
            [2010, 11428, 40, 22],
            [2010, 11429, 14, 11],
            [2010, 11430, 9, 10],
            [2010, 11431, 12, 10],
            [2010, 11432, 7, 7],
            [2010, 11433, 10, 11],
            [2010, 11434, 10, 9],
            [2010, 11435, 7, 8],
            [2010, 11436, 17, 15],
            [2010, 11437, 11, 10],
            [2010, 11438, 10, 9],
            [2010, 11439, 11, 9],
            [2010, 11440, 16, 13],
            [2010, 11441, 41, 24],
            [2010, 11442, 9, 8],
            [2010, 11443, 11, 11],
            [2010, 11444, 10, 8],
            [2010, 11445, 8, 7],
            [2010, 11446, 11, 9],
            [2010, 11447, 16, 12],
            [2010, 11448, 11, 9],
            [2010, 11449, 12, 8],
            [2010, 11450, 12, 10],
            [2010, 11451, 9, 7],
            [2010, 11452, 10, 9],
            [2010, 11453, 27, 15],
            [2010, 11454, 12, 10],
            [2010, 11455, 7, 7],
            [2010, 11456, 8, 8],
            [2010, 11457, 9, 9],
            [2010, 11458, 6, 7],
            [2010, 11459, 6, 6],
            [2010, 11460, 7, 6],
            [2010, 11461, 9, 8],
            [2010, 11462, 7, 7],
            [2010, 11463, 10, 9],
            [2010, 11464, 9, 7],
            [2010, 11465, 14, 11],
            [2010, 11466, 14, 9],
            [2010, 11467, 14, 11],
            [2010, 11468, 26, 18],
            [2010, 11469, 13, 10],
            [2010, 11470, 15, 12],
            [2010, 11471, 13, 11],
            [2010, 11472, 20, 13],
            [2010, 11473, 10, 9],
            [2010, 11474, 7, 8],
            [2010, 11475, 9, 9],
            [2010, 11476, 9, 8],
            [2010, 11477, 17, 13],
            [2010, 11478, 21, 14],
            [2010, 11479, 11, 9],
            [2010, 11480, 17, 14],
            [2010, 11481, 12, 10],
            [2010, 11482, 14, 11],
            [2010, 11483, 17, 13],
            [2010, 11484, 14, 12],
            [2010, 11485, 17, 13],
            [2010, 11486, 14, 12],
            [2010, 11487, 14, 10],
            [2010, 11488, 16, 13],
            [2010, 11489, 9, 8],
            [2010, 11490, 10, 9],
            [2010, 11491, 10, 9],
            [2010, 11492, 8, 7],
            [2010, 11493, 8, 8],
            [2010, 11494, 6, 7],
            [2010, 11495, 6, 6],
            [2010, 11496, 7, 8],
            [2010, 11497, 8, 7],
            [2010, 11498, 9, 8],
            [2010, 11499, 8, 8],
            [2010, 11500, 17, 15],
            [2010, 11501, 7, 7],
            [2010, 11502, 11, 9],
            [2010, 11503, 7, 8],
            [2010, 11504, 8, 8],
            [2010, 11505, 14, 11],
            [2010, 11506, 10, 9],
            [2010, 11507, 11, 11],
            [2010, 11508, 7, 8],
            [2010, 11509, 18, 12],
            [2010, 11510, 11, 9],
            [2010, 11511, 9, 8],
            [2010, 11512, 17, 11],
            [2010, 11513, 13, 11],
            [2010, 11514, 9, 9],
            [2010, 11515, 9, 9],
            [2010, 11516, 14, 11],
            [2010, 11517, 17, 14],
            [2010, 11518, 10, 13],
            [2010, 11519, 16, 11],
            [2010, 11520, 24, 16],
            [2010, 11521, 8, 6],
            [2010, 11522, 10, 10],
            [2010, 11523, 11, 9],
            [2010, 11524, 8, 7],
            [2010, 11525, 11, 8],
            [2010, 11526, 15, 11],
            [2010, 11527, 10, 10],
            [2010, 11528, 8, 7],
            [2010, 11529, 25, 34],
            [2010, 11530, 68, 51],
            [2010, 11531, 68, 39],
            [2010, 11532, 35, 39],
            [2010, 11533, 21, 16],
            [2010, 11534, 92, 51],
            [2010, 11535, 39, 25],
            [2010, 11536, 35, 21],
            [2010, 11537, 39, 20],
            [2010, 11538, 44, 39],
            [2010, 11539, 66, 56],
            [2010, 11540, 20, 16],
            [2010, 11541, 44, 36],
            [2010, 11542, 50, 31],
            [2010, 11543, 31, 56],
            [2010, 11544, 54, 30],
            [2010, 11545, 76, 76],
            [2010, 11546, 82, 51],
            [2010, 11547, 63, 85],
            [2010, 11548, 82, 51],
            [2010, 11549, 49, 30],
            [2010, 11550, 36, 41],
            [2010, 11551, 48, 34],
            [2010, 11552, 54, 39],
            [2010, 11553, 115, 56],
            [2010, 11554, 41, 49],
            [2010, 11555, 54, 56],
            [2010, 11556, 19, 24],
            [2010, 11557, 25, 56],
            [2010, 11558, 64, 56],
            [2010, 11559, 63, 76],
            [2010, 11560, 44, 61],
            [2010, 11561, 97, 81],
            [2010, 11562, 51, 71],
            [2010, 11563, 115, 71],
            [2010, 11564, 71, 86],
            [2010, 11565, 65, 36],
            [2010, 11566, 115, 85],
            [2010, 11567, 40, 39],
            [2010, 11568, 35, 58],
            [2010, 11569, 76, 76],
            [2010, 11570, 30, 39],
            [2010, 11571, 11, 11],
            [2010, 11572, 12, 13],
            [2010, 11573, 96, 69],
            [2010, 11574, 10, 12],
            [2010, 11576, 12, 12],
            [2010, 11577, 12, 11],
            [2010, 11578, 18, 18],
            [2010, 11579, 18, 20],
            [2010, 11580, 10, 11],
            [2010, 11581, 12, 13],
            [2010, 11582, 15, 16],
            [2010, 11583, 34, 24],
            [2010, 11585, 34, 23],
            [2010, 11586, 43, 25],
            [2010, 11588, 109, 33],
            [2010, 11590, 23, 15],
            [2010, 11592, 39, 22],
            [2010, 11593, 26, 17],
            [2010, 11594, 76, 40],
            [2010, 11596, 31, 26],
            [2010, 11598, 46, 22],
            [2010, 11601, 45, 34],
            [2010, 11604, 13, 14],
            [2010, 11605, 20, 16],
            [2010, 11705, 37, 29],
            [2010, 11706, 80, 37],
            [2010, 11709, 49, 25],
            [2010, 11710, 113, 33],
            [2010, 11714, 11, 11],
            [2010, 11717, 21, 20],
            [2010, 11721, 15, 17],
            [2010, 11722, 46, 35],
            [2010, 11724, 45, 38],
            [2010, 11728, 48, 33],
            [2010, 11730, 20, 13],
            [2010, 11731, 98, 38],
            [2010, 11737, 33, 31],
            [2010, 11738, 115, 60],
            [2010, 11739, 16, 19],
            [2010, 11741, 14, 13],
            [2010, 11755, 11, 10],
            [2010, 11759, 14, 15],
            [2010, 11760, 80, 72],
            [2010, 11763, 16, 15],
            [2010, 11766, 33, 22],
            [2010, 11776, 50, 33],
            [2010, 11777, 21, 15],
            [2010, 11792, 48, 33],
            [2010, 11794, 22, 17],
            [2010, 11795, 16, 16],
            [2010, 11796, 28, 22],
            [2010, 11797, 23, 15],
            [2010, 11798, 26, 20],
            [2010, 11799, 27, 23],
            [2010, 11800, 30, 25],
            [2010, 11801, 25, 18],
            [2010, 11802, 25, 24],
            [2010, 11803, 26, 25],
            [2010, 11804, 18, 19],
            [2010, 11805, 28, 18],
            [2010, 11806, 30, 23],
            [2010, 11807, 28, 20],
            [2010, 11808, 21, 12],
            [2010, 11809, 13, 11],
            [2010, 11810, 21, 11],
            [2010, 11811, 15, 11],
            [2010, 11812, 21, 21],
            [2010, 11813, 11, 11],
            [2010, 11814, 18, 13],
            [2010, 11815, 13, 11],
            [2010, 11816, 21, 12],
            [2010, 11817, 17, 11],
            [2010, 11818, 14, 15],
            [2010, 11819, 21, 12],
            [2010, 11820, 14, 12],
            [2010, 11821, 21, 13],
            [2010, 11822, 21, 14],
            [2010, 11823, 31, 15],
            [2010, 11824, 16, 12],
            [2010, 11825, 21, 13],
            [2010, 11826, 14, 12],
            [2010, 11827, 19, 12],
            [2010, 11828, 16, 11],
            [2010, 11829, 21, 21],
            [2010, 11830, 14, 13],
            [2010, 11831, 14, 12],
            [2010, 11832, 23, 11],
            [2010, 11833, 21, 14],
            [2010, 11834, 6, 6],
            [2010, 11835, 21, 11],
            [2010, 11836, 21, 15],
            [2010, 11837, 11, 11],
            [2010, 11838, 7, 6],
            [2010, 11839, 11, 10],
            [2010, 11840, 8, 7],
            [2010, 11841, 6, 5],
            [2010, 11842, 12, 11],
            [2010, 11843, 21, 14],
            [2010, 11844, 15, 13],
            [2010, 11845, 21, 12],
            [2010, 11846, 21, 12],
            [2010, 11847, 13, 12],
            [2010, 11848, 12, 11],
            [2010, 11849, 19, 12],
            [2010, 11850, 12, 11],
            [2010, 11851, 21, 12],
            [2010, 11852, 15, 13],
            [2010, 11853, 11, 11],
            [2010, 11854, 18, 18],
            [2010, 11855, 15, 14],
            [2010, 11858, 13, 32],
            [2010, 11859, 18, 34],
            [2010, 11860, 22, 32],
            [2010, 11869, 22, 21],
            [2010, 11875, 40, 34],
            [2010, 11876, 32, 37],
            [2010, 11878, 23, 18],
            [2010, 11890, 32, 31],
            [2010, 11894, 30, 28],
            [2010, 11900, 25, 19],
            [2010, 11902, 38, 42],
            [2010, 11905, 40, 36],
            [2010, 11914, 25, 25],
            [2010, 11915, 30, 31],
            [2010, 11918, 31, 21],
            [2010, 11919, 13, 17],
            [2010, 11920, 18, 13],
            [2010, 11921, 23, 18],
            [2010, 11922, 21, 21],
            [2010, 11923, 17, 22],
            [2010, 11924, 17, 19],
            [2010, 11925, 25, 18],
            [2010, 11926, 15, 13],
            [2010, 11927, 21, 27],
            [2010, 11928, 14, 11],
            [2010, 11929, 17, 12],
            [2010, 11930, 20, 15],
            [2010, 11931, 32, 27],
            [2010, 11932, 31, 29],
            [2010, 11933, 42, 28],
            [2010, 11934, 23, 16],
            [2010, 11935, 33, 20],
            [2010, 11936, 19, 18],
            [2010, 11937, 50, 25],
            [2010, 11938, 31, 21],
            [2010, 11939, 48, 27],
            [2010, 11940, 46, 28],
            [2010, 11941, 51, 25],
            [2010, 11942, 51, 31],
            [2010, 12091, 31, 16],
            [2010, 12092, 69, 27],
            [2010, 12093, 7, 11],
            [2010, 12094, 26, 18],
            [2010, 12095, 49, 32],
            [2010, 12096, 28, 22],
            [2010, 12097, 28, 21],
            [2010, 12098, 27, 18],
            [2010, 12099, 49, 30],
            [2010, 12100, 11, 9],
            [2010, 12101, 16, 12],
            [2010, 12102, 11, 12],
            [2010, 12103, 28, 18],
            [2010, 12104, 44, 23],
            [2010, 12105, 21, 14],
            [2010, 12106, 13, 12],
            [2010, 12107, 20, 16],
            [2010, 12108, 22, 19],
            [2010, 12109, 23, 21],
            [2010, 12110, 17, 15],
            [2010, 12111, 31, 20],
            [2010, 12112, 30, 18],
            [2010, 12113, 18, 13],
            [2010, 12114, 22, 15],
            [2010, 12115, 11, 13],
            [2010, 12116, 13, 12],
            [2010, 12117, 24, 21],
            [2010, 12118, 23, 18],
            [2010, 12119, 55, 28],
            [2010, 12120, 14, 16],
            [2010, 12121, 17, 15],
            [2010, 12122, 11, 12],
            [2010, 12123, 12, 13],
            [2010, 12124, 12, 21],
            [2010, 12125, 13, 21],
            [2010, 12126, 13, 21],
            [2010, 12127, 11, 12],
            [2010, 12128, 59, 45],
            [2010, 12129, 48, 49],
            [2010, 12130, 78, 62],
            [2010, 12131, 78, 62],
            [2010, 12132, 57, 45],
            [2010, 12133, 63, 45],
            [2010, 12134, 59, 58],
            [2010, 12135, 63, 43],
            [2010, 12136, 32, 24],
            [2010, 12137, 63, 59],
            [2010, 12138, 58, 45],
            [2010, 12139, 41, 41],
            [2010, 12140, 61, 42],
            [2010, 12141, 98, 54],
            [2010, 12142, 78, 42],
            [2010, 12143, 77, 64],
            [2010, 12144, 59, 39],
            [2010, 12145, 61, 52],
            [2010, 12146, 68, 48],
            [2010, 12147, 43, 35],
            [2010, 12148, 73, 49],
            [2010, 12149, 71, 53],
            [2010, 12150, 41, 18],
            [2010, 12151, 63, 59],
            [2010, 12152, 68, 38],
            [2010, 12153, 63, 32],
            [2010, 12154, 71, 55],
            [2010, 12155, 54, 48],
            [2010, 12156, 78, 37],
            [2010, 12157, 63, 30],
            [2010, 12158, 30, 15],
            [2010, 12159, 48, 59],
            [2010, 12160, 21, 21],
            [2010, 12161, 11, 11],
            [2010, 12162, 12, 13],
            [2010, 12163, 21, 21],
            [2010, 12164, 11, 18],
            [2010, 12165, 14, 14],
            [2010, 12166, 14, 15],
            [2010, 12167, 13, 14],
            [2010, 12168, 21, 21],
            [2010, 12169, 12, 11],
            [2010, 12170, 11, 12],
            [2010, 12171, 58, 39],
            [2010, 12172, 54, 32],
            [2010, 12173, 20, 17],
            [2010, 12174, 60, 32],
            [2010, 12175, 50, 30],
            [2010, 12191, 30, 28],
            [2010, 12192, 17, 21],
            [2010, 12193, 39, 28],
            [2010, 12194, 33, 22],
            [2010, 12195, 17, 21],
            [2010, 12196, 17, 21],
            [2010, 12197, 19, 23],
            [2010, 12198, 18, 20],
            [2010, 12199, 38, 23],
            [2010, 12200, 55, 40],
            [2010, 12201, 25, 24],
            [2010, 12202, 48, 28],
            [2010, 12203, 41, 27],
            [2010, 12204, 32, 22],
            [2010, 12205, 32, 27],
            [2010, 12206, 30, 20],
            [2010, 12207, 42, 26],
            [2010, 12208, 31, 20],
            [2010, 12209, 23, 21],
            [2010, 12210, 35, 28],
            [2010, 12211, 31, 21],
            [2010, 12212, 34, 24],
            [2010, 12213, 26, 27],
            [2010, 12214, 32, 21],
            [2010, 12215, 28, 21],
            [2010, 12216, 39, 24],
            [2010, 12217, 30, 20],
            [2010, 12218, 37, 20],
            [2010, 12219, 50, 27],
            [2010, 12220, 29, 20],
            [2010, 12221, 38, 22],
            [2010, 12222, 36, 27],
            [2010, 12223, 48, 27],
            [2010, 12224, 38, 26],
            [2010, 12225, 34, 28],
            [2010, 12226, 43, 22],
            [2010, 12227, 56, 27],
            [2010, 12228, 54, 27],
            [2010, 12229, 47, 21],
            [2010, 12230, 42, 30],
            [2010, 12231, 28, 26],
            [2010, 12232, 46, 28],
            [2010, 12233, 37, 28],
            [2010, 12234, 52, 30],
            [2010, 12235, 54, 26],
            [2010, 12236, 32, 20],
            [2010, 12237, 53, 40],
            [2010, 12238, 51, 31],
            [2010, 12239, 45, 22],
            [2010, 12240, 30, 39],
            [2010, 12241, 16, 16],
            [2010, 12242, 41, 26],
            [2010, 12243, 11, 11],
            [2010, 12244, 11, 11],
            [2010, 12245, 11, 11],
            [2010, 12246, 16, 11],
            [2010, 12247, 16, 16],
            [2010, 12248, 11, 11],
            [2010, 12249, 6, 6],
            [2010, 12250, 16, 11],
            [2010, 12251, 11, 16],
            [2010, 12253, 13, 11],
            [2010, 12254, 21, 21],
            [2010, 12255, 16, 16],
            [2010, 12256, 16, 16],
            [2010, 12257, 31, 26],
            [2010, 12258, 16, 11],
            [2010, 12259, 11, 4],
            [2010, 12260, 6, 6],
            [2010, 12261, 6, 6],
            [2010, 12262, 26, 16],
            [2010, 12263, 11, 16],
            [2010, 12264, 11, 11],
            [2010, 12265, 21, 21],
            [2010, 12266, 26, 26],
            [2010, 12267, 6, 11],
            [2010, 12268, 21, 16],
            [2010, 12269, 16, 16],
            [2010, 12270, 26, 26],
            [2010, 12271, 11, 11],
            [2010, 12272, 11, 11],
            [2010, 12273, 16, 16],
            [2010, 12274, 21, 16],
            [2010, 12275, 16, 11],
            [2010, 12276, 26, 21],
            [2010, 12277, 16, 11],
            [2010, 12278, 11, 11],
            [2010, 12279, 16, 11],
            [2010, 12280, 16, 16],
            [2010, 12281, 6, 6],
            [2010, 12282, 16, 21],
            [2010, 12283, 11, 11],
            [2010, 12284, 11, 16],
            [2010, 12285, 16, 16],
            [2010, 12286, 16, 11],
            [2010, 12287, 11, 11],
            [2010, 12288, 16, 16],
            [2010, 12289, 16, 16],
            [2010, 12290, 11, 11],
            [2010, 12291, 11, 16],
            [2010, 12292, 11, 11],
            [2010, 12293, 21, 16],
            [2010, 12294, 11, 11],
            [2010, 12295, 16, 16],
            [2010, 12296, 41, 36],
            [2010, 12297, 16, 16],
            [2010, 12298, 16, 16],
            [2010, 12299, 31, 36],
            [2010, 12300, 16, 17],
            [2010, 12301, 13, 11],
            [2010, 12302, 28, 19],
            [2010, 12303, 28, 13],
            [2010, 12304, 22, 22],
            [2010, 12305, 13, 8],
            [2010, 12306, 14, 10],
            [2010, 12307, 24, 19],
            [2010, 12308, 23, 14],
            [2010, 12309, 22, 14],
            [2010, 12310, 22, 14],
            [2010, 12311, 27, 20],
            [2010, 12326, 12, 12],
            [2010, 12327, 37, 31],
            [2010, 12328, 14, 15],
            [2010, 12329, 8, 9],
            [2010, 12330, 13, 14],
            [2010, 12331, 9, 10],
            [2010, 12332, 19, 20],
            [2010, 12333, 24, 20],
            [2010, 12334, 14, 13],
            [2010, 12335, 14, 12],
            [2010, 12336, 21, 16],
            [2010, 12337, 16, 13],
            [2010, 12338, 14, 12],
            [2010, 12339, 11, 12],
            [2010, 12340, 15, 12],
            [2010, 12341, 19, 15],
            [2010, 12342, 22, 15],
            [2010, 12343, 28, 23],
            [2010, 12344, 14, 12],
            [2010, 12345, 13, 12],
            [2010, 12346, 24, 19],
            [2010, 12347, 24, 19],
            [2010, 12348, 19, 15],
            [2010, 12349, 20, 15],
            [2010, 12350, 24, 17],
            [2010, 12351, 24, 16],
            [2010, 12352, 9, 9],
            [2010, 12353, 12, 12],
            [2010, 12354, 10, 10],
            [2010, 12355, 12, 13],
            [2010, 12356, 10, 11],
            [2010, 12357, 23, 23],
            [2010, 12358, 15, 16],
            [2010, 12359, 28, 22],
            [2010, 12360, 38, 32],
            [2010, 12361, 23, 17],
            [2010, 12362, 14, 17],
            [2010, 12363, 20, 18],
            [2010, 12364, 10, 12],
            [2010, 12365, 11, 11],
            [2010, 12366, 26, 24],
            [2010, 12367, 30, 23],
            [2010, 12368, 13, 13],
            [2010, 12369, 29, 28],
            [2010, 12370, 15, 16],
            [2010, 12371, 19, 17],
            [2010, 12372, 13, 12],
            [2010, 12373, 22, 23],
            [2010, 12374, 14, 13],
            [2010, 12375, 26, 23],
            [2010, 12376, 15, 15],
            [2010, 12377, 14, 18],
            [2010, 12378, 16, 14],
            [2010, 12379, 16, 16],
            [2010, 12380, 21, 17],
            [2010, 12381, 14, 14],
            [2010, 12382, 22, 22],
            [2010, 12383, 9, 8],
            [2010, 12384, 14, 13],
            [2010, 12385, 14, 16],
            [2010, 12386, 13, 13],
            [2010, 12387, 12, 11],
            [2010, 12388, 14, 15],
            [2010, 12389, 13, 12],
            [2010, 12390, 13, 15],
            [2010, 12391, 17, 18],
            [2010, 12392, 38, 30],
            [2010, 12393, 21, 22],
            [2010, 12394, 17, 15],
            [2010, 12395, 13, 12],
            [2010, 12396, 18, 16],
            [2010, 12397, 13, 14],
            [2010, 12398, 35, 26],
            [2010, 12399, 33, 24],
            [2010, 12400, 16, 14],
            [2010, 12401, 21, 14],
            [2010, 12402, 23, 16],
            [2010, 12403, 16, 15],
            [2010, 12404, 18, 15],
            [2010, 12405, 14, 12],
            [2010, 12406, 21, 18],
            [2010, 12407, 22, 18],
            [2010, 12490, 25, 24],
            [2010, 12491, 11, 12],
            [2010, 12492, 11, 11],
            [2010, 12493, 26, 26],
            [2010, 12494, 40, 37],
            [2010, 12495, 22, 22],
            [2010, 12496, 39, 30],
            [2010, 12497, 45, 34],
            [2010, 12498, 41, 32],
            [2010, 12499, 35, 42],
            [2010, 12500, 26, 16],
            [2010, 12501, 30, 32],
            [2010, 12502, 26, 26],
            [2010, 12503, 50, 38],
            [2010, 12504, 46, 45],
            [2010, 12505, 60, 46],
            [2010, 12506, 29, 27],
            [2010, 12507, 31, 27],
            [2010, 12508, 37, 34],
            [2010, 12509, 24, 23],
            [2010, 12510, 26, 27],
            [2010, 12511, 33, 29],
            [2010, 12512, 21, 23],
            [2010, 12513, 16, 19],
            [2010, 12514, 27, 27],
            [2010, 12515, 22, 22],
            [2010, 12516, 23, 24],
            [2010, 12517, 23, 24],
            [2010, 12518, 62, 41],
            [2010, 12519, 118, 56],
            [2010, 12520, 28, 28],
            [2010, 12521, 34, 34],
            [2010, 12522, 11, 15],
            [2010, 12523, 26, 16],
            [2010, 12524, 36, 31],
            [2010, 12525, 31, 21],
            [2010, 12526, 11, 11],
            [2010, 12527, 11, 11],
            [2010, 12528, 11, 11],
            [2010, 12529, 11, 11],
            [2010, 12530, 20, 15],
            [2010, 12531, 41, 31],
            [2010, 12532, 31, 16],
            [2010, 12533, 50, 46],
            [2010, 12534, 10, 11],
            [2010, 12535, 31, 21],
            [2010, 12536, 16, 11],
            [2010, 12537, 11, 11],
            [2010, 12538, 21, 20],
            [2010, 12539, 11, 11],
            [2010, 12540, 20, 15],
            [2010, 12541, 15, 14],
            [2010, 12542, 21, 20],
            [2010, 12543, 25, 31],
            [2010, 12544, 46, 46],
            [2010, 12545, 11, 11],
            [2010, 12546, 31, 35],
            [2010, 12547, 25, 26],
            [2010, 12548, 36, 32],
            [2010, 12549, 11, 11],
            [2010, 12550, 11, 11],
            [2010, 12551, 31, 21],
            [2010, 12552, 31, 21],
            [2010, 12553, 16, 16],
            [2010, 12554, 11, 11],
            [2010, 12555, 6, 7],
            [2010, 12556, 11, 12],
            [2010, 12557, 11, 18],
            [2010, 12558, 11, 20],
            [2010, 12559, 11, 11],
            [2010, 12560, 4, 6],
            [2010, 12561, 9, 10],
            [2010, 12562, 10, 11],
            [2010, 12563, 15, 14],
            [2010, 12564, 15, 18],
            [2010, 12565, 26, 17],
            [2010, 12566, 15, 11],
            [2010, 12567, 11, 11],
            [2010, 12568, 46, 46],
            [2010, 12569, 46, 46],
            [2010, 12570, 20, 21],
            [2010, 12571, 31, 21],
            [2010, 12572, 41, 25],
            [2010, 12573, 21, 21],
            [2010, 12574, 11, 11],
            [2010, 12575, 11, 13],
            [2010, 12576, 31, 21],
            [2010, 12577, 10, 11],
            [2010, 12578, 41, 46],
            [2010, 12579, 16, 21],
            [2010, 12580, 20, 21],
            [2010, 12581, 121, 107],
            [2010, 12582, 110, 128],
            [2010, 12583, 149, 161],
            [2010, 12584, 121, 96],
            [2010, 12585, 121, 150],
            [2010, 12587, 10, 14],
            [2010, 12588, 10, 11],
            [2010, 12589, 72, 60],
            [2010, 12590, 55, 45],
            [2010, 12591, 70, 55],
            [2010, 12592, 78, 65],
            [2010, 12593, 55, 41],
            [2010, 12594, 47, 45],
            [2010, 12595, 75, 75],
            [2010, 12596, 39, 32],
            [2010, 12597, 35, 30],
            [2010, 12598, 72, 60],
            [2010, 12599, 72, 60],
            [2010, 12600, 72, 60],
            [2010, 12601, 62, 51],
            [2010, 12602, 25, 24],
            [2010, 12603, 28, 22],
            [2010, 12604, 28, 19],
            [2010, 12605, 24, 20],
            [2010, 12606, 31, 30],
            [2010, 12607, 35, 30],
            [2010, 12608, 41, 28],
            [2010, 12609, 30, 25],
            [2010, 12610, 45, 34],
            [2010, 12611, 35, 31],
            [2010, 12612, 40, 24],
            [2010, 12613, 29, 27],
            [2010, 12614, 26, 24],
            [2010, 12615, 31, 23],
            [2010, 12616, 37, 32],
            [2010, 12617, 25, 29],
            [2010, 12618, 32, 26],
            [2010, 12619, 28, 28],
            [2010, 12620, 22, 19],
            [2010, 12621, 37, 32],
            [2010, 12622, 30, 27],
            [2010, 12623, 29, 23],
            [2010, 12624, 45, 41],
            [2010, 12625, 40, 35],
            [2010, 12626, 26, 31],
            [2010, 12627, 21, 23],
            [2010, 12628, 30, 25],
            [2010, 12629, 23, 24],
            [2010, 12630, 40, 31],
            [2010, 12631, 41, 31],
            [2010, 12632, 32, 27],
            [2010, 12633, 17, 20],
            [2011, 964, 11, 11],
            [2011, 2142, 11, 10],
            [2011, 2922, 10, 11],
            [2011, 4536, 14, 13],
            [2011, 5273, 16, 14],
            [2011, 11581, 12, 12],
            [2011, 11582, 14, 15],
            [2011, 12312, 166, 105],
            [2011, 12313, 116, 91],
            [2011, 12314, 116, 91],
            [2011, 12315, 166, 105],
            [2011, 12316, 166, 105],
            [2011, 12317, 166, 105],
            [2011, 12318, 166, 105],
            [2011, 12319, 166, 105],
            [2011, 12320, 116, 91],
            [2011, 12321, 81, 83],
            [2011, 12322, 166, 105],
            [2011, 12323, 166, 105],
            [2011, 12324, 116, 91],
            [2011, 12325, 116, 91],
            [2011, 12523, 23, 11],
            [2011, 12524, 48, 31],
            [2011, 12525, 26, 21],
            [2011, 12526, 14, 15],
            [2011, 12527, 10, 11],
            [2011, 12528, 9, 11],
            [2011, 12529, 10, 11],
            [2011, 12530, 18, 11],
            [2011, 12532, 26, 15],
            [2011, 12534, 10, 11],
            [2011, 12535, 21, 21],
            [2011, 12536, 11, 11],
            [2011, 12537, 11, 11],
            [2011, 12538, 16, 16],
            [2011, 12539, 17, 11],
            [2011, 12540, 24, 17],
            [2011, 12541, 15, 14],
            [2011, 12542, 20, 16],
            [2011, 12543, 25, 23],
            [2011, 12545, 11, 11],
            [2011, 12546, 30, 31],
            [2011, 12547, 23, 21],
            [2011, 12548, 35, 26],
            [2011, 12549, 11, 11],
            [2011, 12550, 11, 11],
            [2011, 12551, 30, 21],
            [2011, 12552, 34, 21],
            [2011, 12553, 15, 14],
            [2011, 12554, 9, 11],
            [2011, 12556, 9, 12],
            [2011, 12557, 10, 16],
            [2011, 12558, 11, 20],
            [2011, 12559, 11, 11],
            [2011, 12560, 4, 6],
            [2011, 12561, 7, 10],
            [2011, 12562, 9, 11],
            [2011, 12563, 15, 14],
            [2011, 12565, 25, 17],
            [2011, 12566, 13, 11],
            [2011, 12567, 11, 11],
            [2011, 12568, 35, 44],
            [2011, 12569, 35, 44],
            [2011, 12570, 18, 21],
            [2011, 12571, 45, 21],
            [2011, 12573, 21, 21],
            [2011, 12574, 10, 11],
            [2011, 12575, 11, 13],
            [2011, 12576, 26, 21],
            [2011, 12577, 10, 11],
            [2011, 12578, 41, 44],
            [2011, 12579, 14, 21],
            [2011, 12580, 18, 16],
            [2011, 12581, 116, 101],
            [2011, 12582, 108, 126],
            [2011, 12583, 143, 159],
            [2011, 12584, 116, 89],
            [2011, 12585, 118, 147],
            [2011, 12589, 69, 58],
            [2011, 12590, 53, 43],
            [2011, 12591, 67, 54],
            [2011, 12592, 75, 63],
            [2011, 12593, 53, 39],
            [2011, 12594, 45, 43],
            [2011, 12595, 73, 72],
            [2011, 12596, 36, 30],
            [2011, 12597, 33, 29],
            [2011, 12598, 69, 58],
            [2011, 12599, 69, 58],
            [2011, 12600, 69, 58],
            [2011, 12639, 11, 9],
            [2011, 12640, 14, 10],
            [2011, 12641, 22, 24],
            [2011, 12642, 22, 24],
            [2011, 12643, 37, 33],
            [2011, 12644, 37, 28],
            [2011, 12645, 64, 55],
            [2011, 12646, 39, 46],
            [2011, 12647, 24, 37],
            [2011, 12648, 35, 33],
            [2011, 12649, 31, 30],
            [2011, 12650, 28, 28],
            [2011, 12651, 38, 34],
            [2011, 12652, 43, 38],
            [2011, 12653, 45, 46],
            [2011, 12654, 22, 24],
            [2011, 12655, 37, 40],
            [2011, 12656, 44, 36],
            [2011, 12657, 22, 24],
            [2011, 12658, 46, 41],
            [2011, 12659, 51, 47],
            [2011, 12660, 50, 44],
            [2011, 12661, 48, 44],
            [2011, 12662, 43, 41],
            [2011, 12663, 45, 38],
            [2011, 12664, 57, 52],
            [2011, 12665, 44, 41],
            [2011, 12667, 14, 14],
            [2011, 12668, 6, 6],
            [2011, 12669, 4, 4],
            [2011, 12670, 8, 9],
            [2011, 12671, 12, 13],
            [2011, 12672, 12, 14],
            [2011, 12673, 12, 15],
            [2011, 12674, 12, 12],
            [2011, 12675, 17, 17],
            [2011, 12676, 16, 17],
            [2011, 12677, 11, 14],
            [2011, 12678, 43, 42],
            [2011, 12679, 18, 20],
            [2011, 12680, 19, 17],
            [2011, 12681, 5, 6],
            [2011, 12682, 18, 19],
            [2011, 12683, 12, 15],
            [2011, 12684, 35, 24],
            [2011, 12685, 40, 37],
            [2011, 12686, 22, 20],
            [2011, 12687, 23, 22],
            [2011, 12688, 23, 21],
            [2011, 12689, 35, 28],
            [2011, 12690, 38, 29],
            [2011, 12691, 42, 30],
            [2011, 12692, 38, 30],
            [2011, 12693, 31, 26],
            [2011, 12694, 30, 25],
            [2011, 12695, 40, 28],
            [2011, 12696, 37, 29],
            [2011, 12697, 40, 29],
            [2011, 12698, 11, 10],
            [2011, 12699, 10, 9],
            [2011, 12700, 11, 10],
            [2011, 12701, 15, 12],
            [2011, 12702, 14, 11],
            [2011, 12703, 34, 44],
            [2011, 12704, 20, 15],
            [2011, 12705, 26, 17],
            [2011, 12706, 29, 29],
            [2011, 12707, 35, 31],
            [2011, 12708, 30, 25],
            [2011, 12709, 36, 30],
            [2011, 12710, 40, 33],
            [2011, 12711, 39, 34],
            [2011, 12712, 43, 39],
            [2011, 12713, 35, 35],
            [2011, 12714, 44, 35],
            [2011, 12715, 45, 41],
            [2011, 12716, 27, 25],
            [2011, 12717, 31, 30],
            [2011, 12718, 24, 22],
            [2011, 12719, 30, 24],
            [2011, 12720, 30, 25],
            [2011, 12721, 30, 21],
            [2011, 12722, 15, 13],
            [2011, 12723, 25, 22],
            [2011, 12724, 15, 13],
            [2011, 12725, 11, 13],
            [2011, 12726, 8, 8],
            [2011, 12727, 23, 26],
            [2011, 12728, 9, 9],
            [2011, 12729, 26, 29],
            [2011, 12730, 26, 16],
            [2011, 12731, 22, 26],
            [2011, 12732, 18, 21],
            [2011, 12733, 17, 16],
            [2011, 12734, 19, 19],
            [2011, 12735, 14, 15],
            [2011, 12736, 15, 20],
            [2011, 12737, 26, 17],
            [2011, 12738, 10, 13],
            [2011, 12739, 15, 18],
            [2011, 12740, 21, 22],
            [2011, 12741, 16, 18],
            [2011, 12742, 7, 8],
            [2011, 12743, 25, 15],
            [2011, 12744, 11, 16],
            [2011, 12745, 15, 16],
            [2011, 12746, 10, 11],
            [2011, 12747, 12, 18],
            [2011, 12748, 8, 13],
            [2011, 12749, 11, 18],
            [2011, 12750, 7, 7],
            [2011, 12751, 6, 9],
            [2011, 12752, 25, 19],
            [2011, 12753, 10, 17],
            [2011, 12754, 10, 9],
            [2011, 12755, 6, 6],
            [2011, 12756, 13, 16],
            [2011, 12757, 6, 8],
            [2011, 12758, 12, 15],
            [2011, 12759, 20, 18],
            [2011, 12760, 25, 19],
            [2011, 12761, 10, 13],
            [2011, 12762, 10, 11],
            [2011, 12763, 17, 21],
            [2011, 12764, 12, 16],
            [2011, 12765, 10, 11],
            [2011, 12766, 13, 17],
            [2011, 12767, 14, 19],
            [2011, 12768, 13, 14],
            [2011, 12769, 18, 12],
            [2011, 12770, 11, 16],
            [2011, 12771, 20, 20],
            [2011, 12772, 12, 11],
            [2011, 12773, 11, 12],
            [2011, 12774, 11, 13],
            [2011, 12775, 20, 27],
            [2011, 12776, 19, 27],
            [2011, 12777, 9, 9],
            [2011, 12778, 19, 27],
            [2011, 12779, 20, 23],
            [2011, 12780, 9, 9],
            [2011, 12781, 20, 27],
            [2011, 12782, 15, 17],
            [2011, 12783, 9, 9],
            [2011, 12784, 19, 27],
            [2011, 12785, 25, 15],
            [2011, 12786, 11, 11],
            [2011, 12787, 21, 22],
            [2011, 12788, 8, 9],
            [2011, 12789, 17, 17],
            [2011, 12790, 18, 16],
            [2011, 12791, 13, 10],
            [2011, 12792, 15, 16],
            [2011, 12793, 14, 12],
            [2011, 12794, 21, 19],
            [2011, 12795, 14, 12],
            [2011, 12796, 10, 11],
            [2011, 12797, 10, 10],
            [2011, 12798, 10, 15],
            [2011, 12799, 7, 11],
            [2011, 12800, 20, 11],
            [2011, 12801, 11, 8],
            [2011, 12802, 12, 10],
            [2011, 12803, 63, 39],
            [2011, 12804, 15, 15],
            [2011, 12805, 19, 13],
            [2011, 12806, 13, 12],
            [2011, 12807, 33, 18],
            [2011, 12808, 15, 15],
            [2011, 12809, 7, 10],
            [2011, 12810, 15, 20],
            [2011, 12811, 11, 13],
            [2011, 12812, 18, 15],
            [2011, 12813, 9, 9],
            [2011, 12814, 13, 15],
            [2011, 12815, 16, 13],
            [2011, 12816, 8, 10],
            [2011, 12817, 11, 10],
            [2011, 12818, 10, 10],
            [2011, 12819, 14, 21],
            [2011, 12820, 11, 11],
            [2011, 12821, 8, 4],
            [2011, 12822, 11, 13],
            [2011, 12823, 5, 4],
            [2011, 12824, 10, 13],
            [2011, 12825, 10, 9],
            [2011, 12826, 8, 7],
            [2011, 12827, 33, 20],
            [2011, 12828, 9, 7],
            [2011, 12829, 11, 11],
            [2011, 12830, 9, 6],
            [2011, 12831, 91, 66],
            [2011, 12832, 21, 21],
            [2011, 12833, 9, 6],
            [2011, 12834, 23, 15],
            [2011, 12835, 5, 4],
            [2011, 12836, 21, 11],
            [2011, 12837, 5, 4],
            [2011, 12838, 8, 6],
            [2011, 12839, 5, 4],
            [2011, 12840, 19, 10],
            [2011, 12841, 3, 2],
            [2011, 12842, 8, 9],
            [2011, 12843, 5, 5],
            [2011, 12844, 7, 10],
            [2011, 12845, 9, 7],
            [2011, 12846, 8, 10],
            [2011, 12847, 21, 15],
            [2011, 12848, 14, 11],
            [2011, 12849, 7, 9],
            [2011, 12850, 23, 12],
            [2011, 12851, 14, 12],
            [2011, 12852, 9, 9],
            [2011, 12853, 6, 4],
            [2011, 12854, 31, 19],
            [2011, 12855, 4, 3],
            [2011, 12856, 16, 9],
            [2011, 12857, 8, 7],
            [2011, 12858, 3, 2],
            [2011, 12859, 23, 13],
            [2011, 12860, 15, 12],
            [2011, 12861, 6, 4],
            [2011, 12862, 6, 5],
            [2011, 12863, 66, 31],
            [2011, 12864, 5, 4],
            [2011, 12865, 37, 14],
            [2011, 12866, 5, 4],
            [2011, 12867, 66, 29],
            [2011, 12868, 8, 6],
            [2011, 12869, 10, 12],
            [2011, 12870, 8, 5],
            [2011, 12871, 41, 19],
            [2011, 12872, 9, 7],
            [2011, 12873, 12, 10],
            [2011, 12874, 6, 5],
            [2011, 12875, 66, 35],
            [2011, 12876, 11, 9],
            [2011, 12877, 6, 5],
            [2011, 12878, 11, 9],
            [2011, 12879, 9, 9],
            [2011, 12880, 6, 5],
            [2011, 12881, 13, 10],
            [2011, 12882, 12, 10],
            [2011, 12883, 5, 4],
            [2011, 12884, 47, 27],
            [2011, 12885, 3, 2],
            [2011, 12886, 27, 22],
            [2011, 12887, 5, 4],
            [2011, 12888, 16, 12],
            [2011, 12889, 77, 35],
            [2011, 12890, 7, 5],
            [2011, 12891, 35, 20],
            [2011, 12892, 10, 9],
            [2011, 12893, 8, 6],
            [2011, 12894, 19, 12],
            [2011, 12895, 6, 5],
            [2011, 12896, 33, 21],
            [2011, 12897, 8, 6],
            [2011, 12898, 19, 12],
            [2011, 12899, 19, 16],
            [2011, 12900, 8, 6],
            [2011, 12901, 27, 15],
            [2011, 12902, 7, 6],
            [2011, 12903, 29, 35],
            [2011, 12904, 13, 11],
            [2011, 12905, 29, 20],
            [2011, 12906, 11, 9],
            [2011, 12907, 22, 18],
            [2011, 12908, 14, 12],
            [2011, 12909, 5, 4],
            [2011, 12910, 9, 7],
            [2011, 12911, 4, 4],
            [2011, 12912, 13, 12],
            [2011, 12913, 8, 7],
            [2011, 12914, 7, 5],
            [2011, 12915, 4, 3],
            [2011, 12916, 7, 5],
            [2011, 12917, 12, 10],
            [2011, 12918, 4, 3],
            [2011, 12919, 6, 4],
            [2011, 12920, 19, 16],
            [2011, 12921, 16, 13],
            [2011, 12922, 9, 8],
            [2011, 12923, 8, 7],
            [2011, 12924, 10, 9],
            [2011, 12925, 6, 5],
            [2011, 12926, 6, 5],
            [2011, 12927, 17, 14],
            [2011, 12928, 33, 22],
            [2011, 12929, 8, 6],
            [2011, 12930, 9, 7],
            [2011, 12931, 7, 5],
            [2011, 12932, 10, 8],
            [2011, 12933, 6, 4],
            [2011, 12934, 9, 7],
            [2011, 12935, 7, 6],
            [2011, 12936, 4, 3],
            [2011, 12937, 9, 7],
            [2011, 12938, 7, 5],
            [2011, 12939, 3, 2],
            [2011, 12940, 6, 5],
            [2011, 12941, 14, 12],
            [2011, 12942, 10, 8],
            [2011, 12943, 7, 6],
            [2011, 12944, 6, 5],
            [2011, 12945, 4, 3],
            [2011, 12946, 6, 5],
            [2011, 12947, 9, 7],
            [2011, 12948, 7, 5],
            [2011, 12949, 6, 5],
            [2011, 12950, 9, 7],
            [2011, 12951, 10, 8],
            [2011, 12952, 25, 21],
            [2011, 12953, 16, 14],
            [2011, 12954, 10, 8],
            [2011, 12955, 9, 7],
            [2011, 12956, 5, 4],
            [2011, 12957, 8, 6],
            [2011, 12958, 8, 7],
            [2011, 12959, 6, 4],
            [2011, 12960, 7, 5],
            [2011, 12961, 6, 4],
            [2011, 12962, 8, 5],
            [2011, 12963, 5, 5],
            [2011, 12964, 9, 7],
            [2011, 12965, 22, 19],
            [2011, 12966, 10, 7],
            [2011, 12967, 10, 8],
            [2011, 12968, 13, 11],
            [2011, 12969, 7, 5],
            [2011, 12970, 7, 5],
            [2011, 12971, 8, 7],
            [2011, 12972, 6, 5],
            [2011, 12973, 6, 4],
            [2011, 12974, 8, 6],
            [2011, 12975, 6, 5],
            [2011, 12976, 6, 5],
            [2011, 12977, 4, 3],
            [2011, 12978, 12, 9],
            [2011, 12979, 13, 11],
            [2011, 12980, 8, 6],
            [2011, 12981, 8, 6],
            [2011, 12982, 14, 11],
            [2011, 12983, 8, 5],
            [2011, 12984, 5, 5],
            [2011, 12985, 8, 6],
            [2011, 12986, 5, 4],
            [2011, 12987, 8, 7],
            [2011, 12988, 23, 20],
            [2011, 12989, 12, 9],
            [2011, 12990, 8, 6],
            [2011, 12991, 6, 5],
            [2011, 12992, 6, 5],
            [2011, 12993, 4, 3],
            [2011, 12994, 7, 6],
            [2011, 12995, 5, 4],
            [2011, 12996, 7, 5],
            [2011, 12997, 8, 6],
            [2011, 12998, 6, 5],
            [2011, 12999, 7, 5],
            [2011, 13000, 6, 5],
            [2011, 13001, 14, 15],
            [2011, 13002, 18, 18],
            [2011, 13003, 16, 17],
            [2011, 13004, 26, 23],
            [2011, 13005, 21, 21],
            [2011, 13006, 26, 24],
            [2011, 13007, 21, 21],
            [2011, 13008, 29, 23],
            [2011, 13009, 22, 22],
            [2011, 13010, 21, 21],
            [2011, 13011, 38, 28],
            [2011, 13012, 27, 26],
            [2011, 13013, 17, 18],
            [2011, 13014, 20, 20],
            [2011, 13015, 14, 16],
            [2011, 13016, 18, 15],
            [2011, 13017, 9, 8],
            [2011, 13018, 22, 23],
            [2011, 13019, 17, 10],
            [2011, 13020, 11, 16],
            [2011, 13021, 16, 22],
            [2011, 13022, 11, 8],
            [2011, 13023, 22, 16],
            [2011, 13024, 36, 31],
            [2011, 13025, 12, 18],
            [2011, 13026, 22, 15],
            [2011, 13027, 21, 14],
            [2011, 13028, 10, 6],
            [2011, 13029, 16, 19],
            [2011, 13030, 16, 17],
            [2011, 13031, 13, 13],
            [2011, 13032, 27, 25],
            [2011, 13033, 11, 10],
            [2011, 13034, 8, 8],
            [2011, 13035, 9, 6],
            [2011, 13036, 22, 9],
            [2011, 13037, 10, 9],
            [2011, 13038, 24, 18],
            [2011, 13039, 14, 14],
            [2011, 13040, 19, 19],
            [2011, 13041, 15, 15],
            [2011, 13042, 7, 10],
            [2011, 13043, 9, 6],
            [2011, 13044, 16, 19],
            [2011, 13045, 8, 12],
            [2011, 13046, 20, 18],
            [2011, 13047, 24, 24],
            [2011, 13048, 13, 13],
            [2011, 13049, 15, 14],
            [2011, 13050, 14, 14],
            [2011, 13051, 18, 20],
            [2011, 13052, 13, 14],
            [2011, 13053, 12, 10],
            [2011, 13054, 19, 21],
            [2011, 13055, 23, 15],
            [2011, 13056, 16, 19],
            [2011, 13057, 18, 18],
            [2011, 13058, 22, 21],
            [2011, 13059, 13, 9],
            [2011, 13060, 18, 14],
            [2011, 13061, 21, 20],
            [2011, 13062, 16, 13],
            [2011, 13063, 34, 6],
            [2011, 13064, 11, 16],
            [2011, 13065, 15, 16],
            [2011, 13066, 14, 12],
            [2011, 13067, 18, 14],
            [2011, 13068, 16, 18],
            [2011, 13069, 24, 19],
            [2011, 13070, 11, 8],
            [2011, 13071, 13, 8],
            [2011, 13072, 12, 15],
            [2011, 13073, 12, 12],
            [2011, 13074, 13, 15],
            [2011, 13075, 24, 25],
            [2011, 13076, 14, 10],
            [2011, 13077, 30, 24],
            [2011, 13078, 38, 35],
            [2011, 13079, 13, 17],
            [2011, 13080, 14, 10],
            [2011, 13081, 16, 15],
            [2011, 13082, 8, 9],
            [2011, 13083, 16, 11],
            [2011, 13084, 26, 20],
            [2011, 13085, 32, 22],
            [2011, 13086, 7, 8],
            [2011, 13087, 18, 14],
            [2011, 13088, 21, 14],
            [2011, 13089, 14, 13],
            [2011, 13090, 14, 14],
            [2011, 13091, 10, 6],
            [2011, 13092, 29, 22],
            [2011, 13093, 15, 14],
            [2011, 13094, 34, 20],
            [2011, 13095, 15, 15],
            [2011, 13096, 10, 12],
            [2011, 13097, 18, 13],
            [2011, 13098, 14, 14],
            [2011, 13099, 9, 12],
            [2011, 13100, 24, 21],
            [2011, 13101, 18, 17],
            [2011, 13102, 24, 18],
            [2011, 13103, 24, 18],
            [2011, 13104, 20, 29],
            [2011, 13105, 18, 14],
            [2011, 13106, 22, 17],
            [2011, 13107, 16, 12],
            [2011, 13108, 18, 15],
            [2011, 13109, 13, 13],
            [2011, 13111, 17, 15],
            [2011, 13112, 13, 12],
            [2011, 13113, 20, 12],
            [2011, 13114, 17, 16],
            [2011, 13115, 15, 11],
            [2011, 13116, 19, 20],
            [2011, 13117, 17, 17],
            [2011, 13118, 14, 10],
            [2011, 13119, 24, 18],
            [2011, 13120, 16, 8],
            [2011, 13121, 17, 21],
            [2011, 13122, 31, 17],
            [2011, 13123, 19, 16],
            [2011, 13124, 12, 13],
            [2011, 13125, 12, 10],
            [2011, 13126, 24, 17],
            [2011, 13127, 17, 15],
            [2011, 13128, 12, 15],
            [2011, 13129, 24, 20],
            [2011, 13130, 18, 14],
            [2011, 13131, 14, 11],
            [2011, 13132, 15, 13],
            [2011, 13133, 21, 14],
            [2011, 13134, 20, 15],
            [2011, 13135, 19, 12],
            [2011, 13136, 16, 22],
            [2011, 13137, 20, 23],
            [2011, 13138, 16, 12],
            [2011, 13139, 7, 7],
            [2011, 13140, 20, 12],
            [2011, 13141, 11, 9],
            [2011, 13142, 9, 8],
            [2011, 13143, 10, 8],
            [2011, 13144, 14, 12],
            [2011, 13145, 7, 7],
            [2011, 13146, 7, 7],
            [2011, 13147, 12, 9],
            [2011, 13148, 13, 13],
            [2011, 13149, 9, 7],
            [2011, 13150, 11, 10],
            [2011, 13151, 7, 8],
            [2011, 13152, 11, 10],
            [2011, 13153, 7, 7],
            [2011, 13154, 8, 8],
            [2011, 13155, 9, 7],
            [2011, 13156, 9, 8],
            [2011, 13157, 19, 14],
            [2011, 13158, 7, 7],
            [2011, 13159, 9, 8],
            [2011, 13160, 9, 7],
            [2011, 13161, 7, 7],
            [2011, 13162, 12, 11],
            [2011, 13163, 11, 8],
            [2011, 13164, 9, 8],
            [2011, 13165, 11, 8],
            [2011, 13166, 8, 7],
            [2011, 13167, 21, 15],
            [2011, 13168, 9, 8],
            [2011, 13169, 11, 9],
            [2011, 13170, 13, 12],
            [2011, 13171, 11, 9],
            [2011, 13172, 7, 7],
            [2011, 13173, 12, 10],
            [2011, 13174, 9, 7],
            [2011, 13175, 7, 7],
            [2011, 13176, 10, 8],
            [2011, 13177, 9, 9],
            [2011, 13178, 12, 10],
            [2011, 13179, 10, 8],
            [2011, 13180, 18, 11],
            [2011, 13181, 7, 7],
            [2011, 13182, 9, 8],
            [2011, 13183, 36, 24],
            [2011, 13184, 7, 7],
            [2011, 13185, 11, 12],
            [2011, 13186, 15, 16],
            [2011, 13187, 8, 11],
            [2011, 13188, 8, 10],
            [2011, 13189, 13, 11],
            [2011, 13190, 7, 11],
            [2011, 13191, 23, 15],
            [2011, 13192, 9, 12],
            [2011, 13193, 10, 14],
            [2011, 13194, 11, 10],
            [2011, 13195, 25, 16],
            [2011, 13196, 17, 12],
            [2011, 13197, 102, 37],
            [2011, 13198, 13, 10],
            [2011, 13199, 7, 8],
            [2011, 13200, 22, 15],
            [2011, 13201, 17, 13],
            [2011, 13202, 24, 14],
            [2011, 13203, 8, 9],
            [2011, 13204, 27, 15],
            [2011, 13205, 9, 12],
            [2011, 13206, 17, 13],
            [2011, 13207, 13, 12],
            [2011, 13208, 12, 12],
            [2011, 13209, 9, 8],
            [2011, 13210, 25, 20],
            [2011, 13211, 15, 12],
            [2011, 13212, 66, 40],
            [2011, 13213, 33, 19],
            [2011, 13214, 20, 18],
            [2011, 13215, 10, 12],
            [2011, 13216, 22, 17],
            [2011, 13217, 7, 10],
            [2011, 13218, 15, 14],
            [2011, 13219, 11, 11],
            [2011, 13220, 9, 11],
            [2011, 13221, 8, 11],
            [2011, 13222, 9, 11],
            [2011, 13223, 21, 16],
            [2011, 13224, 63, 24],
            [2011, 13225, 15, 11],
            [2011, 13226, 9, 12],
            [2011, 13227, 20, 15],
            [2011, 13228, 10, 11],
            [2011, 13229, 7, 9],
            [2011, 13230, 23, 14],
            [2011, 13231, 11, 11],
            [2011, 13232, 18, 15],
            [2011, 13233, 19, 16],
            [2011, 13234, 20, 17],
            [2011, 13235, 15, 14],
            [2011, 13236, 12, 10],
            [2011, 13237, 10, 8],
            [2011, 13238, 17, 15],
            [2011, 13239, 16, 13],
            [2011, 13240, 17, 15],
            [2011, 13241, 19, 16],
            [2011, 13242, 18, 16],
            [2011, 13243, 19, 16],
            [2011, 13244, 22, 21],
            [2011, 13245, 18, 15],
            [2011, 13246, 21, 14],
            [2011, 13247, 19, 18],
            [2011, 13248, 13, 11],
            [2011, 13249, 12, 9],
            [2011, 13250, 18, 15],
            [2011, 13251, 20, 16],
            [2011, 13252, 23, 18],
            [2011, 13253, 20, 16],
            [2011, 13254, 12, 10],
            [2011, 13255, 12, 11],
            [2011, 13256, 15, 13],
            [2011, 13257, 15, 13],
            [2011, 13258, 21, 20],
            [2011, 13259, 22, 17],
            [2011, 13260, 18, 13],
            [2011, 13261, 16, 13],
            [2011, 13262, 21, 16],
            [2011, 13263, 17, 15],
            [2011, 13264, 16, 14],
            [2011, 13265, 29, 19],
            [2011, 13266, 14, 11],
            [2011, 13267, 39, 30],
            [2011, 13268, 14, 13],
            [2011, 13269, 18, 14],
            [2011, 13270, 20, 16],
            [2011, 13271, 18, 14],
            [2011, 13272, 10, 9],
            [2011, 13273, 14, 12],
            [2011, 13274, 12, 11],
            [2011, 13275, 14, 12],
            [2011, 13276, 12, 10],
            [2011, 13277, 20, 15],
            [2011, 13278, 13, 11],
            [2011, 13279, 39, 21],
            [2011, 13280, 17, 13],
            [2011, 13281, 14, 13],
            [2011, 13282, 15, 12],
            [2011, 13283, 23, 18],
            [2011, 13284, 21, 20],
            [2011, 13285, 14, 12],
            [2011, 13286, 26, 16],
            [2011, 13287, 17, 15],
            [2011, 13288, 20, 17],
            [2011, 13289, 21, 20],
            [2011, 13290, 9, 9],
            [2011, 13291, 18, 16],
            [2011, 13292, 9, 8],
            [2011, 13293, 18, 20],
            [2011, 13294, 14, 12],
            [2011, 13295, 30, 17],
            [2011, 13296, 17, 17],
            [2011, 13297, 14, 11],
            [2011, 13298, 18, 16],
            [2011, 13299, 12, 14],
            [2011, 13300, 13, 15],
            [2011, 13301, 17, 17],
            [2011, 13302, 18, 17],
            [2011, 13303, 13, 15],
            [2011, 13304, 22, 16],
            [2011, 13305, 16, 14],
            [2011, 13306, 8, 8],
            [2011, 13307, 35, 34],
            [2011, 13308, 17, 15],
            [2011, 13309, 11, 10],
            [2011, 13310, 17, 13],
            [2011, 13311, 12, 10],
            [2011, 13312, 17, 15],
            [2011, 13313, 56, 27],
            [2011, 13314, 40, 25],
            [2011, 13315, 17, 15],
            [2011, 13316, 12, 10],
            [2011, 13317, 12, 9],
            [2011, 13318, 10, 10],
            [2011, 13319, 19, 16],
            [2011, 13320, 30, 23],
            [2011, 13321, 15, 16],
            [2011, 13322, 14, 12],
            [2011, 13323, 39, 27],
            [2011, 13324, 9, 8],
            [2011, 13325, 16, 16],
            [2011, 13326, 18, 14],
            [2011, 13327, 21, 13],
            [2011, 13328, 15, 14],
            [2011, 13329, 15, 16],
            [2011, 13330, 15, 14],
            [2011, 13331, 27, 19],
            [2011, 13332, 14, 14],
            [2011, 13333, 14, 16],
            [2011, 13334, 12, 11],
            [2011, 13335, 46, 30],
            [2011, 13336, 16, 14],
            [2011, 13337, 8, 8],
            [2011, 13338, 16, 14],
            [2011, 13339, 12, 10],
            [2011, 13340, 15, 15],
            [2011, 13341, 11, 10],
            [2011, 13342, 11, 10],
            [2011, 13343, 15, 13],
            [2011, 13344, 14, 11],
            [2011, 13345, 25, 17],
            [2011, 13346, 11, 8],
            [2011, 13347, 23, 21],
            [2011, 13348, 18, 17],
            [2011, 13349, 37, 23],
            [2011, 13350, 16, 15],
            [2011, 13351, 9, 8],
            [2011, 13352, 13, 12],
            [2011, 13353, 16, 14],
            [2011, 13354, 14, 12],
            [2011, 13355, 15, 11],
            [2011, 13356, 11, 9],
            [2011, 13357, 25, 19],
            [2011, 13358, 16, 16],
            [2011, 13359, 38, 22],
            [2011, 13360, 11, 9],
            [2011, 13361, 37, 23],
            [2011, 13362, 14, 14],
            [2011, 13363, 21, 17],
            [2011, 13364, 12, 12],
            [2011, 13365, 12, 9],
            [2011, 13366, 12, 12],
            [2011, 13367, 12, 9],
            [2011, 13368, 23, 18],
            [2011, 13369, 17, 14],
            [2011, 13370, 16, 12],
            [2011, 13371, 18, 18],
            [2011, 13372, 18, 13],
            [2011, 13373, 12, 10],
            [2011, 13374, 14, 13],
            [2011, 13375, 16, 13],
            [2011, 13376, 10, 11],
            [2011, 13377, 16, 13],
            [2011, 13378, 13, 10],
            [2011, 13379, 14, 12],
            [2011, 13380, 21, 16],
            [2011, 13381, 10, 9],
            [2011, 13382, 16, 13],
            [2011, 13383, 15, 14],
            [2011, 13384, 20, 17],
            [2011, 13385, 9, 8],
            [2011, 13386, 29, 17],
            [2011, 13387, 17, 17],
            [2011, 13388, 15, 14],
            [2011, 13389, 14, 13],
            [2011, 13390, 15, 13],
            [2011, 13391, 13, 12],
            [2011, 13392, 21, 14],
            [2011, 13393, 31, 29],
            [2011, 13394, 14, 12],
            [2011, 13395, 15, 11],
            [2011, 13396, 56, 27],
            [2011, 13397, 9, 8],
            [2011, 13398, 33, 23],
            [2011, 13399, 14, 12],
            [2011, 13400, 25, 17],
            [2011, 13401, 14, 13],
            [2011, 13402, 29, 15],
            [2011, 13403, 18, 16],
            [2011, 13404, 25, 19],
            [2011, 13405, 46, 21],
            [2011, 13406, 11, 10],
            [2011, 13407, 18, 19],
            [2011, 13408, 29, 25],
            [2011, 13409, 20, 17],
            [2011, 13410, 31, 19],
            [2011, 13411, 11, 11],
            [2011, 13412, 51, 29],
            [2011, 13413, 25, 19],
            [2011, 13414, 27, 19],
            [2011, 13415, 19, 15],
            [2011, 13416, 19, 15],
            [2011, 13417, 12, 11],
            [2011, 13418, 10, 9],
            [2011, 13419, 56, 27],
            [2011, 13420, 14, 11],
            [2011, 13421, 20, 13],
            [2011, 13422, 31, 18],
            [2011, 13423, 14, 14],
            [2011, 13424, 39, 18],
            [2011, 13425, 19, 18],
            [2011, 13426, 25, 18],
            [2011, 13427, 31, 25],
            [2011, 13428, 56, 19],
            [2011, 13429, 21, 21],
            [2011, 13430, 25, 27],
            [2011, 13431, 41, 25],
            [2011, 13432, 13, 12],
            [2011, 13433, 23, 17],
            [2011, 13434, 33, 19],
            [2011, 13435, 21, 19],
            [2011, 13436, 21, 20],
            [2011, 13437, 8, 8],
            [2011, 13438, 27, 19],
            [2011, 13439, 11, 10],
            [2011, 13440, 11, 10],
            [2011, 13441, 13, 14],
            [2011, 13442, 51, 25],
            [2011, 13443, 35, 30],
            [2011, 13444, 75, 23],
            [2011, 13445, 16, 12],
            [2011, 13446, 19, 16],
            [2011, 13447, 45, 30],
            [2011, 13448, 31, 31],
            [2011, 13449, 12, 10],
            [2011, 13450, 9, 9],
            [2011, 13451, 9, 7],
            [2011, 13452, 8, 8],
            [2011, 13453, 9, 9],
            [2011, 13454, 22, 15],
            [2011, 13455, 16, 13],
            [2011, 13456, 7, 7],
            [2011, 13457, 7, 7],
            [2011, 13458, 12, 11],
            [2011, 13459, 9, 8],
            [2011, 13460, 10, 8],
            [2011, 13461, 9, 7],
            [2011, 13462, 9, 7],
            [2011, 13463, 16, 11],
            [2011, 13464, 17, 9],
            [2011, 13465, 11, 11],
            [2011, 13466, 10, 9],
            [2011, 13467, 10, 9],
            [2011, 13468, 10, 9],
            [2011, 13469, 11, 9],
            [2011, 13470, 13, 11],
            [2011, 13471, 13, 10],
            [2011, 13472, 15, 9],
            [2011, 13473, 11, 9],
            [2011, 13474, 11, 9],
            [2011, 13475, 12, 10],
            [2011, 13476, 7, 8],
            [2011, 13477, 15, 12],
            [2011, 13478, 7, 8],
            [2011, 13479, 13, 10],
            [2011, 13480, 4, 4],
            [2011, 13481, 9, 8],
            [2011, 13482, 14, 11],
            [2011, 13483, 10, 11],
            [2011, 13484, 10, 9],
            [2011, 13485, 9, 9],
            [2011, 13486, 3, 4],
            [2011, 13487, 18, 13],
            [2011, 13488, 9, 6],
            [2011, 13489, 16, 11],
            [2011, 13490, 7, 8],
            [2011, 13491, 9, 9],
            [2011, 13492, 7, 7],
            [2011, 13493, 8, 6],
            [2011, 13494, 12, 8],
            [2011, 13495, 10, 9],
            [2011, 13496, 10, 10],
            [2011, 13497, 12, 9],
            [2011, 13498, 9, 8],
            [2011, 13499, 15, 10],
            [2011, 13500, 6, 6],
            [2011, 13501, 17, 11],
            [2011, 13502, 8, 7],
            [2011, 13503, 14, 10],
            [2011, 13504, 7, 6],
            [2011, 13505, 7, 6],
            [2011, 13506, 12, 9],
            [2011, 13507, 5, 5],
            [2011, 13508, 12, 10],
            [2011, 13509, 5, 6],
            [2011, 13510, 6, 6],
            [2011, 13511, 17, 12],
            [2011, 13512, 10, 8],
            [2011, 13513, 14, 11],
            [2011, 13514, 12, 10],
            [2011, 13515, 12, 10],
            [2011, 13516, 8, 7],
            [2011, 13517, 7, 7],
            [2011, 13518, 7, 7],
            [2011, 13519, 11, 9],
            [2011, 13520, 12, 11],
            [2011, 13521, 8, 8],
            [2011, 13522, 9, 9],
            [2011, 13523, 11, 11],
            [2011, 13524, 7, 7],
            [2011, 13525, 14, 11],
            [2011, 13526, 9, 7],
            [2011, 13527, 15, 12],
            [2011, 13528, 8, 8],
            [2011, 13529, 7, 7],
            [2011, 13530, 7, 6],
            [2011, 13531, 7, 6],
            [2011, 13532, 7, 6],
            [2011, 13533, 7, 6],
            [2011, 13534, 7, 6],
            [2011, 13535, 17, 13],
            [2011, 13536, 9, 9],
            [2011, 13537, 6, 6],
            [2011, 13538, 6, 6],
            [2011, 13539, 6, 6],
            [2011, 13540, 6, 6],
            [2011, 13541, 9, 9],
            [2011, 13542, 9, 8],
            [2011, 13543, 10, 9],
            [2011, 13544, 10, 10],
            [2011, 13545, 9, 8],
            [2011, 13546, 8, 7],
            [2011, 13547, 8, 9],
            [2011, 13548, 16, 11],
            [2011, 13549, 9, 8],
            [2011, 13550, 21, 13],
            [2011, 13551, 5, 6],
            [2011, 13552, 13, 11],
            [2011, 13553, 6, 7],
            [2011, 13554, 8, 6],
            [2011, 13555, 9, 7],
            [2011, 13556, 8, 9],
            [2011, 13557, 3, 3],
            [2011, 13558, 20, 13],
            [2011, 13559, 4, 4],
            [2011, 13560, 8, 8],
            [2011, 13561, 11, 8],
            [2011, 13562, 9, 9],
            [2011, 13563, 8, 6],
            [2011, 13564, 13, 10],
            [2011, 13565, 9, 8],
            [2011, 13566, 12, 12],
            [2011, 13567, 9, 9],
            [2011, 13568, 4, 5],
            [2011, 13569, 9, 8],
            [2011, 13570, 7, 8],
            [2011, 13571, 11, 9],
            [2011, 13572, 6, 6],
            [2011, 13573, 7, 7],
            [2011, 13574, 10, 9],
            [2011, 13575, 13, 10],
            [2011, 13576, 7, 7],
            [2011, 13577, 7, 7],
            [2011, 13578, 8, 8],
            [2011, 13579, 21, 14],
            [2011, 13580, 10, 7],
            [2011, 13581, 6, 7],
            [2011, 13582, 8, 7],
            [2011, 13583, 10, 9],
            [2011, 13584, 39, 18],
            [2011, 13585, 7, 8],
            [2011, 13586, 7, 6],
            [2011, 13587, 7, 7],
            [2011, 13588, 18, 12],
            [2011, 13589, 7, 7],
            [2011, 13590, 15, 12],
            [2011, 13591, 7, 7],
            [2011, 13592, 7, 7],
            [2011, 13593, 7, 8],
            [2011, 13594, 15, 12],
            [2011, 13595, 10, 7],
            [2011, 13596, 12, 11],
            [2011, 13597, 10, 7],
            [2011, 13598, 8, 7],
            [2011, 13599, 7, 8],
            [2011, 13600, 9, 8],
            [2011, 13601, 7, 7],
            [2011, 13602, 7, 7],
            [2011, 13603, 7, 7],
            [2011, 13604, 12, 10],
            [2011, 13605, 10, 9],
            [2011, 13606, 10, 11],
            [2011, 13607, 9, 7],
            [2011, 13608, 10, 10],
            [2011, 13609, 41, 41],
            [2011, 13610, 35, 35],
            [2011, 13611, 19, 20],
            [2011, 13612, 60, 31],
            [2011, 13613, 110, 46],
            [2011, 13614, 35, 35],
            [2011, 13615, 61, 37],
            [2011, 13616, 15, 15],
            [2011, 13617, 41, 46],
            [2011, 13618, 50, 50],
            [2011, 13619, 45, 64],
            [2011, 13620, 41, 40],
            [2011, 13621, 45, 41],
            [2011, 13622, 50, 38],
            [2011, 13623, 60, 40],
            [2011, 13624, 34, 21],
            [2011, 13625, 25, 27],
            [2011, 13626, 31, 27],
            [2011, 13627, 41, 46],
            [2011, 13628, 40, 41],
            [2011, 13629, 51, 46],
            [2011, 13630, 41, 40],
            [2011, 13631, 50, 51],
            [2011, 13633, 31, 20],
            [2011, 13634, 45, 35],
            [2011, 13635, 40, 41],
            [2011, 13636, 20, 20],
            [2011, 13637, 81, 63],
            [2011, 13638, 71, 50],
            [2011, 13639, 12, 13],
            [2011, 13640, 61, 59],
            [2011, 13641, 44, 24],
            [2011, 13642, 78, 41],
            [2011, 13643, 23, 31],
            [2011, 13644, 61, 41],
            [2011, 13645, 69, 49],
            [2011, 13646, 35, 46],
            [2011, 13647, 52, 31],
            [2011, 13648, 55, 42],
            [2011, 13649, 65, 41],
            [2011, 13650, 9, 9],
            [2011, 13651, 51, 41],
            [2011, 13652, 73, 55],
            [2011, 13653, 9, 9],
            [2011, 13654, 9, 9],
            [2011, 13655, 35, 35],
            [2011, 13656, 80, 50],
            [2011, 13657, 28, 26],
            [2011, 13658, 91, 53],
            [2011, 13659, 45, 35],
            [2011, 13660, 40, 40],
            [2011, 13661, 41, 33],
            [2011, 13662, 50, 35],
            [2011, 13663, 26, 25],
            [2011, 13664, 50, 45],
            [2011, 13665, 51, 44],
            [2011, 13666, 35, 35],
            [2011, 13667, 45, 33],
            [2011, 13668, 12, 11],
            [2011, 13669, 46, 34],
            [2011, 13670, 55, 35],
            [2011, 13671, 51, 30],
            [2011, 13672, 55, 40],
            [2011, 13673, 94, 45],
            [2011, 13674, 45, 35],
            [2011, 13675, 35, 30],
            [2011, 13676, 41, 30],
            [2011, 13677, 17, 21],
            [2011, 13678, 16, 20],
            [2011, 13679, 10, 16],
            [2011, 13680, 11, 15],
            [2011, 13681, 17, 17],
            [2011, 13682, 9, 10],
            [2011, 13683, 19, 19],
            [2011, 13684, 33, 20],
            [2011, 13685, 35, 19],
            [2011, 13686, 23, 20],
            [2011, 13687, 39, 27],
            [2011, 13688, 21, 15],
            [2011, 13689, 25, 15],
            [2011, 13690, 16, 16],
            [2011, 13691, 61, 23],
            [2011, 13692, 21, 23],
            [2011, 13693, 17, 16],
            [2011, 13694, 31, 23],
            [2011, 13695, 27, 23],
            [2011, 13696, 15, 16],
            [2011, 13697, 56, 23],
            [2011, 13698, 23, 18],
            [2011, 13699, 41, 19],
            [2011, 13700, 51, 25],
            [2011, 13701, 18, 19],
            [2011, 13702, 31, 16],
            [2011, 13703, 35, 23],
            [2011, 13704, 41, 21],
            [2011, 13705, 15, 17],
            [2011, 13706, 35, 19],
            [2011, 13707, 46, 27],
            [2011, 13708, 20, 20],
            [2011, 13709, 41, 25],
            [2011, 13710, 25, 20],
            [2011, 13711, 29, 20],
            [2011, 13712, 41, 20],
            [2011, 13713, 51, 37],
            [2011, 13714, 15, 18],
            [2011, 13715, 37, 25],
            [2011, 13716, 27, 18],
            [2011, 13717, 31, 35],
            [2011, 13718, 19, 20],
            [2011, 13719, 41, 23],
            [2011, 13720, 31, 23],
            [2011, 13721, 25, 12],
            [2011, 13722, 29, 27],
            [2011, 13723, 41, 33],
            [2011, 13724, 41, 21],
            [2011, 13725, 41, 16],
            [2011, 13726, 25, 12],
            [2011, 13727, 51, 29],
            [2011, 13728, 27, 20],
            [2011, 13729, 25, 14],
            [2011, 13730, 46, 37],
            [2011, 13731, 46, 23],
            [2011, 13732, 61, 35],
            [2011, 13733, 37, 20],
            [2011, 13734, 31, 15],
            [2011, 13735, 31, 14],
            [2011, 13736, 39, 23],
            [2011, 13737, 41, 21],
            [2011, 13738, 23, 21],
            [2011, 13739, 41, 31],
            [2011, 13740, 41, 13],
            [2011, 13741, 15, 15],
            [2011, 13742, 41, 23],
            [2011, 13743, 39, 21],
            [2011, 13744, 46, 19],
            [2011, 13745, 10, 10],
            [2011, 13746, 21, 23],
            [2011, 13747, 15, 16],
            [2011, 13748, 21, 18],
            [2011, 13749, 12, 12],
            [2011, 13750, 23, 21],
            [2011, 13751, 9, 10],
            [2011, 13752, 10, 14],
            [2011, 13753, 16, 17],
            [2011, 13754, 20, 19],
            [2011, 13755, 13, 14],
            [2011, 13756, 11, 10],
            [2011, 13757, 17, 19],
            [2011, 13758, 11, 10],
            [2011, 13759, 9, 9],
            [2011, 13760, 10, 11],
            [2011, 13761, 13, 10],
            [2011, 13762, 10, 12],
            [2011, 13763, 10, 10],
            [2011, 13764, 8, 8],
            [2011, 13765, 19, 10],
            [2011, 13766, 14, 14],
            [2011, 13767, 16, 14],
            [2011, 13768, 15, 11],
            [2011, 13769, 11, 11],
            [2011, 13770, 16, 18],
            [2011, 13771, 13, 14],
            [2011, 13772, 13, 10],
            [2011, 13773, 17, 14],
            [2011, 13774, 9, 8],
            [2011, 13775, 10, 13],
            [2011, 13776, 11, 12],
            [2011, 13777, 10, 10],
            [2011, 13778, 18, 18],
            [2011, 13779, 15, 11],
            [2011, 13780, 10, 15],
            [2011, 13781, 19, 18],
            [2011, 13782, 20, 25],
            [2011, 13783, 21, 37],
            [2011, 13784, 20, 36],
            [2011, 13785, 17, 21],
            [2011, 13786, 18, 25],
            [2011, 13787, 7, 5],
            [2011, 13788, 6, 6],
            [2011, 13789, 10, 7],
            [2011, 13790, 10, 10],
            [2011, 13791, 8, 7],
            [2011, 13792, 13, 12],
            [2011, 13793, 9, 9],
            [2011, 13794, 14, 12],
            [2011, 13795, 8, 7],
            [2011, 13796, 11, 11],
            [2011, 13797, 11, 10],
            [2011, 13798, 9, 8],
            [2011, 13799, 18, 14],
            [2011, 13800, 8, 8],
            [2011, 13801, 8, 6],
            [2011, 13802, 10, 9],
            [2011, 13803, 12, 9],
            [2011, 13804, 13, 14],
            [2011, 13805, 7, 6],
            [2011, 13806, 11, 9],
            [2011, 13807, 7, 7],
            [2011, 13808, 7, 5],
            [2011, 13809, 13, 9],
            [2011, 13810, 7, 6],
            [2011, 13811, 10, 10],
            [2011, 13812, 10, 9],
            [2011, 13813, 10, 10],
            [2011, 13814, 13, 12],
            [2011, 13815, 12, 11],
            [2011, 13816, 13, 10],
            [2011, 13817, 13, 10],
            [2011, 13818, 10, 9],
            [2011, 13819, 10, 8],
            [2011, 13820, 9, 7],
            [2011, 13821, 7, 6],
            [2011, 13822, 7, 6],
            [2011, 13823, 7, 6],
            [2011, 13824, 11, 9],
            [2011, 13825, 6, 5],
            [2011, 13826, 8, 6],
            [2011, 13827, 7, 6],
            [2011, 13828, 12, 10],
            [2011, 13829, 9, 9],
            [2011, 13830, 7, 7],
            [2011, 13831, 9, 9],
            [2011, 13832, 9, 8],
            [2011, 13833, 13, 14],
            [2011, 13834, 8, 7],
            [2011, 13835, 10, 10],
            [2011, 13836, 11, 9],
            [2011, 13837, 10, 9],
            [2011, 13838, 10, 9],
            [2011, 13839, 12, 12],
            [2011, 13840, 7, 6],
            [2011, 13841, 9, 8],
            [2011, 13842, 10, 10],
            [2011, 13843, 10, 9],
            [2011, 13844, 6, 6],
            [2011, 13845, 8, 8],
            [2011, 13846, 8, 7],
            [2011, 13847, 6, 6],
            [2011, 13848, 8, 7],
            [2011, 13849, 11, 9],
            [2011, 13850, 11, 9],
            [2011, 13851, 13, 14],
            [2011, 13852, 9, 9],
            [2011, 13853, 13, 11],
            [2011, 13854, 17, 15],
            [2011, 13855, 18, 17],
            [2011, 13856, 9, 8],
            [2011, 13857, 9, 8],
            [2011, 13858, 8, 7],
            [2011, 13859, 8, 7],
            [2011, 13860, 8, 7],
            [2011, 13861, 8, 6],
            [2011, 13862, 12, 9],
            [2011, 13863, 7, 7],
            [2011, 13864, 6, 6],
            [2011, 13865, 9, 7],
            [2011, 13866, 7, 7],
            [2011, 13867, 7, 7],
            [2011, 13868, 6, 6],
            [2011, 13869, 10, 7],
            [2011, 13870, 7, 6],
            [2011, 13871, 6, 6],
            [2011, 13872, 8, 6],
            [2011, 13873, 8, 6],
            [2011, 13874, 12, 9],
            [2011, 13875, 9, 7],
            [2011, 13876, 18, 11],
            [2011, 13877, 11, 11],
            [2011, 13878, 7, 7],
            [2011, 13879, 7, 6],
            [2011, 13880, 8, 6],
            [2011, 13881, 9, 6],
            [2011, 13882, 7, 8],
            [2011, 13883, 14, 9],
            [2011, 13884, 7, 8],
            [2011, 13885, 10, 8],
            [2011, 13886, 8, 7],
            [2011, 13887, 7, 6],
            [2011, 13888, 11, 11],
            [2011, 13889, 6, 5],
            [2011, 13890, 10, 8],
            [2011, 13891, 9, 8],
            [2011, 13892, 8, 8],
            [2011, 13893, 12, 14],
            [2011, 13894, 6, 7],
            [2011, 13895, 8, 7],
            [2011, 13896, 6, 7],
            [2011, 13897, 8, 8],
            [2011, 13898, 8, 8],
            [2011, 13899, 10, 8],
            [2011, 13900, 11, 9],
            [2011, 13901, 18, 11],
            [2011, 13902, 8, 8],
            [2011, 13903, 13, 10],
            [2011, 13904, 8, 6],
            [2011, 13905, 10, 9],
            [2011, 13906, 14, 10],
            [2011, 13907, 13, 10],
            [2011, 13908, 10, 9],
            [2011, 13909, 14, 11],
            [2011, 13910, 11, 8],
            [2011, 13911, 8, 8],
            [2011, 13912, 11, 9],
            [2011, 13913, 8, 9],
            [2011, 13914, 9, 9],
            [2011, 13915, 8, 8],
            [2011, 13916, 6, 7],
            [2011, 13917, 7, 7],
            [2011, 13918, 9, 8],
            [2011, 13919, 10, 9],
            [2011, 13920, 13, 10],
            [2011, 13921, 15, 9],
            [2011, 13922, 9, 9],
            [2011, 13923, 8, 7],
            [2011, 13924, 12, 11],
            [2011, 13925, 7, 8],
            [2011, 13926, 8, 8],
            [2011, 13927, 8, 8],
            [2011, 13928, 7, 6],
            [2011, 13929, 7, 7],
            [2011, 13930, 7, 6],
            [2011, 13931, 11, 10],
            [2011, 13932, 9, 7],
            [2011, 13933, 9, 8],
            [2011, 13934, 11, 11],
            [2011, 13935, 7, 7],
            [2011, 13936, 7, 7],
            [2011, 13937, 12, 14],
            [2011, 13938, 7, 7],
            [2011, 13939, 8, 7],
            [2011, 13940, 8, 7],
            [2011, 13941, 10, 9],
            [2011, 13942, 10, 9],
            [2011, 13943, 11, 9],
            [2011, 13944, 8, 8],
            [2011, 13945, 10, 9],
            [2011, 13946, 13, 11],
            [2011, 13947, 14, 11],
            [2011, 13948, 7, 6],
            [2011, 13949, 7, 7],
            [2011, 13950, 10, 9],
            [2011, 13951, 7, 7],
            [2011, 13952, 12, 10],
            [2011, 13953, 12, 11],
            [2011, 13954, 8, 8],
            [2011, 13955, 10, 9],
            [2011, 13956, 10, 9],
            [2011, 13957, 8, 8],
            [2011, 13958, 7, 7],
            [2011, 13959, 9, 8],
            [2011, 13960, 12, 11],
            [2011, 13961, 9, 8],
            [2011, 13962, 11, 11],
            [2011, 13963, 8, 8],
            [2011, 13964, 7, 7],
            [2011, 13965, 7, 7],
            [2011, 13966, 10, 8],
            [2011, 13967, 7, 7],
            [2011, 13968, 7, 7],
            [2011, 13969, 7, 6],
            [2011, 13970, 8, 9],
            [2011, 13971, 8, 7],
            [2011, 13972, 10, 9],
            [2011, 13973, 7, 7],
            [2011, 13974, 8, 7],
            [2011, 13975, 9, 7],
            [2011, 13976, 10, 9],
            [2011, 13977, 7, 8],
            [2011, 13978, 11, 11],
            [2011, 13979, 7, 7],
            [2011, 13980, 7, 6],
            [2011, 13981, 7, 7],
            [2011, 13982, 7, 7],
            [2011, 13983, 13, 10],
            [2011, 13984, 9, 8],
            [2011, 13985, 15, 9],
            [2011, 13986, 8, 8],
            [2011, 13987, 7, 7],
            [2011, 13988, 9, 8],
            [2011, 13989, 8, 7],
            [2011, 13990, 7, 7],
            [2011, 13991, 7, 7],
            [2011, 13992, 7, 7],
            [2011, 13993, 9, 8],
            [2011, 13994, 8, 8],
            [2011, 13995, 14, 12],
            [2011, 13996, 8, 8],
            [2011, 13997, 7, 7],
            [2011, 13998, 7, 7],
            [2011, 13999, 12, 11],
            [2011, 14000, 12, 11],
            [2011, 14001, 12, 9],
            [2011, 14002, 7, 7],
            [2011, 14003, 7, 7],
            [2011, 14004, 7, 7],
            [2011, 14005, 35, 20],
            [2011, 14006, 12, 8],
            [2011, 14007, 15, 12],
            [2011, 14008, 12, 9],
            [2011, 14009, 15, 8],
            [2011, 14010, 10, 8],
            [2011, 14011, 11, 12],
            [2011, 14012, 11, 12],
            [2011, 14013, 12, 12],
            [2011, 14014, 30, 20],
            [2011, 14015, 19, 13],
            [2011, 14016, 14, 12],
            [2011, 14017, 28, 17],
            [2011, 14018, 9, 9],
            [2011, 14019, 8, 7],
            [2011, 14020, 8, 7],
            [2011, 14021, 14, 9],
            [2011, 14022, 9, 9],
            [2011, 14023, 28, 20],
            [2011, 14024, 16, 18],
            [2011, 14025, 13, 15],
            [2011, 14026, 21, 17],
            [2011, 14027, 12, 11],
            [2011, 14028, 12, 11],
            [2011, 14029, 14, 14],
            [2011, 14030, 24, 16],
            [2011, 14031, 28, 22],
            [2011, 14032, 15, 13],
            [2011, 14033, 15, 13],
            [2011, 14034, 16, 15],
            [2011, 14035, 24, 17],
            [2011, 14036, 13, 11],
            [2011, 14037, 21, 14],
            [2011, 14038, 13, 11],
            [2011, 14039, 21, 13],
            [2011, 14040, 20, 16],
            [2011, 14041, 30, 22],
            [2011, 14042, 21, 18],
            [2011, 14043, 14, 11],
            [2011, 14044, 10, 10],
            [2011, 14045, 10, 10],
            [2011, 14046, 9, 15],
            [2011, 14047, 19, 15],
            [2011, 14048, 19, 15],
            [2011, 14049, 28, 15],
            [2011, 14050, 19, 15],
            [2011, 14051, 24, 18],
            [2011, 14052, 13, 11],
            [2011, 14053, 14, 11],
            [2011, 14054, 16, 16],
            [2011, 14055, 29, 16],
            [2011, 14056, 30, 16],
            [2011, 14057, 17, 14],
            [2011, 14058, 17, 14],
            [2011, 14059, 13, 14],
            [2011, 14060, 17, 14],
            [2011, 14061, 17, 18],
            [2011, 14062, 14, 21],
            [2011, 14063, 21, 13],
            [2011, 14064, 17, 14],
            [2011, 14065, 21, 13],
            [2011, 14066, 15, 12],
            [2011, 14067, 18, 21],
            [2011, 14068, 15, 11],
            [2011, 14069, 14, 15],
            [2011, 14070, 21, 27],
            [2011, 14071, 21, 23],
            [2011, 14072, 14, 11],
            [2011, 14073, 21, 21],
            [2011, 14074, 19, 25],
            [2011, 14075, 23, 15],
            [2011, 14076, 23, 16],
            [2011, 14077, 16, 12],
            [2011, 14078, 18, 13],
            [2011, 14079, 14, 12],
            [2011, 14080, 21, 15],
            [2011, 14081, 23, 16],
            [2011, 14082, 25, 17],
            [2011, 14083, 18, 10],
            [2011, 14084, 18, 13],
            [2011, 14085, 17, 13],
            [2011, 14086, 23, 18],
            [2011, 14087, 19, 15],
            [2011, 14088, 15, 12],
            [2011, 14089, 16, 12],
            [2011, 14090, 16, 16],
            [2011, 14091, 21, 17],
            [2011, 14092, 18, 10],
            [2011, 14093, 17, 10],
            [2011, 14094, 12, 10],
            [2011, 14095, 18, 19],
            [2011, 14096, 17, 16],
            [2011, 14097, 18, 13],
            [2011, 14098, 20, 13],
            [2011, 14099, 20, 14],
            [2011, 14100, 18, 12],
            [2011, 14101, 28, 15],
            [2011, 14102, 20, 12],
            [2011, 14103, 17, 17],
            [2011, 14104, 12, 12],
            [2011, 14105, 21, 16],
            [2011, 14106, 17, 12],
            [2011, 14107, 15, 12],
            [2011, 14108, 18, 13],
            [2011, 14109, 18, 12],
            [2011, 14110, 21, 13],
            [2011, 14111, 21, 18],
            [2011, 14112, 18, 13],
            [2011, 14113, 16, 16],
            [2011, 14114, 16, 15],
            [2011, 14115, 20, 17],
            [2011, 14116, 20, 19],
            [2011, 14117, 33, 16],
            [2011, 14118, 24, 19],
            [2011, 14119, 37, 28],
            [2011, 14120, 18, 15],
            [2011, 14121, 25, 16],
            [2011, 14122, 21, 17],
            [2011, 14123, 22, 16],
            [2011, 14124, 11, 12],
            [2011, 14125, 23, 22],
            [2011, 14126, 17, 15],
            [2011, 14127, 17, 15],
            [2011, 14128, 13, 12],
            [2011, 14129, 11, 12],
            [2011, 14130, 19, 19],
            [2011, 14131, 56, 24],
            [2011, 14132, 23, 16],
            [2011, 14133, 12, 13],
            [2011, 14134, 17, 15],
            [2011, 14135, 21, 16],
            [2011, 14136, 18, 14],
            [2011, 14137, 31, 15],
            [2011, 14138, 35, 16],
            [2011, 14139, 25, 18],
            [2011, 14140, 35, 18],
            [2011, 14141, 34, 22],
            [2011, 14142, 15, 16],
            [2011, 14143, 24, 17],
            [2011, 14144, 18, 13],
            [2011, 14145, 24, 16],
            [2011, 14146, 48, 17],
            [2011, 14147, 14, 16],
            [2011, 14148, 15, 12],
            [2011, 14149, 21, 15],
            [2011, 14150, 13, 13],
            [2011, 14151, 17, 13],
            [2011, 14152, 25, 15],
            [2011, 14153, 15, 18],
            [2011, 14154, 20, 14],
            [2011, 14155, 12, 11],
            [2011, 14156, 19, 16],
            [2011, 14157, 33, 22],
            [2011, 14158, 17, 14],
            [2011, 14159, 28, 18],
            [2011, 14160, 17, 15],
            [2011, 14161, 13, 12],
            [2011, 14162, 18, 16],
            [2011, 14163, 12, 13],
            [2011, 14164, 19, 16],
            [2011, 14165, 17, 14],
            [2011, 14166, 30, 16],
            [2011, 14167, 14, 14],
            [2011, 14168, 18, 15],
            [2011, 14169, 12, 12],
            [2011, 14170, 11, 12],
            [2011, 14171, 40, 18],
            [2011, 14172, 26, 22],
            [2011, 14173, 12, 16],
            [2011, 14174, 30, 20],
            [2011, 14175, 25, 40],
            [2011, 14176, 11, 13],
            [2011, 14177, 17, 14],
            [2011, 14178, 12, 12],
            [2011, 14179, 26, 25],
            [2011, 14180, 24, 16],
            [2011, 14181, 25, 22],
            [2011, 14182, 18, 16],
            [2011, 14183, 11, 12],
            [2011, 14184, 32, 13],
            [2011, 14185, 30, 14],
            [2011, 14186, 27, 14],
            [2011, 14187, 12, 15],
            [2011, 14188, 17, 20],
            [2011, 14189, 17, 14],
            [2011, 14190, 10, 12],
            [2011, 14191, 17, 20],
            [2011, 14192, 36, 26],
            [2011, 14193, 21, 28],
            [2011, 14194, 11, 12],
            [2011, 14195, 11, 11],
            [2011, 14196, 50, 25],
            [2011, 14197, 19, 18],
            [2011, 14198, 10, 14],
            [2011, 14199, 16, 18],
            [2011, 14200, 21, 14],
            [2011, 14201, 13, 14],
            [2011, 14202, 11, 12],
            [2011, 14203, 13, 12],
            [2011, 14204, 12, 12],
            [2011, 14205, 24, 16],
            [2011, 14206, 15, 15],
            [2011, 14207, 18, 16],
            [2011, 14208, 15, 14],
            [2011, 14209, 27, 16],
            [2011, 14210, 28, 16],
            [2011, 14211, 25, 21],
            [2011, 14212, 12, 13],
            [2011, 14213, 30, 21],
            [2011, 14214, 11, 11],
            [2011, 14215, 22, 16],
            [2011, 14216, 16, 16],
            [2011, 14217, 17, 18],
            [2011, 14218, 14, 12],
            [2011, 14219, 12, 13],
            [2011, 14220, 18, 17],
            [2011, 14221, 15, 14],
            [2011, 14222, 30, 20],
            [2011, 14223, 20, 15],
            [2011, 14224, 17, 18],
            [2011, 14225, 20, 18],
            [2011, 14226, 32, 14],
            [2011, 14227, 18, 15],
            [2011, 14228, 17, 20],
            [2011, 14229, 16, 16],
            [2011, 14230, 24, 14],
            [2011, 14231, 20, 13],
            [2011, 14232, 12, 12],
            [2011, 14233, 18, 18],
            [2011, 14234, 21, 20],
            [2011, 14235, 20, 16],
            [2011, 14236, 41, 28],
            [2011, 14237, 15, 14],
            [2011, 14238, 17, 15],
            [2011, 14239, 23, 20],
            [2011, 14240, 9, 8],
            [2011, 14241, 17, 11],
            [2011, 14242, 30, 18],
            [2011, 14243, 9, 8],
            [2011, 14244, 28, 17],
            [2011, 14245, 21, 17],
            [2011, 14246, 23, 19],
            [2011, 14247, 33, 20],
            [2011, 14248, 18, 14],
            [2011, 14249, 38, 21],
            [2011, 14250, 29, 19],
            [2011, 14251, 12, 10],
            [2011, 14252, 33, 19],
            [2011, 14253, 32, 18],
            [2011, 14254, 17, 13],
            [2011, 14255, 22, 15],
            [2011, 14256, 17, 13],
            [2011, 14257, 25, 16],
            [2011, 14258, 17, 12],
            [2011, 14259, 29, 17],
            [2011, 14260, 19, 13],
            [2011, 14261, 28, 17],
            [2011, 14262, 30, 19],
            [2011, 14263, 18, 14],
            [2011, 14264, 30, 17],
            [2011, 14265, 31, 18],
            [2011, 14266, 22, 17],
            [2011, 14267, 9, 8],
            [2011, 14268, 9, 8],
            [2011, 14269, 34, 20],
            [2011, 14270, 13, 10],
            [2011, 14271, 12, 10],
            [2011, 14272, 10, 8],
            [2011, 14273, 30, 18],
            [2011, 14274, 22, 16],
            [2011, 14275, 29, 16],
            [2011, 14276, 18, 14],
            [2011, 14277, 11, 8],
            [2011, 14278, 11, 10],
            [2011, 14279, 10, 8],
            [2011, 14280, 25, 16],
            [2011, 14281, 13, 9],
            [2011, 14282, 16, 11],
            [2011, 14283, 14, 9],
            [2011, 14284, 29, 17],
            [2011, 14285, 25, 15],
            [2011, 14286, 27, 17],
            [2011, 14287, 19, 14],
            [2011, 14288, 20, 13],
            [2011, 14289, 29, 17],
            [2011, 14290, 34, 21],
            [2011, 14291, 21, 15],
            [2011, 14292, 23, 14],
            [2011, 14293, 18, 11],
            [2011, 14294, 25, 15],
            [2011, 14295, 26, 15],
            [2011, 14296, 29, 17],
            [2011, 14297, 25, 17],
            [2011, 14298, 16, 10],
            [2011, 14299, 24, 17],
            [2011, 14300, 10, 8],
            [2011, 14301, 12, 10],
            [2011, 14302, 12, 10],
            [2011, 14303, 27, 17],
            [2011, 14304, 20, 13],
            [2011, 14305, 32, 19],
            [2011, 14306, 31, 19],
            [2011, 14307, 9, 8],
            [2011, 14308, 24, 15],
            [2011, 14309, 13, 11],
            [2011, 14310, 25, 16],
            [2011, 14311, 26, 17],
            [2011, 14312, 28, 18],
            [2011, 14313, 18, 11],
            [2011, 14314, 27, 17],
            [2011, 14315, 23, 16],
            [2011, 14316, 24, 16],
            [2011, 14317, 19, 15],
            [2011, 14318, 30, 19],
            [2011, 14319, 16, 12],
            [2011, 14320, 12, 10],
            [2011, 14321, 28, 18],
            [2011, 14322, 19, 15],
            [2011, 14323, 26, 17],
            [2011, 14324, 22, 16],
            [2011, 14325, 40, 17],
            [2011, 14326, 10, 8],
            [2011, 14327, 31, 17],
            [2011, 14328, 21, 14],
            [2011, 14329, 27, 17],
            [2011, 14330, 25, 16],
            [2011, 14331, 25, 17],
            [2011, 14332, 13, 10],
            [2011, 14333, 15, 11],
            [2011, 14334, 30, 17],
            [2011, 14335, 26, 18],
            [2011, 14336, 14, 12],
            [2011, 14337, 15, 12],
            [2011, 14338, 25, 16],
            [2011, 14339, 10, 8],
            [2011, 14340, 13, 9],
            [2011, 14341, 28, 18],
            [2011, 14342, 32, 20],
            [2011, 14343, 27, 17],
            [2011, 14344, 32, 17],
            [2011, 14345, 28, 18],
            [2011, 14346, 31, 18],
            [2011, 14347, 14, 12],
            [2011, 14348, 32, 17],
            [2011, 14349, 20, 14],
            [2011, 14350, 16, 12],
            [2011, 14351, 11, 8],
            [2011, 14352, 28, 17],
            [2011, 14353, 24, 16],
            [2011, 14354, 32, 19],
            [2011, 14355, 24, 17],
            [2011, 14356, 13, 11],
            [2011, 14357, 25, 16],
            [2011, 14358, 17, 13],
            [2011, 14359, 31, 17],
            [2011, 14360, 13, 11],
            [2011, 14361, 27, 17],
            [2011, 14362, 24, 16],
            [2011, 14363, 31, 19],
            [2011, 14364, 26, 16],
            [2011, 14365, 21, 15],
            [2011, 14366, 29, 18],
            [2011, 14367, 35, 19],
            [2011, 14368, 31, 19],
            [2011, 14369, 32, 18],
            [2011, 14370, 13, 11],
            [2011, 14371, 9, 8],
            [2011, 14372, 14, 11],
            [2011, 14373, 27, 18],
            [2011, 14374, 29, 16],
            [2011, 14375, 27, 16],
            [2011, 14376, 9, 8],
            [2011, 14377, 9, 8],
            [2011, 14378, 9, 8],
            [2011, 14379, 31, 19],
            [2011, 14380, 27, 17],
            [2011, 14381, 28, 18],
            [2011, 14382, 28, 18],
            [2011, 14383, 15, 11],
            [2011, 14384, 32, 16],
            [2011, 14385, 31, 17],
            [2011, 14386, 29, 18],
            [2011, 14387, 30, 21],
            [2011, 14388, 41, 24],
            [2011, 14389, 28, 17],
            [2011, 14390, 27, 18],
            [2011, 14391, 16, 11],
            [2011, 14392, 27, 18],
            [2011, 14393, 17, 12],
            [2011, 14394, 32, 18],
            [2011, 14395, 31, 19],
            [2011, 14396, 24, 16],
            [2011, 14397, 26, 17],
            [2011, 14398, 25, 17],
            [2011, 14399, 36, 19],
            [2011, 14400, 34, 21],
            [2011, 14401, 26, 16],
            [2011, 14402, 15, 11],
            [2011, 14403, 29, 18],
            [2011, 14404, 31, 17],
            [2011, 14405, 42, 20],
            [2011, 14406, 42, 24],
            [2011, 14407, 31, 19],
            [2011, 14408, 21, 16],
            [2011, 14409, 30, 17],
            [2011, 14410, 14, 12],
            [2011, 14411, 21, 14],
            [2011, 14412, 19, 12],
            [2011, 14413, 12, 10],
            [2011, 14414, 9, 8],
            [2011, 14415, 27, 18],
            [2011, 14416, 19, 15],
            [2011, 14417, 22, 17],
            [2011, 14418, 27, 17],
            [2011, 14419, 32, 18],
            [2011, 14420, 17, 13],
            [2011, 14421, 36, 18],
            [2011, 14422, 24, 14],
            [2011, 14423, 19, 13],
            [2011, 14424, 18, 14],
            [2011, 14425, 37, 23],
            [2011, 14426, 20, 15],
            [2011, 14427, 28, 17],
            [2011, 14428, 27, 17],
            [2011, 14429, 23, 15],
            [2011, 14430, 29, 18],
            [2011, 14431, 12, 10],
            [2011, 14432, 26, 17],
            [2011, 14433, 40, 23],
            [2011, 14434, 22, 13],
            [2011, 14435, 14, 16],
            [2011, 14436, 27, 26],
            [2011, 14437, 31, 27],
            [2011, 14438, 10, 30],
            [2011, 14439, 15, 33],
            [2011, 14440, 10, 25],
            [2011, 14441, 30, 25],
            [2011, 14442, 10, 15],
            [2011, 14443, 33, 31],
            [2011, 14444, 15, 21],
            [2011, 14445, 13, 25],
            [2011, 14446, 13, 21],
            [2011, 14447, 10, 15],
            [2011, 14448, 27, 31],
            [2011, 14449, 15, 25],
            [2011, 14450, 45, 28],
            [2011, 14451, 20, 20],
            [2011, 14452, 16, 27],
            [2011, 14453, 13, 35],
            [2011, 14454, 20, 20],
            [2011, 14455, 37, 28],
            [2011, 14456, 56, 45],
            [2011, 14457, 31, 31],
            [2011, 14458, 19, 30],
            [2011, 14459, 15, 20],
            [2011, 14460, 20, 20],
            [2011, 14461, 33, 33],
            [2011, 14462, 10, 25],
            [2011, 14463, 15, 20],
            [2011, 14464, 16, 20],
            [2011, 14465, 21, 15],
            [2011, 14466, 18, 20],
            [2011, 14467, 20, 33],
            [2011, 14468, 15, 24],
            [2011, 14469, 20, 20],
            [2011, 14470, 25, 24],
            [2011, 14471, 13, 19],
            [2011, 14472, 33, 33],
            [2011, 14473, 27, 23],
            [2011, 14474, 20, 30],
            [2011, 14475, 18, 20],
            [2011, 14476, 16, 20],
            [2011, 14477, 13, 20],
            [2011, 14478, 23, 24],
            [2011, 14479, 16, 20],
            [2011, 14480, 20, 20],
            [2011, 14481, 46, 40],
            [2011, 14482, 10, 20],
            [2011, 14483, 20, 25],
            [2011, 14484, 15, 25],
            [2011, 14485, 15, 20],
            [2011, 14486, 23, 20],
            [2011, 14487, 15, 30],
            [2011, 14488, 15, 20],
            [2011, 14489, 15, 20],
            [2011, 14490, 19, 20],
            [2011, 14491, 15, 20],
            [2011, 14492, 25, 28],
            [2011, 14493, 20, 27],
            [2011, 14494, 20, 33],
            [2011, 14495, 12, 20],
            [2011, 14496, 20, 26],
            [2011, 14497, 27, 29],
            [2011, 14498, 41, 35],
            [2011, 14499, 23, 24],
            [2011, 14500, 12, 23],
            [2011, 14501, 10, 20],
            [2011, 14502, 21, 20],
            [2011, 14503, 15, 20],
            [2011, 14504, 15, 27],
            [2011, 14505, 23, 23],
            [2011, 14506, 15, 20],
            [2011, 14507, 20, 29],
            [2011, 14508, 12, 20],
            [2011, 14509, 22, 19],
            [2011, 14510, 23, 20],
            [2011, 14511, 20, 33],
            [2011, 14512, 15, 21],
            [2011, 14513, 20, 21],
            [2011, 14514, 27, 31],
            [2011, 14515, 15, 20],
            [2011, 14516, 33, 31],
            [2011, 14517, 20, 31],
            [2011, 14518, 15, 20],
            [2011, 14519, 22, 24],
            [2011, 14520, 15, 30],
            [2011, 14521, 51, 46],
            [2011, 14522, 37, 35],
            [2011, 14523, 27, 20],
            [2011, 14524, 12, 18],
            [2011, 14525, 15, 31],
            [2011, 14526, 29, 31],
            [2011, 14527, 20, 33],
            [2011, 14528, 46, 39],
            [2011, 14529, 46, 35],
            [2011, 14530, 33, 31],
            [2011, 14531, 20, 23],
            [2011, 14532, 13, 12],
            [2011, 14533, 15, 14],
            [2011, 14534, 21, 14],
            [2011, 14535, 12, 8],
            [2011, 14536, 21, 16],
            [2011, 14537, 21, 18],
            [2011, 14538, 27, 16],
            [2011, 14539, 7, 10],
            [2011, 14540, 18, 13],
            [2011, 14541, 22, 18],
            [2011, 14542, 18, 13],
            [2011, 14543, 18, 15],
            [2011, 14544, 10, 11],
            [2011, 14545, 20, 18],
            [2011, 14546, 21, 18],
            [2011, 14547, 21, 16],
            [2011, 14548, 22, 19],
            [2011, 14549, 28, 18],
            [2011, 14550, 19, 17],
            [2011, 14551, 22, 16],
            [2011, 14552, 9, 10],
            [2011, 14553, 16, 19],
            [2011, 14554, 18, 12],
            [2011, 14555, 14, 16],
            [2011, 14556, 27, 21],
            [2011, 14557, 25, 22],
            [2011, 14558, 12, 11],
            [2011, 14559, 12, 11],
            [2011, 14560, 12, 13],
            [2011, 14561, 10, 10],
            [2011, 14562, 96, 34],
            [2011, 14563, 110, 35],
            [2011, 14564, 24, 19],
            [2011, 14565, 20, 45],
            [2011, 14566, 16, 22],
            [2011, 14567, 24, 41],
            [2011, 14568, 80, 80],
            [2011, 14569, 20, 18],
            [2011, 14570, 20, 24],
            [2011, 14571, 16, 17],
            [2011, 14572, 16, 23],
            [2011, 14573, 100, 85],
            [2011, 14574, 12, 11],
            [2011, 14575, 9, 7],
            [2011, 14576, 9, 9],
            [2011, 14577, 37, 25],
            [2011, 14578, 23, 19],
            [2011, 14579, 17, 14],
            [2011, 14580, 9, 9],
            [2011, 14581, 9, 11],
            [2011, 14582, 27, 29],
            [2011, 14583, 21, 18],
            [2011, 14584, 7, 8],
            [2011, 14585, 11, 11],
            [2011, 14586, 11, 13],
            [2011, 14587, 14, 13],
            [2011, 14588, 27, 18],
            [2011, 14589, 9, 10],
            [2011, 14590, 21, 18],
            [2011, 14591, 20, 17],
            [2011, 14592, 2, 2],
            [2011, 14593, 53, 39],
            [2011, 14594, 4, 5],
            [2011, 14595, 9, 9],
            [2011, 14596, 5, 5],
            [2011, 14597, 9, 9],
            [2011, 14598, 15, 9],
            [2011, 14599, 17, 9],
            [2011, 14600, 32, 19],
            [2011, 14601, 8, 8],
            [2011, 14602, 21, 19],
            [2011, 14603, 12, 10],
            [2011, 14604, 12, 10],
            [2011, 14605, 18, 18],
            [2011, 14606, 6, 7],
            [2011, 14607, 6, 6],
            [2011, 14608, 9, 9],
            [2011, 14609, 11, 10],
            [2011, 14610, 4, 4],
            [2011, 14611, 6, 7],
            [2011, 14612, 7, 7],
            [2011, 14613, 21, 19],
            [2011, 14614, 22, 17],
            [2011, 14615, 16, 16],
            [2011, 14616, 13, 13],
            [2011, 14617, 36, 27],
            [2011, 14618, 8, 8],
            [2011, 14619, 18, 15],
            [2011, 14620, 13, 13],
            [2011, 14621, 9, 8],
            [2011, 14622, 14, 12],
            [2011, 14623, 16, 12],
            [2011, 14624, 10, 9],
            [2011, 14625, 13, 11],
            [2011, 14626, 9, 10],
            [2011, 14627, 31, 21],
            [2011, 14628, 17, 17],
            [2011, 14629, 25, 19],
            [2011, 14630, 7, 7],
            [2011, 14631, 6, 5],
            [2011, 14632, 35, 25],
            [2011, 14633, 32, 29],
            [2011, 14634, 10, 10],
            [2011, 14635, 7, 7],
            [2011, 14636, 17, 13],
            [2011, 14637, 15, 13],
            [2011, 14638, 20, 12],
            [2011, 14639, 6, 6],
            [2011, 14640, 10, 7],
            [2011, 14641, 17, 16],
            [2011, 14642, 27, 17],
            [2011, 14643, 6, 7],
            [2011, 14644, 6, 7],
            [2011, 14645, 15, 13],
            [2011, 14646, 9, 10],
            [2011, 14647, 24, 16],
            [2011, 14648, 4, 5],
            [2011, 14649, 13, 12],
            [2011, 14650, 15, 14],
            [2011, 14651, 15, 13],
            [2011, 14652, 19, 16],
            [2011, 14653, 24, 16],
            [2011, 14654, 26, 20],
            [2011, 14655, 4, 4],
            [2011, 14656, 12, 12],
            [2011, 14657, 7, 6],
            [2011, 14658, 17, 13],
            [2011, 14659, 15, 12],
            [2011, 14660, 15, 17],
            [2011, 14661, 9, 12],
            [2011, 14662, 20, 15],
            [2011, 14663, 17, 16],
            [2011, 14664, 9, 9],
            [2011, 14665, 12, 11],
            [2011, 14666, 12, 11],
            [2011, 14667, 19, 15],
            [2011, 14668, 16, 15],
            [2011, 14669, 31, 27],
            [2011, 14670, 15, 14],
            [2011, 14671, 17, 16],
            [2011, 14672, 14, 15],
            [2011, 14673, 23, 19],
            [2011, 14674, 11, 10],
            [2011, 14675, 9, 9],
            [2011, 14676, 14, 12],
            [2011, 14677, 13, 11],
            [2011, 14678, 18, 12],
            [2011, 14679, 14, 14],
            [2011, 14680, 19, 15],
            [2011, 14681, 16, 12],
            [2011, 14682, 12, 10],
            [2011, 14683, 17, 13],
            [2011, 14684, 35, 23],
            [2011, 14685, 14, 9],
            [2011, 14686, 12, 9],
            [2011, 14687, 21, 15],
            [2011, 14688, 6, 7],
            [2011, 14689, 12, 12],
            [2011, 14690, 21, 19],
            [2011, 14691, 16, 13],
            [2011, 14692, 17, 18],
            [2011, 14693, 11, 9],
            [2011, 14694, 9, 7],
            [2011, 14695, 11, 9],
            [2011, 14696, 9, 9],
            [2011, 14697, 14, 12],
            [2011, 14698, 17, 9],
            [2011, 14699, 23, 17],
            [2011, 14700, 25, 19],
            [2011, 14701, 41, 23],
            [2011, 14702, 51, 37],
            [2011, 14703, 41, 26],
            [2011, 14704, 81, 51],
            [2011, 14705, 33, 23],
            [2011, 14706, 56, 29],
            [2011, 14707, 19, 13],
            [2011, 14708, 27, 19],
            [2011, 14709, 39, 25],
            [2011, 14710, 39, 21],
            [2011, 14711, 42, 27],
            [2011, 14712, 51, 31],
            [2011, 14713, 46, 29],
            [2011, 14714, 37, 23],
            [2011, 14715, 21, 13],
            [2011, 14716, 18, 12],
            [2011, 14717, 20, 14],
            [2011, 14718, 29, 27],
            [2011, 14719, 27, 21],
            [2011, 14720, 81, 51],
            [2011, 14721, 61, 35],
            [2011, 14722, 41, 27],
            [2011, 14723, 18, 13],
            [2011, 14724, 27, 23],
            [2011, 14725, 33, 29],
            [2011, 14726, 31, 25],
            [2011, 14727, 56, 27],
            [2011, 14728, 46, 31],
            [2011, 14729, 37, 29],
            [2011, 14730, 33, 25],
            [2011, 14731, 27, 25],
            [2011, 14732, 61, 31],
            [2011, 14733, 46, 25],
            [2011, 14734, 41, 46],
            [2011, 14735, 61, 37],
            [2011, 14736, 56, 33],
            [2011, 14737, 19, 13],
            [2011, 14738, 39, 27],
            [2011, 14739, 27, 23],
            [2011, 14740, 46, 37],
            [2011, 14741, 37, 25],
            [2011, 14742, 31, 31],
            [2011, 14743, 29, 19],
            [2011, 14744, 18, 13],
            [2011, 14745, 38, 35],
            [2011, 14746, 21, 15],
            [2011, 14747, 37, 29],
            [2011, 14748, 27, 23],
            [2011, 14749, 19, 13],
            [2011, 14750, 31, 21],
            [2011, 14751, 39, 23],
            [2011, 14752, 29, 21],
            [2011, 14753, 46, 31],
            [2011, 14754, 25, 23],
            [2011, 14755, 29, 29],
            [2011, 14756, 29, 23],
            [2011, 14757, 25, 15],
            [2011, 14758, 37, 21],
            [2011, 14759, 41, 27],
            [2011, 14760, 41, 29],
            [2011, 14761, 27, 13],
            [2011, 14762, 18, 13],
            [2011, 14763, 33, 46],
            [2011, 14764, 66, 39],
            [2011, 14765, 19, 13],
            [2011, 14766, 56, 35],
            [2011, 14767, 37, 37],
            [2011, 14768, 5, 5],
            [2011, 14769, 51, 31],
            [2011, 14770, 21, 25],
            [2011, 14771, 35, 46],
            [2011, 14772, 66, 46],
            [2011, 14773, 46, 56],
            [2011, 14774, 35, 23],
            [2011, 14775, 41, 39],
            [2011, 14776, 51, 41],
            [2011, 14777, 25, 29],
            [2011, 14778, 16, 13],
            [2011, 14779, 51, 29],
            [2011, 14780, 46, 15],
            [2011, 14781, 11, 11],
            [2011, 14782, 71, 37],
            [2011, 14783, 33, 29],
            [2011, 14784, 18, 29],
            [2011, 14785, 81, 56],
            [2011, 14786, 31, 21],
            [2011, 14787, 31, 20],
            [2011, 14788, 31, 29],
            [2011, 14789, 91, 51],
            [2011, 14790, 61, 25],
            [2011, 14791, 16, 15],
            [2011, 14792, 81, 66],
            [2011, 14793, 46, 29],
            [2011, 14794, 35, 35],
            [2011, 14795, 37, 29],
            [2011, 14796, 41, 61],
            [2011, 14797, 31, 71],
            [2011, 14798, 31, 56],
            [2011, 14799, 56, 29],
            [2011, 14800, 16, 11],
            [2011, 14801, 35, 17],
            [2011, 14802, 25, 15],
            [2011, 14803, 41, 41],
            [2011, 14804, 16, 13],
            [2011, 14805, 41, 41],
            [2011, 14806, 18, 15],
            [2011, 14807, 46, 31],
            [2011, 14808, 61, 61],
            [2011, 14809, 18, 33],
            [2011, 14810, 19, 21],
            [2011, 14811, 19, 25],
            [2011, 14812, 56, 46],
            [2011, 14813, 31, 25],
            [2011, 14814, 46, 29],
            [2011, 14815, 71, 33],
            [2011, 14816, 16, 14],
            [2011, 14817, 16, 11],
            [2011, 14818, 16, 11],
            [2011, 14819, 41, 37],
            [2011, 14820, 81, 71],
            [2011, 14821, 25, 21],
            [2011, 14822, 56, 51],
            [2011, 14823, 23, 23],
            [2011, 14824, 71, 51],
            [2011, 14825, 19, 20],
            [2011, 14826, 51, 23],
            [2011, 14827, 56, 46],
            [2011, 14828, 61, 51],
            [2011, 14829, 19, 21],
            [2011, 14830, 16, 18],
            [2011, 14831, 35, 21],
            [2011, 14832, 51, 46],
            [2011, 14833, 46, 35],
            [2011, 14834, 51, 56],
            [2011, 14835, 66, 25],
            [2011, 14836, 56, 27],
            [2011, 14837, 71, 46],
            [2011, 14838, 71, 56],
            [2011, 14839, 35, 41],
            [2011, 14840, 35, 29],
            [2011, 14841, 27, 25],
            [2011, 14842, 21, 18],
            [2011, 14843, 71, 46],
            [2011, 14844, 19, 20],
            [2011, 14845, 61, 61],
            [2011, 14846, 39, 20],
            [2011, 14847, 16, 14],
            [2011, 14848, 16, 11],
            [2011, 14849, 16, 11],
            [2011, 14850, 51, 33],
            [2011, 14851, 21, 27],
            [2011, 14852, 16, 12],
            [2011, 14853, 31, 27],
            [2011, 14854, 71, 56],
            [2011, 14855, 11, 11],
            [2011, 14856, 11, 11],
            [2011, 14857, 11, 11],
            [2011, 14858, 20, 18],
            [2011, 14859, 30, 27],
            [2011, 14860, 20, 20],
            [2011, 14861, 16, 17],
            [2011, 14862, 22, 16],
            [2011, 14863, 12, 12],
            [2011, 14864, 12, 12],
            [2011, 14865, 24, 30],
            [2011, 14866, 25, 25],
            [2011, 14867, 16, 30],
            [2011, 14868, 30, 27],
            [2011, 14869, 27, 32],
            [2011, 14870, 12, 11],
            [2011, 14871, 12, 11],
            [2011, 14872, 12, 11],
            [2011, 14873, 34, 24],
            [2011, 14874, 25, 20],
            [2011, 14875, 30, 32],
            [2011, 14876, 16, 17],
            [2011, 14877, 53, 43],
            [2011, 14878, 13, 17],
            [2011, 14879, 25, 25],
            [2011, 14880, 25, 14],
            [2011, 14881, 29, 28],
            [2011, 14882, 30, 30],
            [2011, 14883, 13, 20],
            [2011, 14884, 12, 13],
            [2011, 14885, 12, 13],
            [2011, 14886, 30, 21],
            [2011, 14887, 23, 15],
            [2011, 14888, 14, 14],
            [2011, 14889, 30, 25],
            [2011, 14890, 20, 16],
            [2011, 14891, 25, 30],
            [2011, 14892, 30, 35],
            [2011, 14893, 22, 37],
            [2011, 14894, 17, 19],
            [2011, 14895, 26, 20],
            [2011, 14896, 45, 41],
            [2011, 14897, 24, 25],
            [2011, 14898, 38, 28],
            [2011, 14899, 17, 15],
            [2011, 14900, 14, 13],
            [2011, 14901, 12, 13],
            [2011, 14902, 22, 26],
            [2011, 14903, 27, 22],
            [2011, 14904, 30, 26],
            [2011, 14905, 35, 29],
            [2011, 14906, 16, 16],
            [2011, 14907, 11, 11],
            [2011, 14908, 11, 11],
            [2011, 14909, 11, 11],
            [2011, 14910, 20, 22],
            [2011, 14911, 24, 24],
            [2011, 14912, 24, 23],
            [2011, 14913, 16, 18],
            [2011, 14914, 18, 19],
            [2011, 14915, 28, 25],
            [2011, 14916, 30, 21],
            [2011, 14917, 25, 29],
            [2011, 14918, 36, 40],
            [2011, 14919, 15, 15],
            [2011, 14920, 30, 32],
            [2011, 14921, 18, 16],
            [2011, 14922, 13, 14],
            [2011, 14923, 23, 22],
            [2011, 14924, 25, 30],
            [2011, 14925, 24, 20],
            [2011, 14926, 31, 39],
            [2011, 14927, 26, 35],
            [2011, 14928, 24, 30],
            [2011, 14929, 24, 27],
            [2011, 14930, 24, 25],
            [2011, 14931, 14, 14],
            [2011, 14932, 17, 15],
            [2011, 14933, 21, 20],
            [2011, 14934, 39, 39],
            [2011, 14935, 15, 30],
            [2011, 14936, 12, 12],
            [2011, 14937, 12, 12],
            [2011, 14938, 32, 32],
            [2011, 14939, 38, 32],
            [2011, 14940, 14, 12],
            [2011, 14941, 42, 38],
            [2011, 14942, 13, 12],
            [2011, 14943, 24, 18],
            [2011, 14944, 18, 18],
            [2011, 14945, 35, 35],
            [2011, 14946, 15, 15],
            [2011, 14947, 19, 20],
            [2011, 14948, 42, 33],
            [2011, 14949, 42, 32],
            [2011, 14950, 15, 13],
            [2011, 14951, 27, 20],
            [2011, 14952, 45, 25],
            [2011, 14953, 22, 22],
            [2011, 14954, 32, 27],
            [2011, 14955, 19, 14],
            [2011, 14956, 30, 28],
            [2011, 14957, 16, 16],
            [2011, 14958, 19, 40],
            [2011, 14959, 15, 14],
            [2011, 14960, 25, 20],
            [2011, 14961, 21, 24],
            [2011, 14962, 25, 32],
            [2011, 14963, 24, 28],
            [2011, 14964, 17, 17],
            [2011, 14965, 12, 11],
            [2011, 14966, 12, 11],
            [2011, 14967, 20, 21],
            [2011, 14968, 26, 30],
            [2011, 14969, 12, 14],
            [2011, 14970, 12, 14],
            [2011, 14971, 15, 13],
            [2011, 14972, 36, 34],
            [2011, 14973, 23, 22],
            [2011, 14974, 26, 20],
            [2011, 14975, 19, 13],
            [2011, 14976, 28, 20],
            [2011, 14977, 25, 18],
            [2011, 14978, 27, 40],
            [2011, 14979, 21, 18],
            [2011, 14980, 30, 30],
            [2011, 14981, 22, 19],
            [2011, 14982, 13, 14],
            [2011, 14983, 33, 27],
            [2011, 14984, 21, 14],
            [2011, 14985, 21, 20],
            [2011, 14986, 40, 40],
            [2011, 14987, 30, 28],
            [2011, 14988, 22, 24],
            [2011, 14989, 15, 20],
            [2011, 14990, 13, 12],
            [2011, 14991, 8, 7],
            [2011, 14992, 1, 1],
            [2011, 14993, 10, 9],
            [2011, 14994, 10, 6],
            [2011, 14995, 7, 6],
            [2011, 14996, 7, 6],
            [2011, 14997, 29, 20],
            [2011, 14998, 7, 4],
            [2011, 14999, 7, 7],
            [2011, 15000, 19, 17],
            [2011, 15001, 12, 12],
            [2011, 15002, 7, 7],
            [2011, 15003, 18, 16],
            [2011, 15004, 4, 4],
            [2011, 15005, 18, 16],
            [2011, 15006, 15, 14],
            [2011, 15007, 8, 4],
            [2011, 15008, 1, 1],
            [2011, 15009, 16, 14],
            [2011, 15010, 10, 9],
            [2011, 15011, 6, 5],
            [2011, 15012, 1, 1],
            [2011, 15013, 10, 10],
            [2011, 15014, 10, 8],
            [2011, 15015, 16, 15],
            [2011, 15016, 1, 1],
            [2011, 15017, 9, 7],
            [2011, 15018, 13, 12],
            [2011, 15019, 7, 6],
            [2011, 15020, 15, 13],
            [2011, 15021, 7, 5],
            [2011, 15022, 10, 9],
            [2011, 15023, 11, 9],
            [2011, 15024, 10, 9],
            [2011, 15025, 8, 6],
            [2011, 15026, 11, 9],
            [2011, 15027, 7, 6],
            [2011, 15028, 11, 10],
            [2011, 15029, 13, 11],
            [2011, 15030, 8, 5],
            [2011, 15031, 7, 4],
            [2011, 15032, 7, 4],
            [2011, 15033, 4, 2],
            [2011, 15034, 7, 7],
            [2011, 15035, 12, 10],
            [2011, 15036, 9, 8],
            [2011, 15037, 11, 7],
            [2011, 15038, 20, 20],
            [2011, 15039, 13, 10],
            [2011, 15040, 10, 10],
            [2011, 15041, 1, 1],
            [2011, 15042, 11, 8],
            [2011, 15043, 16, 14],
            [2011, 15044, 9, 8],
            [2011, 15045, 8, 6],
            [2011, 15046, 2, 1],
            [2011, 15047, 7, 5],
            [2011, 15048, 15, 15],
            [2011, 15049, 9, 6],
            [2011, 15050, 7, 5],
            [2011, 15051, 15, 13],
            [2011, 15052, 10, 7],
            [2011, 15053, 17, 14],
            [2011, 15054, 9, 8],
            [2011, 15055, 8, 7],
            [2011, 15056, 11, 10],
            [2011, 15057, 7, 5],
            [2011, 15058, 7, 5],
            [2011, 15059, 2, 1],
            [2011, 15060, 3, 1],
            [2011, 15061, 8, 6],
            [2011, 15062, 9, 8],
            [2011, 15063, 1, 1],
            [2011, 15064, 1, 1],
            [2011, 15065, 1, 1],
            [2011, 15066, 9, 8],
            [2011, 15067, 8, 7],
            [2011, 15068, 17, 15],
            [2011, 15069, 11, 10],
            [2011, 15070, 23, 20],
            [2011, 15071, 6, 6],
            [2011, 15072, 14, 13],
            [2011, 15073, 9, 7],
            [2011, 15074, 10, 9],
            [2011, 15075, 1, 1],
            [2011, 15076, 1, 1],
            [2011, 15077, 29, 20],
            [2011, 15078, 8, 6],
            [2011, 15079, 2, 1],
            [2011, 15080, 12, 10],
            [2011, 15081, 29, 20],
            [2011, 15082, 7, 5],
            [2011, 15083, 1, 1],
            [2011, 15084, 7, 6],
            [2011, 15085, 9, 9],
            [2011, 15086, 12, 9],
            [2011, 15087, 7, 6],
            [2011, 15088, 16, 13],
            [2011, 15089, 23, 18],
            [2011, 15090, 21, 16],
            [2011, 15091, 13, 12],
            [2011, 15092, 18, 10],
            [2011, 15093, 15, 9],
            [2011, 15094, 10, 8],
            [2011, 15095, 20, 15],
            [2011, 15096, 15, 10],
            [2011, 15097, 13, 12],
            [2011, 15098, 16, 13],
            [2011, 15099, 21, 15],
            [2011, 15100, 11, 10],
            [2011, 15101, 12, 10],
            [2011, 15102, 16, 9],
            [2011, 15103, 14, 8],
            [2011, 15104, 12, 6],
            [2011, 15105, 12, 10],
            [2011, 15106, 15, 7],
            [2011, 15107, 9, 7],
            [2011, 15108, 22, 14],
            [2011, 15109, 22, 14],
            [2011, 15110, 6, 5],
            [2011, 15111, 15, 10],
            [2011, 15112, 23, 14],
            [2011, 15113, 24, 13],
            [2011, 15114, 10, 8],
            [2011, 15115, 9, 8],
            [2011, 15116, 10, 8],
            [2011, 15117, 11, 8],
            [2011, 15118, 8, 7],
            [2011, 15119, 6, 5],
            [2011, 15120, 8, 7],
            [2011, 15121, 7, 5],
            [2011, 15122, 3, 3],
            [2011, 15123, 3, 3],
            [2011, 15124, 6, 6],
            [2011, 15125, 4, 5],
            [2011, 15126, 7, 7],
            [2011, 15127, 6, 5],
            [2011, 15128, 24, 15],
            [2011, 15129, 7, 5],
            [2011, 15130, 7, 5],
            [2011, 15131, 5, 5],
            [2011, 15132, 26, 18],
            [2011, 15133, 30, 15],
            [2011, 15134, 19, 14],
            [2011, 15135, 21, 12],
            [2011, 15136, 16, 11],
            [2011, 15137, 13, 10],
            [2011, 15138, 18, 10],
            [2011, 15139, 31, 17],
            [2011, 15140, 16, 11],
            [2011, 15141, 12, 8],
            [2011, 15142, 11, 8],
            [2011, 15143, 11, 8],
            [2011, 15144, 18, 9],
            [2011, 15145, 13, 9],
            [2011, 15146, 21, 13],
            [2011, 15147, 9, 6],
            [2011, 15148, 7, 5],
            [2011, 15149, 16, 10],
            [2011, 15150, 15, 9],
            [2011, 15151, 7, 5],
            [2011, 15152, 7, 6],
            [2011, 15153, 18, 10],
            [2011, 15154, 17, 9],
            [2011, 15155, 21, 15],
            [2011, 15156, 15, 9],
            [2011, 15157, 14, 13],
            [2011, 15158, 21, 14],
            [2011, 15159, 7, 7],
            [2011, 15160, 27, 17],
            [2011, 15161, 12, 8],
            [2011, 15162, 17, 9],
            [2011, 15163, 17, 9],
            [2011, 15164, 18, 9],
            [2011, 15165, 27, 11],
            [2011, 15166, 17, 12],
            [2011, 15167, 12, 15],
            [2011, 15168, 23, 15],
            [2011, 15169, 25, 9],
            [2011, 15170, 13, 11],
            [2011, 15171, 13, 7],
            [2011, 15172, 8, 6],
            [2011, 15173, 11, 10],
            [2011, 15174, 11, 7],
            [2011, 15175, 9, 7],
            [2011, 15176, 6, 6],
            [2011, 15177, 24, 13],
            [2011, 15178, 8, 5],
            [2011, 15179, 7, 5],
            [2011, 15180, 9, 6],
            [2011, 15181, 8, 5],
            [2011, 15182, 15, 11],
            [2011, 15183, 20, 11],
            [2011, 15184, 20, 14],
            [2011, 15185, 31, 18],
            [2011, 15186, 17, 12],
            [2011, 15187, 13, 12],
            [2011, 15188, 17, 12],
            [2011, 15189, 15, 14],
            [2011, 15190, 18, 9],
            [2011, 15191, 14, 9],
            [2011, 15192, 11, 9],
            [2011, 15193, 10, 7],
            [2011, 15194, 13, 10],
            [2011, 15195, 18, 16],
            [2011, 15196, 15, 8],
            [2011, 15197, 20, 13],
            [2011, 15198, 16, 12],
            [2011, 15199, 22, 9],
            [2011, 15200, 19, 13],
            [2011, 15201, 14, 10],
            [2011, 15202, 21, 14],
            [2011, 15203, 17, 10],
            [2011, 15204, 17, 10],
            [2011, 15205, 10, 6],
            [2011, 15206, 18, 9],
            [2011, 15207, 11, 8],
            [2011, 15208, 13, 10],
            [2011, 15209, 13, 11],
            [2011, 15210, 11, 10],
            [2011, 15211, 17, 12],
            [2011, 15212, 16, 12],
            [2011, 15213, 31, 20],
            [2011, 15214, 10, 7],
            [2011, 15215, 13, 11],
            [2011, 15216, 15, 10],
            [2011, 15217, 10, 8],
            [2011, 15218, 11, 9],
            [2011, 15219, 14, 9],
            [2011, 15220, 19, 8],
            [2011, 15221, 18, 12],
            [2011, 15222, 22, 12],
            [2011, 15223, 14, 9],
            [2011, 15224, 14, 10],
            [2011, 15225, 10, 9],
            [2011, 15226, 11, 8],
            [2011, 15227, 15, 15],
            [2011, 15228, 17, 14],
            [2011, 15229, 16, 8],
            [2011, 15230, 20, 10],
            [2011, 15231, 10, 11],
            [2011, 15232, 21, 14],
            [2011, 15233, 16, 11],
            [2011, 15234, 17, 13],
            [2011, 15235, 9, 8],
            [2011, 15236, 15, 11],
            [2011, 15237, 18, 10],
            [2011, 15238, 12, 9],
            [2011, 15239, 10, 8],
            [2011, 15240, 12, 8],
            [2011, 15241, 13, 9],
            [2011, 15242, 14, 12],
            [2011, 15243, 19, 10],
            [2011, 15244, 9, 8],
            [2011, 15245, 15, 10],
            [2011, 15246, 20, 14],
            [2011, 15247, 18, 12],
            [2011, 15248, 20, 14],
            [2011, 15249, 14, 8],
            [2011, 15250, 15, 10],
            [2011, 15251, 18, 11],
            [2011, 15252, 17, 14],
            [2011, 15253, 17, 12],
            [2011, 15254, 11, 7],
            [2011, 15255, 12, 12],
            [2011, 15256, 10, 7],
            [2011, 15257, 10, 11],
            [2011, 15258, 12, 7],
            [2011, 15259, 15, 9],
            [2011, 15260, 19, 12],
            [2011, 15261, 15, 9],
            [2011, 15262, 10, 7],
            [2011, 15263, 24, 9],
            [2011, 15264, 20, 14],
            [2011, 15265, 21, 15],
            [2011, 15266, 18, 11],
            [2011, 15267, 16, 10],
            [2011, 15268, 30, 12],
            [2011, 15269, 14, 11],
            [2011, 15270, 16, 7],
            [2011, 15271, 7, 7],
            [2011, 15272, 19, 18],
            [2011, 15273, 14, 6],
            [2011, 15274, 22, 16],
            [2011, 15275, 20, 12],
            [2011, 15276, 17, 11],
            [2011, 15277, 9, 7],
            [2011, 15278, 7, 6],
            [2011, 15279, 21, 17],
            [2011, 15280, 15, 12],
            [2011, 15281, 18, 9],
            [2011, 15282, 28, 15],
            [2011, 15283, 28, 13],
            [2011, 15284, 15, 12],
            [2011, 15285, 11, 10],
            [2011, 15286, 21, 14],
            [2011, 15287, 22, 11],
            [2011, 15288, 18, 8],
            [2011, 15289, 12, 9],
            [2011, 15290, 21, 14],
            [2011, 15291, 9, 6],
            [2011, 15292, 13, 11],
            [2011, 15293, 15, 9],
            [2011, 15294, 22, 15],
            [2011, 15295, 13, 13],
            [2011, 15296, 17, 16],
            [2011, 15297, 19, 14],
            [2011, 15298, 21, 12],
            [2011, 15299, 25, 14],
            [2011, 15300, 24, 14],
            [2011, 15301, 10, 8],
            [2011, 15302, 13, 10],
            [2011, 15303, 10, 6],
            [2011, 15304, 8, 9],
            [2011, 15305, 22, 10],
            [2011, 15306, 6, 6],
            [2011, 15307, 5, 6],
            [2011, 15308, 13, 12],
            [2011, 15309, 10, 9],
            [2011, 15310, 12, 6],
            [2011, 15311, 20, 14],
            [2011, 15312, 14, 11],
            [2011, 15313, 23, 11],
            [2011, 15314, 17, 11],
            [2011, 15315, 16, 11],
            [2011, 15316, 19, 11],
            [2011, 15317, 17, 11],
            [2011, 15318, 10, 8],
            [2011, 15319, 13, 12],
            [2011, 15320, 15, 11],
            [2011, 15321, 9, 5],
            [2011, 15322, 18, 14],
            [2011, 15323, 21, 12],
            [2011, 15324, 16, 12],
            [2011, 15325, 10, 7],
            [2011, 15326, 28, 20],
            [2011, 15327, 14, 11],
            [2011, 15328, 14, 7],
            [2011, 15329, 14, 8],
            [2011, 15330, 10, 6],
            [2011, 15331, 14, 12],
            [2011, 15332, 7, 5],
            [2011, 15333, 10, 7],
            [2011, 15334, 14, 9],
            [2011, 15335, 14, 12],
            [2011, 15336, 20, 13],
            [2011, 15337, 12, 10],
            [2011, 15338, 8, 6],
            [2011, 15339, 16, 9],
            [2011, 15340, 22, 11],
            [2011, 15341, 28, 13],
            [2011, 15342, 22, 14],
            [2011, 15343, 16, 12],
            [2011, 15344, 9, 8],
            [2011, 15345, 10, 8],
            [2011, 15346, 13, 8],
            [2011, 15347, 17, 10],
            [2011, 15348, 17, 10],
            [2011, 15349, 11, 8],
            [2011, 15350, 23, 12],
            [2011, 15351, 19, 9],
            [2011, 15352, 13, 7],
            [2011, 15353, 17, 13],
            [2011, 15354, 21, 14],
            [2011, 15355, 14, 12],
            [2011, 15356, 18, 9],
            [2011, 15357, 15, 14],
            [2011, 15358, 18, 12],
            [2011, 15359, 18, 14],
            [2011, 15360, 17, 17],
            [2011, 15361, 46, 39],
            [2011, 15362, 4, 7],
            [2011, 15363, 6, 7],
            [2011, 15364, 40, 25],
            [2011, 15365, 6, 7],
            [2011, 15366, 15, 18],
            [2011, 15367, 15, 18],
            [2011, 15368, 6, 7],
            [2011, 15369, 12, 10],
            [2011, 15370, 12, 11],
            [2011, 15371, 15, 13],
            [2011, 15372, 15, 11],
            [2011, 15373, 16, 15],
            [2011, 15374, 20, 13],
            [2011, 15375, 12, 10],
            [2011, 15376, 6, 6],
            [2011, 15377, 14, 12],
            [2011, 15378, 18, 12],
            [2011, 15379, 14, 12],
            [2011, 15380, 5, 5],
            [2011, 15381, 18, 13],
            [2011, 15382, 18, 13],
            [2011, 15383, 9, 8],
            [2011, 15384, 6, 6],
            [2011, 15385, 8, 7],
            [2011, 15386, 14, 12],
            [2011, 15387, 8, 7],
            [2011, 15388, 6, 6],
            [2011, 15389, 13, 16],
            [2011, 15390, 15, 12],
            [2011, 15391, 27, 13],
            [2011, 15392, 23, 13],
            [2011, 15393, 6, 6],
            [2011, 15394, 14, 14],
            [2011, 15395, 10, 10],
            [2011, 15396, 7, 6],
            [2011, 15397, 14, 11],
            [2011, 15398, 20, 15],
            [2011, 15399, 16, 13],
            [2011, 15400, 21, 12],
            [2011, 15401, 23, 14],
            [2011, 15402, 9, 8],
            [2011, 15403, 21, 11],
            [2011, 15404, 20, 13],
            [2011, 15405, 23, 13],
            [2011, 15406, 13, 13],
            [2011, 15407, 21, 15],
            [2011, 15408, 21, 13],
            [2011, 15409, 25, 12],
            [2011, 15410, 17, 11],
            [2011, 15411, 7, 6],
            [2011, 15412, 17, 12],
            [2011, 15413, 5, 5],
            [2011, 15414, 13, 10],
            [2011, 15415, 15, 13],
            [2011, 15416, 20, 12],
            [2011, 15417, 19, 11],
            [2011, 15418, 20, 13],
            [2011, 15419, 18, 15],
            [2011, 15420, 9, 8],
            [2012, 964, 11, 10],
            [2012, 2142, 11, 10],
            [2012, 2922, 9, 10],
            [2012, 4536, 13, 12],
            [2012, 5273, 15, 13],
            [2012, 11581, 11, 11],
            [2012, 11582, 13, 14],
            [2012, 12312, 158, 100],
            [2012, 12313, 110, 86],
            [2012, 12314, 110, 86],
            [2012, 12315, 158, 100],
            [2012, 12316, 158, 100],
            [2012, 12317, 158, 100],
            [2012, 12318, 158, 100],
            [2012, 12319, 158, 100],
            [2012, 12320, 110, 86],
            [2012, 12321, 77, 79],
            [2012, 12322, 158, 100],
            [2012, 12323, 158, 100],
            [2012, 12324, 110, 86],
            [2012, 12325, 110, 86],
            [2012, 12523, 22, 11],
            [2012, 12524, 48, 31],
            [2012, 12525, 21, 20],
            [2012, 12526, 14, 15],
            [2012, 12527, 10, 11],
            [2012, 12528, 9, 11],
            [2012, 12529, 10, 11],
            [2012, 12530, 16, 11],
            [2012, 12532, 21, 15],
            [2012, 12534, 10, 11],
            [2012, 12535, 21, 16],
            [2012, 12536, 11, 11],
            [2012, 12537, 11, 11],
            [2012, 12538, 11, 13],
            [2012, 12539, 17, 11],
            [2012, 12540, 17, 17],
            [2012, 12541, 15, 14],
            [2012, 12542, 16, 16],
            [2012, 12543, 21, 21],
            [2012, 12545, 11, 11],
            [2012, 12546, 26, 31],
            [2012, 12547, 21, 21],
            [2012, 12548, 31, 21],
            [2012, 12549, 11, 11],
            [2012, 12550, 11, 11],
            [2012, 12551, 26, 21],
            [2012, 12552, 34, 21],
            [2012, 12553, 15, 14],
            [2012, 12554, 8, 11],
            [2012, 12556, 9, 11],
            [2012, 12557, 10, 16],
            [2012, 12558, 11, 16],
            [2012, 12559, 11, 11],
            [2012, 12560, 4, 6],
            [2012, 12561, 7, 10],
            [2012, 12562, 9, 11],
            [2012, 12563, 15, 11],
            [2012, 12565, 24, 16],
            [2012, 12566, 13, 11],
            [2012, 12567, 11, 11],
            [2012, 12568, 35, 40],
            [2012, 12569, 35, 40],
            [2012, 12570, 18, 21],
            [2012, 12571, 44, 21],
            [2012, 12573, 21, 21],
            [2012, 12574, 10, 11],
            [2012, 12575, 11, 11],
            [2012, 12576, 26, 21],
            [2012, 12577, 10, 11],
            [2012, 12578, 41, 40],
            [2012, 12579, 14, 21],
            [2012, 12580, 16, 16],
            [2012, 12581, 116, 100],
            [2012, 12582, 107, 123],
            [2012, 12583, 142, 155],
            [2012, 12584, 114, 85],
            [2012, 12585, 117, 144],
            [2012, 12589, 66, 56],
            [2012, 12590, 50, 41],
            [2012, 12591, 65, 52],
            [2012, 12592, 73, 61],
            [2012, 12593, 51, 37],
            [2012, 12594, 41, 41],
            [2012, 12595, 71, 68],
            [2012, 12596, 34, 28],
            [2012, 12597, 31, 28],
            [2012, 12598, 66, 56],
            [2012, 12599, 66, 56],
            [2012, 12600, 66, 56],
            [2012, 12639, 11, 9],
            [2012, 12640, 14, 10],
            [2012, 12641, 21, 22],
            [2012, 12642, 21, 22],
            [2012, 12643, 36, 29],
            [2012, 12644, 34, 26],
            [2012, 12645, 57, 51],
            [2012, 12646, 36, 41],
            [2012, 12647, 22, 34],
            [2012, 12648, 33, 30],
            [2012, 12649, 28, 28],
            [2012, 12650, 24, 25],
            [2012, 12651, 37, 32],
            [2012, 12652, 41, 36],
            [2012, 12653, 44, 42],
            [2012, 12654, 21, 22],
            [2012, 12655, 35, 35],
            [2012, 12656, 40, 32],
            [2012, 12657, 21, 22],
            [2012, 12658, 43, 40],
            [2012, 12659, 49, 45],
            [2012, 12660, 47, 38],
            [2012, 12661, 45, 41],
            [2012, 12662, 40, 38],
            [2012, 12663, 39, 33],
            [2012, 12664, 54, 47],
            [2012, 12665, 40, 37],
            [2012, 12667, 13, 12],
            [2012, 12668, 6, 6],
            [2012, 12669, 4, 4],
            [2012, 12670, 7, 8],
            [2012, 12671, 12, 13],
            [2012, 12672, 12, 14],
            [2012, 12673, 12, 15],
            [2012, 12674, 11, 10],
            [2012, 12675, 17, 17],
            [2012, 12676, 15, 15],
            [2012, 12677, 10, 12],
            [2012, 12678, 43, 37],
            [2012, 12679, 17, 16],
            [2012, 12680, 17, 15],
            [2012, 12681, 5, 4],
            [2012, 12682, 16, 14],
            [2012, 12683, 11, 10],
            [2012, 12684, 34, 21],
            [2012, 12685, 39, 32],
            [2012, 12686, 21, 19],
            [2012, 12687, 22, 21],
            [2012, 12688, 22, 20],
            [2012, 12689, 34, 25],
            [2012, 12690, 37, 26],
            [2012, 12691, 40, 26],
            [2012, 12692, 36, 25],
            [2012, 12693, 30, 23],
            [2012, 12694, 29, 22],
            [2012, 12695, 39, 26],
            [2012, 12696, 35, 26],
            [2012, 12697, 38, 26],
            [2012, 12698, 10, 9],
            [2012, 12699, 9, 8],
            [2012, 12700, 10, 9],
            [2012, 12701, 13, 11],
            [2012, 12702, 13, 10],
            [2012, 12703, 32, 40],
            [2012, 12704, 18, 13],
            [2012, 12705, 25, 15],
            [2012, 12706, 27, 26],
            [2012, 12707, 33, 27],
            [2012, 12708, 29, 23],
            [2012, 12709, 36, 26],
            [2012, 12710, 38, 28],
            [2012, 12711, 37, 29],
            [2012, 12712, 40, 36],
            [2012, 12713, 33, 33],
            [2012, 12714, 42, 32],
            [2012, 12715, 42, 36],
            [2012, 12716, 26, 22],
            [2012, 12717, 29, 26],
            [2012, 12718, 23, 19],
            [2012, 12719, 29, 22],
            [2012, 12720, 28, 22],
            [2012, 12721, 29, 19],
            [2012, 12722, 14, 12],
            [2012, 12723, 21, 18],
            [2012, 12724, 14, 12],
            [2012, 12725, 11, 13],
            [2012, 12726, 8, 8],
            [2012, 12727, 21, 24],
            [2012, 12728, 9, 9],
            [2012, 12729, 24, 28],
            [2012, 12730, 23, 13],
            [2012, 12731, 21, 25],
            [2012, 12732, 15, 16],
            [2012, 12733, 15, 13],
            [2012, 12734, 18, 17],
            [2012, 12735, 13, 14],
            [2012, 12736, 15, 17],
            [2012, 12737, 23, 15],
            [2012, 12738, 10, 12],
            [2012, 12739, 14, 16],
            [2012, 12740, 19, 22],
            [2012, 12741, 16, 17],
            [2012, 12742, 7, 7],
            [2012, 12743, 22, 15],
            [2012, 12744, 11, 13],
            [2012, 12745, 13, 15],
            [2012, 12746, 9, 11],
            [2012, 12747, 12, 15],
            [2012, 12748, 8, 12],
            [2012, 12749, 10, 15],
            [2012, 12750, 7, 7],
            [2012, 12751, 6, 8],
            [2012, 12752, 23, 17],
            [2012, 12753, 10, 13],
            [2012, 12754, 9, 9],
            [2012, 12755, 6, 6],
            [2012, 12756, 12, 10],
            [2012, 12757, 6, 7],
            [2012, 12758, 12, 13],
            [2012, 12759, 19, 18],
            [2012, 12760, 25, 17],
            [2012, 12761, 10, 12],
            [2012, 12762, 10, 10],
            [2012, 12763, 15, 21],
            [2012, 12764, 11, 15],
            [2012, 12765, 10, 10],
            [2012, 12766, 12, 15],
            [2012, 12767, 13, 19],
            [2012, 12768, 12, 12],
            [2012, 12769, 16, 10],
            [2012, 12770, 10, 14],
            [2012, 12771, 18, 18],
            [2012, 12772, 11, 11],
            [2012, 12773, 10, 11],
            [2012, 12774, 11, 11],
            [2012, 12775, 19, 24],
            [2012, 12776, 19, 23],
            [2012, 12777, 8, 8],
            [2012, 12778, 19, 24],
            [2012, 12779, 18, 20],
            [2012, 12780, 8, 8],
            [2012, 12781, 19, 24],
            [2012, 12782, 13, 14],
            [2012, 12783, 8, 8],
            [2012, 12784, 19, 24],
            [2012, 12785, 23, 15],
            [2012, 12786, 10, 10],
            [2012, 12787, 19, 22],
            [2012, 12788, 7, 8],
            [2012, 12789, 15, 17],
            [2012, 12790, 17, 14],
            [2012, 12791, 12, 9],
            [2012, 12792, 14, 15],
            [2012, 12793, 12, 12],
            [2012, 12794, 20, 15],
            [2012, 12795, 13, 11],
            [2012, 12796, 10, 10],
            [2012, 12797, 10, 10],
            [2012, 12798, 8, 14],
            [2012, 12799, 7, 10],
            [2012, 12800, 20, 11],
            [2012, 12801, 10, 6],
            [2012, 12802, 10, 9],
            [2012, 12803, 63, 39],
            [2012, 12804, 14, 13],
            [2012, 12805, 19, 12],
            [2012, 12806, 12, 11],
            [2012, 12807, 33, 18],
            [2012, 12808, 15, 14],
            [2012, 12809, 6, 9],
            [2012, 12810, 14, 18],
            [2012, 12811, 11, 13],
            [2012, 12812, 18, 14],
            [2012, 12813, 9, 9],
            [2012, 12814, 12, 13],
            [2012, 12815, 15, 12],
            [2012, 12816, 8, 10],
            [2012, 12817, 11, 9],
            [2012, 12818, 9, 9],
            [2012, 12819, 14, 21],
            [2012, 12820, 10, 10],
            [2012, 12821, 8, 4],
            [2012, 12822, 10, 12],
            [2012, 12823, 5, 4],
            [2012, 12824, 10, 13],
            [2012, 12825, 9, 8],
            [2012, 12826, 8, 7],
            [2012, 12827, 33, 20],
            [2012, 12828, 9, 7],
            [2012, 12829, 11, 11],
            [2012, 12830, 9, 6],
            [2012, 12831, 91, 66],
            [2012, 12832, 21, 21],
            [2012, 12833, 9, 6],
            [2012, 12834, 23, 14],
            [2012, 12835, 5, 4],
            [2012, 12836, 20, 10],
            [2012, 12837, 5, 4],
            [2012, 12838, 8, 6],
            [2012, 12839, 5, 4],
            [2012, 12840, 18, 9],
            [2012, 12841, 3, 2],
            [2012, 12842, 8, 9],
            [2012, 12843, 5, 5],
            [2012, 12844, 7, 10],
            [2012, 12845, 9, 7],
            [2012, 12846, 8, 9],
            [2012, 12847, 21, 15],
            [2012, 12848, 13, 10],
            [2012, 12849, 7, 9],
            [2012, 12850, 21, 12],
            [2012, 12851, 14, 11],
            [2012, 12852, 8, 8],
            [2012, 12853, 6, 4],
            [2012, 12854, 31, 18],
            [2012, 12855, 4, 3],
            [2012, 12856, 15, 9],
            [2012, 12857, 8, 7],
            [2012, 12858, 3, 2],
            [2012, 12859, 23, 13],
            [2012, 12860, 14, 11],
            [2012, 12861, 6, 4],
            [2012, 12862, 6, 5],
            [2012, 12863, 66, 31],
            [2012, 12864, 5, 4],
            [2012, 12865, 35, 14],
            [2012, 12866, 5, 4],
            [2012, 12867, 66, 29],
            [2012, 12868, 8, 6],
            [2012, 12869, 10, 10],
            [2012, 12870, 8, 5],
            [2012, 12871, 41, 18],
            [2012, 12872, 9, 7],
            [2012, 12873, 11, 10],
            [2012, 12874, 6, 5],
            [2012, 12875, 66, 35],
            [2012, 12876, 11, 9],
            [2012, 12877, 6, 5],
            [2012, 12878, 11, 9],
            [2012, 12879, 8, 8],
            [2012, 12880, 6, 5],
            [2012, 12881, 12, 9],
            [2012, 12882, 12, 10],
            [2012, 12883, 5, 4],
            [2012, 12884, 46, 27],
            [2012, 12885, 3, 2],
            [2012, 12886, 27, 21],
            [2012, 12887, 5, 4],
            [2012, 12888, 16, 12],
            [2012, 12889, 77, 35],
            [2012, 12890, 7, 5],
            [2012, 12891, 33, 20],
            [2012, 12892, 10, 9],
            [2012, 12893, 8, 6],
            [2012, 12894, 17, 12],
            [2012, 12895, 6, 5],
            [2012, 12896, 31, 21],
            [2012, 12897, 8, 6],
            [2012, 12898, 18, 11],
            [2012, 12899, 18, 15],
            [2012, 12900, 8, 6],
            [2012, 12901, 27, 15],
            [2012, 12902, 7, 6],
            [2012, 12903, 29, 35],
            [2012, 12904, 13, 10],
            [2012, 12905, 29, 20],
            [2012, 12906, 11, 9],
            [2012, 12907, 20, 16],
            [2012, 12908, 13, 11],
            [2012, 12909, 5, 4],
            [2012, 12910, 9, 7],
            [2012, 12911, 4, 4],
            [2012, 12912, 13, 11],
            [2012, 12913, 8, 7],
            [2012, 12914, 7, 5],
            [2012, 12915, 4, 3],
            [2012, 12916, 7, 5],
            [2012, 12917, 12, 10],
            [2012, 12918, 4, 3],
            [2012, 12919, 6, 4],
            [2012, 12920, 18, 15],
            [2012, 12921, 16, 13],
            [2012, 12922, 9, 8],
            [2012, 12923, 8, 7],
            [2012, 12924, 10, 9],
            [2012, 12925, 6, 5],
            [2012, 12926, 6, 5],
            [2012, 12927, 16, 13],
            [2012, 12928, 28, 19],
            [2012, 12929, 8, 6],
            [2012, 12930, 9, 7],
            [2012, 12931, 7, 5],
            [2012, 12932, 10, 8],
            [2012, 12933, 6, 4],
            [2012, 12934, 9, 7],
            [2012, 12935, 7, 6],
            [2012, 12936, 4, 3],
            [2012, 12937, 9, 7],
            [2012, 12938, 7, 5],
            [2012, 12939, 3, 2],
            [2012, 12940, 6, 5],
            [2012, 12941, 14, 11],
            [2012, 12942, 10, 8],
            [2012, 12943, 7, 6],
            [2012, 12944, 6, 5],
            [2012, 12945, 4, 3],
            [2012, 12946, 6, 5],
            [2012, 12947, 9, 7],
            [2012, 12948, 7, 5],
            [2012, 12949, 6, 5],
            [2012, 12950, 9, 7],
            [2012, 12951, 10, 8],
            [2012, 12952, 23, 18],
            [2012, 12953, 15, 13],
            [2012, 12954, 10, 8],
            [2012, 12955, 9, 7],
            [2012, 12956, 5, 4],
            [2012, 12957, 8, 6],
            [2012, 12958, 8, 7],
            [2012, 12959, 6, 4],
            [2012, 12960, 7, 5],
            [2012, 12961, 6, 4],
            [2012, 12962, 8, 5],
            [2012, 12963, 5, 5],
            [2012, 12964, 9, 7],
            [2012, 12965, 20, 17],
            [2012, 12966, 10, 7],
            [2012, 12967, 10, 8],
            [2012, 12968, 13, 11],
            [2012, 12969, 7, 5],
            [2012, 12970, 7, 5],
            [2012, 12971, 8, 7],
            [2012, 12972, 6, 5],
            [2012, 12973, 6, 4],
            [2012, 12974, 8, 6],
            [2012, 12975, 6, 5],
            [2012, 12976, 6, 5],
            [2012, 12977, 4, 3],
            [2012, 12978, 12, 9],
            [2012, 12979, 13, 10],
            [2012, 12980, 8, 6],
            [2012, 12981, 8, 6],
            [2012, 12982, 13, 10],
            [2012, 12983, 8, 5],
            [2012, 12984, 5, 5],
            [2012, 12985, 8, 6],
            [2012, 12986, 5, 4],
            [2012, 12987, 8, 7],
            [2012, 12988, 20, 18],
            [2012, 12989, 12, 9],
            [2012, 12990, 8, 6],
            [2012, 12991, 6, 5],
            [2012, 12992, 6, 5],
            [2012, 12993, 4, 3],
            [2012, 12994, 7, 6],
            [2012, 12995, 5, 4],
            [2012, 12996, 7, 5],
            [2012, 12997, 8, 6],
            [2012, 12998, 6, 5],
            [2012, 12999, 7, 5],
            [2012, 13000, 6, 5],
            [2012, 13001, 13, 14],
            [2012, 13002, 17, 17],
            [2012, 13003, 15, 16],
            [2012, 13004, 25, 20],
            [2012, 13005, 20, 19],
            [2012, 13006, 25, 21],
            [2012, 13007, 19, 19],
            [2012, 13008, 27, 20],
            [2012, 13009, 20, 19],
            [2012, 13010, 19, 18],
            [2012, 13011, 36, 24],
            [2012, 13012, 24, 23],
            [2012, 13013, 16, 16],
            [2012, 13014, 18, 19],
            [2012, 13015, 13, 16],
            [2012, 13016, 17, 14],
            [2012, 13017, 9, 6],
            [2012, 13018, 20, 20],
            [2012, 13019, 16, 9],
            [2012, 13020, 10, 15],
            [2012, 13021, 15, 21],
            [2012, 13022, 10, 6],
            [2012, 13023, 21, 15],
            [2012, 13024, 32, 27],
            [2012, 13025, 11, 18],
            [2012, 13026, 21, 14],
            [2012, 13027, 20, 13],
            [2012, 13028, 9, 5],
            [2012, 13029, 15, 17],
            [2012, 13030, 15, 15],
            [2012, 13031, 12, 12],
            [2012, 13032, 25, 22],
            [2012, 13033, 10, 9],
            [2012, 13034, 7, 6],
            [2012, 13035, 9, 5],
            [2012, 13036, 20, 8],
            [2012, 13037, 10, 8],
            [2012, 13038, 22, 17],
            [2012, 13039, 13, 13],
            [2012, 13040, 18, 17],
            [2012, 13041, 14, 14],
            [2012, 13042, 7, 10],
            [2012, 13043, 9, 6],
            [2012, 13044, 15, 19],
            [2012, 13045, 7, 11],
            [2012, 13046, 19, 17],
            [2012, 13047, 23, 22],
            [2012, 13048, 13, 12],
            [2012, 13049, 14, 13],
            [2012, 13050, 13, 13],
            [2012, 13051, 17, 18],
            [2012, 13052, 12, 13],
            [2012, 13053, 11, 9],
            [2012, 13054, 17, 20],
            [2012, 13055, 21, 14],
            [2012, 13056, 15, 17],
            [2012, 13057, 17, 16],
            [2012, 13058, 20, 20],
            [2012, 13059, 12, 9],
            [2012, 13060, 17, 13],
            [2012, 13061, 20, 19],
            [2012, 13062, 15, 12],
            [2012, 13063, 31, 6],
            [2012, 13064, 11, 15],
            [2012, 13065, 14, 15],
            [2012, 13066, 13, 11],
            [2012, 13067, 17, 14],
            [2012, 13068, 15, 18],
            [2012, 13069, 23, 18],
            [2012, 13070, 10, 6],
            [2012, 13071, 12, 7],
            [2012, 13072, 11, 14],
            [2012, 13073, 11, 11],
            [2012, 13074, 13, 14],
            [2012, 13075, 22, 22],
            [2012, 13076, 13, 9],
            [2012, 13077, 28, 22],
            [2012, 13078, 34, 35],
            [2012, 13079, 12, 16],
            [2012, 13080, 13, 10],
            [2012, 13081, 15, 14],
            [2012, 13082, 8, 8],
            [2012, 13083, 15, 10],
            [2012, 13084, 25, 19],
            [2012, 13085, 28, 20],
            [2012, 13086, 7, 7],
            [2012, 13087, 16, 13],
            [2012, 13088, 20, 13],
            [2012, 13089, 13, 12],
            [2012, 13090, 13, 13],
            [2012, 13091, 9, 6],
            [2012, 13092, 26, 21],
            [2012, 13093, 14, 9],
            [2012, 13094, 31, 18],
            [2012, 13095, 14, 14],
            [2012, 13096, 10, 12],
            [2012, 13097, 17, 12],
            [2012, 13098, 13, 13],
            [2012, 13099, 8, 12],
            [2012, 13100, 22, 20],
            [2012, 13101, 18, 16],
            [2012, 13102, 23, 17],
            [2012, 13103, 22, 17],
            [2012, 13104, 19, 28],
            [2012, 13105, 16, 13],
            [2012, 13106, 20, 16],
            [2012, 13107, 15, 11],
            [2012, 13108, 17, 14],
            [2012, 13109, 13, 12],
            [2012, 13111, 16, 14],
            [2012, 13112, 12, 12],
            [2012, 13113, 19, 11],
            [2012, 13114, 15, 15],
            [2012, 13115, 15, 10],
            [2012, 13116, 18, 19],
            [2012, 13117, 16, 16],
            [2012, 13118, 13, 10],
            [2012, 13119, 23, 17],
            [2012, 13120, 15, 8],
            [2012, 13121, 16, 20],
            [2012, 13122, 29, 16],
            [2012, 13123, 18, 15],
            [2012, 13124, 12, 12],
            [2012, 13125, 11, 10],
            [2012, 13126, 24, 17],
            [2012, 13127, 16, 14],
            [2012, 13128, 12, 14],
            [2012, 13129, 22, 19],
            [2012, 13130, 17, 13],
            [2012, 13131, 14, 11],
            [2012, 13132, 13, 12],
            [2012, 13133, 19, 13],
            [2012, 13134, 19, 14],
            [2012, 13135, 18, 12],
            [2012, 13136, 15, 21],
            [2012, 13137, 19, 22],
            [2012, 13138, 15, 11],
            [2012, 13139, 7, 7],
            [2012, 13140, 18, 12],
            [2012, 13141, 10, 9],
            [2012, 13142, 9, 8],
            [2012, 13143, 10, 8],
            [2012, 13144, 13, 12],
            [2012, 13145, 7, 7],
            [2012, 13147, 12, 9],
            [2012, 13148, 13, 12],
            [2012, 13149, 9, 7],
            [2012, 13150, 11, 10],
            [2012, 13152, 11, 10],
            [2012, 13153, 7, 7],
            [2012, 13154, 8, 8],
            [2012, 13155, 9, 7],
            [2012, 13156, 9, 8],
            [2012, 13158, 7, 7],
            [2012, 13159, 9, 8],
            [2012, 13160, 9, 7],
            [2012, 13161, 7, 7],
            [2012, 13163, 11, 8],
            [2012, 13164, 9, 8],
            [2012, 13165, 11, 8],
            [2012, 13166, 8, 7],
            [2012, 13167, 19, 14],
            [2012, 13168, 9, 8],
            [2012, 13169, 11, 9],
            [2012, 13170, 13, 12],
            [2012, 13171, 11, 9],
            [2012, 13172, 7, 7],
            [2012, 13173, 12, 10],
            [2012, 13174, 9, 7],
            [2012, 13175, 7, 7],
            [2012, 13176, 10, 8],
            [2012, 13177, 9, 9],
            [2012, 13178, 12, 10],
            [2012, 13179, 10, 8],
            [2012, 13180, 16, 11],
            [2012, 13181, 7, 7],
            [2012, 13182, 9, 8],
            [2012, 13183, 33, 23],
            [2012, 13184, 7, 7],
            [2012, 13185, 11, 11],
            [2012, 13186, 14, 16],
            [2012, 13187, 8, 11],
            [2012, 13188, 7, 10],
            [2012, 13189, 13, 10],
            [2012, 13190, 7, 11],
            [2012, 13191, 23, 15],
            [2012, 13192, 9, 11],
            [2012, 13193, 9, 14],
            [2012, 13194, 11, 10],
            [2012, 13195, 25, 16],
            [2012, 13196, 17, 12],
            [2012, 13197, 100, 36],
            [2012, 13198, 13, 10],
            [2012, 13199, 7, 7],
            [2012, 13200, 22, 15],
            [2012, 13201, 16, 12],
            [2012, 13202, 23, 14],
            [2012, 13203, 8, 9],
            [2012, 13204, 25, 14],
            [2012, 13205, 9, 11],
            [2012, 13206, 17, 13],
            [2012, 13207, 13, 12],
            [2012, 13208, 11, 11],
            [2012, 13209, 8, 8],
            [2012, 13210, 24, 20],
            [2012, 13211, 15, 11],
            [2012, 13212, 62, 39],
            [2012, 13213, 32, 18],
            [2012, 13214, 20, 18],
            [2012, 13215, 10, 11],
            [2012, 13216, 22, 16],
            [2012, 13217, 7, 10],
            [2012, 13218, 15, 13],
            [2012, 13219, 11, 11],
            [2012, 13220, 9, 11],
            [2012, 13221, 8, 10],
            [2012, 13222, 9, 11],
            [2012, 13223, 21, 15],
            [2012, 13224, 61, 24],
            [2012, 13225, 15, 11],
            [2012, 13226, 9, 11],
            [2012, 13227, 20, 15],
            [2012, 13228, 10, 11],
            [2012, 13229, 7, 9],
            [2012, 13230, 22, 14],
            [2012, 13231, 11, 11],
            [2012, 13232, 17, 14],
            [2012, 13233, 18, 15],
            [2012, 13234, 19, 16],
            [2012, 13235, 15, 13],
            [2012, 13236, 12, 10],
            [2012, 13237, 10, 8],
            [2012, 13238, 16, 14],
            [2012, 13239, 16, 13],
            [2012, 13240, 17, 14],
            [2012, 13241, 17, 15],
            [2012, 13242, 17, 15],
            [2012, 13243, 19, 15],
            [2012, 13244, 22, 19],
            [2012, 13245, 17, 14],
            [2012, 13246, 19, 13],
            [2012, 13247, 19, 17],
            [2012, 13248, 13, 11],
            [2012, 13249, 12, 9],
            [2012, 13250, 18, 15],
            [2012, 13251, 19, 15],
            [2012, 13252, 22, 16],
            [2012, 13253, 18, 15],
            [2012, 13254, 12, 10],
            [2012, 13255, 12, 10],
            [2012, 13256, 15, 13],
            [2012, 13257, 15, 13],
            [2012, 13258, 21, 18],
            [2012, 13259, 21, 16],
            [2012, 13260, 17, 13],
            [2012, 13261, 16, 13],
            [2012, 13262, 20, 15],
            [2012, 13263, 17, 14],
            [2012, 13264, 16, 14],
            [2012, 13265, 27, 18],
            [2012, 13266, 14, 11],
            [2012, 13267, 37, 29],
            [2012, 13269, 17, 13],
            [2012, 13270, 20, 15],
            [2012, 13271, 18, 13],
            [2012, 13272, 9, 8],
            [2012, 13273, 14, 12],
            [2012, 13274, 11, 10],
            [2012, 13275, 14, 12],
            [2012, 13276, 12, 10],
            [2012, 13277, 20, 14],
            [2012, 13278, 12, 10],
            [2012, 13279, 37, 18],
            [2012, 13280, 16, 12],
            [2012, 13281, 13, 13],
            [2012, 13282, 15, 12],
            [2012, 13283, 21, 17],
            [2012, 13284, 21, 19],
            [2012, 13285, 14, 12],
            [2012, 13286, 24, 15],
            [2012, 13288, 20, 16],
            [2012, 13289, 21, 19],
            [2012, 13290, 9, 9],
            [2012, 13291, 17, 15],
            [2012, 13292, 9, 8],
            [2012, 13293, 17, 18],
            [2012, 13294, 14, 12],
            [2012, 13295, 25, 15],
            [2012, 13296, 16, 16],
            [2012, 13297, 14, 11],
            [2012, 13298, 17, 15],
            [2012, 13299, 11, 13],
            [2012, 13300, 12, 14],
            [2012, 13302, 17, 15],
            [2012, 13303, 12, 14],
            [2012, 13304, 21, 15],
            [2012, 13305, 15, 13],
            [2012, 13306, 8, 8],
            [2012, 13307, 33, 32],
            [2012, 13308, 16, 14],
            [2012, 13309, 10, 10],
            [2012, 13310, 17, 13],
            [2012, 13311, 11, 10],
            [2012, 13312, 17, 14],
            [2012, 13313, 51, 25],
            [2012, 13314, 40, 23],
            [2012, 13315, 17, 14],
            [2012, 13316, 12, 10],
            [2012, 13317, 12, 9],
            [2012, 13318, 10, 10],
            [2012, 13319, 18, 15],
            [2012, 13320, 29, 21],
            [2012, 13321, 14, 15],
            [2012, 13322, 14, 12],
            [2012, 13323, 39, 25],
            [2012, 13324, 9, 8],
            [2012, 13325, 15, 15],
            [2012, 13326, 17, 13],
            [2012, 13327, 21, 12],
            [2012, 13328, 15, 13],
            [2012, 13329, 14, 14],
            [2012, 13330, 15, 13],
            [2012, 13331, 25, 18],
            [2012, 13332, 14, 13],
            [2012, 13333, 13, 15],
            [2012, 13334, 12, 11],
            [2012, 13335, 41, 29],
            [2012, 13336, 15, 13],
            [2012, 13337, 8, 8],
            [2012, 13338, 15, 13],
            [2012, 13339, 12, 10],
            [2012, 13340, 15, 14],
            [2012, 13341, 10, 9],
            [2012, 13342, 10, 9],
            [2012, 13343, 15, 12],
            [2012, 13344, 13, 11],
            [2012, 13345, 23, 16],
            [2012, 13346, 10, 8],
            [2012, 13347, 21, 20],
            [2012, 13348, 18, 16],
            [2012, 13349, 35, 21],
            [2012, 13350, 16, 14],
            [2012, 13351, 9, 8],
            [2012, 13352, 12, 11],
            [2012, 13353, 16, 13],
            [2012, 13354, 14, 11],
            [2012, 13355, 15, 11],
            [2012, 13356, 10, 9],
            [2012, 13357, 25, 18],
            [2012, 13358, 15, 15],
            [2012, 13359, 35, 21],
            [2012, 13360, 11, 9],
            [2012, 13361, 33, 21],
            [2012, 13362, 13, 13],
            [2012, 13363, 20, 16],
            [2012, 13364, 11, 11],
            [2012, 13365, 12, 9],
            [2012, 13366, 11, 11],
            [2012, 13367, 12, 9],
            [2012, 13368, 23, 18],
            [2012, 13369, 16, 13],
            [2012, 13370, 15, 11],
            [2012, 13371, 18, 16],
            [2012, 13372, 17, 12],
            [2012, 13373, 11, 10],
            [2012, 13374, 14, 13],
            [2012, 13375, 15, 13],
            [2012, 13376, 9, 11],
            [2012, 13377, 16, 13],
            [2012, 13378, 12, 10],
            [2012, 13379, 14, 12],
            [2012, 13380, 20, 15],
            [2012, 13381, 9, 8],
            [2012, 13382, 16, 13],
            [2012, 13384, 20, 17],
            [2012, 13385, 9, 8],
            [2012, 13386, 27, 16],
            [2012, 13387, 16, 16],
            [2012, 13388, 14, 13],
            [2012, 13389, 14, 13],
            [2012, 13390, 15, 13],
            [2012, 13391, 12, 12],
            [2012, 13392, 20, 13],
            [2012, 13393, 29, 27],
            [2012, 13394, 14, 12],
            [2012, 13395, 14, 11],
            [2012, 13396, 51, 25],
            [2012, 13397, 9, 8],
            [2012, 13398, 33, 21],
            [2012, 13399, 14, 12],
            [2012, 13400, 23, 16],
            [2012, 13401, 13, 12],
            [2012, 13402, 27, 14],
            [2012, 13403, 17, 15],
            [2012, 13404, 25, 18],
            [2012, 13405, 41, 19],
            [2012, 13406, 11, 10],
            [2012, 13407, 17, 17],
            [2012, 13408, 29, 23],
            [2012, 13409, 20, 17],
            [2012, 13410, 29, 18],
            [2012, 13411, 10, 11],
            [2012, 13412, 46, 25],
            [2012, 13413, 23, 17],
            [2012, 13414, 25, 18],
            [2012, 13415, 18, 14],
            [2012, 13416, 18, 14],
            [2012, 13417, 12, 11],
            [2012, 13418, 9, 8],
            [2012, 13419, 51, 25],
            [2012, 13420, 13, 11],
            [2012, 13421, 19, 12],
            [2012, 13422, 29, 16],
            [2012, 13423, 13, 13],
            [2012, 13424, 37, 15],
            [2012, 13425, 18, 15],
            [2012, 13426, 23, 15],
            [2012, 13427, 29, 23],
            [2012, 13428, 51, 18],
            [2012, 13429, 21, 19],
            [2012, 13430, 23, 25],
            [2012, 13431, 39, 23],
            [2012, 13432, 12, 11],
            [2012, 13433, 23, 16],
            [2012, 13434, 31, 18],
            [2012, 13435, 21, 17],
            [2012, 13436, 20, 18],
            [2012, 13437, 8, 8],
            [2012, 13438, 25, 18],
            [2012, 13439, 10, 9],
            [2012, 13440, 10, 9],
            [2012, 13441, 12, 13],
            [2012, 13442, 46, 23],
            [2012, 13443, 35, 29],
            [2012, 13444, 75, 21],
            [2012, 13445, 15, 11],
            [2012, 13446, 17, 15],
            [2012, 13447, 45, 29],
            [2012, 13448, 29, 29],
            [2012, 13449, 12, 10],
            [2012, 13450, 9, 9],
            [2012, 13451, 9, 7],
            [2012, 13452, 8, 8],
            [2012, 13453, 9, 9],
            [2012, 13454, 21, 14],
            [2012, 13455, 15, 13],
            [2012, 13456, 7, 7],
            [2012, 13457, 7, 7],
            [2012, 13458, 11, 10],
            [2012, 13459, 9, 8],
            [2012, 13460, 10, 8],
            [2012, 13461, 9, 7],
            [2012, 13462, 9, 7],
            [2012, 13463, 15, 11],
            [2012, 13464, 16, 9],
            [2012, 13465, 11, 11],
            [2012, 13466, 10, 9],
            [2012, 13467, 10, 9],
            [2012, 13468, 10, 9],
            [2012, 13469, 10, 9],
            [2012, 13470, 13, 11],
            [2012, 13471, 12, 10],
            [2012, 13472, 14, 9],
            [2012, 13473, 11, 9],
            [2012, 13474, 11, 9],
            [2012, 13475, 12, 10],
            [2012, 13476, 7, 8],
            [2012, 13478, 7, 8],
            [2012, 13479, 13, 10],
            [2012, 13480, 4, 4],
            [2012, 13481, 9, 8],
            [2012, 13482, 13, 11],
            [2012, 13483, 10, 11],
            [2012, 13484, 10, 9],
            [2012, 13485, 9, 9],
            [2012, 13486, 3, 4],
            [2012, 13487, 18, 13],
            [2012, 13488, 9, 6],
            [2012, 13489, 15, 10],
            [2012, 13490, 7, 8],
            [2012, 13491, 9, 9],
            [2012, 13492, 7, 7],
            [2012, 13493, 8, 6],
            [2012, 13494, 12, 8],
            [2012, 13495, 10, 9],
            [2012, 13496, 10, 10],
            [2012, 13497, 12, 9],
            [2012, 13498, 9, 8],
            [2012, 13499, 14, 10],
            [2012, 13500, 6, 6],
            [2012, 13501, 17, 11],
            [2012, 13502, 8, 7],
            [2012, 13503, 13, 10],
            [2012, 13504, 7, 6],
            [2012, 13505, 7, 6],
            [2012, 13506, 12, 9],
            [2012, 13507, 5, 5],
            [2012, 13508, 12, 10],
            [2012, 13509, 5, 6],
            [2012, 13511, 16, 12],
            [2012, 13512, 10, 8],
            [2012, 13513, 14, 10],
            [2012, 13514, 12, 10],
            [2012, 13516, 8, 7],
            [2012, 13517, 7, 7],
            [2012, 13518, 7, 7],
            [2012, 13519, 11, 9],
            [2012, 13520, 12, 11],
            [2012, 13521, 8, 8],
            [2012, 13522, 9, 9],
            [2012, 13523, 11, 10],
            [2012, 13524, 7, 7],
            [2012, 13525, 13, 11],
            [2012, 13526, 9, 7],
            [2012, 13527, 15, 12],
            [2012, 13528, 8, 8],
            [2012, 13529, 7, 7],
            [2012, 13530, 7, 6],
            [2012, 13531, 7, 6],
            [2012, 13532, 7, 6],
            [2012, 13533, 7, 6],
            [2012, 13534, 7, 6],
            [2012, 13535, 15, 12],
            [2012, 13536, 9, 9],
            [2012, 13537, 6, 6],
            [2012, 13538, 6, 6],
            [2012, 13539, 6, 6],
            [2012, 13540, 6, 6],
            [2012, 13541, 9, 9],
            [2012, 13542, 9, 8],
            [2012, 13543, 10, 9],
            [2012, 13544, 10, 10],
            [2012, 13545, 9, 8],
            [2012, 13546, 8, 7],
            [2012, 13547, 8, 9],
            [2012, 13548, 15, 10],
            [2012, 13549, 9, 8],
            [2012, 13550, 20, 13],
            [2012, 13551, 5, 6],
            [2012, 13552, 13, 11],
            [2012, 13553, 6, 7],
            [2012, 13554, 8, 6],
            [2012, 13555, 9, 7],
            [2012, 13556, 8, 9],
            [2012, 13557, 3, 3],
            [2012, 13558, 18, 12],
            [2012, 13560, 8, 8],
            [2012, 13561, 11, 8],
            [2012, 13562, 9, 9],
            [2012, 13563, 8, 6],
            [2012, 13564, 13, 10],
            [2012, 13565, 9, 8],
            [2012, 13566, 12, 12],
            [2012, 13567, 9, 9],
            [2012, 13568, 4, 5],
            [2012, 13569, 9, 8],
            [2012, 13570, 7, 8],
            [2012, 13571, 11, 9],
            [2012, 13572, 6, 6],
            [2012, 13573, 7, 7],
            [2012, 13574, 10, 9],
            [2012, 13575, 13, 10],
            [2012, 13576, 7, 7],
            [2012, 13577, 7, 7],
            [2012, 13578, 8, 8],
            [2012, 13579, 21, 13],
            [2012, 13580, 10, 7],
            [2012, 13581, 6, 7],
            [2012, 13582, 8, 7],
            [2012, 13583, 10, 9],
            [2012, 13584, 36, 17],
            [2012, 13585, 7, 8],
            [2012, 13586, 7, 6],
            [2012, 13587, 7, 7],
            [2012, 13588, 17, 12],
            [2012, 13589, 7, 7],
            [2012, 13590, 15, 12],
            [2012, 13591, 7, 7],
            [2012, 13592, 7, 7],
            [2012, 13593, 7, 8],
            [2012, 13594, 15, 12],
            [2012, 13595, 10, 7],
            [2012, 13596, 12, 11],
            [2012, 13597, 10, 7],
            [2012, 13598, 8, 7],
            [2012, 13599, 7, 8],
            [2012, 13600, 9, 8],
            [2012, 13601, 7, 7],
            [2012, 13602, 7, 7],
            [2012, 13603, 7, 7],
            [2012, 13604, 12, 10],
            [2012, 13605, 10, 9],
            [2012, 13606, 10, 11],
            [2012, 13607, 9, 7],
            [2012, 13608, 10, 10],
            [2012, 13609, 40, 40],
            [2012, 13610, 35, 35],
            [2012, 13611, 18, 19],
            [2012, 13612, 51, 29],
            [2012, 13613, 101, 41],
            [2012, 13614, 35, 35],
            [2012, 13615, 60, 35],
            [2012, 13616, 13, 13],
            [2012, 13617, 39, 41],
            [2012, 13618, 49, 46],
            [2012, 13619, 45, 61],
            [2012, 13620, 40, 39],
            [2012, 13621, 45, 41],
            [2012, 13622, 47, 36],
            [2012, 13623, 56, 40],
            [2012, 13624, 32, 21],
            [2012, 13625, 25, 25],
            [2012, 13626, 31, 27],
            [2012, 13627, 39, 46],
            [2012, 13628, 38, 40],
            [2012, 13629, 51, 41],
            [2012, 13630, 40, 40],
            [2012, 13631, 48, 51],
            [2012, 13633, 31, 19],
            [2012, 13634, 31, 28],
            [2012, 13635, 40, 41],
            [2012, 13636, 20, 20],
            [2012, 13637, 81, 61],
            [2012, 13638, 68, 46],
            [2012, 13639, 11, 11],
            [2012, 13640, 54, 59],
            [2012, 13641, 41, 24],
            [2012, 13642, 78, 41],
            [2012, 13643, 23, 31],
            [2012, 13644, 60, 39],
            [2012, 13645, 66, 47],
            [2012, 13646, 35, 46],
            [2012, 13647, 51, 30],
            [2012, 13648, 55, 41],
            [2012, 13649, 65, 41],
            [2012, 13650, 9, 9],
            [2012, 13651, 51, 41],
            [2012, 13652, 67, 55],
            [2012, 13653, 9, 9],
            [2012, 13654, 9, 9],
            [2012, 13655, 35, 35],
            [2012, 13656, 78, 50],
            [2012, 13657, 26, 23],
            [2012, 13658, 88, 52],
            [2012, 13659, 45, 33],
            [2012, 13660, 40, 38],
            [2012, 13661, 40, 33],
            [2012, 13662, 50, 35],
            [2012, 13663, 23, 23],
            [2012, 13664, 45, 44],
            [2012, 13665, 50, 40],
            [2012, 13666, 35, 35],
            [2012, 13667, 45, 33],
            [2012, 13668, 12, 11],
            [2012, 13669, 46, 31],
            [2012, 13670, 50, 35],
            [2012, 13671, 49, 30],
            [2012, 13672, 46, 39],
            [2012, 13673, 85, 41],
            [2012, 13674, 44, 35],
            [2012, 13675, 35, 29],
            [2012, 13676, 38, 30],
            [2012, 13677, 16, 19],
            [2012, 13678, 15, 19],
            [2012, 13679, 9, 15],
            [2012, 13680, 10, 14],
            [2012, 13681, 17, 16],
            [2012, 13682, 8, 9],
            [2012, 13683, 18, 17],
            [2012, 13684, 29, 18],
            [2012, 13685, 33, 17],
            [2012, 13686, 21, 17],
            [2012, 13687, 35, 23],
            [2012, 13688, 19, 14],
            [2012, 13689, 23, 13],
            [2012, 13690, 16, 14],
            [2012, 13691, 61, 20],
            [2012, 13692, 19, 20],
            [2012, 13693, 17, 15],
            [2012, 13694, 27, 20],
            [2012, 13695, 27, 20],
            [2012, 13696, 15, 14],
            [2012, 13697, 51, 20],
            [2012, 13698, 21, 15],
            [2012, 13699, 37, 17],
            [2012, 13700, 46, 21],
            [2012, 13701, 18, 17],
            [2012, 13702, 27, 14],
            [2012, 13703, 31, 20],
            [2012, 13704, 37, 18],
            [2012, 13705, 15, 15],
            [2012, 13706, 31, 16],
            [2012, 13707, 41, 23],
            [2012, 13708, 20, 18],
            [2012, 13709, 37, 21],
            [2012, 13710, 23, 17],
            [2012, 13711, 25, 17],
            [2012, 13712, 41, 17],
            [2012, 13713, 46, 31],
            [2012, 13714, 15, 15],
            [2012, 13715, 37, 21],
            [2012, 13716, 23, 15],
            [2012, 13717, 27, 31],
            [2012, 13718, 19, 17],
            [2012, 13719, 41, 19],
            [2012, 13720, 27, 20],
            [2012, 13721, 23, 10],
            [2012, 13722, 25, 25],
            [2012, 13723, 37, 29],
            [2012, 13724, 39, 18],
            [2012, 13725, 39, 14],
            [2012, 13726, 23, 10],
            [2012, 13727, 46, 25],
            [2012, 13728, 25, 17],
            [2012, 13729, 23, 12],
            [2012, 13730, 41, 31],
            [2012, 13731, 41, 20],
            [2012, 13732, 56, 28],
            [2012, 13733, 33, 17],
            [2012, 13734, 27, 13],
            [2012, 13735, 27, 12],
            [2012, 13736, 35, 20],
            [2012, 13737, 37, 18],
            [2012, 13738, 23, 19],
            [2012, 13739, 37, 27],
            [2012, 13740, 41, 11],
            [2012, 13741, 15, 14],
            [2012, 13742, 37, 20],
            [2012, 13743, 35, 18],
            [2012, 13744, 41, 16],
            [2012, 13745, 10, 9],
            [2012, 13746, 21, 22],
            [2012, 13747, 15, 16],
            [2012, 13748, 21, 18],
            [2012, 13749, 12, 12],
            [2012, 13750, 23, 21],
            [2012, 13751, 9, 10],
            [2012, 13752, 10, 12],
            [2012, 13753, 16, 17],
            [2012, 13754, 20, 19],
            [2012, 13755, 13, 14],
            [2012, 13756, 11, 10],
            [2012, 13757, 17, 19],
            [2012, 13758, 11, 10],
            [2012, 13759, 9, 8],
            [2012, 13760, 10, 10],
            [2012, 13761, 13, 10],
            [2012, 13762, 10, 12],
            [2012, 13763, 10, 9],
            [2012, 13764, 8, 8],
            [2012, 13765, 19, 10],
            [2012, 13766, 14, 14],
            [2012, 13767, 16, 14],
            [2012, 13768, 15, 11],
            [2012, 13769, 11, 11],
            [2012, 13770, 15, 17],
            [2012, 13771, 13, 14],
            [2012, 13772, 13, 10],
            [2012, 13773, 17, 14],
            [2012, 13774, 9, 8],
            [2012, 13775, 9, 13],
            [2012, 13776, 10, 11],
            [2012, 13777, 10, 9],
            [2012, 13778, 18, 18],
            [2012, 13779, 15, 11],
            [2012, 13780, 10, 14],
            [2012, 13781, 19, 18],
            [2012, 13782, 20, 24],
            [2012, 13783, 21, 33],
            [2012, 13784, 20, 31],
            [2012, 13785, 17, 21],
            [2012, 13786, 17, 24],
            [2012, 13787, 7, 5],
            [2012, 13788, 6, 6],
            [2012, 13789, 9, 7],
            [2012, 13790, 10, 9],
            [2012, 13791, 8, 7],
            [2012, 13792, 12, 12],
            [2012, 13793, 9, 9],
            [2012, 13794, 14, 12],
            [2012, 13795, 8, 7],
            [2012, 13796, 10, 11],
            [2012, 13797, 10, 10],
            [2012, 13798, 9, 8],
            [2012, 13799, 18, 14],
            [2012, 13800, 8, 8],
            [2012, 13801, 8, 6],
            [2012, 13802, 9, 9],
            [2012, 13803, 11, 9],
            [2012, 13804, 12, 14],
            [2012, 13805, 7, 6],
            [2012, 13806, 10, 9],
            [2012, 13807, 7, 7],
            [2012, 13808, 7, 5],
            [2012, 13809, 11, 9],
            [2012, 13810, 7, 6],
            [2012, 13811, 10, 10],
            [2012, 13812, 9, 9],
            [2012, 13813, 10, 9],
            [2012, 13814, 12, 12],
            [2012, 13815, 12, 11],
            [2012, 13816, 12, 10],
            [2012, 13817, 10, 10],
            [2012, 13818, 10, 9],
            [2012, 13819, 10, 8],
            [2012, 13820, 9, 7],
            [2012, 13821, 6, 6],
            [2012, 13822, 6, 6],
            [2012, 13823, 6, 6],
            [2012, 13824, 10, 9],
            [2012, 13825, 6, 5],
            [2012, 13826, 7, 6],
            [2012, 13827, 7, 6],
            [2012, 13828, 11, 10],
            [2012, 13829, 9, 9],
            [2012, 13830, 7, 7],
            [2012, 13831, 8, 9],
            [2012, 13832, 7, 8],
            [2012, 13833, 13, 14],
            [2012, 13834, 7, 7],
            [2012, 13835, 10, 10],
            [2012, 13836, 10, 9],
            [2012, 13837, 10, 9],
            [2012, 13838, 10, 9],
            [2012, 13839, 11, 12],
            [2012, 13840, 7, 6],
            [2012, 13841, 9, 8],
            [2012, 13842, 10, 10],
            [2012, 13843, 10, 9],
            [2012, 13844, 6, 6],
            [2012, 13845, 8, 8],
            [2012, 13846, 7, 7],
            [2012, 13847, 6, 6],
            [2012, 13848, 7, 7],
            [2012, 13849, 10, 9],
            [2012, 13850, 10, 9],
            [2012, 13851, 13, 14],
            [2012, 13852, 8, 9],
            [2012, 13853, 13, 10],
            [2012, 13854, 15, 15],
            [2012, 13855, 18, 17],
            [2012, 13856, 8, 8],
            [2012, 13857, 9, 7],
            [2012, 13858, 8, 7],
            [2012, 13859, 8, 7],
            [2012, 13860, 7, 6],
            [2012, 13861, 7, 6],
            [2012, 13862, 12, 9],
            [2012, 13863, 7, 6],
            [2012, 13864, 6, 5],
            [2012, 13865, 9, 7],
            [2012, 13866, 6, 6],
            [2012, 13867, 7, 6],
            [2012, 13868, 6, 6],
            [2012, 13869, 10, 7],
            [2012, 13870, 7, 6],
            [2012, 13871, 6, 5],
            [2012, 13872, 8, 6],
            [2012, 13873, 6, 5],
            [2012, 13874, 11, 9],
            [2012, 13875, 9, 7],
            [2012, 13876, 18, 11],
            [2012, 13877, 11, 10],
            [2012, 13878, 7, 6],
            [2012, 13879, 7, 6],
            [2012, 13880, 7, 6],
            [2012, 13881, 8, 6],
            [2012, 13882, 7, 6],
            [2012, 13883, 14, 9],
            [2012, 13884, 7, 8],
            [2012, 13885, 9, 6],
            [2012, 13886, 7, 6],
            [2012, 13887, 7, 6],
            [2012, 13888, 11, 11],
            [2012, 13889, 6, 5],
            [2012, 13890, 9, 8],
            [2012, 13891, 9, 7],
            [2012, 13892, 8, 8],
            [2012, 13893, 12, 14],
            [2012, 13894, 6, 7],
            [2012, 13895, 7, 7],
            [2012, 13896, 6, 6],
            [2012, 13897, 7, 7],
            [2012, 13898, 8, 7],
            [2012, 13899, 8, 7],
            [2012, 13900, 11, 8],
            [2012, 13901, 18, 11],
            [2012, 13902, 7, 7],
            [2012, 13903, 13, 10],
            [2012, 13904, 8, 6],
            [2012, 13905, 10, 9],
            [2012, 13906, 14, 9],
            [2012, 13907, 11, 10],
            [2012, 13908, 10, 9],
            [2012, 13909, 14, 11],
            [2012, 13910, 9, 7],
            [2012, 13911, 8, 7],
            [2012, 13912, 8, 9],
            [2012, 13913, 8, 9],
            [2012, 13914, 8, 9],
            [2012, 13915, 7, 7],
            [2012, 13916, 6, 7],
            [2012, 13917, 6, 6],
            [2012, 13918, 8, 8],
            [2012, 13919, 9, 8],
            [2012, 13920, 13, 9],
            [2012, 13921, 15, 9],
            [2012, 13922, 9, 8],
            [2012, 13923, 8, 7],
            [2012, 13924, 12, 10],
            [2012, 13925, 7, 7],
            [2012, 13926, 8, 8],
            [2012, 13927, 8, 8],
            [2012, 13928, 7, 6],
            [2012, 13929, 7, 7],
            [2012, 13930, 7, 6],
            [2012, 13931, 11, 10],
            [2012, 13932, 9, 7],
            [2012, 13933, 9, 8],
            [2012, 13934, 11, 11],
            [2012, 13935, 7, 6],
            [2012, 13936, 7, 7],
            [2012, 13937, 12, 11],
            [2012, 13938, 7, 7],
            [2012, 13939, 8, 7],
            [2012, 13940, 8, 7],
            [2012, 13941, 8, 9],
            [2012, 13942, 10, 8],
            [2012, 13943, 11, 8],
            [2012, 13944, 8, 8],
            [2012, 13945, 8, 7],
            [2012, 13946, 12, 10],
            [2012, 13947, 14, 11],
            [2012, 13948, 6, 6],
            [2012, 13949, 6, 6],
            [2012, 13950, 10, 9],
            [2012, 13951, 7, 7],
            [2012, 13952, 12, 10],
            [2012, 13953, 12, 10],
            [2012, 13954, 8, 8],
            [2012, 13955, 10, 9],
            [2012, 13956, 10, 9],
            [2012, 13957, 8, 7],
            [2012, 13958, 7, 7],
            [2012, 13959, 8, 8],
            [2012, 13960, 12, 10],
            [2012, 13961, 9, 8],
            [2012, 13962, 11, 10],
            [2012, 13963, 7, 7],
            [2012, 13964, 7, 7],
            [2012, 13965, 7, 7],
            [2012, 13966, 9, 7],
            [2012, 13967, 7, 6],
            [2012, 13968, 7, 7],
            [2012, 13969, 7, 6],
            [2012, 13970, 7, 7],
            [2012, 13971, 7, 7],
            [2012, 13972, 10, 8],
            [2012, 13973, 7, 6],
            [2012, 13974, 7, 6],
            [2012, 13975, 8, 7],
            [2012, 13976, 9, 9],
            [2012, 13977, 7, 8],
            [2012, 13978, 11, 11],
            [2012, 13979, 7, 6],
            [2012, 13980, 6, 6],
            [2012, 13981, 7, 7],
            [2012, 13982, 7, 7],
            [2012, 13983, 13, 10],
            [2012, 13984, 9, 8],
            [2012, 13985, 15, 9],
            [2012, 13986, 8, 8],
            [2012, 13987, 7, 7],
            [2012, 13988, 9, 8],
            [2012, 13989, 7, 6],
            [2012, 13990, 7, 7],
            [2012, 13991, 7, 7],
            [2012, 13992, 7, 6],
            [2012, 13993, 9, 8],
            [2012, 13994, 8, 8],
            [2012, 13995, 14, 12],
            [2012, 13996, 8, 8],
            [2012, 13997, 7, 6],
            [2012, 13998, 7, 7],
            [2012, 13999, 12, 11],
            [2012, 14000, 12, 11],
            [2012, 14001, 12, 9],
            [2012, 14002, 7, 7],
            [2012, 14003, 7, 7],
            [2012, 14004, 7, 7],
            [2012, 14005, 25, 20],
            [2012, 14006, 12, 8],
            [2012, 14007, 15, 12],
            [2012, 14008, 12, 9],
            [2012, 14009, 15, 8],
            [2012, 14010, 10, 8],
            [2012, 14011, 10, 12],
            [2012, 14012, 10, 12],
            [2012, 14013, 12, 12],
            [2012, 14014, 28, 18],
            [2012, 14015, 18, 12],
            [2012, 14016, 13, 12],
            [2012, 14017, 27, 16],
            [2012, 14018, 9, 9],
            [2012, 14019, 8, 7],
            [2012, 14020, 8, 7],
            [2012, 14021, 14, 9],
            [2012, 14022, 9, 9],
            [2012, 14023, 28, 18],
            [2012, 14024, 15, 18],
            [2012, 14025, 13, 14],
            [2012, 14026, 21, 17],
            [2012, 14027, 12, 11],
            [2012, 14028, 11, 11],
            [2012, 14029, 13, 13],
            [2012, 14030, 22, 15],
            [2012, 14031, 26, 21],
            [2012, 14032, 14, 12],
            [2012, 14033, 13, 12],
            [2012, 14034, 15, 14],
            [2012, 14035, 23, 16],
            [2012, 14036, 12, 11],
            [2012, 14037, 21, 14],
            [2012, 14038, 12, 11],
            [2012, 14039, 19, 13],
            [2012, 14040, 18, 15],
            [2012, 14041, 28, 22],
            [2012, 14042, 20, 17],
            [2012, 14043, 13, 11],
            [2012, 14044, 10, 10],
            [2012, 14045, 10, 9],
            [2012, 14046, 9, 14],
            [2012, 14047, 18, 14],
            [2012, 14048, 18, 14],
            [2012, 14049, 26, 15],
            [2012, 14050, 18, 15],
            [2012, 14051, 22, 17],
            [2012, 14052, 12, 11],
            [2012, 14053, 13, 11],
            [2012, 14054, 15, 15],
            [2012, 14055, 27, 15],
            [2012, 14056, 28, 14],
            [2012, 14057, 16, 14],
            [2012, 14058, 16, 12],
            [2012, 14059, 12, 13],
            [2012, 14060, 17, 13],
            [2012, 14061, 16, 17],
            [2012, 14062, 13, 19],
            [2012, 14063, 21, 12],
            [2012, 14064, 16, 13],
            [2012, 14065, 21, 12],
            [2012, 14066, 14, 11],
            [2012, 14067, 17, 19],
            [2012, 14068, 15, 10],
            [2012, 14069, 13, 14],
            [2012, 14070, 21, 23],
            [2012, 14071, 21, 21],
            [2012, 14072, 13, 10],
            [2012, 14073, 21, 19],
            [2012, 14074, 18, 23],
            [2012, 14075, 21, 14],
            [2012, 14076, 21, 15],
            [2012, 14077, 15, 11],
            [2012, 14078, 17, 12],
            [2012, 14079, 13, 11],
            [2012, 14080, 21, 14],
            [2012, 14081, 21, 15],
            [2012, 14082, 23, 16],
            [2012, 14083, 17, 9],
            [2012, 14084, 17, 12],
            [2012, 14085, 16, 12],
            [2012, 14086, 21, 17],
            [2012, 14087, 18, 14],
            [2012, 14088, 14, 11],
            [2012, 14089, 15, 11],
            [2012, 14090, 15, 15],
            [2012, 14091, 21, 16],
            [2012, 14092, 17, 9],
            [2012, 14093, 16, 9],
            [2012, 14094, 11, 9],
            [2012, 14095, 17, 17],
            [2012, 14096, 16, 15],
            [2012, 14097, 17, 12],
            [2012, 14098, 19, 12],
            [2012, 14099, 19, 13],
            [2012, 14100, 17, 11],
            [2012, 14101, 24, 14],
            [2012, 14102, 19, 11],
            [2012, 14103, 16, 16],
            [2012, 14104, 11, 11],
            [2012, 14105, 21, 15],
            [2012, 14106, 16, 11],
            [2012, 14107, 14, 11],
            [2012, 14108, 15, 12],
            [2012, 14109, 17, 11],
            [2012, 14110, 20, 12],
            [2012, 14111, 21, 17],
            [2012, 14112, 17, 12],
            [2012, 14113, 15, 15],
            [2012, 14114, 15, 14],
            [2012, 14115, 19, 16],
            [2012, 14116, 18, 18],
            [2012, 14117, 32, 13],
            [2012, 14118, 23, 17],
            [2012, 14119, 35, 26],
            [2012, 14120, 17, 12],
            [2012, 14121, 24, 13],
            [2012, 14122, 20, 15],
            [2012, 14123, 20, 15],
            [2012, 14124, 10, 11],
            [2012, 14125, 22, 20],
            [2012, 14126, 17, 12],
            [2012, 14127, 16, 13],
            [2012, 14128, 12, 12],
            [2012, 14129, 11, 9],
            [2012, 14130, 18, 17],
            [2012, 14131, 51, 22],
            [2012, 14132, 21, 14],
            [2012, 14133, 12, 10],
            [2012, 14134, 16, 13],
            [2012, 14135, 20, 14],
            [2012, 14136, 17, 12],
            [2012, 14137, 29, 14],
            [2012, 14138, 34, 14],
            [2012, 14139, 24, 17],
            [2012, 14140, 34, 17],
            [2012, 14141, 33, 21],
            [2012, 14142, 14, 15],
            [2012, 14143, 23, 16],
            [2012, 14144, 16, 11],
            [2012, 14145, 22, 15],
            [2012, 14146, 46, 16],
            [2012, 14147, 14, 14],
            [2012, 14148, 14, 10],
            [2012, 14149, 19, 14],
            [2012, 14150, 12, 11],
            [2012, 14151, 16, 12],
            [2012, 14152, 24, 14],
            [2012, 14153, 13, 15],
            [2012, 14154, 20, 13],
            [2012, 14155, 12, 10],
            [2012, 14156, 19, 15],
            [2012, 14157, 32, 20],
            [2012, 14158, 15, 13],
            [2012, 14159, 26, 17],
            [2012, 14160, 17, 14],
            [2012, 14161, 11, 11],
            [2012, 14162, 16, 14],
            [2012, 14163, 10, 11],
            [2012, 14164, 16, 15],
            [2012, 14165, 16, 12],
            [2012, 14166, 30, 14],
            [2012, 14167, 13, 10],
            [2012, 14168, 17, 14],
            [2012, 14169, 11, 10],
            [2012, 14170, 11, 10],
            [2012, 14171, 37, 17],
            [2012, 14172, 26, 21],
            [2012, 14173, 11, 15],
            [2012, 14174, 27, 19],
            [2012, 14175, 23, 38],
            [2012, 14176, 11, 12],
            [2012, 14177, 15, 13],
            [2012, 14178, 11, 11],
            [2012, 14179, 25, 23],
            [2012, 14180, 22, 15],
            [2012, 14181, 24, 16],
            [2012, 14182, 17, 15],
            [2012, 14183, 11, 10],
            [2012, 14184, 30, 11],
            [2012, 14185, 28, 13],
            [2012, 14186, 25, 13],
            [2012, 14187, 11, 13],
            [2012, 14188, 16, 18],
            [2012, 14189, 16, 13],
            [2012, 14190, 10, 10],
            [2012, 14191, 15, 19],
            [2012, 14192, 34, 24],
            [2012, 14193, 20, 25],
            [2012, 14194, 11, 11],
            [2012, 14195, 10, 10],
            [2012, 14196, 46, 24],
            [2012, 14197, 18, 17],
            [2012, 14198, 10, 12],
            [2012, 14199, 15, 17],
            [2012, 14200, 20, 12],
            [2012, 14201, 13, 13],
            [2012, 14202, 11, 11],
            [2012, 14203, 11, 11],
            [2012, 14204, 10, 11],
            [2012, 14205, 21, 15],
            [2012, 14206, 15, 13],
            [2012, 14207, 17, 14],
            [2012, 14208, 14, 12],
            [2012, 14209, 26, 15],
            [2012, 14210, 25, 15],
            [2012, 14211, 23, 20],
            [2012, 14212, 11, 11],
            [2012, 14213, 30, 20],
            [2012, 14214, 10, 10],
            [2012, 14215, 22, 15],
            [2012, 14216, 15, 13],
            [2012, 14217, 16, 17],
            [2012, 14218, 13, 11],
            [2012, 14219, 11, 10],
            [2012, 14220, 16, 16],
            [2012, 14221, 14, 13],
            [2012, 14222, 28, 18],
            [2012, 14223, 18, 14],
            [2012, 14224, 17, 17],
            [2012, 14225, 18, 17],
            [2012, 14226, 31, 13],
            [2012, 14227, 17, 14],
            [2012, 14228, 16, 19],
            [2012, 14229, 16, 15],
            [2012, 14230, 23, 13],
            [2012, 14231, 17, 12],
            [2012, 14232, 11, 10],
            [2012, 14233, 17, 15],
            [2012, 14234, 20, 18],
            [2012, 14235, 19, 13],
            [2012, 14236, 38, 26],
            [2012, 14237, 13, 12],
            [2012, 14238, 15, 14],
            [2012, 14239, 21, 17],
            [2012, 14240, 8, 6],
            [2012, 14241, 16, 9],
            [2012, 14242, 29, 16],
            [2012, 14243, 8, 6],
            [2012, 14244, 27, 15],
            [2012, 14245, 20, 15],
            [2012, 14246, 22, 17],
            [2012, 14247, 32, 18],
            [2012, 14248, 17, 12],
            [2012, 14249, 35, 19],
            [2012, 14250, 28, 17],
            [2012, 14251, 11, 8],
            [2012, 14252, 31, 17],
            [2012, 14253, 30, 16],
            [2012, 14254, 16, 11],
            [2012, 14255, 21, 13],
            [2012, 14256, 16, 11],
            [2012, 14257, 24, 14],
            [2012, 14258, 16, 10],
            [2012, 14259, 28, 15],
            [2012, 14260, 18, 11],
            [2012, 14261, 27, 15],
            [2012, 14262, 29, 17],
            [2012, 14263, 17, 12],
            [2012, 14264, 29, 15],
            [2012, 14265, 30, 16],
            [2012, 14266, 21, 15],
            [2012, 14267, 8, 6],
            [2012, 14268, 8, 6],
            [2012, 14269, 33, 18],
            [2012, 14270, 12, 8],
            [2012, 14271, 11, 8],
            [2012, 14272, 9, 6],
            [2012, 14273, 29, 16],
            [2012, 14274, 21, 14],
            [2012, 14275, 28, 14],
            [2012, 14276, 17, 12],
            [2012, 14277, 10, 6],
            [2012, 14278, 10, 8],
            [2012, 14279, 9, 6],
            [2012, 14280, 24, 14],
            [2012, 14281, 12, 7],
            [2012, 14282, 15, 9],
            [2012, 14283, 13, 7],
            [2012, 14284, 28, 15],
            [2012, 14285, 24, 13],
            [2012, 14286, 26, 15],
            [2012, 14287, 18, 12],
            [2012, 14288, 19, 11],
            [2012, 14289, 28, 15],
            [2012, 14290, 33, 19],
            [2012, 14291, 20, 13],
            [2012, 14292, 22, 12],
            [2012, 14293, 17, 9],
            [2012, 14294, 24, 13],
            [2012, 14295, 25, 13],
            [2012, 14296, 28, 15],
            [2012, 14297, 24, 15],
            [2012, 14298, 15, 9],
            [2012, 14299, 23, 15],
            [2012, 14300, 9, 7],
            [2012, 14301, 11, 9],
            [2012, 14302, 11, 9],
            [2012, 14303, 26, 16],
            [2012, 14304, 19, 11],
            [2012, 14305, 31, 17],
            [2012, 14306, 30, 18],
            [2012, 14307, 8, 7],
            [2012, 14308, 23, 14],
            [2012, 14309, 12, 10],
            [2012, 14310, 24, 15],
            [2012, 14311, 25, 16],
            [2012, 14312, 27, 17],
            [2012, 14313, 17, 10],
            [2012, 14314, 26, 16],
            [2012, 14315, 22, 15],
            [2012, 14316, 23, 15],
            [2012, 14317, 18, 14],
            [2012, 14318, 29, 18],
            [2012, 14319, 15, 11],
            [2012, 14320, 11, 9],
            [2012, 14321, 27, 17],
            [2012, 14322, 18, 14],
            [2012, 14323, 25, 16],
            [2012, 14324, 21, 15],
            [2012, 14325, 39, 16],
            [2012, 14326, 9, 7],
            [2012, 14327, 30, 16],
            [2012, 14328, 20, 13],
            [2012, 14329, 26, 16],
            [2012, 14330, 24, 15],
            [2012, 14331, 24, 16],
            [2012, 14332, 12, 9],
            [2012, 14333, 14, 10],
            [2012, 14334, 29, 16],
            [2012, 14335, 25, 17],
            [2012, 14336, 13, 11],
            [2012, 14337, 14, 11],
            [2012, 14338, 24, 15],
            [2012, 14339, 9, 7],
            [2012, 14340, 12, 8],
            [2012, 14341, 27, 17],
            [2012, 14342, 31, 19],
            [2012, 14343, 26, 16],
            [2012, 14344, 30, 16],
            [2012, 14345, 27, 17],
            [2012, 14346, 30, 17],
            [2012, 14347, 13, 11],
            [2012, 14348, 30, 16],
            [2012, 14349, 19, 13],
            [2012, 14350, 15, 11],
            [2012, 14351, 10, 7],
            [2012, 14352, 27, 16],
            [2012, 14353, 23, 15],
            [2012, 14354, 30, 18],
            [2012, 14355, 23, 16],
            [2012, 14356, 12, 10],
            [2012, 14357, 24, 15],
            [2012, 14358, 16, 12],
            [2012, 14359, 30, 16],
            [2012, 14360, 12, 10],
            [2012, 14361, 26, 16],
            [2012, 14362, 23, 15],
            [2012, 14363, 30, 18],
            [2012, 14364, 25, 15],
            [2012, 14365, 20, 13],
            [2012, 14366, 28, 17],
            [2012, 14367, 33, 18],
            [2012, 14368, 29, 18],
            [2012, 14369, 30, 17],
            [2012, 14370, 12, 10],
            [2012, 14371, 8, 7],
            [2012, 14372, 13, 10],
            [2012, 14373, 26, 16],
            [2012, 14374, 28, 15],
            [2012, 14375, 26, 15],
            [2012, 14376, 8, 7],
            [2012, 14377, 8, 7],
            [2012, 14378, 8, 7],
            [2012, 14379, 30, 18],
            [2012, 14380, 26, 16],
            [2012, 14381, 27, 17],
            [2012, 14382, 27, 17],
            [2012, 14383, 14, 10],
            [2012, 14384, 31, 15],
            [2012, 14385, 29, 16],
            [2012, 14386, 28, 17],
            [2012, 14387, 29, 19],
            [2012, 14388, 39, 22],
            [2012, 14389, 27, 16],
            [2012, 14390, 26, 16],
            [2012, 14391, 15, 10],
            [2012, 14392, 26, 16],
            [2012, 14393, 16, 11],
            [2012, 14394, 31, 16],
            [2012, 14395, 30, 17],
            [2012, 14396, 23, 15],
            [2012, 14397, 25, 16],
            [2012, 14398, 24, 15],
            [2012, 14399, 34, 18],
            [2012, 14400, 32, 19],
            [2012, 14401, 25, 15],
            [2012, 14402, 14, 10],
            [2012, 14403, 28, 17],
            [2012, 14404, 30, 15],
            [2012, 14405, 40, 18],
            [2012, 14406, 40, 22],
            [2012, 14407, 30, 17],
            [2012, 14408, 20, 14],
            [2012, 14409, 29, 15],
            [2012, 14410, 13, 11],
            [2012, 14411, 20, 12],
            [2012, 14412, 18, 11],
            [2012, 14413, 11, 9],
            [2012, 14414, 8, 7],
            [2012, 14415, 26, 16],
            [2012, 14416, 18, 13],
            [2012, 14417, 21, 15],
            [2012, 14418, 26, 12],
            [2012, 14419, 30, 16],
            [2012, 14420, 16, 12],
            [2012, 14421, 35, 16],
            [2012, 14422, 23, 13],
            [2012, 14423, 18, 11],
            [2012, 14424, 17, 12],
            [2012, 14425, 35, 21],
            [2012, 14426, 19, 13],
            [2012, 14427, 27, 15],
            [2012, 14428, 26, 15],
            [2012, 14429, 22, 13],
            [2012, 14430, 28, 16],
            [2012, 14431, 11, 9],
            [2012, 14432, 25, 15],
            [2012, 14433, 38, 21],
            [2012, 14434, 21, 12],
            [2012, 14435, 13, 14],
            [2012, 14436, 27, 24],
            [2012, 14438, 20, 41],
            [2012, 14440, 20, 38],
            [2012, 14442, 20, 23],
            [2012, 14445, 26, 38],
            [2012, 14446, 26, 32],
            [2012, 14447, 20, 23],
            [2012, 14449, 18, 30],
            [2012, 14450, 63, 40],
            [2012, 14452, 32, 39],
            [2012, 14453, 26, 48],
            [2012, 14458, 29, 45],
            [2012, 14459, 30, 30],
            [2012, 14460, 30, 30],
            [2012, 14462, 20, 36],
            [2012, 14463, 18, 24],
            [2012, 14464, 32, 30],
            [2012, 14465, 42, 23],
            [2012, 14466, 27, 30],
            [2012, 14468, 30, 35],
            [2012, 14470, 30, 29],
            [2012, 14471, 26, 29],
            [2012, 14473, 33, 28],
            [2012, 14476, 32, 30],
            [2012, 14478, 28, 29],
            [2012, 14480, 30, 30],
            [2012, 14484, 30, 35],
            [2012, 14485, 18, 24],
            [2012, 14486, 33, 28],
            [2012, 14488, 23, 30],
            [2012, 14489, 18, 24],
            [2012, 14490, 38, 30],
            [2012, 14491, 23, 30],
            [2012, 14493, 30, 41],
            [2012, 14495, 24, 30],
            [2012, 14496, 40, 39],
            [2012, 14500, 24, 35],
            [2012, 14501, 20, 30],
            [2012, 14502, 42, 30],
            [2012, 14503, 30, 30],
            [2012, 14505, 28, 28],
            [2012, 14507, 30, 44],
            [2012, 14508, 18, 30],
            [2012, 14509, 33, 29],
            [2012, 14510, 33, 28],
            [2012, 14512, 30, 30],
            [2012, 14513, 40, 32],
            [2012, 14514, 38, 44],
            [2012, 14516, 40, 38],
            [2012, 14518, 30, 29],
            [2012, 14519, 44, 36],
            [2012, 14520, 30, 41],
            [2012, 14524, 24, 27],
            [2012, 14527, 30, 50],
            [2012, 14528, 46, 39],
            [2012, 14530, 47, 44],
            [2012, 14532, 11, 11],
            [2012, 14533, 13, 14],
            [2012, 14534, 19, 13],
            [2012, 14535, 12, 7],
            [2012, 14536, 20, 15],
            [2012, 14537, 20, 16],
            [2012, 14538, 25, 16],
            [2012, 14539, 7, 8],
            [2012, 14540, 17, 12],
            [2012, 14541, 20, 16],
            [2012, 14542, 17, 12],
            [2012, 14543, 16, 14],
            [2012, 14544, 10, 10],
            [2012, 14545, 20, 17],
            [2012, 14546, 21, 16],
            [2012, 14547, 21, 15],
            [2012, 14548, 22, 17],
            [2012, 14549, 28, 17],
            [2012, 14550, 19, 16],
            [2012, 14551, 21, 14],
            [2012, 14552, 9, 10],
            [2012, 14553, 16, 17],
            [2012, 14554, 17, 11],
            [2012, 14555, 12, 14],
            [2012, 14556, 25, 19],
            [2012, 14557, 24, 20],
            [2012, 14558, 12, 11],
            [2012, 14559, 12, 11],
            [2012, 14560, 12, 12],
            [2012, 14561, 9, 9],
            [2012, 14562, 92, 34],
            [2012, 14563, 103, 34],
            [2012, 14564, 24, 19],
            [2012, 14565, 20, 43],
            [2012, 14566, 16, 22],
            [2012, 14567, 24, 40],
            [2012, 14568, 77, 77],
            [2012, 14569, 20, 18],
            [2012, 14570, 20, 24],
            [2012, 14571, 16, 17],
            [2012, 14572, 16, 23],
            [2012, 14573, 96, 82],
            [2012, 14574, 12, 11],
            [2012, 14575, 8, 6],
            [2012, 14576, 9, 8],
            [2012, 14577, 35, 23],
            [2012, 14578, 21, 18],
            [2012, 14579, 17, 12],
            [2012, 14580, 8, 8],
            [2012, 14581, 9, 11],
            [2012, 14582, 25, 27],
            [2012, 14583, 20, 15],
            [2012, 14584, 7, 7],
            [2012, 14585, 11, 10],
            [2012, 14586, 11, 12],
            [2012, 14587, 12, 11],
            [2012, 14588, 25, 17],
            [2012, 14589, 8, 7],
            [2012, 14590, 20, 18],
            [2012, 14591, 20, 16],
            [2012, 14592, 2, 2],
            [2012, 14593, 53, 39],
            [2012, 14594, 4, 4],
            [2012, 14595, 9, 9],
            [2012, 14596, 5, 4],
            [2012, 14597, 9, 7],
            [2012, 14598, 15, 9],
            [2012, 14599, 17, 9],
            [2012, 14600, 32, 18],
            [2012, 14601, 7, 6],
            [2012, 14602, 21, 19],
            [2012, 14603, 12, 8],
            [2012, 14604, 10, 9],
            [2012, 14605, 16, 15],
            [2012, 14606, 6, 6],
            [2012, 14607, 6, 6],
            [2012, 14608, 9, 9],
            [2012, 14609, 11, 8],
            [2012, 14610, 4, 4],
            [2012, 14611, 6, 5],
            [2012, 14612, 5, 7],
            [2012, 14613, 21, 17],
            [2012, 14614, 22, 16],
            [2012, 14615, 16, 16],
            [2012, 14616, 13, 13],
            [2012, 14617, 36, 25],
            [2012, 14618, 7, 7],
            [2012, 14619, 18, 15],
            [2012, 14620, 13, 13],
            [2012, 14621, 8, 6],
            [2012, 14622, 14, 11],
            [2012, 14623, 16, 12],
            [2012, 14624, 9, 9],
            [2012, 14625, 11, 7],
            [2012, 14626, 8, 6],
            [2012, 14627, 31, 20],
            [2012, 14628, 17, 16],
            [2012, 14629, 25, 18],
            [2012, 14630, 7, 7],
            [2012, 14631, 6, 5],
            [2012, 14632, 33, 25],
            [2012, 14633, 32, 29],
            [2012, 14634, 10, 9],
            [2012, 14635, 7, 6],
            [2012, 14636, 17, 12],
            [2012, 14637, 15, 12],
            [2012, 14638, 20, 12],
            [2012, 14639, 5, 6],
            [2012, 14640, 9, 6],
            [2012, 14641, 17, 16],
            [2012, 14642, 25, 15],
            [2012, 14643, 6, 6],
            [2012, 14644, 6, 7],
            [2012, 14645, 15, 13],
            [2012, 14646, 8, 7],
            [2012, 14647, 23, 14],
            [2012, 14648, 4, 4],
            [2012, 14649, 12, 11],
            [2012, 14650, 15, 13],
            [2012, 14651, 15, 12],
            [2012, 14652, 19, 15],
            [2012, 14653, 23, 16],
            [2012, 14654, 22, 18],
            [2012, 14655, 4, 4],
            [2012, 14656, 11, 12],
            [2012, 14657, 7, 6],
            [2012, 14658, 17, 13],
            [2012, 14659, 15, 12],
            [2012, 14660, 14, 15],
            [2012, 14661, 9, 11],
            [2012, 14662, 20, 14],
            [2012, 14663, 17, 15],
            [2012, 14664, 8, 8],
            [2012, 14665, 12, 11],
            [2012, 14666, 12, 11],
            [2012, 14667, 19, 13],
            [2012, 14668, 15, 13],
            [2012, 14669, 29, 27],
            [2012, 14670, 15, 13],
            [2012, 14671, 17, 15],
            [2012, 14672, 14, 15],
            [2012, 14673, 21, 18],
            [2012, 14674, 10, 9],
            [2012, 14675, 8, 7],
            [2012, 14676, 14, 12],
            [2012, 14677, 13, 11],
            [2012, 14678, 18, 11],
            [2012, 14679, 13, 11],
            [2012, 14680, 17, 14],
            [2012, 14681, 16, 12],
            [2012, 14682, 11, 9],
            [2012, 14683, 17, 13],
            [2012, 14684, 35, 23],
            [2012, 14685, 14, 8],
            [2012, 14686, 11, 8],
            [2012, 14687, 21, 15],
            [2012, 14688, 6, 6],
            [2012, 14689, 12, 11],
            [2012, 14690, 21, 17],
            [2012, 14691, 16, 12],
            [2012, 14692, 17, 17],
            [2012, 14693, 11, 8],
            [2012, 14694, 8, 6],
            [2012, 14695, 11, 8],
            [2012, 14696, 9, 9],
            [2012, 14697, 14, 12],
            [2012, 14698, 17, 9],
            [2012, 14699, 21, 17],
            [2012, 14700, 21, 17],
            [2012, 14701, 35, 21],
            [2012, 14702, 45, 32],
            [2012, 14703, 35, 24],
            [2012, 14704, 75, 46],
            [2012, 14705, 28, 21],
            [2012, 14706, 50, 27],
            [2012, 14707, 15, 11],
            [2012, 14708, 23, 17],
            [2012, 14709, 34, 23],
            [2012, 14710, 34, 19],
            [2012, 14711, 36, 25],
            [2012, 14712, 45, 26],
            [2012, 14713, 40, 26],
            [2012, 14714, 32, 21],
            [2012, 14715, 17, 11],
            [2012, 14716, 14, 10],
            [2012, 14717, 16, 12],
            [2012, 14718, 25, 24],
            [2012, 14719, 23, 19],
            [2012, 14720, 75, 44],
            [2012, 14721, 55, 30],
            [2012, 14722, 35, 25],
            [2012, 14723, 14, 11],
            [2012, 14724, 23, 21],
            [2012, 14725, 28, 27],
            [2012, 14726, 26, 23],
            [2012, 14727, 50, 25],
            [2012, 14728, 40, 27],
            [2012, 14729, 32, 27],
            [2012, 14730, 28, 23],
            [2012, 14731, 23, 23],
            [2012, 14732, 55, 27],
            [2012, 14733, 40, 23],
            [2012, 14734, 35, 40],
            [2012, 14735, 55, 32],
            [2012, 14736, 50, 29],
            [2012, 14737, 15, 11],
            [2012, 14738, 34, 25],
            [2012, 14739, 23, 21],
            [2012, 14740, 40, 33],
            [2012, 14741, 32, 23],
            [2012, 14742, 26, 27],
            [2012, 14743, 25, 17],
            [2012, 14744, 14, 11],
            [2012, 14745, 33, 31],
            [2012, 14746, 17, 13],
            [2012, 14747, 32, 27],
            [2012, 14748, 23, 21],
            [2012, 14749, 15, 11],
            [2012, 14750, 26, 19],
            [2012, 14751, 34, 21],
            [2012, 14752, 25, 19],
            [2012, 14753, 40, 27],
            [2012, 14754, 21, 21],
            [2012, 14755, 25, 27],
            [2012, 14756, 25, 21],
            [2012, 14757, 21, 13],
            [2012, 14758, 32, 19],
            [2012, 14759, 35, 25],
            [2012, 14760, 35, 27],
            [2012, 14761, 23, 11],
            [2012, 14762, 14, 11],
            [2012, 14763, 28, 41],
            [2012, 14764, 60, 33],
            [2012, 14765, 15, 11],
            [2012, 14766, 50, 31],
            [2012, 14767, 32, 33],
            [2012, 14768, 5, 5],
            [2012, 14769, 46, 29],
            [2012, 14770, 20, 23],
            [2012, 14771, 33, 41],
            [2012, 14772, 61, 41],
            [2012, 14773, 41, 51],
            [2012, 14774, 33, 21],
            [2012, 14775, 39, 35],
            [2012, 14776, 46, 39],
            [2012, 14777, 23, 27],
            [2012, 14778, 15, 12],
            [2012, 14779, 46, 27],
            [2012, 14780, 41, 14],
            [2012, 14781, 11, 11],
            [2012, 14782, 71, 35],
            [2012, 14783, 31, 27],
            [2012, 14784, 17, 27],
            [2012, 14785, 71, 51],
            [2012, 14786, 29, 20],
            [2012, 14787, 29, 19],
            [2012, 14788, 29, 27],
            [2012, 14789, 81, 46],
            [2012, 14790, 56, 23],
            [2012, 14791, 15, 14],
            [2012, 14792, 71, 66],
            [2012, 14793, 41, 27],
            [2012, 14794, 33, 33],
            [2012, 14795, 35, 27],
            [2012, 14796, 39, 56],
            [2012, 14797, 29, 66],
            [2012, 14798, 31, 51],
            [2012, 14799, 51, 27],
            [2012, 14800, 15, 11],
            [2012, 14801, 33, 16],
            [2012, 14802, 23, 14],
            [2012, 14803, 39, 39],
            [2012, 14804, 15, 13],
            [2012, 14805, 39, 39],
            [2012, 14806, 17, 14],
            [2012, 14807, 41, 29],
            [2012, 14808, 56, 56],
            [2012, 14809, 17, 29],
            [2012, 14810, 18, 20],
            [2012, 14811, 18, 23],
            [2012, 14812, 51, 41],
            [2012, 14813, 29, 23],
            [2012, 14814, 41, 27],
            [2012, 14815, 66, 31],
            [2012, 14816, 15, 13],
            [2012, 14817, 15, 11],
            [2012, 14818, 15, 11],
            [2012, 14819, 39, 35],
            [2012, 14820, 81, 66],
            [2012, 14821, 23, 20],
            [2012, 14822, 51, 46],
            [2012, 14823, 21, 21],
            [2012, 14824, 71, 46],
            [2012, 14825, 18, 19],
            [2012, 14826, 46, 21],
            [2012, 14827, 51, 41],
            [2012, 14828, 56, 46],
            [2012, 14829, 19, 20],
            [2012, 14830, 15, 17],
            [2012, 14831, 33, 20],
            [2012, 14832, 51, 41],
            [2012, 14833, 41, 33],
            [2012, 14834, 46, 51],
            [2012, 14835, 61, 23],
            [2012, 14836, 51, 25],
            [2012, 14837, 66, 41],
            [2012, 14838, 66, 51],
            [2012, 14839, 33, 39],
            [2012, 14840, 35, 27],
            [2012, 14841, 25, 23],
            [2012, 14842, 20, 17],
            [2012, 14843, 66, 41],
            [2012, 14844, 18, 19],
            [2012, 14845, 56, 56],
            [2012, 14846, 39, 19],
            [2012, 14847, 15, 13],
            [2012, 14848, 15, 11],
            [2012, 14849, 15, 11],
            [2012, 14850, 46, 31],
            [2012, 14851, 20, 25],
            [2012, 14852, 16, 12],
            [2012, 14853, 29, 25],
            [2012, 14854, 66, 51],
            [2012, 14855, 11, 11],
            [2012, 14856, 11, 11],
            [2012, 14857, 11, 11],
            [2012, 14858, 19, 17],
            [2012, 14859, 27, 27],
            [2012, 14860, 20, 19],
            [2012, 14861, 16, 15],
            [2012, 14862, 22, 16],
            [2012, 14863, 11, 12],
            [2012, 14864, 11, 11],
            [2012, 14865, 23, 27],
            [2012, 14866, 23, 24],
            [2012, 14867, 16, 27],
            [2012, 14868, 29, 26],
            [2012, 14869, 27, 29],
            [2012, 14870, 11, 11],
            [2012, 14871, 11, 11],
            [2012, 14872, 11, 11],
            [2012, 14873, 32, 24],
            [2012, 14874, 25, 18],
            [2012, 14875, 29, 31],
            [2012, 14876, 16, 17],
            [2012, 14877, 53, 40],
            [2012, 14878, 12, 16],
            [2012, 14879, 24, 24],
            [2012, 14880, 23, 14],
            [2012, 14881, 29, 26],
            [2012, 14882, 29, 29],
            [2012, 14883, 12, 19],
            [2012, 14884, 12, 13],
            [2012, 14885, 12, 12],
            [2012, 14886, 27, 21],
            [2012, 14887, 21, 15],
            [2012, 14888, 14, 14],
            [2012, 14889, 28, 24],
            [2012, 14890, 18, 15],
            [2012, 14891, 23, 30],
            [2012, 14892, 28, 33],
            [2012, 14893, 21, 35],
            [2012, 14894, 17, 18],
            [2012, 14895, 25, 19],
            [2012, 14896, 43, 39],
            [2012, 14897, 22, 23],
            [2012, 14898, 38, 27],
            [2012, 14899, 16, 15],
            [2012, 14900, 14, 12],
            [2012, 14901, 12, 12],
            [2012, 14902, 21, 24],
            [2012, 14903, 25, 21],
            [2012, 14904, 29, 25],
            [2012, 14905, 35, 29],
            [2012, 14906, 15, 16],
            [2012, 14907, 11, 11],
            [2012, 14908, 11, 11],
            [2012, 14909, 11, 11],
            [2012, 14910, 19, 21],
            [2012, 14911, 24, 23],
            [2012, 14912, 24, 22],
            [2012, 14913, 16, 17],
            [2012, 14914, 17, 18],
            [2012, 14915, 26, 23],
            [2012, 14916, 28, 20],
            [2012, 14917, 24, 29],
            [2012, 14918, 34, 39],
            [2012, 14919, 14, 14],
            [2012, 14920, 30, 31],
            [2012, 14921, 18, 15],
            [2012, 14922, 12, 13],
            [2012, 14923, 23, 21],
            [2012, 14924, 24, 27],
            [2012, 14925, 23, 19],
            [2012, 14926, 29, 36],
            [2012, 14927, 25, 33],
            [2012, 14928, 23, 28],
            [2012, 14929, 24, 26],
            [2012, 14930, 23, 24],
            [2012, 14931, 14, 13],
            [2012, 14932, 17, 14],
            [2012, 14933, 20, 18],
            [2012, 14934, 39, 39],
            [2012, 14935, 15, 28],
            [2012, 14936, 11, 12],
            [2012, 14937, 12, 12],
            [2012, 14938, 30, 30],
            [2012, 14939, 36, 30],
            [2012, 14940, 13, 12],
            [2012, 14941, 42, 38],
            [2012, 14942, 12, 11],
            [2012, 14943, 23, 18],
            [2012, 14944, 18, 17],
            [2012, 14945, 33, 32],
            [2012, 14946, 14, 14],
            [2012, 14947, 19, 19],
            [2012, 14948, 39, 33],
            [2012, 14949, 39, 30],
            [2012, 14950, 14, 12],
            [2012, 14951, 26, 19],
            [2012, 14952, 43, 24],
            [2012, 14953, 20, 21],
            [2012, 14954, 32, 27],
            [2012, 14955, 19, 14],
            [2012, 14956, 27, 26],
            [2012, 14957, 15, 16],
            [2012, 14958, 18, 36],
            [2012, 14959, 14, 13],
            [2012, 14960, 24, 18],
            [2012, 14961, 21, 23],
            [2012, 14962, 25, 31],
            [2012, 14963, 24, 26],
            [2012, 14964, 17, 16],
            [2012, 14965, 11, 11],
            [2012, 14966, 11, 11],
            [2012, 14967, 18, 19],
            [2012, 14968, 25, 28],
            [2012, 14969, 12, 13],
            [2012, 14970, 12, 13],
            [2012, 14971, 15, 12],
            [2012, 14972, 34, 32],
            [2012, 14973, 23, 21],
            [2012, 14974, 25, 19],
            [2012, 14975, 18, 13],
            [2012, 14976, 26, 19],
            [2012, 14977, 24, 18],
            [2012, 14978, 26, 39],
            [2012, 14979, 21, 17],
            [2012, 14980, 28, 28],
            [2012, 14981, 22, 19],
            [2012, 14982, 12, 12],
            [2012, 14983, 31, 25],
            [2012, 14984, 20, 14],
            [2012, 14985, 20, 20],
            [2012, 14986, 38, 37],
            [2012, 14987, 28, 25],
            [2012, 14988, 21, 23],
            [2012, 14989, 15, 19],
            [2012, 14990, 12, 11],
            [2012, 14991, 8, 6],
            [2012, 14992, 1, 1],
            [2012, 14993, 10, 8],
            [2012, 14994, 10, 6],
            [2012, 14995, 7, 6],
            [2012, 14996, 7, 6],
            [2012, 14997, 29, 20],
            [2012, 14998, 7, 4],
            [2012, 14999, 7, 6],
            [2012, 15000, 19, 17],
            [2012, 15001, 11, 11],
            [2012, 15002, 7, 6],
            [2012, 15003, 17, 15],
            [2012, 15004, 4, 4],
            [2012, 15005, 17, 15],
            [2012, 15006, 14, 12],
            [2012, 15007, 8, 4],
            [2012, 15008, 1, 1],
            [2012, 15009, 15, 13],
            [2012, 15010, 10, 8],
            [2012, 15011, 6, 5],
            [2012, 15012, 1, 1],
            [2012, 15013, 10, 9],
            [2012, 15014, 10, 7],
            [2012, 15015, 15, 15],
            [2012, 15016, 1, 1],
            [2012, 15017, 9, 6],
            [2012, 15018, 12, 11],
            [2012, 15019, 7, 6],
            [2012, 15020, 14, 12],
            [2012, 15021, 7, 5],
            [2012, 15022, 10, 8],
            [2012, 15023, 11, 8],
            [2012, 15024, 10, 8],
            [2012, 15025, 8, 6],
            [2012, 15026, 10, 8],
            [2012, 15027, 7, 6],
            [2012, 15028, 10, 9],
            [2012, 15029, 12, 10],
            [2012, 15030, 8, 5],
            [2012, 15031, 7, 4],
            [2012, 15032, 7, 4],
            [2012, 15033, 4, 2],
            [2012, 15034, 7, 6],
            [2012, 15035, 11, 9],
            [2012, 15036, 9, 7],
            [2012, 15037, 11, 6],
            [2012, 15038, 20, 19],
            [2012, 15039, 12, 9],
            [2012, 15040, 10, 9],
            [2012, 15041, 1, 1],
            [2012, 15042, 11, 7],
            [2012, 15043, 15, 13],
            [2012, 15044, 9, 7],
            [2012, 15045, 8, 6],
            [2012, 15046, 2, 1],
            [2012, 15047, 7, 5],
            [2012, 15048, 14, 13],
            [2012, 15049, 9, 6],
            [2012, 15050, 7, 5],
            [2012, 15051, 13, 12],
            [2012, 15052, 10, 6],
            [2012, 15053, 16, 14],
            [2012, 15054, 9, 6],
            [2012, 15055, 8, 6],
            [2012, 15056, 10, 9],
            [2012, 15057, 7, 5],
            [2012, 15058, 7, 5],
            [2012, 15059, 2, 1],
            [2012, 15060, 3, 1],
            [2012, 15061, 8, 6],
            [2012, 15062, 9, 7],
            [2012, 15063, 1, 1],
            [2012, 15064, 1, 1],
            [2012, 15065, 1, 1],
            [2012, 15066, 9, 7],
            [2012, 15067, 8, 6],
            [2012, 15068, 16, 14],
            [2012, 15069, 10, 9],
            [2012, 15070, 21, 20],
            [2012, 15071, 6, 5],
            [2012, 15072, 13, 12],
            [2012, 15073, 9, 6],
            [2012, 15074, 10, 8],
            [2012, 15075, 1, 1],
            [2012, 15076, 1, 1],
            [2012, 15077, 29, 19],
            [2012, 15078, 8, 6],
            [2012, 15079, 2, 1],
            [2012, 15080, 11, 9],
            [2012, 15081, 28, 20],
            [2012, 15082, 7, 5],
            [2012, 15083, 1, 1],
            [2012, 15084, 7, 6],
            [2012, 15085, 9, 8],
            [2012, 15086, 11, 8],
            [2012, 15087, 7, 6],
            [2012, 15088, 15, 12],
            [2012, 15089, 21, 17],
            [2012, 15090, 20, 16],
            [2012, 15091, 12, 11],
            [2012, 15092, 17, 10],
            [2012, 15093, 15, 9],
            [2012, 15094, 9, 7],
            [2012, 15095, 19, 15],
            [2012, 15096, 15, 10],
            [2012, 15097, 13, 12],
            [2012, 15098, 15, 13],
            [2012, 15099, 20, 15],
            [2012, 15100, 10, 10],
            [2012, 15101, 12, 10],
            [2012, 15102, 15, 9],
            [2012, 15103, 13, 8],
            [2012, 15104, 11, 6],
            [2012, 15105, 12, 10],
            [2012, 15106, 13, 7],
            [2012, 15107, 8, 7],
            [2012, 15108, 21, 14],
            [2012, 15109, 21, 14],
            [2012, 15110, 6, 5],
            [2012, 15111, 15, 10],
            [2012, 15112, 21, 14],
            [2012, 15113, 24, 13],
            [2012, 15114, 9, 8],
            [2012, 15115, 9, 7],
            [2012, 15116, 9, 8],
            [2012, 15117, 11, 8],
            [2012, 15118, 8, 7],
            [2012, 15119, 6, 5],
            [2012, 15120, 8, 7],
            [2012, 15121, 7, 5],
            [2012, 15122, 3, 3],
            [2012, 15123, 3, 3],
            [2012, 15124, 5, 5],
            [2012, 15125, 4, 5],
            [2012, 15126, 7, 6],
            [2012, 15127, 6, 5],
            [2012, 15128, 24, 15],
            [2012, 15129, 7, 5],
            [2012, 15130, 6, 5],
            [2012, 15131, 5, 5],
            [2012, 15132, 26, 18],
            [2012, 15133, 30, 14],
            [2012, 15134, 18, 14],
            [2012, 15135, 20, 12],
            [2012, 15136, 15, 11],
            [2012, 15137, 13, 9],
            [2012, 15138, 17, 10],
            [2012, 15139, 31, 17],
            [2012, 15140, 15, 11],
            [2012, 15141, 11, 7],
            [2012, 15142, 11, 8],
            [2012, 15143, 11, 8],
            [2012, 15144, 17, 9],
            [2012, 15145, 13, 9],
            [2012, 15146, 21, 13],
            [2012, 15147, 9, 6],
            [2012, 15148, 7, 5],
            [2012, 15149, 15, 10],
            [2012, 15150, 14, 8],
            [2012, 15151, 7, 5],
            [2012, 15152, 7, 6],
            [2012, 15153, 17, 9],
            [2012, 15154, 17, 9],
            [2012, 15155, 21, 15],
            [2012, 15156, 13, 9],
            [2012, 15157, 13, 13],
            [2012, 15158, 21, 12],
            [2012, 15159, 7, 7],
            [2012, 15160, 27, 17],
            [2012, 15161, 11, 8],
            [2012, 15162, 15, 9],
            [2012, 15163, 16, 9],
            [2012, 15164, 17, 9],
            [2012, 15165, 26, 10],
            [2012, 15166, 17, 12],
            [2012, 15167, 11, 15],
            [2012, 15168, 21, 15],
            [2012, 15169, 23, 9],
            [2012, 15170, 12, 11],
            [2012, 15171, 12, 7],
            [2012, 15172, 8, 6],
            [2012, 15173, 11, 10],
            [2012, 15174, 11, 7],
            [2012, 15175, 9, 6],
            [2012, 15176, 6, 6],
            [2012, 15177, 23, 13],
            [2012, 15178, 7, 5],
            [2012, 15179, 7, 5],
            [2012, 15180, 8, 6],
            [2012, 15181, 8, 5],
            [2012, 15182, 15, 11],
            [2012, 15183, 18, 11],
            [2012, 15184, 18, 12],
            [2012, 15185, 31, 18],
            [2012, 15186, 17, 12],
            [2012, 15187, 12, 12],
            [2012, 15188, 17, 12],
            [2012, 15189, 15, 14],
            [2012, 15190, 17, 9],
            [2012, 15191, 14, 9],
            [2012, 15192, 10, 9],
            [2012, 15193, 9, 7],
            [2012, 15194, 13, 10],
            [2012, 15195, 18, 15],
            [2012, 15196, 15, 8],
            [2012, 15197, 20, 13],
            [2012, 15198, 15, 12],
            [2012, 15199, 21, 9],
            [2012, 15200, 19, 12],
            [2012, 15201, 13, 9],
            [2012, 15202, 21, 12],
            [2012, 15203, 17, 10],
            [2012, 15204, 17, 10],
            [2012, 15205, 9, 6],
            [2012, 15206, 17, 9],
            [2012, 15207, 10, 8],
            [2012, 15208, 12, 10],
            [2012, 15209, 13, 11],
            [2012, 15210, 11, 10],
            [2012, 15211, 16, 12],
            [2012, 15212, 15, 12],
            [2012, 15213, 30, 20],
            [2012, 15214, 10, 7],
            [2012, 15215, 13, 11],
            [2012, 15216, 14, 10],
            [2012, 15217, 10, 8],
            [2012, 15218, 11, 9],
            [2012, 15219, 14, 9],
            [2012, 15220, 18, 8],
            [2012, 15221, 18, 12],
            [2012, 15222, 21, 11],
            [2012, 15223, 14, 9],
            [2012, 15224, 12, 9],
            [2012, 15225, 10, 8],
            [2012, 15226, 11, 7],
            [2012, 15227, 15, 15],
            [2012, 15228, 17, 14],
            [2012, 15229, 16, 8],
            [2012, 15230, 18, 10],
            [2012, 15231, 10, 11],
            [2012, 15232, 21, 14],
            [2012, 15233, 16, 11],
            [2012, 15234, 16, 12],
            [2012, 15235, 9, 8],
            [2012, 15236, 15, 11],
            [2012, 15237, 17, 10],
            [2012, 15238, 11, 9],
            [2012, 15239, 10, 8],
            [2012, 15240, 12, 8],
            [2012, 15241, 13, 8],
            [2012, 15242, 14, 12],
            [2012, 15243, 19, 10],
            [2012, 15244, 9, 7],
            [2012, 15245, 14, 10],
            [2012, 15246, 19, 14],
            [2012, 15247, 17, 12],
            [2012, 15248, 18, 14],
            [2012, 15249, 13, 8],
            [2012, 15250, 14, 10],
            [2012, 15251, 17, 11],
            [2012, 15252, 17, 14],
            [2012, 15253, 17, 12],
            [2012, 15254, 10, 7],
            [2012, 15255, 12, 12],
            [2012, 15256, 9, 7],
            [2012, 15257, 9, 10],
            [2012, 15258, 11, 7],
            [2012, 15259, 15, 9],
            [2012, 15260, 18, 12],
            [2012, 15261, 15, 8],
            [2012, 15262, 10, 7],
            [2012, 15263, 23, 9],
            [2012, 15264, 20, 14],
            [2012, 15265, 20, 15],
            [2012, 15266, 17, 11],
            [2012, 15267, 15, 10],
            [2012, 15268, 30, 12],
            [2012, 15269, 13, 11],
            [2012, 15270, 15, 7],
            [2012, 15271, 7, 7],
            [2012, 15272, 19, 18],
            [2012, 15273, 13, 6],
            [2012, 15274, 21, 16],
            [2012, 15275, 18, 12],
            [2012, 15276, 17, 10],
            [2012, 15277, 8, 7],
            [2012, 15278, 7, 6],
            [2012, 15279, 21, 17],
            [2012, 15280, 14, 12],
            [2012, 15281, 17, 9],
            [2012, 15282, 28, 15],
            [2012, 15283, 28, 13],
            [2012, 15284, 15, 12],
            [2012, 15285, 11, 10],
            [2012, 15286, 21, 14],
            [2012, 15287, 21, 11],
            [2012, 15288, 17, 8],
            [2012, 15289, 11, 9],
            [2012, 15290, 21, 12],
            [2012, 15291, 9, 6],
            [2012, 15292, 12, 10],
            [2012, 15293, 14, 9],
            [2012, 15294, 22, 14],
            [2012, 15295, 13, 12],
            [2012, 15296, 17, 16],
            [2012, 15297, 19, 14],
            [2012, 15298, 20, 11],
            [2012, 15299, 25, 14],
            [2012, 15300, 24, 13],
            [2012, 15301, 10, 8],
            [2012, 15302, 13, 10],
            [2012, 15303, 9, 6],
            [2012, 15304, 7, 9],
            [2012, 15305, 21, 10],
            [2012, 15306, 6, 6],
            [2012, 15307, 5, 6],
            [2012, 15308, 12, 11],
            [2012, 15309, 9, 9],
            [2012, 15310, 11, 6],
            [2012, 15311, 18, 12],
            [2012, 15312, 14, 11],
            [2012, 15313, 23, 11],
            [2012, 15314, 17, 11],
            [2012, 15315, 16, 11],
            [2012, 15316, 19, 11],
            [2012, 15317, 17, 11],
            [2012, 15318, 9, 8],
            [2012, 15319, 13, 12],
            [2012, 15320, 14, 10],
            [2012, 15321, 8, 5],
            [2012, 15322, 18, 14],
            [2012, 15323, 20, 12],
            [2012, 15324, 15, 12],
            [2012, 15325, 10, 7],
            [2012, 15326, 28, 20],
            [2012, 15327, 13, 11],
            [2012, 15328, 13, 7],
            [2012, 15329, 14, 8],
            [2012, 15330, 9, 6],
            [2012, 15331, 13, 12],
            [2012, 15332, 6, 5],
            [2012, 15333, 10, 7],
            [2012, 15334, 13, 8],
            [2012, 15335, 13, 11],
            [2012, 15336, 20, 12],
            [2012, 15337, 11, 10],
            [2012, 15338, 8, 6],
            [2012, 15339, 16, 9],
            [2012, 15340, 21, 11],
            [2012, 15341, 28, 12],
            [2012, 15342, 22, 14],
            [2012, 15343, 16, 12],
            [2012, 15344, 8, 7],
            [2012, 15345, 10, 8],
            [2012, 15346, 13, 8],
            [2012, 15347, 16, 10],
            [2012, 15348, 16, 10],
            [2012, 15349, 11, 8],
            [2012, 15350, 21, 12],
            [2012, 15351, 19, 9],
            [2012, 15352, 13, 7],
            [2012, 15353, 16, 13],
            [2012, 15354, 21, 14],
            [2012, 15355, 14, 12],
            [2012, 15356, 17, 9],
            [2012, 15357, 15, 14],
            [2012, 15358, 17, 12],
            [2012, 15359, 17, 14],
            [2012, 15360, 17, 17],
            [2012, 15361, 41, 35],
            [2012, 15362, 4, 7],
            [2012, 15363, 6, 7],
            [2012, 15364, 40, 21],
            [2012, 15365, 6, 7],
            [2012, 15366, 15, 16],
            [2012, 15367, 15, 16],
            [2012, 15368, 6, 7],
            [2012, 15369, 11, 9],
            [2012, 15370, 12, 10],
            [2012, 15371, 15, 12],
            [2012, 15372, 13, 11],
            [2012, 15373, 15, 13],
            [2012, 15374, 19, 12],
            [2012, 15375, 11, 10],
            [2012, 15376, 6, 5],
            [2012, 15377, 14, 11],
            [2012, 15378, 18, 12],
            [2012, 15379, 14, 11],
            [2012, 15380, 5, 5],
            [2012, 15381, 18, 12],
            [2012, 15382, 17, 12],
            [2012, 15383, 9, 8],
            [2012, 15384, 6, 6],
            [2012, 15385, 7, 7],
            [2012, 15386, 13, 11],
            [2012, 15387, 7, 7],
            [2012, 15388, 6, 6],
            [2012, 15389, 13, 15],
            [2012, 15390, 15, 12],
            [2012, 15391, 26, 13],
            [2012, 15392, 22, 13],
            [2012, 15393, 5, 6],
            [2012, 15394, 14, 13],
            [2012, 15395, 10, 9],
            [2012, 15396, 6, 5],
            [2012, 15397, 14, 10],
            [2012, 15398, 19, 15],
            [2012, 15399, 15, 12],
            [2012, 15400, 20, 11],
            [2012, 15401, 23, 13],
            [2012, 15402, 9, 8],
            [2012, 15403, 21, 11],
            [2012, 15404, 19, 12],
            [2012, 15405, 23, 13],
            [2012, 15406, 13, 12],
            [2012, 15407, 21, 15],
            [2012, 15408, 21, 12],
            [2012, 15409, 25, 11],
            [2012, 15410, 16, 10],
            [2012, 15411, 6, 6],
            [2012, 15412, 17, 12],
            [2012, 15413, 5, 5],
            [2012, 15414, 13, 10],
            [2012, 15415, 15, 12],
            [2012, 15416, 20, 12],
            [2012, 15417, 18, 11],
            [2012, 15418, 20, 11],
            [2012, 15419, 17, 14],
            [2012, 15420, 9, 8],
            [2012, 15459, 34, 33],
            [2012, 15460, 25, 43],
            [2012, 15461, 26, 24],
            [2012, 15462, 38, 44],
            [2012, 15463, 21, 24],
            [2012, 15464, 26, 27],
            [2012, 15465, 46, 37],
            [2012, 15466, 71, 68],
            [2012, 15467, 47, 48],
            [2012, 15468, 41, 40],
            [2012, 15469, 20, 24],
            [2012, 15470, 40, 40],
            [2012, 15471, 40, 40],
            [2012, 15472, 20, 33],
            [2012, 15473, 20, 25],
            [2012, 15474, 36, 40],
            [2012, 15475, 18, 28],
            [2012, 15476, 26, 40],
            [2012, 15477, 26, 27],
            [2012, 15478, 58, 48],
            [2012, 15479, 22, 34],
            [2012, 15480, 24, 35],
            [2012, 15481, 50, 52],
            [2012, 15482, 34, 44],
            [2012, 15483, 30, 34],
            [2012, 15484, 48, 43],
            [2012, 15485, 19, 35],
            [2012, 15486, 13, 21],
            [2012, 15487, 30, 37],
            [2012, 15488, 34, 40],
            [2012, 15489, 25, 26],
            [2012, 15490, 99, 90],
            [2012, 15491, 49, 43],
            [2012, 15492, 37, 40],
            [2012, 15493, 17, 39],
            [2012, 15494, 35, 37],
            [2012, 15495, 62, 47],
            [2012, 15496, 23, 30],
            [2012, 15497, 36, 40],
            [2012, 15498, 18, 25],
            [2012, 15499, 40, 40],
            [2012, 15500, 16, 14],
            [2012, 15501, 15, 14],
            [2012, 15502, 15, 14],
            [2012, 15503, 14, 13],
            [2012, 15504, 16, 16],
            [2012, 15505, 62, 54],
            [2012, 15506, 30, 66],
            [2012, 15507, 60, 50],
            [2012, 15508, 60, 50],
            [2012, 15509, 40, 40],
            [2012, 15510, 40, 40],
            [2012, 15511, 74, 56],
            [2012, 15512, 70, 70],
            [2012, 15513, 23, 42],
            [2012, 15514, 40, 66],
            [2012, 15515, 40, 60],
            [2012, 15516, 32, 36],
            [2012, 15517, 70, 70],
            [2012, 15518, 40, 50],
            [2012, 15519, 30, 55],
            [2012, 15520, 40, 58],
            [2012, 15521, 54, 55],
            [2012, 15522, 82, 68],
            [2012, 15523, 82, 68],
            [2012, 15524, 30, 54],
            [2012, 15525, 40, 66],
            [2012, 15526, 38, 44],
            [2012, 15527, 30, 40],
            [2012, 15528, 22, 39],
            [2012, 15529, 40, 62],
            [2012, 15530, 90, 82],
            [2012, 15531, 90, 82],
            [2012, 15532, 70, 70],
            [2012, 15533, 30, 62],
            [2012, 15534, 58, 62],
            [2012, 15535, 70, 70],
            [2012, 15536, 40, 46],
            [2012, 15537, 16, 14],
            [2012, 15538, 40, 38],
            [2012, 15539, 18, 26],
            [2012, 15540, 12, 24],
            [2012, 15541, 28, 29],
            [2012, 15542, 44, 44],
            [2012, 15543, 38, 28],
            [2012, 15544, 5, 5],
            [2012, 15548, 13, 12],
            [2012, 15550, 4, 4],
            [2012, 15551, 6, 6],
            [2012, 15552, 14, 12],
            [2012, 15553, 12, 10],
            [2012, 15554, 13, 11],
            [2012, 15555, 7, 7],
            [2012, 15556, 12, 11],
            [2012, 15557, 18, 13],
            [2012, 15558, 7, 8],
            [2012, 15559, 7, 7],
            [2013, 964, 10, 10],
            [2013, 2142, 11, 10],
            [2013, 2922, 9, 10],
            [2013, 4536, 13, 12],
            [2013, 5273, 14, 12],
            [2013, 11581, 11, 10],
            [2013, 11582, 13, 13],
            [2013, 12312, 149, 95],
            [2013, 12313, 104, 82],
            [2013, 12314, 104, 82],
            [2013, 12315, 149, 95],
            [2013, 12316, 149, 95],
            [2013, 12317, 149, 95],
            [2013, 12318, 149, 95],
            [2013, 12319, 149, 95],
            [2013, 12320, 104, 82],
            [2013, 12321, 73, 75],
            [2013, 12322, 149, 95],
            [2013, 12323, 149, 95],
            [2013, 12324, 104, 82],
            [2013, 12325, 104, 82],
            [2013, 12474, 16, 16],
            [2013, 12475, 27, 17],
            [2013, 12476, 16, 13],
            [2013, 12477, 23, 18],
            [2013, 12478, 25, 20],
            [2013, 12479, 21, 21],
            [2013, 12480, 16, 13],
            [2013, 12481, 65, 38],
            [2013, 12482, 16, 13],
            [2013, 12483, 53, 44],
            [2013, 12484, 17, 13],
            [2013, 12485, 88, 42],
            [2013, 12486, 102, 39],
            [2013, 12487, 46, 27],
            [2013, 12488, 52, 36],
            [2013, 12489, 75, 21],
            [2013, 12523, 20, 11],
            [2013, 12524, 42, 27],
            [2013, 12525, 20, 19],
            [2013, 12526, 14, 14],
            [2013, 12527, 10, 10],
            [2013, 12528, 9, 11],
            [2013, 12529, 10, 11],
            [2013, 12530, 16, 11],
            [2013, 12532, 18, 14],
            [2013, 12534, 10, 11],
            [2013, 12535, 20, 15],
            [2013, 12536, 11, 11],
            [2013, 12537, 10, 10],
            [2013, 12538, 11, 13],
            [2013, 12539, 16, 11],
            [2013, 12540, 15, 15],
            [2013, 12541, 15, 13],
            [2013, 12542, 15, 15],
            [2013, 12543, 19, 18],
            [2013, 12545, 11, 10],
            [2013, 12546, 24, 26],
            [2013, 12547, 19, 19],
            [2013, 12548, 30, 20],
            [2013, 12549, 11, 10],
            [2013, 12550, 11, 10],
            [2013, 12551, 24, 19],
            [2013, 12552, 31, 19],
            [2013, 12553, 15, 13],
            [2013, 12554, 8, 10],
            [2013, 12556, 9, 10],
            [2013, 12557, 10, 14],
            [2013, 12558, 11, 15],
            [2013, 12559, 11, 11],
            [2013, 12560, 4, 6],
            [2013, 12561, 7, 9],
            [2013, 12562, 9, 10],
            [2013, 12563, 14, 11],
            [2013, 12565, 22, 15],
            [2013, 12566, 13, 11],
            [2013, 12567, 11, 10],
            [2013, 12568, 31, 33],
            [2013, 12569, 31, 33],
            [2013, 12570, 18, 19],
            [2013, 12571, 39, 19],
            [2013, 12573, 21, 20],
            [2013, 12574, 10, 11],
            [2013, 12575, 11, 11],
            [2013, 12576, 25, 19],
            [2013, 12577, 10, 11],
            [2013, 12578, 34, 32],
            [2013, 12579, 13, 18],
            [2013, 12580, 15, 15],
            [2013, 12581, 110, 95],
            [2013, 12582, 105, 121],
            [2013, 12583, 135, 152],
            [2013, 12584, 110, 80],
            [2013, 12585, 111, 140],
            [2013, 12586, 57, 20],
            [2013, 12589, 64, 54],
            [2013, 12590, 48, 38],
            [2013, 12591, 63, 50],
            [2013, 12592, 72, 57],
            [2013, 12593, 49, 35],
            [2013, 12594, 39, 38],
            [2013, 12595, 68, 64],
            [2013, 12596, 32, 27],
            [2013, 12597, 29, 26],
            [2013, 12598, 64, 54],
            [2013, 12599, 64, 54],
            [2013, 12600, 64, 54],
            [2013, 12634, 29, 22],
            [2013, 12635, 70, 53],
            [2013, 12636, 21, 21],
            [2013, 12637, 38, 18],
            [2013, 12638, 65, 23],
            [2013, 12639, 11, 9],
            [2013, 12640, 13, 10],
            [2013, 12641, 19, 20],
            [2013, 12642, 19, 20],
            [2013, 12643, 34, 27],
            [2013, 12644, 34, 24],
            [2013, 12645, 52, 44],
            [2013, 12646, 33, 37],
            [2013, 12647, 21, 30],
            [2013, 12648, 30, 28],
            [2013, 12649, 26, 25],
            [2013, 12650, 22, 23],
            [2013, 12651, 34, 29],
            [2013, 12652, 39, 33],
            [2013, 12653, 43, 38],
            [2013, 12654, 19, 19],
            [2013, 12655, 33, 31],
            [2013, 12656, 36, 27],
            [2013, 12657, 19, 20],
            [2013, 12658, 41, 36],
            [2013, 12659, 47, 42],
            [2013, 12660, 45, 36],
            [2013, 12661, 40, 38],
            [2013, 12662, 38, 35],
            [2013, 12663, 38, 29],
            [2013, 12664, 51, 41],
            [2013, 12665, 39, 34],
            [2013, 12668, 6, 6],
            [2013, 12669, 4, 4],
            [2013, 12670, 7, 8],
            [2013, 12671, 12, 13],
            [2013, 12672, 12, 13],
            [2013, 12673, 12, 14],
            [2013, 12674, 11, 10],
            [2013, 12675, 16, 15],
            [2013, 12680, 16, 14],
            [2013, 12681, 5, 4],
            [2013, 12682, 15, 13],
            [2013, 12683, 11, 10],
            [2013, 12684, 32, 19],
            [2013, 12685, 37, 27],
            [2013, 12686, 20, 18],
            [2013, 12687, 21, 20],
            [2013, 12688, 20, 19],
            [2013, 12689, 33, 22],
            [2013, 12690, 35, 23],
            [2013, 12691, 37, 24],
            [2013, 12692, 33, 24],
            [2013, 12693, 28, 21],
            [2013, 12694, 27, 21],
            [2013, 12695, 36, 23],
            [2013, 12696, 33, 21],
            [2013, 12697, 36, 23],
            [2013, 12698, 10, 8],
            [2013, 12699, 9, 7],
            [2013, 12700, 10, 8],
            [2013, 12701, 12, 10],
            [2013, 12702, 12, 9],
            [2013, 12703, 30, 32],
            [2013, 12704, 18, 12],
            [2013, 12705, 23, 13],
            [2013, 12706, 26, 23],
            [2013, 12707, 32, 24],
            [2013, 12708, 28, 21],
            [2013, 12709, 36, 24],
            [2013, 12710, 37, 24],
            [2013, 12711, 36, 26],
            [2013, 12712, 38, 32],
            [2013, 12713, 31, 28],
            [2013, 12714, 40, 28],
            [2013, 12715, 40, 29],
            [2013, 12716, 24, 20],
            [2013, 12717, 28, 24],
            [2013, 12718, 22, 17],
            [2013, 12719, 28, 21],
            [2013, 12720, 27, 21],
            [2013, 12721, 28, 17],
            [2013, 12722, 13, 11],
            [2013, 12723, 18, 16],
            [2013, 12724, 13, 11],
            [2013, 12725, 11, 13],
            [2013, 12726, 8, 8],
            [2013, 12727, 19, 23],
            [2013, 12728, 9, 9],
            [2013, 12729, 21, 27],
            [2013, 12730, 23, 13],
            [2013, 12731, 20, 24],
            [2013, 12732, 14, 15],
            [2013, 12735, 12, 13],
            [2013, 12736, 15, 16],
            [2013, 12737, 23, 14],
            [2013, 12738, 10, 11],
            [2013, 12739, 13, 15],
            [2013, 12740, 18, 20],
            [2013, 12741, 16, 16],
            [2013, 12742, 7, 7],
            [2013, 12743, 22, 14],
            [2013, 12744, 11, 12],
            [2013, 12745, 13, 14],
            [2013, 12746, 9, 11],
            [2013, 12747, 12, 14],
            [2013, 12748, 8, 12],
            [2013, 12749, 10, 14],
            [2013, 12750, 7, 7],
            [2013, 12751, 6, 8],
            [2013, 12752, 22, 16],
            [2013, 12753, 10, 12],
            [2013, 12754, 9, 9],
            [2013, 12755, 6, 6],
            [2013, 12756, 12, 10],
            [2013, 12757, 6, 7],
            [2013, 12758, 12, 12],
            [2013, 12759, 17, 16],
            [2013, 12760, 22, 14],
            [2013, 12761, 10, 12],
            [2013, 12762, 10, 10],
            [2013, 12763, 14, 18],
            [2013, 12765, 10, 10],
            [2013, 12766, 12, 15],
            [2013, 12767, 13, 17],
            [2013, 12768, 12, 12],
            [2013, 12770, 10, 13],
            [2013, 12771, 17, 16],
            [2013, 12772, 10, 10],
            [2013, 12773, 10, 10],
            [2013, 12775, 18, 21],
            [2013, 12776, 18, 20],
            [2013, 12777, 8, 8],
            [2013, 12778, 18, 21],
            [2013, 12779, 16, 17],
            [2013, 12780, 8, 8],
            [2013, 12781, 18, 21],
            [2013, 12782, 12, 13],
            [2013, 12783, 8, 8],
            [2013, 12784, 18, 21],
            [2013, 12785, 21, 14],
            [2013, 12786, 9, 9],
            [2013, 12787, 18, 20],
            [2013, 12788, 7, 8],
            [2013, 12789, 14, 16],
            [2013, 12790, 16, 13],
            [2013, 12791, 11, 8],
            [2013, 12792, 13, 13],
            [2013, 12793, 11, 11],
            [2013, 12794, 19, 14],
            [2013, 12795, 12, 10],
            [2013, 12796, 10, 10],
            [2013, 12797, 10, 8],
            [2013, 12798, 8, 13],
            [2013, 12799, 7, 10],
            [2013, 12800, 20, 11],
            [2013, 12801, 10, 6],
            [2013, 12802, 10, 9],
            [2013, 12803, 63, 39],
            [2013, 12804, 14, 13],
            [2013, 12805, 19, 11],
            [2013, 12806, 12, 11],
            [2013, 12807, 31, 16],
            [2013, 12808, 14, 14],
            [2013, 12809, 6, 9],
            [2013, 12810, 14, 17],
            [2013, 12811, 10, 13],
            [2013, 12812, 17, 14],
            [2013, 12813, 9, 9],
            [2013, 12814, 12, 13],
            [2013, 12815, 14, 12],
            [2013, 12816, 8, 9],
            [2013, 12817, 11, 9],
            [2013, 12818, 9, 9],
            [2013, 12819, 13, 20],
            [2013, 12820, 10, 9],
            [2013, 12821, 8, 4],
            [2013, 12822, 10, 11],
            [2013, 12823, 5, 4],
            [2013, 12824, 10, 13],
            [2013, 12825, 9, 8],
            [2013, 12826, 8, 7],
            [2013, 12827, 33, 19],
            [2013, 12828, 9, 7],
            [2013, 12829, 10, 10],
            [2013, 12830, 9, 6],
            [2013, 12831, 91, 66],
            [2013, 12832, 20, 20],
            [2013, 12833, 9, 6],
            [2013, 12834, 23, 13],
            [2013, 12835, 5, 4],
            [2013, 12836, 19, 9],
            [2013, 12837, 5, 4],
            [2013, 12838, 8, 6],
            [2013, 12839, 5, 4],
            [2013, 12840, 17, 8],
            [2013, 12841, 3, 2],
            [2013, 12842, 8, 9],
            [2013, 12843, 5, 5],
            [2013, 12844, 7, 9],
            [2013, 12845, 9, 7],
            [2013, 12846, 8, 8],
            [2013, 12847, 21, 14],
            [2013, 12848, 12, 10],
            [2013, 12849, 7, 8],
            [2013, 12850, 21, 10],
            [2013, 12851, 13, 10],
            [2013, 12852, 8, 8],
            [2013, 12853, 6, 4],
            [2013, 12854, 30, 17],
            [2013, 12855, 4, 3],
            [2013, 12856, 14, 8],
            [2013, 12857, 8, 7],
            [2013, 12858, 3, 2],
            [2013, 12859, 23, 13],
            [2013, 12860, 14, 11],
            [2013, 12861, 6, 4],
            [2013, 12862, 6, 5],
            [2013, 12863, 66, 31],
            [2013, 12864, 5, 4],
            [2013, 12865, 35, 13],
            [2013, 12866, 5, 4],
            [2013, 12867, 66, 29],
            [2013, 12868, 8, 6],
            [2013, 12869, 10, 10],
            [2013, 12870, 7, 5],
            [2013, 12871, 41, 17],
            [2013, 12872, 9, 7],
            [2013, 12873, 11, 10],
            [2013, 12874, 6, 5],
            [2013, 12875, 66, 35],
            [2013, 12876, 11, 8],
            [2013, 12877, 6, 5],
            [2013, 12878, 10, 8],
            [2013, 12879, 8, 8],
            [2013, 12880, 6, 5],
            [2013, 12881, 11, 8],
            [2013, 12882, 12, 9],
            [2013, 12883, 5, 4],
            [2013, 12884, 46, 27],
            [2013, 12885, 3, 2],
            [2013, 12886, 27, 19],
            [2013, 12887, 5, 4],
            [2013, 12888, 16, 12],
            [2013, 12889, 77, 35],
            [2013, 12890, 7, 5],
            [2013, 12891, 33, 20],
            [2013, 12892, 10, 8],
            [2013, 12893, 8, 6],
            [2013, 12894, 17, 12],
            [2013, 12895, 6, 5],
            [2013, 12896, 31, 20],
            [2013, 12897, 8, 6],
            [2013, 12898, 17, 11],
            [2013, 12899, 17, 13],
            [2013, 12900, 8, 6],
            [2013, 12901, 27, 14],
            [2013, 12902, 7, 6],
            [2013, 12903, 29, 35],
            [2013, 12904, 12, 10],
            [2013, 12905, 29, 19],
            [2013, 12906, 11, 8],
            [2013, 12907, 17, 14],
            [2013, 12908, 12, 10],
            [2013, 12909, 5, 4],
            [2013, 12910, 9, 7],
            [2013, 12911, 4, 4],
            [2013, 12912, 12, 10],
            [2013, 12913, 8, 7],
            [2013, 12914, 7, 5],
            [2013, 12915, 4, 3],
            [2013, 12916, 7, 5],
            [2013, 12917, 11, 9],
            [2013, 12918, 4, 3],
            [2013, 12919, 6, 4],
            [2013, 12920, 17, 14],
            [2013, 12921, 15, 12],
            [2013, 12922, 9, 8],
            [2013, 12923, 8, 7],
            [2013, 12924, 10, 9],
            [2013, 12925, 6, 5],
            [2013, 12926, 6, 5],
            [2013, 12927, 14, 11],
            [2013, 12928, 25, 16],
            [2013, 12929, 8, 6],
            [2013, 12930, 9, 7],
            [2013, 12931, 7, 5],
            [2013, 12932, 10, 7],
            [2013, 12933, 6, 4],
            [2013, 12934, 9, 7],
            [2013, 12935, 7, 6],
            [2013, 12936, 4, 3],
            [2013, 12937, 9, 7],
            [2013, 12938, 7, 5],
            [2013, 12939, 3, 2],
            [2013, 12940, 6, 5],
            [2013, 12941, 13, 10],
            [2013, 12942, 10, 8],
            [2013, 12943, 7, 6],
            [2013, 12944, 6, 5],
            [2013, 12945, 4, 3],
            [2013, 12946, 6, 5],
            [2013, 12947, 9, 7],
            [2013, 12948, 7, 5],
            [2013, 12949, 6, 5],
            [2013, 12950, 9, 7],
            [2013, 12951, 9, 8],
            [2013, 12952, 20, 16],
            [2013, 12953, 14, 12],
            [2013, 12954, 10, 8],
            [2013, 12955, 8, 6],
            [2013, 12956, 5, 4],
            [2013, 12957, 8, 6],
            [2013, 12958, 8, 7],
            [2013, 12959, 6, 4],
            [2013, 12960, 7, 5],
            [2013, 12961, 6, 4],
            [2013, 12962, 8, 5],
            [2013, 12963, 5, 5],
            [2013, 12964, 9, 7],
            [2013, 12965, 18, 15],
            [2013, 12966, 10, 7],
            [2013, 12967, 10, 8],
            [2013, 12968, 12, 10],
            [2013, 12969, 7, 5],
            [2013, 12970, 7, 5],
            [2013, 12971, 8, 7],
            [2013, 12972, 6, 5],
            [2013, 12973, 6, 4],
            [2013, 12974, 8, 6],
            [2013, 12975, 6, 5],
            [2013, 12976, 6, 5],
            [2013, 12977, 4, 3],
            [2013, 12978, 11, 8],
            [2013, 12979, 12, 10],
            [2013, 12980, 8, 6],
            [2013, 12981, 8, 6],
            [2013, 12982, 11, 10],
            [2013, 12983, 8, 5],
            [2013, 12984, 5, 5],
            [2013, 12985, 8, 6],
            [2013, 12986, 5, 4],
            [2013, 12987, 8, 7],
            [2013, 12988, 18, 15],
            [2013, 12989, 12, 9],
            [2013, 12990, 8, 6],
            [2013, 12991, 6, 5],
            [2013, 12992, 6, 5],
            [2013, 12993, 4, 3],
            [2013, 12994, 7, 6],
            [2013, 12995, 5, 4],
            [2013, 12996, 7, 5],
            [2013, 12997, 8, 6],
            [2013, 12998, 6, 5],
            [2013, 12999, 7, 5],
            [2013, 13000, 6, 5],
            [2013, 13001, 13, 13],
            [2013, 13002, 16, 16],
            [2013, 13003, 14, 15],
            [2013, 13004, 24, 18],
            [2013, 13005, 20, 18],
            [2013, 13006, 25, 19],
            [2013, 13007, 18, 18],
            [2013, 13008, 25, 19],
            [2013, 13009, 19, 18],
            [2013, 13010, 18, 17],
            [2013, 13011, 34, 21],
            [2013, 13012, 22, 20],
            [2013, 13013, 15, 15],
            [2013, 13014, 17, 18],
            [2013, 13015, 12, 16],
            [2013, 13016, 16, 13],
            [2013, 13017, 8, 5],
            [2013, 13018, 19, 19],
            [2013, 13019, 15, 8],
            [2013, 13020, 9, 14],
            [2013, 13021, 14, 19],
            [2013, 13022, 10, 5],
            [2013, 13023, 20, 13],
            [2013, 13024, 32, 23],
            [2013, 13025, 11, 18],
            [2013, 13026, 20, 12],
            [2013, 13027, 19, 11],
            [2013, 13028, 8, 5],
            [2013, 13029, 14, 16],
            [2013, 13030, 14, 14],
            [2013, 13031, 11, 11],
            [2013, 13032, 24, 20],
            [2013, 13033, 9, 8],
            [2013, 13034, 6, 6],
            [2013, 13035, 8, 5],
            [2013, 13036, 19, 8],
            [2013, 13037, 9, 7],
            [2013, 13038, 21, 15],
            [2013, 13039, 12, 12],
            [2013, 13040, 17, 16],
            [2013, 13041, 14, 13],
            [2013, 13042, 6, 9],
            [2013, 13043, 8, 5],
            [2013, 13044, 14, 19],
            [2013, 13045, 7, 11],
            [2013, 13046, 18, 15],
            [2013, 13047, 21, 20],
            [2013, 13048, 12, 11],
            [2013, 13049, 13, 12],
            [2013, 13050, 12, 12],
            [2013, 13051, 16, 17],
            [2013, 13052, 11, 12],
            [2013, 13053, 10, 8],
            [2013, 13054, 16, 19],
            [2013, 13055, 20, 13],
            [2013, 13056, 14, 16],
            [2013, 13057, 15, 15],
            [2013, 13058, 19, 18],
            [2013, 13059, 11, 8],
            [2013, 13060, 16, 12],
            [2013, 13061, 19, 17],
            [2013, 13062, 14, 11],
            [2013, 13063, 30, 5],
            [2013, 13064, 10, 14],
            [2013, 13065, 13, 13],
            [2013, 13066, 12, 10],
            [2013, 13067, 16, 14],
            [2013, 13068, 14, 17],
            [2013, 13069, 21, 16],
            [2013, 13070, 10, 6],
            [2013, 13071, 11, 7],
            [2013, 13072, 10, 13],
            [2013, 13073, 10, 10],
            [2013, 13074, 12, 13],
            [2013, 13075, 21, 20],
            [2013, 13076, 12, 8],
            [2013, 13077, 26, 20],
            [2013, 13078, 33, 29],
            [2013, 13079, 11, 15],
            [2013, 13080, 12, 9],
            [2013, 13081, 14, 12],
            [2013, 13082, 7, 7],
            [2013, 13083, 14, 9],
            [2013, 13084, 23, 17],
            [2013, 13085, 27, 18],
            [2013, 13086, 6, 7],
            [2013, 13087, 15, 12],
            [2013, 13088, 19, 12],
            [2013, 13089, 12, 11],
            [2013, 13090, 12, 11],
            [2013, 13091, 8, 5],
            [2013, 13092, 25, 19],
            [2013, 13093, 13, 8],
            [2013, 13094, 30, 16],
            [2013, 13095, 13, 13],
            [2013, 13096, 9, 11],
            [2013, 13097, 16, 11],
            [2013, 13098, 12, 12],
            [2013, 13099, 8, 1],
            [2013, 13100, 20, 19],
            [2013, 13101, 17, 16],
            [2013, 13102, 21, 16],
            [2013, 13103, 20, 17],
            [2013, 13104, 18, 27],
            [2013, 13105, 15, 13],
            [2013, 13106, 19, 15],
            [2013, 13107, 14, 10],
            [2013, 13108, 15, 13],
            [2013, 13109, 13, 12],
            [2013, 13111, 15, 13],
            [2013, 13112, 12, 11],
            [2013, 13113, 17, 11],
            [2013, 13114, 13, 13],
            [2013, 13115, 14, 10],
            [2013, 13116, 16, 18],
            [2013, 13117, 15, 15],
            [2013, 13118, 12, 9],
            [2013, 13119, 20, 17],
            [2013, 13120, 14, 7],
            [2013, 13121, 15, 19],
            [2013, 13122, 26, 15],
            [2013, 13123, 16, 14],
            [2013, 13124, 11, 12],
            [2013, 13125, 11, 9],
            [2013, 13126, 24, 16],
            [2013, 13127, 15, 14],
            [2013, 13128, 11, 13],
            [2013, 13129, 22, 18],
            [2013, 13130, 16, 13],
            [2013, 13131, 12, 10],
            [2013, 13132, 12, 11],
            [2013, 13133, 18, 13],
            [2013, 13134, 18, 14],
            [2013, 13135, 17, 12],
            [2013, 13136, 14, 20],
            [2013, 13137, 18, 21],
            [2013, 13138, 14, 11],
            [2013, 13139, 6, 6],
            [2013, 13140, 18, 11],
            [2013, 13141, 10, 8],
            [2013, 13142, 9, 8],
            [2013, 13143, 8, 6],
            [2013, 13144, 12, 11],
            [2013, 13145, 7, 7],
            [2013, 13147, 12, 9],
            [2013, 13148, 12, 11],
            [2013, 13149, 8, 7],
            [2013, 13150, 10, 9],
            [2013, 13152, 11, 9],
            [2013, 13153, 7, 7],
            [2013, 13154, 8, 8],
            [2013, 13155, 9, 7],
            [2013, 13156, 9, 8],
            [2013, 13158, 7, 7],
            [2013, 13159, 9, 8],
            [2013, 13160, 9, 7],
            [2013, 13161, 7, 7],
            [2013, 13163, 11, 8],
            [2013, 13164, 9, 8],
            [2013, 13165, 10, 8],
            [2013, 13166, 8, 7],
            [2013, 13167, 19, 12],
            [2013, 13168, 8, 7],
            [2013, 13169, 11, 9],
            [2013, 13170, 13, 11],
            [2013, 13171, 11, 9],
            [2013, 13172, 7, 7],
            [2013, 13173, 11, 9],
            [2013, 13174, 9, 7],
            [2013, 13175, 7, 7],
            [2013, 13176, 9, 8],
            [2013, 13177, 9, 9],
            [2013, 13178, 11, 9],
            [2013, 13179, 10, 8],
            [2013, 13180, 16, 11],
            [2013, 13181, 7, 7],
            [2013, 13182, 9, 8],
            [2013, 13183, 31, 22],
            [2013, 13184, 7, 7],
            [2013, 13185, 11, 11],
            [2013, 13186, 14, 15],
            [2013, 13187, 7, 11],
            [2013, 13188, 7, 10],
            [2013, 13189, 12, 10],
            [2013, 13190, 7, 10],
            [2013, 13191, 23, 14],
            [2013, 13192, 9, 11],
            [2013, 13193, 9, 12],
            [2013, 13194, 11, 9],
            [2013, 13195, 25, 16],
            [2013, 13196, 17, 11],
            [2013, 13197, 100, 35],
            [2013, 13198, 13, 10],
            [2013, 13199, 7, 7],
            [2013, 13200, 22, 15],
            [2013, 13201, 16, 12],
            [2013, 13202, 22, 13],
            [2013, 13203, 8, 8],
            [2013, 13204, 25, 13],
            [2013, 13205, 9, 11],
            [2013, 13206, 17, 12],
            [2013, 13207, 12, 12],
            [2013, 13208, 10, 11],
            [2013, 13209, 8, 8],
            [2013, 13210, 24, 19],
            [2013, 13211, 15, 11],
            [2013, 13212, 60, 38],
            [2013, 13213, 29, 18],
            [2013, 13214, 19, 17],
            [2013, 13215, 10, 11],
            [2013, 13216, 21, 16],
            [2013, 13217, 7, 10],
            [2013, 13218, 15, 13],
            [2013, 13219, 11, 11],
            [2013, 13220, 9, 11],
            [2013, 13221, 7, 10],
            [2013, 13222, 9, 11],
            [2013, 13223, 21, 15],
            [2013, 13224, 60, 24],
            [2013, 13225, 15, 11],
            [2013, 13226, 9, 11],
            [2013, 13227, 20, 14],
            [2013, 13228, 10, 10],
            [2013, 13229, 7, 9],
            [2013, 13230, 22, 14],
            [2013, 13231, 10, 10],
            [2013, 13232, 16, 13],
            [2013, 13233, 16, 14],
            [2013, 13234, 18, 14],
            [2013, 13235, 15, 12],
            [2013, 13236, 11, 9],
            [2013, 13237, 9, 7],
            [2013, 13238, 15, 13],
            [2013, 13239, 16, 12],
            [2013, 13240, 16, 13],
            [2013, 13241, 15, 13],
            [2013, 13242, 16, 14],
            [2013, 13243, 18, 14],
            [2013, 13244, 21, 16],
            [2013, 13245, 16, 13],
            [2013, 13246, 17, 12],
            [2013, 13247, 19, 15],
            [2013, 13248, 12, 10],
            [2013, 13249, 11, 8],
            [2013, 13250, 18, 14],
            [2013, 13251, 17, 14],
            [2013, 13252, 21, 15],
            [2013, 13253, 16, 14],
            [2013, 13254, 12, 10],
            [2013, 13255, 11, 10],
            [2013, 13256, 14, 12],
            [2013, 13257, 15, 12],
            [2013, 13258, 21, 16],
            [2013, 13259, 20, 14],
            [2013, 13260, 16, 12],
            [2013, 13261, 16, 12],
            [2013, 13262, 19, 14],
            [2013, 13263, 16, 13],
            [2013, 13264, 15, 13],
            [2013, 13265, 26, 16],
            [2013, 13266, 14, 10],
            [2013, 13267, 35, 26],
            [2013, 13269, 15, 12],
            [2013, 13270, 19, 14],
            [2013, 13271, 16, 12],
            [2013, 13272, 9, 8],
            [2013, 13273, 14, 11],
            [2013, 13274, 10, 10],
            [2013, 13275, 13, 11],
            [2013, 13276, 11, 9],
            [2013, 13279, 35, 17],
            [2013, 13280, 15, 11],
            [2013, 13281, 13, 12],
            [2013, 13282, 14, 11],
            [2013, 13283, 20, 16],
            [2013, 13284, 20, 17],
            [2013, 13285, 14, 11],
            [2013, 13286, 21, 14],
            [2013, 13288, 20, 15],
            [2013, 13289, 18, 16],
            [2013, 13290, 9, 9],
            [2013, 13291, 16, 14],
            [2013, 13292, 9, 8],
            [2013, 13293, 17, 17],
            [2013, 13294, 14, 11],
            [2013, 13295, 23, 15],
            [2013, 13296, 15, 15],
            [2013, 13297, 14, 10],
            [2013, 13298, 17, 15],
            [2013, 13299, 10, 12],
            [2013, 13300, 12, 14],
            [2013, 13302, 16, 14],
            [2013, 13303, 12, 14],
            [2013, 13304, 20, 14],
            [2013, 13305, 14, 12],
            [2013, 13306, 8, 8],
            [2013, 13307, 28, 27],
            [2013, 13308, 15, 13],
            [2013, 13309, 10, 10],
            [2013, 13310, 16, 12],
            [2013, 13311, 10, 10],
            [2013, 13312, 17, 13],
            [2013, 13313, 48, 23],
            [2013, 13314, 36, 21],
            [2013, 13315, 17, 13],
            [2013, 13316, 11, 9],
            [2013, 13317, 11, 8],
            [2013, 13318, 10, 10],
            [2013, 13319, 17, 14],
            [2013, 13320, 26, 19],
            [2013, 13321, 14, 14],
            [2013, 13322, 13, 11],
            [2013, 13323, 34, 21],
            [2013, 13324, 8, 7],
            [2013, 13325, 14, 14],
            [2013, 13326, 16, 12],
            [2013, 13327, 20, 12],
            [2013, 13328, 14, 12],
            [2013, 13329, 14, 13],
            [2013, 13330, 15, 12],
            [2013, 13331, 22, 16],
            [2013, 13332, 13, 12],
            [2013, 13333, 13, 14],
            [2013, 13334, 11, 10],
            [2013, 13335, 36, 26],
            [2013, 13336, 14, 12],
            [2013, 13338, 14, 12],
            [2013, 13339, 11, 9],
            [2013, 13340, 15, 13],
            [2013, 13341, 10, 9],
            [2013, 13342, 10, 9],
            [2013, 13343, 14, 11],
            [2013, 13344, 12, 10],
            [2013, 13345, 22, 16],
            [2013, 13346, 10, 7],
            [2013, 13347, 21, 20],
            [2013, 13348, 18, 14],
            [2013, 13349, 33, 20],
            [2013, 13350, 15, 13],
            [2013, 13351, 9, 8],
            [2013, 13352, 11, 10],
            [2013, 13353, 16, 12],
            [2013, 13355, 15, 10],
            [2013, 13356, 10, 8],
            [2013, 13357, 25, 18],
            [2013, 13358, 14, 14],
            [2013, 13359, 32, 20],
            [2013, 13360, 11, 8],
            [2013, 13361, 31, 20],
            [2013, 13362, 13, 13],
            [2013, 13363, 18, 15],
            [2013, 13364, 11, 11],
            [2013, 13365, 11, 8],
            [2013, 13366, 10, 10],
            [2013, 13367, 11, 8],
            [2013, 13368, 21, 18],
            [2013, 13369, 15, 12],
            [2013, 13370, 14, 11],
            [2013, 13371, 17, 15],
            [2013, 13372, 16, 12],
            [2013, 13373, 10, 10],
            [2013, 13374, 13, 12],
            [2013, 13375, 14, 12],
            [2013, 13376, 9, 10],
            [2013, 13377, 15, 12],
            [2013, 13378, 12, 10],
            [2013, 13379, 13, 11],
            [2013, 13380, 18, 14],
            [2013, 13381, 9, 8],
            [2013, 13382, 15, 12],
            [2013, 13384, 18, 16],
            [2013, 13385, 8, 7],
            [2013, 13386, 23, 15],
            [2013, 13387, 15, 14],
            [2013, 13388, 13, 12],
            [2013, 13389, 13, 12],
            [2013, 13390, 14, 12],
            [2013, 13391, 11, 11],
            [2013, 13392, 18, 12],
            [2013, 13393, 28, 25],
            [2013, 13394, 14, 11],
            [2013, 13395, 14, 10],
            [2013, 13396, 49, 24],
            [2013, 13397, 8, 7],
            [2013, 13398, 30, 19],
            [2013, 13399, 13, 11],
            [2013, 13401, 12, 11],
            [2013, 13402, 24, 13],
            [2013, 13403, 17, 15],
            [2013, 13404, 24, 17],
            [2013, 13405, 37, 18],
            [2013, 13407, 17, 17],
            [2013, 13408, 24, 20],
            [2013, 13409, 18, 16],
            [2013, 13410, 26, 16],
            [2013, 13411, 10, 11],
            [2013, 13412, 42, 23],
            [2013, 13413, 23, 17],
            [2013, 13414, 22, 17],
            [2013, 13415, 17, 14],
            [2013, 13416, 16, 13],
            [2013, 13417, 12, 10],
            [2013, 13418, 9, 8],
            [2013, 13419, 47, 23],
            [2013, 13420, 12, 10],
            [2013, 13421, 17, 12],
            [2013, 13423, 12, 12],
            [2013, 13424, 34, 15],
            [2013, 13425, 18, 15],
            [2013, 13426, 22, 15],
            [2013, 13427, 28, 22],
            [2013, 13428, 46, 18],
            [2013, 13429, 20, 18],
            [2013, 13430, 21, 22],
            [2013, 13431, 35, 22],
            [2013, 13432, 11, 10],
            [2013, 13433, 21, 15],
            [2013, 13434, 29, 18],
            [2013, 13435, 19, 15],
            [2013, 13438, 24, 18],
            [2013, 13439, 10, 9],
            [2013, 13440, 9, 9],
            [2013, 13441, 12, 13],
            [2013, 13442, 42, 21],
            [2013, 13443, 32, 26],
            [2013, 13445, 14, 10],
            [2013, 13446, 17, 15],
            [2013, 13447, 40, 26],
            [2013, 13448, 27, 26],
            [2013, 13449, 11, 9],
            [2013, 13450, 9, 9],
            [2013, 13451, 9, 7],
            [2013, 13452, 8, 8],
            [2013, 13453, 9, 9],
            [2013, 13454, 20, 13],
            [2013, 13455, 14, 12],
            [2013, 13456, 7, 7],
            [2013, 13457, 7, 7],
            [2013, 13458, 10, 10],
            [2013, 13460, 10, 8],
            [2013, 13461, 9, 7],
            [2013, 13462, 9, 7],
            [2013, 13463, 14, 10],
            [2013, 13464, 15, 9],
            [2013, 13465, 11, 10],
            [2013, 13466, 10, 9],
            [2013, 13467, 9, 8],
            [2013, 13468, 9, 8],
            [2013, 13469, 10, 8],
            [2013, 13470, 13, 10],
            [2013, 13471, 11, 9],
            [2013, 13472, 14, 9],
            [2013, 13473, 11, 9],
            [2013, 13474, 11, 9],
            [2013, 13475, 12, 9],
            [2013, 13476, 7, 8],
            [2013, 13478, 7, 8],
            [2013, 13479, 13, 10],
            [2013, 13480, 4, 4],
            [2013, 13481, 9, 8],
            [2013, 13482, 12, 10],
            [2013, 13483, 10, 10],
            [2013, 13484, 10, 9],
            [2013, 13485, 9, 9],
            [2013, 13486, 3, 4],
            [2013, 13487, 18, 12],
            [2013, 13488, 9, 6],
            [2013, 13489, 14, 10],
            [2013, 13490, 7, 8],
            [2013, 13491, 9, 9],
            [2013, 13492, 7, 7],
            [2013, 13493, 8, 6],
            [2013, 13494, 12, 8],
            [2013, 13495, 10, 9],
            [2013, 13496, 10, 10],
            [2013, 13497, 11, 9],
            [2013, 13498, 9, 8],
            [2013, 13499, 13, 9],
            [2013, 13501, 16, 10],
            [2013, 13502, 8, 7],
            [2013, 13503, 12, 9],
            [2013, 13504, 7, 6],
            [2013, 13505, 7, 6],
            [2013, 13506, 11, 8],
            [2013, 13507, 5, 5],
            [2013, 13508, 11, 9],
            [2013, 13509, 5, 6],
            [2013, 13511, 15, 11],
            [2013, 13512, 10, 8],
            [2013, 13513, 13, 10],
            [2013, 13514, 12, 10],
            [2013, 13516, 8, 7],
            [2013, 13517, 7, 7],
            [2013, 13518, 7, 7],
            [2013, 13519, 11, 9],
            [2013, 13520, 12, 10],
            [2013, 13521, 8, 8],
            [2013, 13522, 9, 9],
            [2013, 13523, 10, 10],
            [2013, 13524, 7, 7],
            [2013, 13525, 12, 10],
            [2013, 13526, 9, 7],
            [2013, 13527, 14, 11],
            [2013, 13528, 8, 8],
            [2013, 13529, 7, 7],
            [2013, 13530, 7, 6],
            [2013, 13531, 7, 6],
            [2013, 13532, 7, 6],
            [2013, 13533, 7, 6],
            [2013, 13534, 7, 6],
            [2013, 13536, 9, 9],
            [2013, 13537, 6, 6],
            [2013, 13538, 6, 6],
            [2013, 13539, 6, 6],
            [2013, 13540, 6, 6],
            [2013, 13541, 9, 9],
            [2013, 13542, 9, 8],
            [2013, 13543, 10, 8],
            [2013, 13544, 10, 10],
            [2013, 13546, 8, 7],
            [2013, 13547, 8, 8],
            [2013, 13548, 14, 10],
            [2013, 13550, 20, 12],
            [2013, 13552, 12, 10],
            [2013, 13556, 8, 8],
            [2013, 13557, 3, 3],
            [2013, 13558, 16, 11],
            [2013, 13560, 8, 8],
            [2013, 13561, 10, 8],
            [2013, 13562, 9, 9],
            [2013, 13563, 8, 6],
            [2013, 13564, 13, 10],
            [2013, 13565, 9, 8],
            [2013, 13566, 12, 11],
            [2013, 13567, 9, 9],
            [2013, 13568, 4, 5],
            [2013, 13569, 9, 8],
            [2013, 13570, 7, 8],
            [2013, 13571, 11, 9],
            [2013, 13572, 6, 6],
            [2013, 13573, 7, 7],
            [2013, 13574, 10, 9],
            [2013, 13575, 12, 9],
            [2013, 13576, 7, 7],
            [2013, 13577, 7, 7],
            [2013, 13578, 8, 8],
            [2013, 13579, 20, 12],
            [2013, 13580, 10, 7],
            [2013, 13581, 6, 7],
            [2013, 13582, 8, 7],
            [2013, 13583, 9, 8],
            [2013, 13584, 32, 16],
            [2013, 13585, 7, 8],
            [2013, 13586, 7, 6],
            [2013, 13587, 7, 7],
            [2013, 13588, 16, 11],
            [2013, 13589, 7, 7],
            [2013, 13590, 14, 11],
            [2013, 13591, 7, 7],
            [2013, 13592, 7, 7],
            [2013, 13593, 7, 8],
            [2013, 13594, 14, 11],
            [2013, 13595, 10, 7],
            [2013, 13596, 12, 10],
            [2013, 13597, 9, 7],
            [2013, 13598, 8, 7],
            [2013, 13599, 7, 8],
            [2013, 13600, 9, 8],
            [2013, 13601, 7, 7],
            [2013, 13602, 7, 7],
            [2013, 13603, 7, 7],
            [2013, 13604, 12, 10],
            [2013, 13605, 10, 9],
            [2013, 13606, 10, 10],
            [2013, 13607, 9, 7],
            [2013, 13608, 10, 9],
            [2013, 13609, 37, 37],
            [2013, 13610, 32, 32],
            [2013, 13611, 18, 18],
            [2013, 13612, 48, 26],
            [2013, 13613, 98, 38],
            [2013, 13614, 32, 32],
            [2013, 13615, 60, 35],
            [2013, 13616, 13, 12],
            [2013, 13617, 36, 38],
            [2013, 13618, 46, 43],
            [2013, 13619, 42, 58],
            [2013, 13620, 37, 36],
            [2013, 13621, 42, 38],
            [2013, 13622, 44, 33],
            [2013, 13623, 53, 37],
            [2013, 13624, 29, 19],
            [2013, 13625, 23, 21],
            [2013, 13626, 28, 24],
            [2013, 13627, 36, 43],
            [2013, 13628, 35, 37],
            [2013, 13629, 51, 41],
            [2013, 13630, 37, 37],
            [2013, 13631, 45, 48],
            [2013, 13632, 36, 17],
            [2013, 13633, 28, 17],
            [2013, 13634, 28, 25],
            [2013, 13635, 37, 38],
            [2013, 13636, 19, 18],
            [2013, 13637, 78, 61],
            [2013, 13638, 68, 46],
            [2013, 13639, 11, 10],
            [2013, 13640, 51, 56],
            [2013, 13641, 38, 21],
            [2013, 13642, 75, 38],
            [2013, 13643, 22, 28],
            [2013, 13644, 57, 36],
            [2013, 13645, 63, 44],
            [2013, 13646, 32, 43],
            [2013, 13647, 48, 27],
            [2013, 13648, 52, 38],
            [2013, 13649, 62, 38],
            [2013, 13650, 9, 9],
            [2013, 13651, 48, 38],
            [2013, 13652, 64, 52],
            [2013, 13653, 9, 9],
            [2013, 13654, 9, 9],
            [2013, 13655, 32, 32],
            [2013, 13656, 78, 50],
            [2013, 13657, 23, 20],
            [2013, 13658, 85, 49],
            [2013, 13659, 42, 30],
            [2013, 13660, 37, 35],
            [2013, 13661, 37, 30],
            [2013, 13662, 47, 32],
            [2013, 13663, 21, 20],
            [2013, 13664, 42, 41],
            [2013, 13665, 47, 37],
            [2013, 13666, 32, 32],
            [2013, 13667, 42, 30],
            [2013, 13668, 12, 11],
            [2013, 13669, 43, 28],
            [2013, 13670, 47, 32],
            [2013, 13671, 46, 27],
            [2013, 13672, 43, 36],
            [2013, 13673, 82, 38],
            [2013, 13674, 41, 32],
            [2013, 13675, 32, 26],
            [2013, 13676, 35, 27],
            [2013, 13677, 16, 18],
            [2013, 13678, 14, 17],
            [2013, 13679, 9, 15],
            [2013, 13680, 10, 14],
            [2013, 13681, 16, 15],
            [2013, 13682, 8, 9],
            [2013, 13683, 17, 15],
            [2013, 13684, 27, 17],
            [2013, 13685, 27, 16],
            [2013, 13686, 19, 15],
            [2013, 13687, 31, 21],
            [2013, 13688, 17, 13],
            [2013, 13689, 21, 12],
            [2013, 13690, 16, 13],
            [2013, 13691, 61, 18],
            [2013, 13692, 17, 18],
            [2013, 13693, 17, 14],
            [2013, 13694, 25, 18],
            [2013, 13695, 23, 18],
            [2013, 13696, 15, 13],
            [2013, 13697, 46, 18],
            [2013, 13698, 19, 14],
            [2013, 13699, 33, 16],
            [2013, 13700, 41, 20],
            [2013, 13701, 18, 16],
            [2013, 13702, 25, 13],
            [2013, 13703, 27, 18],
            [2013, 13704, 33, 17],
            [2013, 13705, 15, 14],
            [2013, 13706, 27, 15],
            [2013, 13707, 37, 21],
            [2013, 13708, 20, 17],
            [2013, 13709, 33, 20],
            [2013, 13710, 21, 16],
            [2013, 13711, 23, 16],
            [2013, 13712, 37, 16],
            [2013, 13713, 41, 29],
            [2013, 13714, 15, 13],
            [2013, 13715, 37, 19],
            [2013, 13716, 21, 14],
            [2013, 13717, 25, 27],
            [2013, 13718, 19, 16],
            [2013, 13719, 37, 18],
            [2013, 13720, 25, 18],
            [2013, 13721, 21, 9],
            [2013, 13722, 23, 23],
            [2013, 13723, 33, 27],
            [2013, 13724, 35, 17],
            [2013, 13725, 33, 13],
            [2013, 13726, 21, 9],
            [2013, 13727, 41, 23],
            [2013, 13728, 23, 16],
            [2013, 13729, 21, 11],
            [2013, 13730, 37, 29],
            [2013, 13731, 37, 18],
            [2013, 13732, 51, 25],
            [2013, 13733, 29, 16],
            [2013, 13734, 23, 12],
            [2013, 13735, 27, 11],
            [2013, 13736, 35, 18],
            [2013, 13737, 35, 17],
            [2013, 13738, 21, 18],
            [2013, 13739, 35, 25],
            [2013, 13740, 37, 10],
            [2013, 13741, 15, 12],
            [2013, 13742, 33, 18],
            [2013, 13743, 31, 17],
            [2013, 13744, 37, 15],
            [2013, 13745, 10, 9],
            [2013, 13746, 20, 20],
            [2013, 13747, 15, 15],
            [2013, 13748, 21, 18],
            [2013, 13749, 12, 12],
            [2013, 13750, 23, 20],
            [2013, 13751, 9, 10],
            [2013, 13753, 16, 16],
            [2013, 13754, 20, 18],
            [2013, 13755, 13, 14],
            [2013, 13756, 11, 10],
            [2013, 13757, 17, 18],
            [2013, 13758, 11, 10],
            [2013, 13759, 9, 8],
            [2013, 13760, 10, 10],
            [2013, 13761, 13, 10],
            [2013, 13762, 10, 12],
            [2013, 13763, 10, 9],
            [2013, 13764, 8, 8],
            [2013, 13765, 19, 10],
            [2013, 13766, 14, 14],
            [2013, 13767, 16, 14],
            [2013, 13768, 15, 11],
            [2013, 13769, 11, 11],
            [2013, 13770, 15, 15],
            [2013, 13771, 13, 13],
            [2013, 13772, 13, 10],
            [2013, 13773, 17, 14],
            [2013, 13774, 9, 8],
            [2013, 13775, 9, 13],
            [2013, 13776, 10, 11],
            [2013, 13777, 10, 9],
            [2013, 13778, 18, 17],
            [2013, 13779, 15, 11],
            [2013, 13780, 10, 14],
            [2013, 13781, 19, 16],
            [2013, 13782, 19, 22],
            [2013, 13783, 19, 29],
            [2013, 13784, 19, 28],
            [2013, 13785, 17, 20],
            [2013, 13786, 16, 22],
            [2013, 13787, 7, 5],
            [2013, 13788, 6, 6],
            [2013, 13789, 9, 7],
            [2013, 13790, 10, 9],
            [2013, 13791, 8, 7],
            [2013, 13792, 12, 12],
            [2013, 13793, 9, 9],
            [2013, 13794, 14, 12],
            [2013, 13795, 8, 7],
            [2013, 13796, 10, 11],
            [2013, 13797, 10, 10],
            [2013, 13798, 9, 8],
            [2013, 13799, 18, 14],
            [2013, 13800, 8, 8],
            [2013, 13801, 8, 6],
            [2013, 13802, 9, 9],
            [2013, 13803, 11, 9],
            [2013, 13804, 12, 14],
            [2013, 13805, 7, 6],
            [2013, 13806, 10, 9],
            [2013, 13807, 7, 7],
            [2013, 13808, 7, 5],
            [2013, 13809, 11, 9],
            [2013, 13810, 7, 6],
            [2013, 13811, 10, 10],
            [2013, 13812, 9, 9],
            [2013, 13813, 10, 9],
            [2013, 13814, 12, 12],
            [2013, 13815, 12, 11],
            [2013, 13816, 12, 10],
            [2013, 13817, 10, 10],
            [2013, 13818, 10, 9],
            [2013, 13819, 10, 8],
            [2013, 13820, 9, 7],
            [2013, 13821, 6, 6],
            [2013, 13822, 6, 6],
            [2013, 13823, 6, 6],
            [2013, 13824, 10, 9],
            [2013, 13825, 6, 5],
            [2013, 13826, 7, 6],
            [2013, 13827, 7, 6],
            [2013, 13828, 11, 10],
            [2013, 13829, 9, 9],
            [2013, 13830, 7, 7],
            [2013, 13831, 8, 9],
            [2013, 13832, 7, 8],
            [2013, 13833, 13, 14],
            [2013, 13834, 7, 7],
            [2013, 13835, 10, 10],
            [2013, 13836, 10, 9],
            [2013, 13837, 10, 9],
            [2013, 13838, 10, 9],
            [2013, 13839, 11, 12],
            [2013, 13840, 7, 6],
            [2013, 13841, 9, 8],
            [2013, 13842, 10, 10],
            [2013, 13843, 10, 9],
            [2013, 13844, 6, 6],
            [2013, 13845, 8, 8],
            [2013, 13846, 7, 7],
            [2013, 13847, 6, 6],
            [2013, 13848, 7, 7],
            [2013, 13849, 10, 9],
            [2013, 13850, 10, 9],
            [2013, 13851, 13, 14],
            [2013, 13852, 8, 9],
            [2013, 13853, 13, 10],
            [2013, 13854, 15, 15],
            [2013, 13855, 18, 17],
            [2013, 13856, 8, 8],
            [2013, 13857, 9, 7],
            [2013, 13858, 8, 7],
            [2013, 13859, 8, 7],
            [2013, 13860, 7, 6],
            [2013, 13861, 7, 6],
            [2013, 13862, 12, 9],
            [2013, 13863, 7, 6],
            [2013, 13864, 6, 5],
            [2013, 13865, 9, 7],
            [2013, 13866, 6, 6],
            [2013, 13867, 7, 6],
            [2013, 13868, 6, 6],
            [2013, 13869, 10, 7],
            [2013, 13870, 7, 6],
            [2013, 13871, 6, 5],
            [2013, 13872, 8, 6],
            [2013, 13873, 6, 5],
            [2013, 13874, 11, 9],
            [2013, 13875, 9, 7],
            [2013, 13876, 18, 11],
            [2013, 13877, 11, 10],
            [2013, 13878, 7, 6],
            [2013, 13879, 7, 6],
            [2013, 13880, 7, 6],
            [2013, 13881, 8, 6],
            [2013, 13882, 7, 6],
            [2013, 13883, 14, 9],
            [2013, 13884, 7, 8],
            [2013, 13885, 9, 6],
            [2013, 13886, 7, 6],
            [2013, 13887, 7, 6],
            [2013, 13888, 11, 11],
            [2013, 13889, 6, 5],
            [2013, 13890, 9, 8],
            [2013, 13891, 9, 7],
            [2013, 13892, 8, 8],
            [2013, 13893, 12, 14],
            [2013, 13894, 6, 7],
            [2013, 13895, 7, 7],
            [2013, 13896, 6, 6],
            [2013, 13897, 7, 7],
            [2013, 13898, 8, 7],
            [2013, 13899, 8, 7],
            [2013, 13900, 11, 8],
            [2013, 13901, 18, 11],
            [2013, 13902, 7, 7],
            [2013, 13903, 13, 10],
            [2013, 13904, 8, 6],
            [2013, 13905, 10, 9],
            [2013, 13906, 14, 9],
            [2013, 13907, 11, 10],
            [2013, 13908, 10, 9],
            [2013, 13909, 14, 11],
            [2013, 13910, 9, 7],
            [2013, 13911, 8, 7],
            [2013, 13912, 8, 9],
            [2013, 13913, 8, 9],
            [2013, 13914, 8, 9],
            [2013, 13915, 7, 7],
            [2013, 13916, 6, 7],
            [2013, 13917, 6, 6],
            [2013, 13918, 8, 8],
            [2013, 13919, 9, 8],
            [2013, 13920, 13, 9],
            [2013, 13921, 15, 9],
            [2013, 13922, 9, 8],
            [2013, 13923, 8, 7],
            [2013, 13924, 12, 10],
            [2013, 13925, 7, 7],
            [2013, 13926, 8, 8],
            [2013, 13927, 8, 8],
            [2013, 13928, 7, 6],
            [2013, 13929, 7, 7],
            [2013, 13930, 7, 6],
            [2013, 13931, 11, 10],
            [2013, 13932, 9, 7],
            [2013, 13933, 9, 8],
            [2013, 13934, 11, 11],
            [2013, 13935, 7, 6],
            [2013, 13936, 7, 7],
            [2013, 13937, 12, 11],
            [2013, 13938, 7, 7],
            [2013, 13939, 8, 7],
            [2013, 13940, 8, 7],
            [2013, 13941, 8, 9],
            [2013, 13942, 10, 8],
            [2013, 13943, 11, 8],
            [2013, 13944, 8, 8],
            [2013, 13945, 8, 7],
            [2013, 13946, 12, 10],
            [2013, 13947, 14, 11],
            [2013, 13948, 6, 6],
            [2013, 13949, 6, 6],
            [2013, 13950, 10, 9],
            [2013, 13951, 7, 7],
            [2013, 13952, 12, 10],
            [2013, 13953, 12, 10],
            [2013, 13954, 8, 8],
            [2013, 13955, 10, 9],
            [2013, 13956, 10, 9],
            [2013, 13957, 8, 7],
            [2013, 13958, 7, 7],
            [2013, 13959, 8, 8],
            [2013, 13960, 12, 10],
            [2013, 13961, 9, 8],
            [2013, 13962, 11, 10],
            [2013, 13963, 7, 7],
            [2013, 13964, 7, 7],
            [2013, 13965, 7, 7],
            [2013, 13966, 9, 7],
            [2013, 13967, 7, 6],
            [2013, 13968, 7, 7],
            [2013, 13969, 7, 6],
            [2013, 13970, 7, 7],
            [2013, 13971, 7, 7],
            [2013, 13972, 10, 8],
            [2013, 13973, 7, 6],
            [2013, 13974, 7, 6],
            [2013, 13975, 8, 7],
            [2013, 13976, 9, 9],
            [2013, 13977, 7, 8],
            [2013, 13978, 11, 11],
            [2013, 13979, 7, 6],
            [2013, 13980, 6, 6],
            [2013, 13981, 7, 7],
            [2013, 13982, 7, 7],
            [2013, 13983, 13, 10],
            [2013, 13984, 9, 8],
            [2013, 13985, 15, 9],
            [2013, 13986, 8, 8],
            [2013, 13987, 7, 7],
            [2013, 13988, 9, 8],
            [2013, 13989, 7, 6],
            [2013, 13990, 7, 7],
            [2013, 13991, 7, 7],
            [2013, 13992, 7, 6],
            [2013, 13993, 9, 8],
            [2013, 13994, 8, 8],
            [2013, 13995, 14, 12],
            [2013, 13996, 8, 8],
            [2013, 13997, 7, 6],
            [2013, 13998, 7, 7],
            [2013, 13999, 12, 11],
            [2013, 14000, 12, 11],
            [2013, 14001, 12, 9],
            [2013, 14002, 7, 7],
            [2013, 14003, 7, 7],
            [2013, 14004, 7, 7],
            [2013, 14005, 25, 20],
            [2013, 14006, 12, 8],
            [2013, 14007, 15, 12],
            [2013, 14008, 12, 9],
            [2013, 14009, 15, 8],
            [2013, 14010, 10, 8],
            [2013, 14011, 10, 11],
            [2013, 14012, 10, 11],
            [2013, 14013, 12, 11],
            [2013, 14014, 26, 16],
            [2013, 14015, 17, 12],
            [2013, 14016, 13, 12],
            [2013, 14017, 26, 15],
            [2013, 14018, 9, 9],
            [2013, 14019, 8, 7],
            [2013, 14020, 8, 7],
            [2013, 14021, 14, 9],
            [2013, 14022, 9, 9],
            [2013, 14023, 27, 16],
            [2013, 14024, 14, 16],
            [2013, 14025, 13, 14],
            [2013, 14026, 21, 16],
            [2013, 14027, 11, 11],
            [2013, 14028, 11, 11],
            [2013, 14029, 13, 12],
            [2013, 14030, 21, 14],
            [2013, 14031, 25, 19],
            [2013, 14032, 13, 12],
            [2013, 14033, 12, 12],
            [2013, 14034, 14, 13],
            [2013, 14035, 23, 15],
            [2013, 14036, 12, 11],
            [2013, 14037, 20, 14],
            [2013, 14038, 12, 11],
            [2013, 14039, 17, 12],
            [2013, 14040, 17, 14],
            [2013, 14041, 26, 21],
            [2013, 14042, 19, 16],
            [2013, 14043, 13, 11],
            [2013, 14044, 10, 10],
            [2013, 14045, 10, 9],
            [2013, 14046, 9, 14],
            [2013, 14047, 17, 14],
            [2013, 14048, 17, 14],
            [2013, 14049, 24, 14],
            [2013, 14050, 17, 14],
            [2013, 14051, 21, 16],
            [2013, 14052, 12, 11],
            [2013, 14053, 13, 11],
            [2013, 14054, 14, 14],
            [2013, 14055, 26, 14],
            [2013, 14056, 26, 14],
            [2013, 14057, 15, 14],
            [2013, 14058, 15, 11],
            [2013, 14059, 12, 12],
            [2013, 14060, 16, 12],
            [2013, 14061, 15, 15],
            [2013, 14062, 13, 17],
            [2013, 14063, 20, 11],
            [2013, 14064, 16, 12],
            [2013, 14065, 20, 11],
            [2013, 14066, 14, 10],
            [2013, 14067, 16, 17],
            [2013, 14068, 15, 9],
            [2013, 14069, 13, 13],
            [2013, 14070, 20, 21],
            [2013, 14071, 20, 19],
            [2013, 14072, 13, 9],
            [2013, 14073, 20, 17],
            [2013, 14074, 17, 21],
            [2013, 14075, 20, 13],
            [2013, 14076, 20, 14],
            [2013, 14077, 15, 10],
            [2013, 14078, 16, 11],
            [2013, 14079, 13, 10],
            [2013, 14080, 20, 13],
            [2013, 14081, 20, 13],
            [2013, 14082, 22, 15],
            [2013, 14083, 16, 8],
            [2013, 14084, 16, 11],
            [2013, 14085, 16, 11],
            [2013, 14086, 20, 15],
            [2013, 14087, 17, 13],
            [2013, 14088, 14, 10],
            [2013, 14089, 15, 10],
            [2013, 14090, 15, 14],
            [2013, 14091, 20, 15],
            [2013, 14092, 16, 8],
            [2013, 14093, 16, 8],
            [2013, 14094, 11, 8],
            [2013, 14095, 16, 15],
            [2013, 14096, 16, 14],
            [2013, 14097, 16, 11],
            [2013, 14098, 18, 11],
            [2013, 14099, 18, 12],
            [2013, 14100, 16, 10],
            [2013, 14101, 23, 13],
            [2013, 14102, 18, 10],
            [2013, 14103, 16, 15],
            [2013, 14104, 11, 10],
            [2013, 14105, 20, 14],
            [2013, 14106, 16, 10],
            [2013, 14107, 14, 10],
            [2013, 14108, 15, 11],
            [2013, 14109, 16, 10],
            [2013, 14110, 19, 11],
            [2013, 14111, 20, 15],
            [2013, 14112, 16, 11],
            [2013, 14113, 15, 14],
            [2013, 14114, 15, 13],
            [2013, 14115, 18, 15],
            [2013, 14116, 17, 16],
            [2013, 14117, 32, 12],
            [2013, 14118, 22, 16],
            [2013, 14119, 34, 23],
            [2013, 14120, 17, 11],
            [2013, 14121, 24, 12],
            [2013, 14122, 20, 14],
            [2013, 14123, 18, 14],
            [2013, 14124, 10, 10],
            [2013, 14125, 21, 17],
            [2013, 14126, 17, 11],
            [2013, 14127, 16, 12],
            [2013, 14128, 11, 10],
            [2013, 14129, 10, 9],
            [2013, 14130, 17, 14],
            [2013, 14131, 46, 19],
            [2013, 14132, 20, 12],
            [2013, 14133, 11, 9],
            [2013, 14134, 15, 12],
            [2013, 14135, 19, 13],
            [2013, 14136, 16, 11],
            [2013, 14137, 28, 13],
            [2013, 14138, 33, 13],
            [2013, 14139, 22, 15],
            [2013, 14140, 34, 16],
            [2013, 14141, 32, 16],
            [2013, 14142, 14, 14],
            [2013, 14143, 22, 15],
            [2013, 14144, 15, 10],
            [2013, 14145, 20, 12],
            [2013, 14146, 44, 14],
            [2013, 14147, 14, 13],
            [2013, 14148, 13, 9],
            [2013, 14149, 17, 13],
            [2013, 14150, 12, 10],
            [2013, 14151, 15, 11],
            [2013, 14152, 23, 13],
            [2013, 14153, 12, 13],
            [2013, 14154, 20, 12],
            [2013, 14155, 12, 9],
            [2013, 14156, 19, 14],
            [2013, 14157, 32, 18],
            [2013, 14158, 15, 12],
            [2013, 14159, 24, 14],
            [2013, 14160, 16, 13],
            [2013, 14161, 10, 10],
            [2013, 14162, 15, 13],
            [2013, 14163, 10, 10],
            [2013, 14164, 15, 14],
            [2013, 14165, 16, 11],
            [2013, 14166, 30, 13],
            [2013, 14167, 12, 9],
            [2013, 14168, 16, 13],
            [2013, 14169, 11, 9],
            [2013, 14170, 10, 9],
            [2013, 14171, 36, 15],
            [2013, 14172, 26, 18],
            [2013, 14173, 10, 13],
            [2013, 14174, 26, 18],
            [2013, 14175, 23, 36],
            [2013, 14176, 10, 11],
            [2013, 14177, 14, 12],
            [2013, 14178, 10, 10],
            [2013, 14179, 25, 20],
            [2013, 14180, 21, 14],
            [2013, 14181, 24, 14],
            [2013, 14182, 17, 14],
            [2013, 14183, 10, 9],
            [2013, 14184, 28, 10],
            [2013, 14185, 27, 12],
            [2013, 14186, 23, 12],
            [2013, 14187, 10, 12],
            [2013, 14188, 15, 14],
            [2013, 14189, 15, 12],
            [2013, 14190, 10, 9],
            [2013, 14191, 14, 18],
            [2013, 14192, 33, 20],
            [2013, 14193, 20, 19],
            [2013, 14194, 10, 10],
            [2013, 14195, 10, 9],
            [2013, 14196, 46, 22],
            [2013, 14197, 17, 14],
            [2013, 14198, 10, 11],
            [2013, 14199, 14, 15],
            [2013, 14200, 19, 11],
            [2013, 14201, 12, 11],
            [2013, 14202, 10, 10],
            [2013, 14203, 11, 10],
            [2013, 14204, 10, 10],
            [2013, 14205, 18, 13],
            [2013, 14206, 14, 12],
            [2013, 14207, 16, 12],
            [2013, 14208, 13, 10],
            [2013, 14209, 26, 14],
            [2013, 14210, 24, 12],
            [2013, 14211, 21, 15],
            [2013, 14212, 10, 10],
            [2013, 14213, 30, 19],
            [2013, 14214, 10, 9],
            [2013, 14215, 21, 14],
            [2013, 14216, 14, 12],
            [2013, 14217, 15, 14],
            [2013, 14218, 12, 10],
            [2013, 14219, 10, 9],
            [2013, 14220, 15, 14],
            [2013, 14221, 13, 11],
            [2013, 14222, 27, 15],
            [2013, 14223, 16, 13],
            [2013, 14224, 16, 15],
            [2013, 14225, 17, 14],
            [2013, 14226, 30, 12],
            [2013, 14227, 15, 13],
            [2013, 14228, 15, 16],
            [2013, 14229, 16, 14],
            [2013, 14230, 22, 12],
            [2013, 14231, 16, 11],
            [2013, 14232, 11, 9],
            [2013, 14233, 16, 14],
            [2013, 14234, 20, 14],
            [2013, 14235, 18, 12],
            [2013, 14236, 36, 23],
            [2013, 14237, 13, 10],
            [2013, 14238, 14, 13],
            [2013, 14239, 21, 14],
            [2013, 14240, 7, 5],
            [2013, 14241, 14, 8],
            [2013, 14242, 26, 15],
            [2013, 14243, 7, 5],
            [2013, 14244, 25, 14],
            [2013, 14245, 19, 14],
            [2013, 14246, 21, 16],
            [2013, 14247, 28, 17],
            [2013, 14248, 16, 11],
            [2013, 14249, 31, 18],
            [2013, 14250, 27, 16],
            [2013, 14251, 10, 7],
            [2013, 14252, 28, 16],
            [2013, 14253, 28, 15],
            [2013, 14254, 15, 10],
            [2013, 14255, 20, 12],
            [2013, 14256, 15, 10],
            [2013, 14257, 23, 13],
            [2013, 14258, 15, 9],
            [2013, 14259, 26, 14],
            [2013, 14260, 17, 10],
            [2013, 14261, 25, 14],
            [2013, 14262, 27, 16],
            [2013, 14263, 16, 11],
            [2013, 14264, 27, 14],
            [2013, 14265, 28, 16],
            [2013, 14266, 20, 15],
            [2013, 14267, 7, 6],
            [2013, 14268, 7, 6],
            [2013, 14269, 31, 18],
            [2013, 14270, 11, 8],
            [2013, 14271, 10, 8],
            [2013, 14272, 8, 6],
            [2013, 14273, 28, 16],
            [2013, 14274, 20, 14],
            [2013, 14275, 27, 14],
            [2013, 14276, 16, 12],
            [2013, 14277, 9, 6],
            [2013, 14278, 9, 8],
            [2013, 14279, 8, 6],
            [2013, 14280, 23, 14],
            [2013, 14281, 11, 7],
            [2013, 14282, 14, 9],
            [2013, 14283, 12, 7],
            [2013, 14284, 27, 15],
            [2013, 14285, 22, 13],
            [2013, 14286, 24, 15],
            [2013, 14287, 17, 12],
            [2013, 14288, 18, 11],
            [2013, 14289, 27, 15],
            [2013, 14290, 31, 19],
            [2013, 14291, 19, 13],
            [2013, 14292, 21, 12],
            [2013, 14293, 16, 9],
            [2013, 14294, 23, 13],
            [2013, 14295, 24, 13],
            [2013, 14296, 27, 15],
            [2013, 14297, 23, 15],
            [2013, 14298, 14, 8],
            [2013, 14299, 22, 15],
            [2013, 14300, 8, 6],
            [2013, 14301, 10, 8],
            [2013, 14302, 10, 8],
            [2013, 14303, 25, 15],
            [2013, 14304, 18, 11],
            [2013, 14305, 30, 17],
            [2013, 14306, 29, 17],
            [2013, 14307, 7, 6],
            [2013, 14308, 22, 13],
            [2013, 14309, 11, 9],
            [2013, 14310, 23, 14],
            [2013, 14311, 24, 15],
            [2013, 14312, 26, 16],
            [2013, 14313, 16, 9],
            [2013, 14314, 25, 15],
            [2013, 14315, 21, 14],
            [2013, 14316, 22, 14],
            [2013, 14317, 17, 13],
            [2013, 14318, 27, 17],
            [2013, 14319, 14, 10],
            [2013, 14320, 10, 8],
            [2013, 14321, 26, 16],
            [2013, 14322, 17, 13],
            [2013, 14323, 24, 15],
            [2013, 14324, 20, 13],
            [2013, 14325, 37, 15],
            [2013, 14326, 8, 6],
            [2013, 14327, 29, 15],
            [2013, 14328, 19, 12],
            [2013, 14329, 25, 15],
            [2013, 14330, 23, 14],
            [2013, 14331, 23, 15],
            [2013, 14332, 11, 8],
            [2013, 14333, 13, 9],
            [2013, 14334, 27, 15],
            [2013, 14335, 24, 16],
            [2013, 14336, 12, 10],
            [2013, 14337, 13, 10],
            [2013, 14338, 23, 14],
            [2013, 14339, 8, 5],
            [2013, 14340, 11, 7],
            [2013, 14341, 26, 15],
            [2013, 14342, 29, 17],
            [2013, 14343, 25, 14],
            [2013, 14344, 28, 14],
            [2013, 14345, 25, 15],
            [2013, 14346, 28, 15],
            [2013, 14347, 12, 9],
            [2013, 14348, 28, 14],
            [2013, 14349, 18, 11],
            [2013, 14350, 14, 10],
            [2013, 14351, 9, 6],
            [2013, 14352, 26, 14],
            [2013, 14353, 22, 13],
            [2013, 14354, 28, 16],
            [2013, 14355, 21, 14],
            [2013, 14356, 11, 8],
            [2013, 14357, 23, 13],
            [2013, 14358, 15, 10],
            [2013, 14359, 28, 14],
            [2013, 14360, 11, 8],
            [2013, 14361, 24, 14],
            [2013, 14362, 21, 13],
            [2013, 14363, 28, 16],
            [2013, 14364, 24, 13],
            [2013, 14365, 19, 13],
            [2013, 14366, 26, 15],
            [2013, 14367, 31, 16],
            [2013, 14368, 27, 16],
            [2013, 14369, 28, 15],
            [2013, 14370, 11, 8],
            [2013, 14371, 7, 5],
            [2013, 14372, 12, 8],
            [2013, 14373, 24, 14],
            [2013, 14374, 26, 13],
            [2013, 14375, 24, 13],
            [2013, 14376, 7, 5],
            [2013, 14377, 7, 5],
            [2013, 14378, 7, 6],
            [2013, 14379, 28, 16],
            [2013, 14380, 25, 14],
            [2013, 14381, 25, 15],
            [2013, 14382, 26, 15],
            [2013, 14383, 13, 8],
            [2013, 14384, 29, 13],
            [2013, 14385, 28, 14],
            [2013, 14386, 27, 15],
            [2013, 14387, 28, 17],
            [2013, 14388, 37, 20],
            [2013, 14389, 26, 14],
            [2013, 14390, 24, 14],
            [2013, 14391, 13, 8],
            [2013, 14392, 22, 14],
            [2013, 14393, 15, 9],
            [2013, 14394, 27, 14],
            [2013, 14395, 29, 15],
            [2013, 14396, 22, 13],
            [2013, 14397, 24, 14],
            [2013, 14398, 23, 13],
            [2013, 14399, 32, 16],
            [2013, 14400, 30, 17],
            [2013, 14401, 24, 13],
            [2013, 14402, 13, 8],
            [2013, 14403, 27, 15],
            [2013, 14404, 29, 13],
            [2013, 14405, 37, 16],
            [2013, 14406, 38, 20],
            [2013, 14407, 28, 15],
            [2013, 14408, 18, 12],
            [2013, 14409, 28, 13],
            [2013, 14410, 12, 9],
            [2013, 14411, 19, 10],
            [2013, 14412, 17, 9],
            [2013, 14413, 10, 7],
            [2013, 14414, 7, 5],
            [2013, 14415, 25, 14],
            [2013, 14416, 17, 11],
            [2013, 14417, 18, 13],
            [2013, 14418, 25, 13],
            [2013, 14419, 27, 14],
            [2013, 14420, 15, 10],
            [2013, 14421, 32, 14],
            [2013, 14422, 22, 11],
            [2013, 14423, 16, 9],
            [2013, 14424, 16, 10],
            [2013, 14425, 29, 19],
            [2013, 14426, 17, 11],
            [2013, 14427, 25, 13],
            [2013, 14428, 23, 13],
            [2013, 14429, 20, 11],
            [2013, 14430, 25, 14],
            [2013, 14431, 10, 7],
            [2013, 14432, 24, 13],
            [2013, 14433, 35, 19],
            [2013, 14434, 20, 11],
            [2013, 14435, 12, 12],
            [2013, 14436, 26, 23],
            [2013, 14438, 20, 41],
            [2013, 14440, 20, 38],
            [2013, 14442, 20, 23],
            [2013, 14445, 26, 38],
            [2013, 14446, 26, 32],
            [2013, 14447, 20, 23],
            [2013, 14449, 17, 25],
            [2013, 14450, 63, 40],
            [2013, 14452, 32, 39],
            [2013, 14453, 26, 48],
            [2013, 14458, 29, 45],
            [2013, 14459, 30, 30],
            [2013, 14460, 30, 30],
            [2013, 14462, 20, 34],
            [2013, 14463, 16, 20],
            [2013, 14464, 32, 30],
            [2013, 14465, 42, 23],
            [2013, 14466, 27, 30],
            [2013, 14468, 30, 35],
            [2013, 14470, 26, 24],
            [2013, 14471, 26, 29],
            [2013, 14473, 27, 22],
            [2013, 14476, 32, 30],
            [2013, 14478, 24, 24],
            [2013, 14480, 30, 30],
            [2013, 14484, 30, 35],
            [2013, 14485, 16, 21],
            [2013, 14486, 33, 28],
            [2013, 14488, 23, 30],
            [2013, 14489, 18, 21],
            [2013, 14490, 38, 30],
            [2013, 14491, 23, 30],
            [2013, 14493, 30, 41],
            [2013, 14495, 24, 30],
            [2013, 14496, 40, 39],
            [2013, 14500, 24, 35],
            [2013, 14501, 20, 30],
            [2013, 14502, 42, 30],
            [2013, 14503, 30, 30],
            [2013, 14505, 22, 22],
            [2013, 14507, 30, 44],
            [2013, 14508, 18, 30],
            [2013, 14509, 33, 29],
            [2013, 14510, 33, 28],
            [2013, 14512, 30, 30],
            [2013, 14513, 40, 32],
            [2013, 14514, 38, 44],
            [2013, 14516, 40, 38],
            [2013, 14518, 30, 29],
            [2013, 14519, 44, 36],
            [2013, 14520, 30, 41],
            [2013, 14524, 24, 27],
            [2013, 14527, 30, 50],
            [2013, 14528, 39, 31],
            [2013, 14530, 47, 44],
            [2013, 14532, 10, 10],
            [2013, 14533, 11, 11],
            [2013, 14534, 18, 11],
            [2013, 14535, 12, 6],
            [2013, 14536, 20, 14],
            [2013, 14537, 20, 16],
            [2013, 14538, 24, 15],
            [2013, 14539, 7, 7],
            [2013, 14540, 16, 11],
            [2013, 14541, 19, 15],
            [2013, 14542, 16, 11],
            [2013, 14543, 16, 13],
            [2013, 14544, 10, 9],
            [2013, 14545, 20, 17],
            [2013, 14546, 21, 16],
            [2013, 14547, 20, 14],
            [2013, 14548, 22, 16],
            [2013, 14549, 25, 16],
            [2013, 14550, 19, 15],
            [2013, 14551, 21, 13],
            [2013, 14552, 8, 9],
            [2013, 14553, 14, 17],
            [2013, 14554, 17, 9],
            [2013, 14555, 11, 12],
            [2013, 14556, 23, 16],
            [2013, 14557, 22, 19],
            [2013, 14558, 12, 10],
            [2013, 14559, 12, 11],
            [2013, 14562, 89, 33],
            [2013, 14563, 99, 34],
            [2013, 14564, 23, 19],
            [2013, 14565, 20, 41],
            [2013, 14566, 16, 22],
            [2013, 14567, 24, 39],
            [2013, 14568, 75, 75],
            [2013, 14569, 20, 18],
            [2013, 14570, 20, 24],
            [2013, 14571, 16, 17],
            [2013, 14572, 16, 23],
            [2013, 14573, 92, 79],
            [2013, 14574, 12, 11],
            [2013, 14575, 8, 6],
            [2013, 14576, 9, 8],
            [2013, 14577, 31, 20],
            [2013, 14578, 19, 16],
            [2013, 14579, 16, 12],
            [2013, 14580, 8, 8],
            [2013, 14581, 9, 10],
            [2013, 14582, 24, 23],
            [2013, 14583, 19, 14],
            [2013, 14584, 7, 7],
            [2013, 14585, 11, 10],
            [2013, 14586, 11, 12],
            [2013, 14588, 22, 15],
            [2013, 14590, 18, 16],
            [2013, 14591, 18, 15],
            [2013, 14592, 2, 2],
            [2013, 14593, 83, 39],
            [2013, 14594, 4, 4],
            [2013, 14596, 5, 4],
            [2013, 14598, 15, 9],
            [2013, 14599, 21, 11],
            [2013, 14600, 30, 17],
            [2013, 14601, 7, 6],
            [2013, 14602, 20, 17],
            [2013, 14603, 12, 8],
            [2013, 14604, 10, 9],
            [2013, 14605, 15, 14],
            [2013, 14607, 6, 6],
            [2013, 14608, 9, 9],
            [2013, 14609, 11, 8],
            [2013, 14610, 4, 4],
            [2013, 14611, 6, 5],
            [2013, 14613, 21, 16],
            [2013, 14614, 21, 15],
            [2013, 14616, 13, 13],
            [2013, 14617, 32, 22],
            [2013, 14618, 7, 7],
            [2013, 14619, 18, 14],
            [2013, 14620, 13, 13],
            [2013, 14621, 8, 6],
            [2013, 14622, 14, 11],
            [2013, 14623, 16, 12],
            [2013, 14624, 9, 9],
            [2013, 14625, 11, 7],
            [2013, 14626, 8, 6],
            [2013, 14627, 30, 19],
            [2013, 14628, 17, 15],
            [2013, 14629, 24, 17],
            [2013, 14630, 7, 7],
            [2013, 14631, 6, 5],
            [2013, 14632, 31, 23],
            [2013, 14633, 30, 26],
            [2013, 14634, 10, 9],
            [2013, 14635, 7, 6],
            [2013, 14636, 16, 12],
            [2013, 14637, 15, 12],
            [2013, 14638, 20, 12],
            [2013, 14639, 5, 6],
            [2013, 14640, 9, 6],
            [2013, 14642, 24, 15],
            [2013, 14643, 6, 6],
            [2013, 14644, 6, 7],
            [2013, 14645, 15, 13],
            [2013, 14646, 8, 7],
            [2013, 14647, 23, 14],
            [2013, 14648, 4, 4],
            [2013, 14649, 12, 10],
            [2013, 14650, 15, 12],
            [2013, 14651, 15, 12],
            [2013, 14652, 19, 15],
            [2013, 14653, 22, 15],
            [2013, 14655, 4, 4],
            [2013, 14656, 11, 12],
            [2013, 14657, 7, 6],
            [2013, 14658, 17, 13],
            [2013, 14659, 15, 12],
            [2013, 14660, 14, 14],
            [2013, 14662, 19, 13],
            [2013, 14663, 17, 15],
            [2013, 14664, 8, 8],
            [2013, 14665, 12, 11],
            [2013, 14666, 12, 11],
            [2013, 14667, 18, 13],
            [2013, 14668, 15, 13],
            [2013, 14669, 27, 23],
            [2013, 14670, 15, 12],
            [2013, 14671, 16, 14],
            [2013, 14672, 14, 14],
            [2013, 14673, 19, 16],
            [2013, 14674, 10, 9],
            [2013, 14675, 8, 7],
            [2013, 14676, 14, 12],
            [2013, 14677, 13, 11],
            [2013, 14678, 18, 11],
            [2013, 14680, 17, 13],
            [2013, 14681, 16, 12],
            [2013, 14682, 11, 9],
            [2013, 14683, 17, 13],
            [2013, 14684, 31, 21],
            [2013, 14686, 11, 8],
            [2013, 14687, 21, 15],
            [2013, 14688, 6, 6],
            [2013, 14689, 12, 11],
            [2013, 14690, 21, 16],
            [2013, 14691, 16, 12],
            [2013, 14692, 17, 16],
            [2013, 14693, 11, 8],
            [2013, 14694, 8, 6],
            [2013, 14696, 9, 9],
            [2013, 14697, 14, 12],
            [2013, 14698, 16, 9],
            [2013, 14699, 20, 16],
            [2013, 14700, 17, 15],
            [2013, 14701, 30, 18],
            [2013, 14702, 39, 29],
            [2013, 14703, 30, 22],
            [2013, 14704, 67, 41],
            [2013, 14705, 24, 19],
            [2013, 14706, 42, 25],
            [2013, 14707, 13, 10],
            [2013, 14708, 19, 16],
            [2013, 14709, 29, 21],
            [2013, 14710, 29, 18],
            [2013, 14711, 31, 22],
            [2013, 14712, 39, 23],
            [2013, 14713, 35, 23],
            [2013, 14714, 27, 18],
            [2013, 14715, 13, 9],
            [2013, 14716, 12, 8],
            [2013, 14717, 12, 10],
            [2013, 14718, 21, 21],
            [2013, 14719, 19, 17],
            [2013, 14720, 69, 39],
            [2013, 14721, 49, 27],
            [2013, 14722, 30, 22],
            [2013, 14723, 12, 9],
            [2013, 14724, 19, 18],
            [2013, 14725, 24, 24],
            [2013, 14726, 22, 20],
            [2013, 14727, 44, 22],
            [2013, 14728, 35, 24],
            [2013, 14729, 27, 24],
            [2013, 14730, 24, 20],
            [2013, 14731, 19, 20],
            [2013, 14732, 49, 24],
            [2013, 14733, 35, 20],
            [2013, 14734, 30, 36],
            [2013, 14735, 49, 28],
            [2013, 14736, 44, 26],
            [2013, 14737, 13, 9],
            [2013, 14738, 29, 22],
            [2013, 14739, 19, 18],
            [2013, 14740, 35, 29],
            [2013, 14741, 27, 20],
            [2013, 14742, 22, 24],
            [2013, 14743, 21, 15],
            [2013, 14744, 12, 9],
            [2013, 14745, 28, 27],
            [2013, 14746, 13, 11],
            [2013, 14747, 27, 24],
            [2013, 14748, 19, 18],
            [2013, 14749, 13, 9],
            [2013, 14750, 22, 17],
            [2013, 14751, 29, 18],
            [2013, 14752, 21, 17],
            [2013, 14753, 35, 24],
            [2013, 14754, 17, 18],
            [2013, 14755, 21, 24],
            [2013, 14756, 21, 18],
            [2013, 14757, 17, 11],
            [2013, 14758, 27, 17],
            [2013, 14759, 30, 22],
            [2013, 14760, 30, 24],
            [2013, 14761, 19, 9],
            [2013, 14762, 12, 9],
            [2013, 14763, 24, 36],
            [2013, 14764, 54, 29],
            [2013, 14765, 13, 9],
            [2013, 14766, 44, 26],
            [2013, 14767, 27, 29],
            [2013, 14768, 5, 5],
            [2013, 14769, 41, 27],
            [2013, 14770, 19, 19],
            [2013, 14771, 31, 39],
            [2013, 14772, 56, 37],
            [2013, 14773, 39, 46],
            [2013, 14774, 31, 20],
            [2013, 14775, 37, 33],
            [2013, 14776, 41, 37],
            [2013, 14777, 21, 25],
            [2013, 14778, 14, 12],
            [2013, 14779, 41, 25],
            [2013, 14780, 39, 13],
            [2013, 14781, 11, 11],
            [2013, 14782, 66, 33],
            [2013, 14783, 29, 25],
            [2013, 14784, 16, 25],
            [2013, 14785, 66, 46],
            [2013, 14786, 27, 19],
            [2013, 14787, 27, 18],
            [2013, 14788, 27, 25],
            [2013, 14789, 71, 41],
            [2013, 14790, 51, 21],
            [2013, 14791, 14, 13],
            [2013, 14792, 66, 61],
            [2013, 14793, 39, 25],
            [2013, 14794, 31, 29],
            [2013, 14795, 33, 25],
            [2013, 14796, 37, 51],
            [2013, 14797, 27, 56],
            [2013, 14798, 29, 46],
            [2013, 14799, 46, 25],
            [2013, 14800, 14, 11],
            [2013, 14801, 31, 15],
            [2013, 14802, 21, 13],
            [2013, 14803, 37, 37],
            [2013, 14804, 14, 12],
            [2013, 14805, 37, 37],
            [2013, 14806, 16, 13],
            [2013, 14807, 39, 27],
            [2013, 14808, 51, 51],
            [2013, 14809, 16, 27],
            [2013, 14810, 17, 19],
            [2013, 14811, 17, 21],
            [2013, 14812, 46, 39],
            [2013, 14813, 27, 21],
            [2013, 14814, 39, 25],
            [2013, 14815, 61, 29],
            [2013, 14816, 14, 12],
            [2013, 14817, 14, 11],
            [2013, 14818, 14, 11],
            [2013, 14819, 37, 33],
            [2013, 14820, 71, 61],
            [2013, 14821, 21, 19],
            [2013, 14822, 46, 37],
            [2013, 14823, 20, 20],
            [2013, 14824, 66, 41],
            [2013, 14825, 17, 18],
            [2013, 14826, 41, 20],
            [2013, 14827, 46, 37],
            [2013, 14828, 51, 41],
            [2013, 14829, 19, 19],
            [2013, 14830, 14, 16],
            [2013, 14831, 31, 19],
            [2013, 14832, 46, 37],
            [2013, 14833, 39, 31],
            [2013, 14834, 41, 46],
            [2013, 14835, 56, 21],
            [2013, 14836, 46, 23],
            [2013, 14837, 61, 37],
            [2013, 14838, 61, 46],
            [2013, 14839, 31, 37],
            [2013, 14840, 33, 25],
            [2013, 14841, 23, 19],
            [2013, 14842, 19, 16],
            [2013, 14843, 61, 37],
            [2013, 14844, 17, 18],
            [2013, 14845, 51, 51],
            [2013, 14846, 39, 18],
            [2013, 14847, 14, 12],
            [2013, 14848, 14, 11],
            [2013, 14849, 14, 11],
            [2013, 14850, 41, 29],
            [2013, 14851, 19, 23],
            [2013, 14852, 15, 12],
            [2013, 14853, 27, 23],
            [2013, 14854, 61, 46],
            [2013, 14855, 11, 11],
            [2013, 14856, 11, 11],
            [2013, 14857, 11, 11],
            [2013, 14858, 18, 17],
            [2013, 14859, 26, 27],
            [2013, 14860, 19, 18],
            [2013, 14861, 16, 14],
            [2013, 14862, 21, 15],
            [2013, 14863, 11, 11],
            [2013, 14864, 11, 11],
            [2013, 14865, 21, 26],
            [2013, 14866, 22, 23],
            [2013, 14867, 16, 25],
            [2013, 14868, 28, 25],
            [2013, 14869, 25, 26],
            [2013, 14870, 11, 11],
            [2013, 14871, 11, 11],
            [2013, 14872, 11, 11],
            [2013, 14873, 30, 23],
            [2013, 14874, 23, 17],
            [2013, 14875, 28, 29],
            [2013, 14876, 15, 16],
            [2013, 14877, 53, 38],
            [2013, 14878, 12, 15],
            [2013, 14879, 23, 22],
            [2013, 14880, 21, 13],
            [2013, 14881, 27, 24],
            [2013, 14882, 27, 28],
            [2013, 14883, 12, 18],
            [2013, 14884, 11, 12],
            [2013, 14885, 11, 11],
            [2013, 14886, 26, 20],
            [2013, 14887, 21, 15],
            [2013, 14888, 14, 13],
            [2013, 14889, 27, 24],
            [2013, 14890, 16, 14],
            [2013, 14891, 22, 29],
            [2013, 14892, 28, 30],
            [2013, 14893, 20, 33],
            [2013, 14894, 16, 17],
            [2013, 14895, 23, 17],
            [2013, 14896, 41, 35],
            [2013, 14897, 22, 22],
            [2013, 14898, 37, 26],
            [2013, 14899, 16, 14],
            [2013, 14900, 14, 12],
            [2013, 14901, 11, 12],
            [2013, 14902, 21, 23],
            [2013, 14903, 24, 19],
            [2013, 14904, 29, 25],
            [2013, 14905, 35, 29],
            [2013, 14906, 15, 15],
            [2013, 14907, 10, 11],
            [2013, 14908, 10, 11],
            [2013, 14909, 10, 11],
            [2013, 14910, 19, 19],
            [2013, 14911, 24, 22],
            [2013, 14912, 22, 21],
            [2013, 14913, 15, 15],
            [2013, 14914, 16, 17],
            [2013, 14915, 24, 22],
            [2013, 14916, 27, 18],
            [2013, 14917, 24, 28],
            [2013, 14918, 33, 37],
            [2013, 14919, 13, 13],
            [2013, 14920, 29, 29],
            [2013, 14921, 17, 14],
            [2013, 14922, 12, 12],
            [2013, 14923, 22, 20],
            [2013, 14924, 23, 25],
            [2013, 14925, 22, 17],
            [2013, 14926, 28, 35],
            [2013, 14927, 24, 31],
            [2013, 14928, 21, 26],
            [2013, 14929, 24, 25],
            [2013, 14930, 23, 23],
            [2013, 14931, 14, 13],
            [2013, 14932, 17, 13],
            [2013, 14933, 19, 16],
            [2013, 14934, 39, 39],
            [2013, 14935, 15, 25],
            [2013, 14936, 11, 11],
            [2013, 14937, 11, 11],
            [2013, 14938, 29, 28],
            [2013, 14939, 33, 27],
            [2013, 14940, 12, 11],
            [2013, 14941, 42, 38],
            [2013, 14942, 12, 11],
            [2013, 14943, 23, 17],
            [2013, 14944, 17, 16],
            [2013, 14945, 31, 31],
            [2013, 14946, 14, 14],
            [2013, 14947, 19, 18],
            [2013, 14948, 38, 33],
            [2013, 14949, 39, 27],
            [2013, 14950, 13, 11],
            [2013, 14951, 24, 17],
            [2013, 14952, 39, 23],
            [2013, 14953, 20, 20],
            [2013, 14954, 32, 27],
            [2013, 14955, 18, 13],
            [2013, 14956, 27, 24],
            [2013, 14957, 15, 16],
            [2013, 14958, 18, 33],
            [2013, 14959, 14, 12],
            [2013, 14960, 23, 16],
            [2013, 14961, 19, 20],
            [2013, 14962, 24, 28],
            [2013, 14963, 24, 23],
            [2013, 14964, 17, 15],
            [2013, 14965, 11, 11],
            [2013, 14966, 11, 11],
            [2013, 14967, 18, 18],
            [2013, 14968, 23, 27],
            [2013, 14969, 11, 12],
            [2013, 14970, 11, 12],
            [2013, 14971, 14, 12],
            [2013, 14972, 32, 29],
            [2013, 14973, 23, 19],
            [2013, 14974, 24, 18],
            [2013, 14975, 18, 12],
            [2013, 14976, 25, 18],
            [2013, 14977, 23, 17],
            [2013, 14978, 25, 38],
            [2013, 14979, 21, 16],
            [2013, 14980, 26, 25],
            [2013, 14981, 22, 19],
            [2013, 14982, 12, 12],
            [2013, 14983, 29, 23],
            [2013, 14984, 19, 13],
            [2013, 14985, 19, 19],
            [2013, 14986, 36, 33],
            [2013, 14987, 26, 24],
            [2013, 14988, 20, 22],
            [2013, 14989, 15, 17],
            [2013, 14990, 11, 10],
            [2013, 14991, 8, 5],
            [2013, 14992, 1, 1],
            [2013, 14993, 10, 7],
            [2013, 14994, 10, 6],
            [2013, 14995, 7, 6],
            [2013, 14996, 7, 6],
            [2013, 14997, 29, 20],
            [2013, 14998, 7, 4],
            [2013, 14999, 7, 6],
            [2013, 15000, 18, 16],
            [2013, 15001, 10, 10],
            [2013, 15002, 7, 6],
            [2013, 15003, 16, 14],
            [2013, 15004, 4, 4],
            [2013, 15005, 16, 14],
            [2013, 15006, 13, 11],
            [2013, 15007, 8, 4],
            [2013, 15008, 1, 1],
            [2013, 15009, 14, 12],
            [2013, 15010, 9, 7],
            [2013, 15011, 6, 5],
            [2013, 15012, 1, 1],
            [2013, 15013, 9, 8],
            [2013, 15014, 10, 6],
            [2013, 15015, 14, 14],
            [2013, 15016, 1, 1],
            [2013, 15017, 9, 5],
            [2013, 15018, 11, 10],
            [2013, 15019, 7, 6],
            [2013, 15020, 13, 11],
            [2013, 15021, 7, 5],
            [2013, 15022, 10, 7],
            [2013, 15023, 10, 7],
            [2013, 15024, 10, 7],
            [2013, 15025, 8, 6],
            [2013, 15026, 9, 7],
            [2013, 15027, 7, 6],
            [2013, 15028, 10, 8],
            [2013, 15029, 11, 9],
            [2013, 15030, 8, 5],
            [2013, 15031, 7, 4],
            [2013, 15032, 7, 4],
            [2013, 15033, 4, 2],
            [2013, 15034, 7, 6],
            [2013, 15035, 10, 8],
            [2013, 15036, 9, 6],
            [2013, 15037, 10, 6],
            [2013, 15038, 19, 18],
            [2013, 15039, 11, 8],
            [2013, 15040, 10, 8],
            [2013, 15041, 1, 1],
            [2013, 15042, 10, 6],
            [2013, 15043, 14, 12],
            [2013, 15044, 9, 6],
            [2013, 15045, 8, 5],
            [2013, 15046, 2, 1],
            [2013, 15047, 7, 5],
            [2013, 15048, 13, 12],
            [2013, 15049, 9, 6],
            [2013, 15050, 7, 5],
            [2013, 15051, 12, 11],
            [2013, 15052, 10, 6],
            [2013, 15053, 15, 13],
            [2013, 15054, 9, 5],
            [2013, 15055, 8, 5],
            [2013, 15056, 10, 8],
            [2013, 15057, 7, 5],
            [2013, 15058, 7, 5],
            [2013, 15059, 2, 1],
            [2013, 15060, 3, 1],
            [2013, 15061, 8, 6],
            [2013, 15062, 9, 6],
            [2013, 15063, 1, 1],
            [2013, 15064, 1, 1],
            [2013, 15065, 1, 1],
            [2013, 15066, 9, 6],
            [2013, 15067, 8, 5],
            [2013, 15068, 15, 13],
            [2013, 15069, 10, 8],
            [2013, 15070, 20, 20],
            [2013, 15071, 6, 5],
            [2013, 15072, 12, 11],
            [2013, 15073, 9, 6],
            [2013, 15074, 10, 7],
            [2013, 15075, 1, 1],
            [2013, 15076, 1, 1],
            [2013, 15077, 29, 18],
            [2013, 15078, 8, 6],
            [2013, 15079, 2, 1],
            [2013, 15080, 10, 8],
            [2013, 15081, 27, 20],
            [2013, 15082, 7, 5],
            [2013, 15083, 1, 1],
            [2013, 15084, 7, 6],
            [2013, 15085, 9, 7],
            [2013, 15086, 10, 7],
            [2013, 15087, 7, 6],
            [2013, 15088, 14, 11],
            [2013, 15089, 20, 16],
            [2013, 15090, 19, 15],
            [2013, 15091, 11, 10],
            [2013, 15092, 16, 10],
            [2013, 15093, 14, 9],
            [2013, 15094, 9, 7],
            [2013, 15095, 18, 15],
            [2013, 15096, 14, 10],
            [2013, 15097, 13, 11],
            [2013, 15098, 15, 13],
            [2013, 15099, 19, 15],
            [2013, 15100, 10, 10],
            [2013, 15101, 12, 10],
            [2013, 15102, 14, 9],
            [2013, 15103, 12, 8],
            [2013, 15104, 9, 6],
            [2013, 15105, 11, 10],
            [2013, 15106, 12, 7],
            [2013, 15107, 8, 7],
            [2013, 15108, 21, 14],
            [2013, 15109, 20, 14],
            [2013, 15110, 6, 5],
            [2013, 15111, 15, 10],
            [2013, 15112, 20, 14],
            [2013, 15113, 23, 13],
            [2013, 15114, 9, 8],
            [2013, 15115, 9, 7],
            [2013, 15116, 9, 8],
            [2013, 15117, 10, 8],
            [2013, 15118, 8, 7],
            [2013, 15119, 6, 5],
            [2013, 15120, 7, 7],
            [2013, 15121, 7, 5],
            [2013, 15122, 3, 3],
            [2013, 15123, 3, 3],
            [2013, 15124, 5, 5],
            [2013, 15125, 4, 5],
            [2013, 15126, 7, 6],
            [2013, 15127, 6, 5],
            [2013, 15128, 23, 15],
            [2013, 15129, 7, 5],
            [2013, 15130, 6, 5],
            [2013, 15131, 5, 4],
            [2013, 15132, 26, 18],
            [2013, 15133, 30, 14],
            [2013, 15134, 18, 13],
            [2013, 15135, 20, 12],
            [2013, 15136, 15, 10],
            [2013, 15137, 12, 9],
            [2013, 15138, 17, 10],
            [2013, 15139, 31, 17],
            [2013, 15140, 15, 11],
            [2013, 15141, 11, 7],
            [2013, 15142, 10, 7],
            [2013, 15143, 10, 7],
            [2013, 15144, 16, 9],
            [2013, 15145, 12, 9],
            [2013, 15146, 20, 13],
            [2013, 15147, 8, 6],
            [2013, 15148, 7, 5],
            [2013, 15149, 13, 10],
            [2013, 15150, 13, 8],
            [2013, 15151, 6, 5],
            [2013, 15152, 7, 6],
            [2013, 15153, 17, 9],
            [2013, 15154, 17, 9],
            [2013, 15155, 20, 15],
            [2013, 15156, 10, 9],
            [2013, 15157, 13, 12],
            [2013, 15158, 20, 12],
            [2013, 15159, 7, 6],
            [2013, 15160, 26, 17],
            [2013, 15161, 10, 8],
            [2013, 15162, 14, 9],
            [2013, 15163, 15, 9],
            [2013, 15164, 16, 9],
            [2013, 15165, 24, 10],
            [2013, 15166, 15, 12],
            [2013, 15167, 10, 15],
            [2013, 15168, 20, 15],
            [2013, 15169, 22, 9],
            [2013, 15170, 12, 10],
            [2013, 15171, 12, 7],
            [2013, 15172, 8, 6],
            [2013, 15173, 11, 10],
            [2013, 15174, 11, 7],
            [2013, 15175, 8, 6],
            [2013, 15176, 6, 6],
            [2013, 15177, 21, 13],
            [2013, 15178, 7, 5],
            [2013, 15179, 7, 5],
            [2013, 15180, 7, 5],
            [2013, 15181, 6, 5],
            [2013, 15182, 15, 11],
            [2013, 15183, 18, 11],
            [2013, 15184, 18, 12],
            [2013, 15185, 31, 18],
            [2013, 15186, 16, 11],
            [2013, 15187, 11, 11],
            [2013, 15188, 15, 12],
            [2013, 15189, 15, 13],
            [2013, 15190, 17, 9],
            [2013, 15191, 13, 9],
            [2013, 15192, 9, 9],
            [2013, 15193, 8, 7],
            [2013, 15194, 12, 10],
            [2013, 15195, 17, 15],
            [2013, 15196, 14, 8],
            [2013, 15197, 20, 13],
            [2013, 15198, 15, 12],
            [2013, 15199, 20, 9],
            [2013, 15200, 18, 12],
            [2013, 15201, 12, 9],
            [2013, 15202, 20, 12],
            [2013, 15203, 15, 10],
            [2013, 15204, 16, 9],
            [2013, 15205, 9, 6],
            [2013, 15206, 17, 9],
            [2013, 15207, 10, 8],
            [2013, 15208, 12, 9],
            [2013, 15209, 12, 11],
            [2013, 15210, 10, 10],
            [2013, 15211, 15, 11],
            [2013, 15212, 14, 12],
            [2013, 15213, 29, 20],
            [2013, 15214, 10, 7],
            [2013, 15215, 12, 10],
            [2013, 15216, 13, 10],
            [2013, 15217, 9, 8],
            [2013, 15218, 10, 9],
            [2013, 15219, 13, 9],
            [2013, 15220, 17, 8],
            [2013, 15221, 17, 12],
            [2013, 15222, 20, 11],
            [2013, 15223, 13, 8],
            [2013, 15224, 12, 9],
            [2013, 15225, 10, 8],
            [2013, 15226, 11, 7],
            [2013, 15227, 14, 15],
            [2013, 15228, 16, 14],
            [2013, 15229, 15, 8],
            [2013, 15230, 18, 10],
            [2013, 15231, 9, 11],
            [2013, 15232, 20, 14],
            [2013, 15233, 15, 11],
            [2013, 15234, 16, 12],
            [2013, 15235, 8, 8],
            [2013, 15236, 14, 11],
            [2013, 15237, 17, 9],
            [2013, 15238, 10, 9],
            [2013, 15239, 9, 8],
            [2013, 15240, 11, 8],
            [2013, 15241, 12, 8],
            [2013, 15242, 13, 11],
            [2013, 15243, 18, 10],
            [2013, 15244, 9, 7],
            [2013, 15245, 14, 9],
            [2013, 15246, 18, 14],
            [2013, 15247, 17, 12],
            [2013, 15248, 18, 14],
            [2013, 15249, 13, 8],
            [2013, 15250, 14, 10],
            [2013, 15251, 17, 11],
            [2013, 15252, 16, 14],
            [2013, 15253, 16, 11],
            [2013, 15254, 10, 6],
            [2013, 15255, 11, 12],
            [2013, 15256, 9, 7],
            [2013, 15257, 8, 10],
            [2013, 15258, 11, 7],
            [2013, 15259, 14, 9],
            [2013, 15260, 18, 12],
            [2013, 15261, 14, 8],
            [2013, 15262, 9, 7],
            [2013, 15263, 22, 9],
            [2013, 15264, 20, 14],
            [2013, 15265, 20, 15],
            [2013, 15266, 16, 11],
            [2013, 15267, 14, 10],
            [2013, 15268, 30, 12],
            [2013, 15269, 13, 11],
            [2013, 15270, 14, 7],
            [2013, 15271, 7, 7],
            [2013, 15272, 18, 17],
            [2013, 15273, 12, 6],
            [2013, 15274, 21, 16],
            [2013, 15275, 18, 12],
            [2013, 15276, 16, 10],
            [2013, 15277, 8, 7],
            [2013, 15278, 6, 6],
            [2013, 15279, 20, 16],
            [2013, 15280, 14, 12],
            [2013, 15281, 17, 9],
            [2013, 15282, 28, 15],
            [2013, 15283, 28, 13],
            [2013, 15284, 14, 12],
            [2013, 15285, 10, 10],
            [2013, 15286, 21, 14],
            [2013, 15287, 20, 11],
            [2013, 15288, 15, 7],
            [2013, 15289, 10, 9],
            [2013, 15290, 20, 12],
            [2013, 15291, 9, 6],
            [2013, 15292, 12, 10],
            [2013, 15293, 14, 9],
            [2013, 15294, 22, 14],
            [2013, 15295, 12, 12],
            [2013, 15296, 17, 16],
            [2013, 15297, 18, 14],
            [2013, 15298, 20, 11],
            [2013, 15299, 24, 14],
            [2013, 15300, 24, 13],
            [2013, 15301, 9, 7],
            [2013, 15302, 12, 9],
            [2013, 15303, 8, 6],
            [2013, 15304, 7, 9],
            [2013, 15305, 21, 10],
            [2013, 15306, 6, 6],
            [2013, 15307, 5, 6],
            [2013, 15308, 12, 11],
            [2013, 15309, 9, 9],
            [2013, 15310, 10, 6],
            [2013, 15311, 18, 12],
            [2013, 15312, 14, 11],
            [2013, 15313, 23, 10],
            [2013, 15314, 16, 11],
            [2013, 15315, 15, 11],
            [2013, 15316, 18, 11],
            [2013, 15317, 16, 11],
            [2013, 15318, 9, 7],
            [2013, 15319, 12, 11],
            [2013, 15320, 14, 10],
            [2013, 15321, 7, 5],
            [2013, 15322, 17, 14],
            [2013, 15323, 20, 12],
            [2013, 15324, 15, 12],
            [2013, 15325, 9, 6],
            [2013, 15326, 28, 20],
            [2013, 15327, 12, 10],
            [2013, 15328, 12, 7],
            [2013, 15329, 13, 8],
            [2013, 15330, 9, 6],
            [2013, 15331, 13, 12],
            [2013, 15332, 6, 5],
            [2013, 15333, 9, 7],
            [2013, 15334, 13, 8],
            [2013, 15335, 12, 11],
            [2013, 15336, 19, 12],
            [2013, 15337, 10, 10],
            [2013, 15338, 8, 6],
            [2013, 15339, 15, 9],
            [2013, 15340, 21, 11],
            [2013, 15341, 25, 12],
            [2013, 15342, 22, 14],
            [2013, 15343, 15, 12],
            [2013, 15344, 7, 7],
            [2013, 15345, 9, 8],
            [2013, 15346, 13, 8],
            [2013, 15347, 15, 10],
            [2013, 15348, 16, 10],
            [2013, 15349, 11, 8],
            [2013, 15350, 20, 11],
            [2013, 15351, 18, 9],
            [2013, 15352, 12, 7],
            [2013, 15353, 15, 12],
            [2013, 15354, 21, 14],
            [2013, 15355, 13, 12],
            [2013, 15356, 16, 9],
            [2013, 15357, 14, 13],
            [2013, 15358, 17, 11],
            [2013, 15359, 17, 14],
            [2013, 15360, 16, 16],
            [2013, 15361, 37, 30],
            [2013, 15362, 4, 6],
            [2013, 15363, 6, 7],
            [2013, 15364, 37, 20],
            [2013, 15365, 6, 7],
            [2013, 15366, 14, 14],
            [2013, 15367, 14, 14],
            [2013, 15368, 6, 7],
            [2013, 15369, 11, 9],
            [2013, 15370, 12, 10],
            [2013, 15371, 15, 12],
            [2013, 15372, 13, 11],
            [2013, 15373, 15, 13],
            [2013, 15374, 18, 12],
            [2013, 15375, 11, 10],
            [2013, 15376, 6, 5],
            [2013, 15377, 13, 11],
            [2013, 15378, 17, 11],
            [2013, 15379, 13, 11],
            [2013, 15380, 5, 5],
            [2013, 15381, 17, 11],
            [2013, 15382, 16, 11],
            [2013, 15383, 8, 7],
            [2013, 15384, 6, 6],
            [2013, 15385, 7, 6],
            [2013, 15386, 12, 10],
            [2013, 15387, 7, 6],
            [2013, 15388, 6, 6],
            [2013, 15389, 12, 15],
            [2013, 15390, 14, 11],
            [2013, 15391, 25, 13],
            [2013, 15392, 21, 13],
            [2013, 15393, 5, 5],
            [2013, 15394, 13, 13],
            [2013, 15395, 9, 8],
            [2013, 15396, 6, 5],
            [2013, 15397, 13, 10],
            [2013, 15398, 18, 15],
            [2013, 15399, 14, 12],
            [2013, 15400, 19, 11],
            [2013, 15401, 22, 12],
            [2013, 15402, 8, 8],
            [2013, 15403, 20, 10],
            [2013, 15404, 19, 11],
            [2013, 15405, 21, 12],
            [2013, 15406, 13, 12],
            [2013, 15407, 21, 14],
            [2013, 15408, 21, 12],
            [2013, 15409, 24, 11],
            [2013, 15410, 15, 10],
            [2013, 15411, 6, 6],
            [2013, 15412, 17, 11],
            [2013, 15413, 5, 5],
            [2013, 15414, 13, 10],
            [2013, 15415, 15, 11],
            [2013, 15416, 19, 11],
            [2013, 15417, 17, 10],
            [2013, 15418, 19, 11],
            [2013, 15419, 16, 14],
            [2013, 15420, 8, 7],
            [2013, 15459, 34, 33],
            [2013, 15460, 25, 43],
            [2013, 15461, 26, 24],
            [2013, 15462, 33, 35],
            [2013, 15463, 21, 24],
            [2013, 15464, 26, 27],
            [2013, 15465, 46, 37],
            [2013, 15466, 71, 68],
            [2013, 15467, 47, 48],
            [2013, 15468, 35, 32],
            [2013, 15469, 20, 24],
            [2013, 15470, 40, 40],
            [2013, 15471, 34, 32],
            [2013, 15472, 20, 33],
            [2013, 15473, 20, 25],
            [2013, 15474, 36, 40],
            [2013, 15475, 18, 28],
            [2013, 15476, 26, 40],
            [2013, 15477, 26, 27],
            [2013, 15478, 58, 48],
            [2013, 15479, 22, 34],
            [2013, 15480, 24, 35],
            [2013, 15481, 50, 52],
            [2013, 15482, 34, 44],
            [2013, 15483, 30, 34],
            [2013, 15484, 48, 43],
            [2013, 15485, 19, 35],
            [2013, 15486, 13, 21],
            [2013, 15487, 30, 37],
            [2013, 15488, 34, 40],
            [2013, 15489, 25, 26],
            [2013, 15490, 99, 90],
            [2013, 15491, 49, 43],
            [2013, 15492, 37, 40],
            [2013, 15493, 17, 39],
            [2013, 15494, 35, 37],
            [2013, 15495, 62, 47],
            [2013, 15496, 23, 30],
            [2013, 15497, 31, 32],
            [2013, 15498, 17, 22],
            [2013, 15499, 34, 32],
            [2013, 15500, 15, 13],
            [2013, 15501, 15, 13],
            [2013, 15502, 15, 13],
            [2013, 15503, 14, 12],
            [2013, 15504, 15, 14],
            [2013, 15505, 62, 54],
            [2013, 15506, 30, 66],
            [2013, 15507, 60, 50],
            [2013, 15508, 60, 50],
            [2013, 15509, 40, 40],
            [2013, 15510, 40, 40],
            [2013, 15511, 74, 56],
            [2013, 15512, 70, 70],
            [2013, 15513, 23, 42],
            [2013, 15514, 40, 66],
            [2013, 15515, 40, 60],
            [2013, 15516, 32, 36],
            [2013, 15517, 70, 70],
            [2013, 15518, 38, 44],
            [2013, 15519, 30, 55],
            [2013, 15520, 40, 58],
            [2013, 15521, 54, 55],
            [2013, 15522, 82, 68],
            [2013, 15523, 82, 68],
            [2013, 15524, 30, 54],
            [2013, 15525, 40, 66],
            [2013, 15526, 33, 35],
            [2013, 15527, 30, 40],
            [2013, 15528, 22, 39],
            [2013, 15529, 40, 62],
            [2013, 15530, 90, 82],
            [2013, 15531, 90, 82],
            [2013, 15532, 70, 70],
            [2013, 15533, 30, 62],
            [2013, 15534, 58, 62],
            [2013, 15535, 70, 70],
            [2013, 15536, 40, 46],
            [2013, 15537, 15, 13],
            [2013, 15538, 34, 31],
            [2013, 15539, 17, 22],
            [2013, 15540, 12, 20],
            [2013, 15541, 24, 23],
            [2013, 15542, 44, 44],
            [2013, 15543, 38, 28],
            [2013, 15544, 5, 5],
            [2013, 15548, 12, 10],
            [2013, 15550, 4, 4],
            [2013, 15551, 6, 6],
            [2013, 15552, 13, 11],
            [2013, 15553, 11, 9],
            [2013, 15554, 13, 11],
            [2013, 15555, 7, 7],
            [2013, 15556, 12, 10],
            [2013, 15557, 18, 11],
            [2013, 15558, 7, 8],
            [2013, 15559, 7, 7],
            [2013, 15560, 98, 34],
            [2013, 15561, 25, 20],
            [2013, 15562, 21, 30],
            [2013, 15563, 12, 10],
            [2013, 15564, 12, 11],
            [2013, 15565, 21, 17],
            [2013, 15566, 22, 17],
            [2013, 15567, 13, 10],
            [2013, 15568, 13, 11],
            [2013, 15569, 16, 14],
            [2013, 15570, 17, 15],
            [2013, 15571, 16, 15],
            [2013, 15572, 16, 15],
            [2013, 15573, 6, 6],
            [2013, 15574, 19, 11],
            [2013, 15575, 5, 7],
            [2013, 15576, 7, 9],
            [2013, 15577, 9, 11],
            [2013, 15578, 9, 9],
            [2013, 15579, 9, 7],
            [2013, 15580, 9, 9],
            [2013, 15581, 8, 7],
            [2013, 15582, 8, 7],
            [2013, 15583, 6, 6],
            [2013, 15584, 11, 8],
            [2013, 15585, 11, 8],
            [2013, 15586, 8, 8],
            [2013, 15587, 8, 8],
            [2013, 15588, 8, 8],
            [2013, 15589, 13, 11],
            [2013, 15590, 11, 10],
            [2013, 15591, 11, 10],
            [2013, 15592, 18, 16],
            [2013, 15593, 18, 12],
            [2013, 15594, 20, 13],
            [2013, 15595, 11, 10],
            [2013, 15596, 26, 15],
            [2013, 15597, 12, 10],
            [2013, 15598, 9, 8],
            [2013, 15599, 15, 11],
            [2013, 15600, 18, 16],
            [2013, 15601, 18, 16],
            [2013, 15602, 15, 13],
            [2013, 15603, 8, 7],
            [2013, 15604, 9, 8],
            [2013, 15605, 6, 7],
            [2013, 15606, 5, 6],
            [2013, 15607, 9, 8],
            [2013, 15608, 8, 6],
            [2013, 15609, 6, 6],
            [2013, 15610, 9, 7],
            [2013, 15611, 8, 6],
            [2013, 15612, 10, 12],
            [2013, 15613, 10, 9],
            [2013, 15614, 13, 14],
            [2013, 15615, 12, 10],
            [2013, 15616, 17, 14],
            [2013, 15617, 12, 12],
            [2013, 15618, 9, 9],
            [2013, 15619, 9, 9],
            [2013, 15620, 39, 33],
            [2013, 15621, 13, 10],
            [2013, 15622, 39, 33],
            [2013, 15623, 10, 11],
            [2013, 15624, 13, 13],
            [2013, 15625, 13, 11],
            [2013, 15626, 15, 14],
            [2014, 964, 10, 9],
            [2014, 2142, 11, 10],
            [2014, 2922, 9, 9],
            [2014, 4536, 12, 11],
            [2014, 5273, 13, 11],
            [2014, 11581, 10, 10],
            [2014, 11582, 13, 12],
            [2014, 12312, 141, 89],
            [2014, 12313, 99, 77],
            [2014, 12314, 99, 77],
            [2014, 12315, 141, 89],
            [2014, 12316, 141, 89],
            [2014, 12317, 141, 89],
            [2014, 12318, 141, 89],
            [2014, 12319, 141, 89],
            [2014, 12320, 99, 77],
            [2014, 12321, 69, 71],
            [2014, 12322, 141, 89],
            [2014, 12323, 141, 89],
            [2014, 12324, 99, 77],
            [2014, 12325, 99, 77],
            [2014, 12474, 16, 16],
            [2014, 12475, 26, 16],
            [2014, 12476, 15, 13],
            [2014, 12477, 23, 17],
            [2014, 12478, 24, 19],
            [2014, 12479, 20, 20],
            [2014, 12480, 15, 13],
            [2014, 12481, 61, 36],
            [2014, 12482, 16, 13],
            [2014, 12483, 50, 42],
            [2014, 12484, 17, 13],
            [2014, 12485, 82, 40],
            [2014, 12486, 96, 37],
            [2014, 12487, 44, 26],
            [2014, 12488, 49, 34],
            [2014, 12489, 71, 20],
            [2014, 12523, 18, 10],
            [2014, 12524, 37, 23],
            [2014, 12525, 19, 17],
            [2014, 12526, 13, 12],
            [2014, 12527, 9, 10],
            [2014, 12528, 9, 10],
            [2014, 12529, 10, 10],
            [2014, 12530, 15, 10],
            [2014, 12532, 16, 12],
            [2014, 12534, 10, 10],
            [2014, 12535, 18, 14],
            [2014, 12536, 10, 10],
            [2014, 12537, 10, 10],
            [2014, 12538, 11, 12],
            [2014, 12539, 15, 10],
            [2014, 12540, 14, 13],
            [2014, 12541, 15, 12],
            [2014, 12542, 14, 13],
            [2014, 12543, 17, 16],
            [2014, 12545, 10, 10],
            [2014, 12546, 22, 22],
            [2014, 12547, 17, 16],
            [2014, 12548, 28, 19],
            [2014, 12549, 10, 10],
            [2014, 12550, 10, 10],
            [2014, 12551, 22, 16],
            [2014, 12552, 27, 17],
            [2014, 12553, 15, 12],
            [2014, 12554, 8, 10],
            [2014, 12556, 8, 9],
            [2014, 12557, 10, 12],
            [2014, 12558, 11, 13],
            [2014, 12559, 11, 10],
            [2014, 12560, 4, 6],
            [2014, 12561, 7, 8],
            [2014, 12562, 8, 10],
            [2014, 12563, 13, 10],
            [2014, 12565, 20, 14],
            [2014, 12566, 12, 10],
            [2014, 12567, 10, 10],
            [2014, 12568, 27, 26],
            [2014, 12569, 28, 27],
            [2014, 12570, 17, 17],
            [2014, 12571, 34, 17],
            [2014, 12573, 20, 18],
            [2014, 12574, 10, 10],
            [2014, 12575, 11, 10],
            [2014, 12576, 23, 17],
            [2014, 12577, 9, 10],
            [2014, 12578, 29, 25],
            [2014, 12579, 12, 16],
            [2014, 12580, 14, 13],
            [2014, 12581, 97, 95],
            [2014, 12582, 105, 121],
            [2014, 12583, 95, 95],
            [2014, 12584, 100, 80],
            [2014, 12585, 105, 95],
            [2014, 12586, 54, 19],
            [2014, 12589, 56, 46],
            [2014, 12590, 43, 32],
            [2014, 12591, 57, 47],
            [2014, 12592, 65, 52],
            [2014, 12593, 46, 33],
            [2014, 12594, 35, 31],
            [2014, 12595, 59, 59],
            [2014, 12596, 27, 23],
            [2014, 12597, 26, 22],
            [2014, 12598, 59, 49],
            [2014, 12599, 57, 49],
            [2014, 12600, 58, 48],
            [2014, 12634, 28, 21],
            [2014, 12635, 66, 50],
            [2014, 12636, 20, 20],
            [2014, 12637, 36, 17],
            [2014, 12638, 61, 22],
            [2014, 12639, 10, 8],
            [2014, 12640, 12, 9],
            [2014, 12641, 18, 18],
            [2014, 12642, 17, 17],
            [2014, 12643, 32, 25],
            [2014, 12644, 30, 21],
            [2014, 12645, 45, 40],
            [2014, 12646, 30, 31],
            [2014, 12647, 19, 25],
            [2014, 12648, 28, 24],
            [2014, 12649, 25, 22],
            [2014, 12650, 21, 20],
            [2014, 12651, 32, 25],
            [2014, 12652, 35, 28],
            [2014, 12653, 39, 34],
            [2014, 12654, 17, 17],
            [2014, 12655, 30, 27],
            [2014, 12656, 33, 24],
            [2014, 12657, 18, 18],
            [2014, 12658, 39, 32],
            [2014, 12660, 43, 33],
            [2014, 12661, 38, 34],
            [2014, 12662, 36, 31],
            [2014, 12663, 37, 27],
            [2014, 12664, 47, 37],
            [2014, 12665, 37, 32],
            [2014, 12668, 6, 5],
            [2014, 12669, 4, 4],
            [2014, 12670, 7, 8],
            [2014, 12671, 12, 13],
            [2014, 12672, 12, 13],
            [2014, 12673, 11, 12],
            [2014, 12674, 10, 9],
            [2014, 12675, 15, 14],
            [2014, 12680, 15, 12],
            [2014, 12681, 5, 4],
            [2014, 12682, 15, 13],
            [2014, 12683, 11, 10],
            [2014, 12685, 34, 24],
            [2014, 12686, 20, 17],
            [2014, 12687, 21, 19],
            [2014, 12688, 20, 18],
            [2014, 12689, 31, 20],
            [2014, 12690, 32, 21],
            [2014, 12691, 34, 21],
            [2014, 12692, 31, 22],
            [2014, 12693, 27, 19],
            [2014, 12695, 33, 21],
            [2014, 12696, 31, 19],
            [2014, 12697, 32, 21],
            [2014, 12699, 9, 7],
            [2014, 12703, 28, 29],
            [2014, 12704, 18, 12],
            [2014, 12705, 23, 13],
            [2014, 12706, 26, 23],
            [2014, 12707, 32, 24],
            [2014, 12708, 25, 19],
            [2014, 12709, 36, 24],
            [2014, 12710, 37, 24],
            [2014, 12711, 36, 26],
            [2014, 12712, 38, 32],
            [2014, 12713, 31, 28],
            [2014, 12714, 40, 28],
            [2014, 12715, 40, 29],
            [2014, 12716, 24, 20],
            [2014, 12717, 28, 24],
            [2014, 12718, 21, 16],
            [2014, 12719, 26, 19],
            [2014, 12720, 26, 19],
            [2014, 12721, 27, 16],
            [2014, 12722, 12, 10],
            [2014, 12723, 17, 15],
            [2014, 12724, 11, 10],
            [2014, 12725, 10, 12],
            [2014, 12726, 8, 8],
            [2014, 12727, 17, 23],
            [2014, 12728, 9, 9],
            [2014, 12729, 19, 26],
            [2014, 12730, 22, 12],
            [2014, 12731, 18, 23],
            [2014, 12732, 13, 14],
            [2014, 12735, 11, 11],
            [2014, 12736, 14, 14],
            [2014, 12737, 22, 13],
            [2014, 12738, 9, 10],
            [2014, 12739, 12, 14],
            [2014, 12740, 16, 17],
            [2014, 12741, 15, 15],
            [2014, 12742, 7, 7],
            [2014, 12743, 21, 13],
            [2014, 12744, 11, 11],
            [2014, 12745, 12, 13],
            [2014, 12746, 9, 10],
            [2014, 12747, 11, 12],
            [2014, 12748, 8, 11],
            [2014, 12749, 9, 12],
            [2014, 12750, 7, 7],
            [2014, 12751, 6, 8],
            [2014, 12752, 20, 14],
            [2014, 12753, 9, 11],
            [2014, 12754, 9, 8],
            [2014, 12755, 6, 6],
            [2014, 12756, 11, 9],
            [2014, 12757, 6, 7],
            [2014, 12758, 11, 11],
            [2014, 12759, 15, 14],
            [2014, 12760, 21, 14],
            [2014, 12761, 10, 11],
            [2014, 12762, 9, 9],
            [2014, 12763, 12, 15],
            [2014, 12765, 9, 9],
            [2014, 12766, 12, 14],
            [2014, 12767, 12, 15],
            [2014, 12768, 11, 11],
            [2014, 12770, 9, 11],
            [2014, 12771, 16, 15],
            [2014, 12772, 10, 10],
            [2014, 12773, 9, 10],
            [2014, 12775, 16, 17],
            [2014, 12776, 17, 18],
            [2014, 12777, 8, 8],
            [2014, 12778, 17, 18],
            [2014, 12779, 14, 15],
            [2014, 12780, 8, 8],
            [2014, 12781, 17, 18],
            [2014, 12782, 11, 12],
            [2014, 12783, 8, 8],
            [2014, 12784, 17, 19],
            [2014, 12785, 21, 14],
            [2014, 12786, 9, 9],
            [2014, 12787, 16, 17],
            [2014, 12788, 7, 8],
            [2014, 12789, 12, 14],
            [2014, 12790, 16, 13],
            [2014, 12791, 11, 8],
            [2014, 12792, 13, 13],
            [2014, 12793, 11, 11],
            [2014, 12795, 12, 10],
            [2014, 12796, 10, 10],
            [2014, 12797, 10, 8],
            [2014, 12798, 8, 12],
            [2014, 12799, 7, 9],
            [2014, 12800, 19, 11],
            [2014, 12801, 9, 6],
            [2014, 12802, 9, 9],
            [2014, 12803, 63, 39],
            [2014, 12804, 13, 12],
            [2014, 12805, 18, 11],
            [2014, 12806, 11, 10],
            [2014, 12807, 29, 15],
            [2014, 12808, 13, 13],
            [2014, 12809, 6, 9],
            [2014, 12810, 13, 16],
            [2014, 12811, 10, 12],
            [2014, 12812, 16, 13],
            [2014, 12813, 9, 9],
            [2014, 12814, 11, 12],
            [2014, 12815, 13, 11],
            [2014, 12816, 7, 9],
            [2014, 12817, 10, 9],
            [2014, 12818, 9, 9],
            [2014, 12819, 13, 17],
            [2014, 12820, 10, 9],
            [2014, 12821, 8, 4],
            [2014, 12822, 10, 11],
            [2014, 12823, 5, 4],
            [2014, 12824, 9, 12],
            [2014, 12825, 9, 8],
            [2014, 12826, 8, 6],
            [2014, 12827, 30, 17],
            [2014, 12828, 9, 7],
            [2014, 12829, 10, 10],
            [2014, 12830, 9, 6],
            [2014, 12831, 74, 52],
            [2014, 12832, 19, 18],
            [2014, 12833, 8, 6],
            [2014, 12834, 23, 13],
            [2014, 12835, 5, 4],
            [2014, 12836, 18, 9],
            [2014, 12837, 5, 4],
            [2014, 12838, 8, 6],
            [2014, 12839, 5, 4],
            [2014, 12840, 16, 8],
            [2014, 12841, 3, 2],
            [2014, 12843, 5, 5],
            [2014, 12845, 9, 7],
            [2014, 12847, 20, 13],
            [2014, 12848, 11, 9],
            [2014, 12849, 7, 8],
            [2014, 12850, 21, 10],
            [2014, 12851, 12, 9],
            [2014, 12852, 8, 8],
            [2014, 12853, 6, 4],
            [2014, 12854, 28, 17],
            [2014, 12855, 4, 3],
            [2014, 12856, 14, 8],
            [2014, 12857, 8, 6],
            [2014, 12858, 3, 2],
            [2014, 12860, 14, 11],
            [2014, 12861, 6, 4],
            [2014, 12862, 6, 5],
            [2014, 12863, 66, 31],
            [2014, 12864, 5, 4],
            [2014, 12865, 32, 13],
            [2014, 12866, 5, 4],
            [2014, 12867, 59, 26],
            [2014, 12868, 8, 6],
            [2014, 12869, 10, 10],
            [2014, 12870, 7, 5],
            [2014, 12871, 41, 16],
            [2014, 12872, 9, 7],
            [2014, 12873, 11, 10],
            [2014, 12874, 6, 5],
            [2014, 12875, 58, 35],
            [2014, 12876, 10, 8],
            [2014, 12877, 6, 5],
            [2014, 12878, 10, 8],
            [2014, 12879, 8, 8],
            [2014, 12880, 6, 5],
            [2014, 12881, 11, 8],
            [2014, 12882, 11, 8],
            [2014, 12883, 5, 4],
            [2014, 12884, 39, 23],
            [2014, 12885, 3, 2],
            [2014, 12886, 24, 17],
            [2014, 12887, 5, 4],
            [2014, 12888, 15, 11],
            [2014, 12889, 77, 35],
            [2014, 12890, 7, 5],
            [2014, 12891, 33, 18],
            [2014, 12892, 9, 8],
            [2014, 12893, 8, 6],
            [2014, 12894, 16, 12],
            [2014, 12895, 6, 5],
            [2014, 12896, 31, 18],
            [2014, 12897, 8, 6],
            [2014, 12898, 17, 11],
            [2014, 12899, 16, 12],
            [2014, 12900, 8, 6],
            [2014, 12901, 25, 14],
            [2014, 12902, 7, 6],
            [2014, 12903, 25, 29],
            [2014, 12904, 11, 9],
            [2014, 12905, 27, 18],
            [2014, 12906, 10, 8],
            [2014, 12907, 15, 12],
            [2014, 12908, 11, 9],
            [2014, 12909, 5, 4],
            [2014, 12910, 9, 7],
            [2014, 12911, 4, 4],
            [2014, 12912, 12, 9],
            [2014, 12913, 8, 7],
            [2014, 12914, 7, 5],
            [2014, 12915, 4, 3],
            [2014, 12916, 7, 5],
            [2014, 12917, 10, 9],
            [2014, 12918, 4, 3],
            [2014, 12919, 6, 4],
            [2014, 12920, 16, 13],
            [2014, 12921, 14, 11],
            [2014, 12922, 9, 7],
            [2014, 12923, 8, 7],
            [2014, 12924, 10, 8],
            [2014, 12925, 6, 5],
            [2014, 12926, 6, 5],
            [2014, 12927, 13, 10],
            [2014, 12928, 22, 14],
            [2014, 12929, 7, 6],
            [2014, 12930, 8, 6],
            [2014, 12931, 7, 5],
            [2014, 12932, 10, 7],
            [2014, 12933, 6, 4],
            [2014, 12934, 9, 7],
            [2014, 12935, 7, 6],
            [2014, 12936, 4, 3],
            [2014, 12937, 9, 7],
            [2014, 12938, 7, 5],
            [2014, 12939, 3, 2],
            [2014, 12940, 6, 5],
            [2014, 12941, 12, 9],
            [2014, 12942, 10, 7],
            [2014, 12943, 7, 6],
            [2014, 12944, 6, 5],
            [2014, 12945, 4, 3],
            [2014, 12946, 6, 5],
            [2014, 12947, 9, 7],
            [2014, 12948, 7, 5],
            [2014, 12949, 6, 5],
            [2014, 12950, 9, 7],
            [2014, 12951, 9, 7],
            [2014, 12952, 18, 14],
            [2014, 12953, 12, 11],
            [2014, 12954, 10, 7],
            [2014, 12955, 7, 6],
            [2014, 12956, 5, 4],
            [2014, 12957, 8, 6],
            [2014, 12958, 8, 6],
            [2014, 12959, 6, 4],
            [2014, 12960, 7, 5],
            [2014, 12961, 6, 4],
            [2014, 12962, 8, 5],
            [2014, 12963, 5, 5],
            [2014, 12964, 9, 6],
            [2014, 12965, 16, 13],
            [2014, 12966, 10, 7],
            [2014, 12967, 10, 7],
            [2014, 12968, 11, 9],
            [2014, 12969, 7, 5],
            [2014, 12970, 7, 5],
            [2014, 12971, 8, 7],
            [2014, 12972, 6, 5],
            [2014, 12973, 6, 4],
            [2014, 12974, 8, 6],
            [2014, 12975, 6, 5],
            [2014, 12976, 6, 5],
            [2014, 12977, 4, 3],
            [2014, 12978, 11, 8],
            [2014, 12979, 11, 9],
            [2014, 12980, 8, 6],
            [2014, 12981, 8, 6],
            [2014, 12982, 10, 9],
            [2014, 12983, 8, 5],
            [2014, 12984, 5, 5],
            [2014, 12985, 8, 6],
            [2014, 12986, 5, 4],
            [2014, 12987, 8, 6],
            [2014, 12988, 15, 13],
            [2014, 12989, 12, 8],
            [2014, 12990, 8, 6],
            [2014, 12991, 6, 5],
            [2014, 12992, 6, 5],
            [2014, 12993, 4, 3],
            [2014, 12994, 7, 6],
            [2014, 12995, 5, 4],
            [2014, 12996, 7, 5],
            [2014, 12997, 8, 6],
            [2014, 12998, 6, 5],
            [2014, 12999, 7, 5],
            [2014, 13000, 6, 5],
            [2014, 13001, 13, 13],
            [2014, 13002, 15, 14],
            [2014, 13004, 23, 17],
            [2014, 13006, 23, 18],
            [2014, 13007, 17, 16],
            [2014, 13008, 24, 18],
            [2014, 13009, 18, 17],
            [2014, 13010, 18, 16],
            [2014, 13011, 31, 19],
            [2014, 13012, 21, 19],
            [2014, 13013, 14, 14],
            [2014, 13014, 17, 17],
            [2014, 13015, 11, 16],
            [2014, 13016, 15, 12],
            [2014, 13017, 8, 4],
            [2014, 13018, 17, 17],
            [2014, 13019, 14, 7],
            [2014, 13020, 9, 13],
            [2014, 13021, 13, 18],
            [2014, 13022, 9, 4],
            [2014, 13023, 18, 12],
            [2014, 13024, 27, 20],
            [2014, 13025, 10, 16],
            [2014, 13026, 18, 11],
            [2014, 13027, 17, 10],
            [2014, 13028, 7, 4],
            [2014, 13029, 13, 14],
            [2014, 13030, 13, 13],
            [2014, 13031, 10, 10],
            [2014, 13032, 22, 18],
            [2014, 13033, 9, 7],
            [2014, 13034, 6, 4],
            [2014, 13035, 8, 4],
            [2014, 13036, 17, 7],
            [2014, 13037, 8, 5],
            [2014, 13038, 19, 13],
            [2014, 13039, 11, 11],
            [2014, 13040, 15, 14],
            [2014, 13041, 13, 11],
            [2014, 13042, 6, 9],
            [2014, 13043, 8, 5],
            [2014, 13044, 13, 18],
            [2014, 13045, 6, 8],
            [2014, 13046, 17, 14],
            [2014, 13047, 19, 18],
            [2014, 13048, 11, 9],
            [2014, 13049, 12, 11],
            [2014, 13050, 11, 10],
            [2014, 13051, 15, 15],
            [2014, 13052, 10, 11],
            [2014, 13053, 9, 7],
            [2014, 13054, 15, 18],
            [2014, 13055, 18, 12],
            [2014, 13056, 13, 14],
            [2014, 13057, 14, 13],
            [2014, 13058, 17, 17],
            [2014, 13059, 11, 7],
            [2014, 13060, 15, 11],
            [2014, 13061, 17, 15],
            [2014, 13062, 12, 9],
            [2014, 13063, 28, 5],
            [2014, 13064, 9, 12],
            [2014, 13065, 12, 12],
            [2014, 13066, 11, 9],
            [2014, 13067, 15, 12],
            [2014, 13068, 13, 16],
            [2014, 13069, 19, 15],
            [2014, 13070, 9, 4],
            [2014, 13071, 11, 6],
            [2014, 13072, 9, 11],
            [2014, 13073, 9, 9],
            [2014, 13074, 11, 12],
            [2014, 13075, 19, 18],
            [2014, 13076, 11, 7],
            [2014, 13077, 25, 18],
            [2014, 13078, 31, 27],
            [2014, 13079, 10, 13],
            [2014, 13080, 11, 7],
            [2014, 13081, 13, 12],
            [2014, 13082, 7, 7],
            [2014, 13083, 13, 8],
            [2014, 13084, 21, 15],
            [2014, 13085, 25, 16],
            [2014, 13086, 6, 5],
            [2014, 13087, 14, 10],
            [2014, 13088, 17, 11],
            [2014, 13089, 11, 10],
            [2014, 13090, 11, 11],
            [2014, 13091, 7, 4],
            [2014, 13092, 23, 17],
            [2014, 13093, 12, 7],
            [2014, 13094, 27, 15],
            [2014, 13095, 12, 12],
            [2014, 13096, 9, 11],
            [2014, 13097, 15, 10],
            [2014, 13098, 12, 11],
            [2014, 13099, 7, 11],
            [2014, 13100, 19, 18],
            [2014, 13101, 17, 15],
            [2014, 13102, 19, 15],
            [2014, 13103, 19, 16],
            [2014, 13104, 18, 24],
            [2014, 13105, 15, 13],
            [2014, 13106, 18, 14],
            [2014, 13107, 14, 10],
            [2014, 13108, 15, 13],
            [2014, 13109, 13, 12],
            [2014, 13111, 15, 13],
            [2014, 13112, 12, 11],
            [2014, 13113, 16, 11],
            [2014, 13114, 12, 12],
            [2014, 13115, 14, 10],
            [2014, 13116, 16, 16],
            [2014, 13117, 15, 14],
            [2014, 13118, 12, 9],
            [2014, 13119, 20, 16],
            [2014, 13120, 13, 7],
            [2014, 13121, 15, 18],
            [2014, 13122, 25, 14],
            [2014, 13123, 16, 13],
            [2014, 13124, 11, 12],
            [2014, 13125, 10, 9],
            [2014, 13126, 22, 15],
            [2014, 13127, 15, 13],
            [2014, 13128, 11, 12],
            [2014, 13129, 22, 17],
            [2014, 13130, 16, 13],
            [2014, 13131, 12, 10],
            [2014, 13132, 12, 11],
            [2014, 13133, 18, 13],
            [2014, 13134, 17, 13],
            [2014, 13136, 14, 18],
            [2014, 13137, 18, 19],
            [2014, 13138, 14, 11],
            [2014, 13139, 6, 6],
            [2014, 13140, 16, 10],
            [2014, 13141, 9, 8],
            [2014, 13142, 8, 7],
            [2014, 13143, 8, 6],
            [2014, 13144, 11, 10],
            [2014, 13145, 7, 7],
            [2014, 13147, 11, 8],
            [2014, 13148, 11, 10],
            [2014, 13149, 8, 7],
            [2014, 13150, 9, 8],
            [2014, 13152, 11, 8],
            [2014, 13153, 7, 7],
            [2014, 13154, 7, 7],
            [2014, 13155, 9, 7],
            [2014, 13156, 8, 8],
            [2014, 13158, 7, 7],
            [2014, 13159, 9, 7],
            [2014, 13160, 9, 7],
            [2014, 13161, 7, 7],
            [2014, 13163, 11, 7],
            [2014, 13164, 9, 8],
            [2014, 13165, 9, 7],
            [2014, 13166, 8, 7],
            [2014, 13167, 17, 10],
            [2014, 13168, 7, 7],
            [2014, 13169, 11, 8],
            [2014, 13170, 12, 10],
            [2014, 13171, 10, 8],
            [2014, 13172, 7, 7],
            [2014, 13173, 10, 8],
            [2014, 13174, 9, 7],
            [2014, 13175, 7, 7],
            [2014, 13176, 9, 7],
            [2014, 13177, 9, 8],
            [2014, 13178, 10, 8],
            [2014, 13179, 9, 7],
            [2014, 13180, 14, 10],
            [2014, 13181, 7, 7],
            [2014, 13182, 9, 7],
            [2014, 13183, 29, 20],
            [2014, 13184, 7, 7],
            [2014, 13185, 11, 10],
            [2014, 13186, 14, 14],
            [2014, 13187, 7, 10],
            [2014, 13188, 7, 10],
            [2014, 13189, 12, 10],
            [2014, 13190, 7, 10],
            [2014, 13191, 21, 14],
            [2014, 13192, 9, 10],
            [2014, 13193, 9, 11],
            [2014, 13194, 11, 9],
            [2014, 13195, 24, 15],
            [2014, 13196, 17, 11],
            [2014, 13197, 90, 30],
            [2014, 13198, 13, 10],
            [2014, 13200, 20, 14],
            [2014, 13201, 16, 12],
            [2014, 13202, 20, 13],
            [2014, 13203, 8, 8],
            [2014, 13204, 23, 13],
            [2014, 13205, 9, 10],
            [2014, 13206, 16, 12],
            [2014, 13207, 12, 11],
            [2014, 13208, 10, 11],
            [2014, 13209, 8, 8],
            [2014, 13210, 23, 17],
            [2014, 13211, 14, 10],
            [2014, 13212, 60, 36],
            [2014, 13213, 27, 16],
            [2014, 13214, 19, 16],
            [2014, 13216, 20, 15],
            [2014, 13218, 14, 12],
            [2014, 13219, 10, 10],
            [2014, 13220, 9, 10],
            [2014, 13222, 9, 11],
            [2014, 13223, 19, 14],
            [2014, 13224, 55, 23],
            [2014, 13225, 15, 11],
            [2014, 13226, 9, 11],
            [2014, 13227, 19, 14],
            [2014, 13230, 22, 14],
            [2014, 13232, 14, 12],
            [2014, 13233, 15, 12],
            [2014, 13234, 18, 13],
            [2014, 13235, 14, 11],
            [2014, 13236, 11, 9],
            [2014, 13237, 8, 7],
            [2014, 13238, 14, 12],
            [2014, 13239, 16, 11],
            [2014, 13240, 15, 12],
            [2014, 13241, 14, 12],
            [2014, 13242, 15, 12],
            [2014, 13243, 17, 12],
            [2014, 13244, 21, 14],
            [2014, 13245, 14, 12],
            [2014, 13246, 16, 11],
            [2014, 13247, 18, 14],
            [2014, 13248, 12, 10],
            [2014, 13249, 10, 8],
            [2014, 13250, 17, 13],
            [2014, 13251, 15, 12],
            [2014, 13252, 20, 13],
            [2014, 13253, 15, 12],
            [2014, 13254, 11, 9],
            [2014, 13255, 10, 9],
            [2014, 13256, 13, 11],
            [2014, 13257, 15, 11],
            [2014, 13258, 20, 15],
            [2014, 13259, 20, 13],
            [2014, 13260, 15, 11],
            [2014, 13261, 16, 11],
            [2014, 13262, 18, 13],
            [2014, 13263, 15, 12],
            [2014, 13264, 14, 12],
            [2014, 13265, 24, 15],
            [2014, 13266, 14, 10],
            [2014, 13267, 33, 24],
            [2014, 13269, 14, 11],
            [2014, 13270, 18, 12],
            [2014, 13271, 14, 11],
            [2014, 13272, 9, 8],
            [2014, 13273, 13, 10],
            [2014, 13274, 10, 9],
            [2014, 13275, 12, 10],
            [2014, 13276, 11, 8],
            [2014, 13279, 32, 16],
            [2014, 13280, 13, 10],
            [2014, 13281, 12, 12],
            [2014, 13282, 13, 10],
            [2014, 13283, 19, 16],
            [2014, 13284, 18, 15],
            [2014, 13285, 14, 10],
            [2014, 13286, 19, 13],
            [2014, 13288, 20, 13],
            [2014, 13289, 17, 14],
            [2014, 13290, 8, 8],
            [2014, 13291, 14, 12],
            [2014, 13292, 8, 8],
            [2014, 13293, 16, 16],
            [2014, 13294, 13, 10],
            [2014, 13295, 21, 14],
            [2014, 13296, 15, 14],
            [2014, 13297, 14, 10],
            [2014, 13298, 16, 14],
            [2014, 13299, 10, 11],
            [2014, 13300, 11, 13],
            [2014, 13302, 14, 12],
            [2014, 13303, 12, 13],
            [2014, 13304, 19, 13],
            [2014, 13305, 13, 11],
            [2014, 13306, 8, 7],
            [2014, 13307, 24, 22],
            [2014, 13308, 14, 12],
            [2014, 13309, 9, 9],
            [2014, 13310, 16, 11],
            [2014, 13311, 10, 9],
            [2014, 13312, 16, 12],
            [2014, 13313, 44, 23],
            [2014, 13314, 31, 19],
            [2014, 13315, 17, 12],
            [2014, 13316, 11, 8],
            [2014, 13317, 10, 8],
            [2014, 13318, 9, 9],
            [2014, 13319, 16, 12],
            [2014, 13320, 23, 16],
            [2014, 13321, 13, 13],
            [2014, 13322, 12, 10],
            [2014, 13323, 29, 17],
            [2014, 13324, 7, 7],
            [2014, 13325, 13, 13],
            [2014, 13326, 15, 11],
            [2014, 13327, 19, 11],
            [2014, 13328, 13, 11],
            [2014, 13329, 13, 12],
            [2014, 13330, 15, 11],
            [2014, 13331, 19, 14],
            [2014, 13332, 13, 11],
            [2014, 13333, 12, 13],
            [2014, 13334, 11, 9],
            [2014, 13335, 31, 23],
            [2014, 13336, 13, 11],
            [2014, 13338, 13, 11],
            [2014, 13339, 11, 8],
            [2014, 13340, 15, 12],
            [2014, 13341, 10, 8],
            [2014, 13342, 9, 8],
            [2014, 13343, 13, 10],
            [2014, 13344, 11, 10],
            [2014, 13345, 21, 15],
            [2014, 13346, 9, 7],
            [2014, 13347, 20, 19],
            [2014, 13348, 18, 13],
            [2014, 13349, 30, 19],
            [2014, 13350, 14, 12],
            [2014, 13351, 8, 8],
            [2014, 13352, 10, 10],
            [2014, 13353, 16, 11],
            [2014, 13355, 15, 10],
            [2014, 13356, 9, 7],
            [2014, 13357, 24, 17],
            [2014, 13358, 13, 12],
            [2014, 13359, 30, 19],
            [2014, 13360, 10, 8],
            [2014, 13361, 29, 19],
            [2014, 13362, 13, 12],
            [2014, 13363, 17, 13],
            [2014, 13364, 10, 10],
            [2014, 13365, 10, 7],
            [2014, 13366, 10, 10],
            [2014, 13367, 10, 7],
            [2014, 13368, 18, 17],
            [2014, 13369, 14, 11],
            [2014, 13370, 14, 10],
            [2014, 13371, 16, 13],
            [2014, 13372, 15, 11],
            [2014, 13373, 10, 9],
            [2014, 13374, 13, 11],
            [2014, 13375, 13, 11],
            [2014, 13376, 8, 10],
            [2014, 13377, 15, 11],
            [2014, 13378, 11, 9],
            [2014, 13379, 13, 10],
            [2014, 13380, 15, 12],
            [2014, 13381, 8, 8],
            [2014, 13382, 15, 11],
            [2014, 13384, 16, 15],
            [2014, 13385, 7, 7],
            [2014, 13386, 20, 13],
            [2014, 13387, 14, 13],
            [2014, 13388, 11, 11],
            [2014, 13389, 13, 11],
            [2014, 13390, 14, 11],
            [2014, 13391, 10, 10],
            [2014, 13392, 16, 11],
            [2014, 13393, 27, 24],
            [2014, 13394, 14, 10],
            [2014, 13395, 13, 10],
            [2014, 13396, 47, 23],
            [2014, 13397, 7, 7],
            [2014, 13398, 27, 17],
            [2014, 13399, 12, 10],
            [2014, 13401, 11, 10],
            [2014, 13402, 21, 12],
            [2014, 13403, 16, 14],
            [2014, 13404, 23, 16],
            [2014, 13405, 33, 17],
            [2014, 13407, 17, 16],
            [2014, 13408, 20, 16],
            [2014, 13409, 16, 14],
            [2014, 13410, 22, 15],
            [2014, 13411, 10, 10],
            [2014, 13412, 38, 21],
            [2014, 13413, 22, 16],
            [2014, 13414, 22, 15],
            [2014, 13415, 17, 13],
            [2014, 13416, 14, 11],
            [2014, 13417, 11, 10],
            [2014, 13418, 9, 8],
            [2014, 13419, 42, 21],
            [2014, 13420, 11, 10],
            [2014, 13421, 15, 11],
            [2014, 13423, 11, 11],
            [2014, 13424, 31, 14],
            [2014, 13425, 18, 15],
            [2014, 13426, 21, 14],
            [2014, 13427, 26, 20],
            [2014, 13428, 42, 17],
            [2014, 13429, 19, 17],
            [2014, 13430, 18, 19],
            [2014, 13431, 32, 20],
            [2014, 13432, 10, 10],
            [2014, 13433, 18, 14],
            [2014, 13434, 26, 17],
            [2014, 13435, 16, 14],
            [2014, 13438, 22, 17],
            [2014, 13439, 9, 8],
            [2014, 13440, 9, 9],
            [2014, 13441, 11, 12],
            [2014, 13442, 37, 20],
            [2014, 13443, 30, 24],
            [2014, 13445, 13, 10],
            [2014, 13446, 16, 14],
            [2014, 13447, 36, 23],
            [2014, 13448, 25, 23],
            [2014, 13449, 11, 9],
            [2014, 13450, 9, 8],
            [2014, 13451, 9, 7],
            [2014, 13452, 8, 8],
            [2014, 13453, 9, 9],
            [2014, 13454, 19, 12],
            [2014, 13455, 13, 11],
            [2014, 13456, 7, 7],
            [2014, 13457, 7, 7],
            [2014, 13458, 9, 9],
            [2014, 13460, 10, 8],
            [2014, 13461, 8, 7],
            [2014, 13462, 8, 7],
            [2014, 13463, 13, 9],
            [2014, 13464, 14, 9],
            [2014, 13465, 11, 10],
            [2014, 13466, 10, 8],
            [2014, 13467, 9, 8],
            [2014, 13468, 9, 8],
            [2014, 13469, 9, 8],
            [2014, 13470, 12, 10],
            [2014, 13471, 10, 8],
            [2014, 13472, 13, 9],
            [2014, 13473, 11, 9],
            [2014, 13474, 11, 9],
            [2014, 13475, 11, 9],
            [2014, 13476, 7, 7],
            [2014, 13478, 7, 7],
            [2014, 13479, 13, 9],
            [2014, 13480, 4, 4],
            [2014, 13481, 8, 7],
            [2014, 13482, 11, 9],
            [2014, 13483, 10, 9],
            [2014, 13484, 10, 9],
            [2014, 13485, 9, 8],
            [2014, 13486, 3, 4],
            [2014, 13487, 17, 11],
            [2014, 13488, 8, 6],
            [2014, 13489, 13, 9],
            [2014, 13490, 7, 7],
            [2014, 13491, 9, 8],
            [2014, 13492, 7, 7],
            [2014, 13493, 8, 6],
            [2014, 13494, 11, 8],
            [2014, 13495, 10, 8],
            [2014, 13496, 10, 9],
            [2014, 13497, 11, 8],
            [2014, 13498, 9, 8],
            [2014, 13499, 12, 9],
            [2014, 13501, 15, 10],
            [2014, 13502, 8, 7],
            [2014, 13503, 11, 8],
            [2014, 13504, 7, 6],
            [2014, 13505, 7, 6],
            [2014, 13506, 10, 8],
            [2014, 13507, 5, 5],
            [2014, 13508, 11, 9],
            [2014, 13509, 5, 6],
            [2014, 13511, 14, 10],
            [2014, 13512, 10, 8],
            [2014, 13513, 12, 9],
            [2014, 13514, 12, 9],
            [2014, 13516, 7, 7],
            [2014, 13517, 7, 7],
            [2014, 13518, 7, 7],
            [2014, 13519, 11, 9],
            [2014, 13520, 12, 10],
            [2014, 13521, 8, 8],
            [2014, 13522, 9, 8],
            [2014, 13523, 9, 9],
            [2014, 13524, 7, 7],
            [2014, 13525, 11, 9],
            [2014, 13526, 9, 7],
            [2014, 13527, 14, 10],
            [2014, 13528, 8, 8],
            [2014, 13529, 7, 7],
            [2014, 13530, 6, 5],
            [2014, 13531, 7, 6],
            [2014, 13532, 7, 6],
            [2014, 13533, 7, 6],
            [2014, 13534, 7, 6],
            [2014, 13536, 9, 9],
            [2014, 13537, 6, 6],
            [2014, 13538, 6, 6],
            [2014, 13539, 6, 6],
            [2014, 13540, 6, 6],
            [2014, 13541, 9, 9],
            [2014, 13542, 9, 8],
            [2014, 13543, 9, 8],
            [2014, 13544, 10, 9],
            [2014, 13546, 7, 7],
            [2014, 13547, 8, 8],
            [2014, 13548, 13, 9],
            [2014, 13550, 19, 11],
            [2014, 13552, 11, 10],
            [2014, 13556, 8, 8],
            [2014, 13557, 3, 3],
            [2014, 13558, 15, 10],
            [2014, 13560, 8, 8],
            [2014, 13561, 9, 7],
            [2014, 13562, 9, 8],
            [2014, 13563, 8, 6],
            [2014, 13564, 13, 9],
            [2014, 13565, 9, 8],
            [2014, 13566, 12, 10],
            [2014, 13567, 9, 8],
            [2014, 13568, 4, 5],
            [2014, 13569, 9, 8],
            [2014, 13570, 7, 7],
            [2014, 13571, 11, 9],
            [2014, 13572, 6, 6],
            [2014, 13573, 7, 7],
            [2014, 13574, 10, 9],
            [2014, 13575, 12, 9],
            [2014, 13576, 7, 7],
            [2014, 13577, 7, 7],
            [2014, 13578, 8, 8],
            [2014, 13579, 19, 11],
            [2014, 13580, 10, 7],
            [2014, 13581, 6, 7],
            [2014, 13582, 8, 7],
            [2014, 13583, 9, 8],
            [2014, 13584, 29, 14],
            [2014, 13585, 7, 7],
            [2014, 13586, 7, 6],
            [2014, 13587, 7, 7],
            [2014, 13588, 15, 10],
            [2014, 13589, 7, 7],
            [2014, 13590, 13, 10],
            [2014, 13591, 7, 7],
            [2014, 13592, 7, 7],
            [2014, 13593, 7, 7],
            [2014, 13594, 13, 10],
            [2014, 13595, 10, 7],
            [2014, 13596, 12, 10],
            [2014, 13597, 9, 7],
            [2014, 13598, 8, 7],
            [2014, 13599, 7, 7],
            [2014, 13600, 9, 8],
            [2014, 13601, 7, 7],
            [2014, 13602, 7, 7],
            [2014, 13603, 7, 7],
            [2014, 13604, 12, 9],
            [2014, 13605, 10, 9],
            [2014, 13606, 10, 10],
            [2014, 13607, 8, 7],
            [2014, 13608, 10, 9],
            [2014, 13609, 34, 34],
            [2014, 13610, 29, 29],
            [2014, 13611, 18, 17],
            [2014, 13612, 45, 23],
            [2014, 13613, 95, 35],
            [2014, 13614, 29, 29],
            [2014, 13615, 57, 33],
            [2014, 13616, 12, 11],
            [2014, 13617, 33, 35],
            [2014, 13618, 43, 40],
            [2014, 13619, 39, 55],
            [2014, 13620, 34, 33],
            [2014, 13621, 39, 35],
            [2014, 13622, 41, 30],
            [2014, 13623, 50, 34],
            [2014, 13624, 26, 17],
            [2014, 13625, 20, 18],
            [2014, 13626, 25, 21],
            [2014, 13627, 33, 40],
            [2014, 13628, 32, 34],
            [2014, 13629, 49, 39],
            [2014, 13630, 34, 34],
            [2014, 13631, 42, 45],
            [2014, 13632, 34, 16],
            [2014, 13633, 24, 15],
            [2014, 13634, 25, 22],
            [2014, 13635, 34, 35],
            [2014, 13636, 17, 15],
            [2014, 13637, 75, 57],
            [2014, 13638, 65, 43],
            [2014, 13639, 10, 10],
            [2014, 13640, 48, 53],
            [2014, 13641, 35, 18],
            [2014, 13642, 72, 35],
            [2014, 13643, 20, 25],
            [2014, 13644, 54, 33],
            [2014, 13645, 60, 41],
            [2014, 13646, 28, 40],
            [2014, 13647, 45, 24],
            [2014, 13648, 49, 35],
            [2014, 13649, 59, 35],
            [2014, 13650, 8, 8],
            [2014, 13651, 45, 35],
            [2014, 13652, 61, 49],
            [2014, 13653, 8, 8],
            [2014, 13654, 9, 8],
            [2014, 13655, 29, 29],
            [2014, 13656, 74, 47],
            [2014, 13657, 20, 17],
            [2014, 13658, 82, 46],
            [2014, 13659, 39, 27],
            [2014, 13660, 34, 32],
            [2014, 13661, 34, 27],
            [2014, 13662, 44, 29],
            [2014, 13663, 18, 17],
            [2014, 13664, 39, 38],
            [2014, 13665, 44, 34],
            [2014, 13666, 30, 29],
            [2014, 13667, 39, 27],
            [2014, 13668, 12, 10],
            [2014, 13669, 40, 25],
            [2014, 13670, 44, 29],
            [2014, 13671, 43, 24],
            [2014, 13672, 40, 33],
            [2014, 13673, 79, 35],
            [2014, 13674, 38, 29],
            [2014, 13675, 29, 23],
            [2014, 13676, 32, 24],
            [2014, 13677, 15, 16],
            [2014, 13678, 13, 15],
            [2014, 13679, 9, 14],
            [2014, 13680, 10, 13],
            [2014, 13681, 15, 14],
            [2014, 13682, 8, 9],
            [2014, 13683, 17, 14],
            [2014, 13684, 26, 16],
            [2014, 13685, 26, 15],
            [2014, 13686, 19, 14],
            [2014, 13687, 29, 19],
            [2014, 13688, 17, 13],
            [2014, 13689, 20, 12],
            [2014, 13690, 14, 12],
            [2014, 13691, 52, 16],
            [2014, 13692, 17, 16],
            [2014, 13693, 16, 13],
            [2014, 13694, 25, 19],
            [2014, 13695, 21, 16],
            [2014, 13696, 14, 12],
            [2014, 13697, 40, 17],
            [2014, 13698, 18, 13],
            [2014, 13699, 29, 15],
            [2014, 13701, 17, 15],
            [2014, 13702, 24, 13],
            [2014, 13704, 29, 16],
            [2014, 13705, 14, 12],
            [2014, 13706, 26, 15],
            [2014, 13707, 32, 19],
            [2014, 13709, 29, 18],
            [2014, 13710, 20, 15],
            [2014, 13711, 22, 15],
            [2014, 13712, 34, 17],
            [2014, 13715, 34, 18],
            [2014, 13716, 21, 13],
            [2014, 13717, 24, 24],
            [2014, 13719, 34, 17],
            [2014, 13720, 23, 16],
            [2014, 13721, 21, 9],
            [2014, 13722, 23, 21],
            [2014, 13723, 31, 24],
            [2014, 13724, 33, 16],
            [2014, 13725, 29, 13],
            [2014, 13726, 20, 9],
            [2014, 13727, 37, 21],
            [2014, 13728, 22, 15],
            [2014, 13729, 21, 11],
            [2014, 13730, 32, 25],
            [2014, 13731, 31, 16],
            [2014, 13732, 43, 21],
            [2014, 13733, 26, 15],
            [2014, 13734, 22, 12],
            [2014, 13735, 24, 11],
            [2014, 13736, 32, 17],
            [2014, 13737, 31, 16],
            [2014, 13738, 20, 16],
            [2014, 13739, 31, 21],
            [2014, 13740, 34, 10],
            [2014, 13741, 14, 11],
            [2014, 13742, 31, 17],
            [2014, 13743, 31, 19],
            [2014, 13744, 33, 14],
            [2014, 13745, 10, 9],
            [2014, 13746, 19, 18],
            [2014, 13747, 15, 14],
            [2014, 13748, 20, 17],
            [2014, 13749, 12, 10],
            [2014, 13750, 22, 18],
            [2014, 13751, 9, 9],
            [2014, 13753, 16, 15],
            [2014, 13754, 18, 15],
            [2014, 13755, 13, 13],
            [2014, 13756, 11, 10],
            [2014, 13757, 17, 16],
            [2014, 13758, 11, 10],
            [2014, 13759, 9, 8],
            [2014, 13760, 10, 10],
            [2014, 13761, 13, 9],
            [2014, 13762, 10, 11],
            [2014, 13763, 10, 9],
            [2014, 13764, 8, 8],
            [2014, 13765, 19, 10],
            [2014, 13766, 14, 12],
            [2014, 13767, 16, 13],
            [2014, 13768, 15, 10],
            [2014, 13769, 11, 10],
            [2014, 13770, 15, 13],
            [2014, 13771, 13, 12],
            [2014, 13772, 13, 10],
            [2014, 13773, 17, 13],
            [2014, 13774, 9, 8],
            [2014, 13775, 9, 12],
            [2014, 13776, 10, 11],
            [2014, 13777, 10, 9],
            [2014, 13778, 18, 15],
            [2014, 13779, 15, 11],
            [2014, 13780, 10, 13],
            [2014, 13781, 18, 14],
            [2014, 13782, 18, 30],
            [2014, 13783, 17, 37],
            [2014, 13784, 18, 36],
            [2014, 13785, 17, 29],
            [2014, 13786, 15, 30],
            [2014, 13787, 7, 5],
            [2014, 13788, 6, 6],
            [2014, 13789, 9, 7],
            [2014, 13790, 10, 9],
            [2014, 13791, 8, 7],
            [2014, 13792, 12, 12],
            [2014, 13793, 9, 9],
            [2014, 13794, 13, 12],
            [2014, 13795, 8, 7],
            [2014, 13796, 10, 10],
            [2014, 13797, 10, 10],
            [2014, 13798, 9, 8],
            [2014, 13799, 16, 13],
            [2014, 13800, 8, 8],
            [2014, 13801, 8, 6],
            [2014, 13802, 9, 9],
            [2014, 13803, 10, 9],
            [2014, 13804, 12, 12],
            [2014, 13805, 7, 6],
            [2014, 13806, 10, 9],
            [2014, 13807, 7, 7],
            [2014, 13808, 7, 5],
            [2014, 13809, 10, 9],
            [2014, 13810, 7, 6],
            [2014, 13811, 10, 10],
            [2014, 13812, 9, 9],
            [2014, 13813, 10, 9],
            [2014, 13814, 12, 12],
            [2014, 13815, 12, 11],
            [2014, 13816, 12, 10],
            [2014, 13817, 10, 10],
            [2014, 13818, 10, 9],
            [2014, 13819, 10, 8],
            [2014, 13820, 9, 7],
            [2014, 13821, 6, 6],
            [2014, 13822, 6, 6],
            [2014, 13823, 6, 6],
            [2014, 13824, 10, 9],
            [2014, 13825, 6, 5],
            [2014, 13826, 7, 6],
            [2014, 13827, 7, 6],
            [2014, 13828, 11, 10],
            [2014, 13829, 9, 9],
            [2014, 13830, 7, 7],
            [2014, 13831, 8, 9],
            [2014, 13832, 7, 8],
            [2014, 13833, 13, 13],
            [2014, 13834, 7, 7],
            [2014, 13835, 10, 10],
            [2014, 13836, 10, 9],
            [2014, 13837, 10, 9],
            [2014, 13838, 10, 9],
            [2014, 13839, 11, 12],
            [2014, 13840, 7, 6],
            [2014, 13841, 9, 8],
            [2014, 13842, 10, 10],
            [2014, 13843, 10, 9],
            [2014, 13844, 6, 6],
            [2014, 13845, 8, 8],
            [2014, 13846, 7, 7],
            [2014, 13847, 6, 6],
            [2014, 13848, 7, 7],
            [2014, 13849, 10, 9],
            [2014, 13850, 10, 9],
            [2014, 13851, 12, 13],
            [2014, 13852, 8, 9],
            [2014, 13853, 13, 10],
            [2014, 13854, 14, 14],
            [2014, 13855, 16, 15],
            [2014, 13856, 8, 8],
            [2014, 13857, 9, 7],
            [2014, 13858, 8, 7],
            [2014, 13859, 8, 7],
            [2014, 13860, 7, 6],
            [2014, 13861, 7, 6],
            [2014, 13862, 12, 9],
            [2014, 13863, 7, 6],
            [2014, 13864, 6, 5],
            [2014, 13865, 9, 7],
            [2014, 13866, 6, 6],
            [2014, 13867, 7, 6],
            [2014, 13868, 6, 6],
            [2014, 13869, 10, 7],
            [2014, 13870, 7, 6],
            [2014, 13871, 6, 5],
            [2014, 13872, 8, 6],
            [2014, 13873, 6, 5],
            [2014, 13874, 11, 9],
            [2014, 13875, 9, 7],
            [2014, 13876, 17, 11],
            [2014, 13877, 11, 10],
            [2014, 13878, 7, 6],
            [2014, 13879, 7, 6],
            [2014, 13880, 7, 6],
            [2014, 13881, 8, 6],
            [2014, 13882, 7, 6],
            [2014, 13883, 14, 9],
            [2014, 13884, 7, 8],
            [2014, 13885, 9, 6],
            [2014, 13886, 7, 6],
            [2014, 13887, 7, 6],
            [2014, 13888, 11, 10],
            [2014, 13889, 6, 5],
            [2014, 13890, 9, 8],
            [2014, 13891, 9, 7],
            [2014, 13892, 8, 8],
            [2014, 13893, 12, 13],
            [2014, 13894, 6, 7],
            [2014, 13895, 7, 7],
            [2014, 13896, 6, 6],
            [2014, 13897, 7, 7],
            [2014, 13898, 8, 7],
            [2014, 13899, 8, 7],
            [2014, 13900, 11, 8],
            [2014, 13901, 17, 11],
            [2014, 13902, 7, 7],
            [2014, 13903, 13, 10],
            [2014, 13904, 8, 6],
            [2014, 13905, 10, 9],
            [2014, 13906, 14, 9],
            [2014, 13907, 11, 10],
            [2014, 13908, 10, 9],
            [2014, 13909, 14, 11],
            [2014, 13910, 9, 7],
            [2014, 13911, 8, 7],
            [2014, 13912, 8, 9],
            [2014, 13913, 8, 9],
            [2014, 13914, 8, 9],
            [2014, 13915, 7, 7],
            [2014, 13916, 6, 7],
            [2014, 13917, 6, 6],
            [2014, 13918, 8, 8],
            [2014, 13919, 9, 8],
            [2014, 13920, 13, 9],
            [2014, 13921, 15, 9],
            [2014, 13922, 9, 8],
            [2014, 13923, 8, 7],
            [2014, 13924, 12, 10],
            [2014, 13925, 7, 7],
            [2014, 13926, 8, 8],
            [2014, 13927, 8, 8],
            [2014, 13928, 7, 6],
            [2014, 13929, 7, 7],
            [2014, 13930, 7, 6],
            [2014, 13931, 11, 10],
            [2014, 13932, 9, 7],
            [2014, 13933, 9, 8],
            [2014, 13934, 11, 11],
            [2014, 13935, 7, 6],
            [2014, 13936, 7, 7],
            [2014, 13937, 12, 11],
            [2014, 13938, 7, 7],
            [2014, 13939, 8, 7],
            [2014, 13940, 8, 7],
            [2014, 13941, 8, 9],
            [2014, 13942, 10, 8],
            [2014, 13943, 11, 8],
            [2014, 13944, 8, 8],
            [2014, 13945, 8, 7],
            [2014, 13946, 12, 10],
            [2014, 13947, 14, 11],
            [2014, 13948, 6, 6],
            [2014, 13949, 6, 6],
            [2014, 13950, 10, 9],
            [2014, 13951, 7, 7],
            [2014, 13952, 12, 10],
            [2014, 13953, 12, 10],
            [2014, 13954, 8, 8],
            [2014, 13955, 10, 9],
            [2014, 13956, 10, 9],
            [2014, 13957, 8, 7],
            [2014, 13958, 7, 7],
            [2014, 13959, 8, 8],
            [2014, 13960, 12, 10],
            [2014, 13961, 9, 8],
            [2014, 13962, 11, 10],
            [2014, 13963, 7, 7],
            [2014, 13964, 7, 7],
            [2014, 13965, 7, 7],
            [2014, 13966, 9, 7],
            [2014, 13967, 7, 6],
            [2014, 13968, 7, 7],
            [2014, 13969, 7, 6],
            [2014, 13970, 7, 7],
            [2014, 13971, 7, 7],
            [2014, 13972, 10, 8],
            [2014, 13973, 7, 6],
            [2014, 13974, 7, 6],
            [2014, 13975, 8, 7],
            [2014, 13976, 9, 9],
            [2014, 13977, 7, 8],
            [2014, 13978, 11, 11],
            [2014, 13979, 7, 6],
            [2014, 13980, 6, 6],
            [2014, 13981, 7, 7],
            [2014, 13982, 7, 7],
            [2014, 13983, 13, 10],
            [2014, 13984, 9, 8],
            [2014, 13985, 15, 9],
            [2014, 13986, 8, 8],
            [2014, 13987, 7, 7],
            [2014, 13988, 9, 8],
            [2014, 13989, 7, 6],
            [2014, 13991, 7, 7],
            [2014, 13992, 7, 6],
            [2014, 13993, 9, 8],
            [2014, 13994, 8, 8],
            [2014, 13995, 14, 12],
            [2014, 13996, 8, 8],
            [2014, 13997, 7, 6],
            [2014, 13998, 7, 7],
            [2014, 13999, 12, 11],
            [2014, 14000, 12, 11],
            [2014, 14001, 12, 9],
            [2014, 14002, 7, 7],
            [2014, 14003, 7, 7],
            [2014, 14004, 7, 7],
            [2014, 14005, 23, 18],
            [2014, 14006, 12, 8],
            [2014, 14007, 14, 12],
            [2014, 14008, 12, 9],
            [2014, 14009, 15, 8],
            [2014, 14010, 10, 8],
            [2014, 14011, 10, 11],
            [2014, 14012, 10, 10],
            [2014, 14013, 12, 11],
            [2014, 14014, 24, 15],
            [2014, 14016, 13, 12],
            [2014, 14017, 24, 14],
            [2014, 14018, 9, 9],
            [2014, 14019, 8, 7],
            [2014, 14020, 8, 7],
            [2014, 14021, 14, 9],
            [2014, 14022, 9, 9],
            [2014, 14023, 25, 15],
            [2014, 14024, 13, 14],
            [2014, 14025, 13, 13],
            [2014, 14026, 21, 15],
            [2014, 14027, 11, 11],
            [2014, 14029, 13, 12],
            [2014, 14030, 20, 13],
            [2014, 14031, 24, 18],
            [2014, 14032, 13, 11],
            [2014, 14033, 12, 12],
            [2014, 14034, 14, 12],
            [2014, 14035, 21, 14],
            [2014, 14036, 12, 10],
            [2014, 14037, 20, 13],
            [2014, 14038, 11, 10],
            [2014, 14040, 17, 13],
            [2014, 14041, 25, 19],
            [2014, 14042, 18, 15],
            [2014, 14043, 13, 11],
            [2014, 14044, 10, 10],
            [2014, 14045, 10, 9],
            [2014, 14046, 9, 13],
            [2014, 14047, 16, 13],
            [2014, 14048, 16, 13],
            [2014, 14049, 22, 13],
            [2014, 14050, 16, 13],
            [2014, 14051, 20, 15],
            [2014, 14052, 12, 11],
            [2014, 14053, 13, 10],
            [2014, 14054, 13, 13],
            [2014, 14055, 25, 14],
            [2014, 14056, 24, 13],
            [2014, 14057, 15, 13],
            [2014, 14058, 15, 11],
            [2014, 14059, 12, 12],
            [2014, 14060, 16, 12],
            [2014, 14061, 15, 14],
            [2014, 14062, 13, 15],
            [2014, 14063, 20, 11],
            [2014, 14064, 16, 12],
            [2014, 14065, 20, 11],
            [2014, 14066, 14, 10],
            [2014, 14067, 16, 16],
            [2014, 14068, 14, 9],
            [2014, 14069, 13, 13],
            [2014, 14070, 20, 19],
            [2014, 14071, 20, 17],
            [2014, 14072, 13, 9],
            [2014, 14073, 20, 17],
            [2014, 14074, 17, 18],
            [2014, 14075, 20, 13],
            [2014, 14076, 20, 13],
            [2014, 14077, 15, 10],
            [2014, 14078, 16, 11],
            [2014, 14079, 13, 10],
            [2014, 14080, 20, 13],
            [2014, 14081, 19, 13],
            [2014, 14082, 20, 14],
            [2014, 14083, 15, 8],
            [2014, 14084, 14, 10],
            [2014, 14085, 16, 11],
            [2014, 14086, 18, 14],
            [2014, 14087, 17, 13],
            [2014, 14088, 14, 10],
            [2014, 14089, 15, 10],
            [2014, 14090, 14, 13],
            [2014, 14092, 15, 8],
            [2014, 14093, 15, 8],
            [2014, 14094, 11, 8],
            [2014, 14095, 15, 14],
            [2014, 14096, 16, 13],
            [2014, 14097, 15, 10],
            [2014, 14098, 17, 11],
            [2014, 14099, 16, 11],
            [2014, 14100, 14, 9],
            [2014, 14101, 22, 13],
            [2014, 14102, 18, 10],
            [2014, 14103, 16, 14],
            [2014, 14104, 11, 10],
            [2014, 14105, 19, 13],
            [2014, 14107, 14, 10],
            [2014, 14108, 15, 11],
            [2014, 14110, 19, 11],
            [2014, 14111, 19, 14],
            [2014, 14112, 15, 11],
            [2014, 14113, 14, 13],
            [2014, 14114, 14, 12],
            [2014, 14115, 18, 14],
            [2014, 14116, 17, 15],
            [2014, 14117, 29, 12],
            [2014, 14118, 22, 15],
            [2014, 14119, 30, 20],
            [2014, 14120, 17, 11],
            [2014, 14121, 22, 12],
            [2014, 14122, 20, 13],
            [2014, 14123, 18, 14],
            [2014, 14124, 10, 10],
            [2014, 14125, 20, 16],
            [2014, 14126, 17, 11],
            [2014, 14127, 16, 12],
            [2014, 14128, 11, 9],
            [2014, 14129, 9, 9],
            [2014, 14130, 17, 14],
            [2014, 14131, 39, 17],
            [2014, 14132, 20, 12],
            [2014, 14133, 11, 9],
            [2014, 14134, 15, 12],
            [2014, 14135, 18, 13],
            [2014, 14136, 16, 11],
            [2014, 14137, 26, 13],
            [2014, 14138, 29, 13],
            [2014, 14139, 20, 14],
            [2014, 14140, 31, 15],
            [2014, 14141, 28, 15],
            [2014, 14142, 14, 13],
            [2014, 14143, 22, 14],
            [2014, 14144, 15, 10],
            [2014, 14145, 19, 12],
            [2014, 14146, 40, 14],
            [2014, 14147, 14, 13],
            [2014, 14148, 13, 9],
            [2014, 14149, 17, 13],
            [2014, 14150, 12, 10],
            [2014, 14151, 15, 11],
            [2014, 14152, 21, 13],
            [2014, 14153, 12, 12],
            [2014, 14154, 20, 12],
            [2014, 14155, 12, 9],
            [2014, 14156, 19, 14],
            [2014, 14157, 30, 17],
            [2014, 14158, 15, 12],
            [2014, 14159, 23, 13],
            [2014, 14160, 16, 13],
            [2014, 14161, 9, 9],
            [2014, 14162, 15, 13],
            [2014, 14163, 10, 10],
            [2014, 14164, 15, 14],
            [2014, 14165, 16, 11],
            [2014, 14166, 28, 13],
            [2014, 14167, 12, 9],
            [2014, 14168, 15, 12],
            [2014, 14169, 10, 8],
            [2014, 14170, 10, 9],
            [2014, 14171, 32, 14],
            [2014, 14172, 24, 17],
            [2014, 14173, 10, 13],
            [2014, 14174, 25, 16],
            [2014, 14175, 21, 33],
            [2014, 14176, 10, 11],
            [2014, 14177, 14, 12],
            [2014, 14178, 9, 9],
            [2014, 14179, 24, 18],
            [2014, 14180, 20, 13],
            [2014, 14181, 23, 14],
            [2014, 14182, 17, 13],
            [2014, 14183, 10, 9],
            [2014, 14184, 25, 10],
            [2014, 14185, 25, 12],
            [2014, 14186, 21, 12],
            [2014, 14187, 10, 12],
            [2014, 14188, 15, 13],
            [2014, 14189, 15, 12],
            [2014, 14190, 10, 9],
            [2014, 14191, 14, 16],
            [2014, 14192, 31, 18],
            [2014, 14193, 20, 18],
            [2014, 14194, 10, 10],
            [2014, 14195, 10, 9],
            [2014, 14196, 39, 20],
            [2014, 14197, 17, 13],
            [2014, 14198, 10, 10],
            [2014, 14199, 14, 14],
            [2014, 14200, 19, 11],
            [2014, 14201, 11, 10],
            [2014, 14202, 10, 10],
            [2014, 14203, 11, 9],
            [2014, 14204, 10, 9],
            [2014, 14205, 16, 12],
            [2014, 14206, 14, 12],
            [2014, 14207, 15, 11],
            [2014, 14208, 13, 10],
            [2014, 14209, 25, 14],
            [2014, 14211, 21, 14],
            [2014, 14212, 10, 10],
            [2014, 14213, 27, 17],
            [2014, 14214, 10, 9],
            [2014, 14215, 20, 13],
            [2014, 14216, 14, 12],
            [2014, 14217, 15, 13],
            [2014, 14218, 11, 9],
            [2014, 14219, 10, 9],
            [2014, 14220, 15, 13],
            [2014, 14221, 13, 11],
            [2014, 14222, 25, 14],
            [2014, 14223, 16, 13],
            [2014, 14224, 15, 14],
            [2014, 14225, 16, 13],
            [2014, 14226, 27, 12],
            [2014, 14228, 15, 15],
            [2014, 14229, 16, 13],
            [2014, 14230, 22, 12],
            [2014, 14231, 16, 11],
            [2014, 14232, 11, 9],
            [2014, 14233, 16, 13],
            [2014, 14235, 17, 12],
            [2014, 14236, 32, 20],
            [2014, 14237, 13, 10],
            [2014, 14238, 14, 13],
            [2014, 14240, 7, 5],
            [2014, 14241, 14, 8],
            [2014, 14242, 25, 14],
            [2014, 14243, 7, 5],
            [2014, 14244, 24, 14],
            [2014, 14245, 19, 14],
            [2014, 14246, 21, 15],
            [2014, 14247, 26, 16],
            [2014, 14248, 15, 11],
            [2014, 14249, 30, 17],
            [2014, 14250, 25, 15],
            [2014, 14251, 10, 7],
            [2014, 14252, 28, 16],
            [2014, 14253, 26, 14],
            [2014, 14254, 14, 10],
            [2014, 14255, 20, 12],
            [2014, 14256, 15, 10],
            [2014, 14257, 23, 13],
            [2014, 14258, 15, 9],
            [2014, 14259, 25, 14],
            [2014, 14260, 17, 10],
            [2014, 14261, 24, 13],
            [2014, 14262, 26, 15],
            [2014, 14263, 16, 11],
            [2014, 14264, 25, 13],
            [2014, 14265, 26, 15],
            [2014, 14266, 20, 14],
            [2014, 14267, 7, 6],
            [2014, 14268, 7, 6],
            [2014, 14269, 29, 17],
            [2014, 14270, 11, 8],
            [2014, 14271, 10, 8],
            [2014, 14272, 8, 6],
            [2014, 14273, 27, 15],
            [2014, 14274, 19, 13],
            [2014, 14275, 26, 14],
            [2014, 14276, 15, 12],
            [2014, 14277, 9, 6],
            [2014, 14278, 9, 8],
            [2014, 14280, 21, 13],
            [2014, 14281, 11, 7],
            [2014, 14282, 13, 9],
            [2014, 14283, 12, 7],
            [2014, 14285, 22, 13],
            [2014, 14286, 23, 14],
            [2014, 14287, 16, 12],
            [2014, 14288, 16, 10],
            [2014, 14289, 27, 14],
            [2014, 14290, 29, 18],
            [2014, 14291, 19, 13],
            [2014, 14292, 19, 12],
            [2014, 14293, 15, 9],
            [2014, 14294, 21, 13],
            [2014, 14295, 23, 13],
            [2014, 14296, 26, 14],
            [2014, 14297, 23, 14],
            [2014, 14298, 13, 8],
            [2014, 14299, 22, 14],
            [2014, 14300, 8, 6],
            [2014, 14301, 9, 8],
            [2014, 14302, 10, 8],
            [2014, 14303, 24, 14],
            [2014, 14304, 18, 11],
            [2014, 14305, 29, 16],
            [2014, 14306, 28, 16],
            [2014, 14307, 7, 6],
            [2014, 14308, 21, 13],
            [2014, 14309, 11, 9],
            [2014, 14310, 22, 14],
            [2014, 14311, 24, 15],
            [2014, 14312, 24, 15],
            [2014, 14313, 15, 9],
            [2014, 14314, 24, 14],
            [2014, 14315, 21, 13],
            [2014, 14316, 22, 14],
            [2014, 14317, 17, 13],
            [2014, 14318, 26, 16],
            [2014, 14319, 14, 10],
            [2014, 14320, 10, 8],
            [2014, 14321, 25, 15],
            [2014, 14322, 17, 13],
            [2014, 14323, 24, 14],
            [2014, 14324, 18, 12],
            [2014, 14325, 34, 14],
            [2014, 14327, 28, 14],
            [2014, 14328, 19, 12],
            [2014, 14329, 24, 14],
            [2014, 14330, 22, 13],
            [2014, 14331, 23, 15],
            [2014, 14332, 11, 8],
            [2014, 14333, 13, 9],
            [2014, 14335, 23, 15],
            [2014, 14337, 13, 10],
            [2014, 14338, 23, 14],
            [2014, 14340, 11, 7],
            [2014, 14341, 25, 14],
            [2014, 14342, 26, 16],
            [2014, 14343, 23, 13],
            [2014, 14344, 27, 14],
            [2014, 14345, 24, 14],
            [2014, 14346, 27, 14],
            [2014, 14347, 12, 9],
            [2014, 14348, 26, 14],
            [2014, 14349, 17, 11],
            [2014, 14350, 14, 10],
            [2014, 14352, 25, 13],
            [2014, 14353, 22, 13],
            [2014, 14354, 26, 15],
            [2014, 14355, 19, 13],
            [2014, 14356, 10, 8],
            [2014, 14357, 23, 13],
            [2014, 14358, 15, 10],
            [2014, 14359, 24, 13],
            [2014, 14360, 11, 8],
            [2014, 14361, 24, 14],
            [2014, 14362, 21, 13],
            [2014, 14363, 27, 15],
            [2014, 14364, 23, 13],
            [2014, 14365, 19, 13],
            [2014, 14366, 25, 14],
            [2014, 14367, 30, 15],
            [2014, 14368, 26, 15],
            [2014, 14369, 27, 14],
            [2014, 14370, 11, 8],
            [2014, 14371, 7, 5],
            [2014, 14372, 12, 8],
            [2014, 14373, 24, 14],
            [2014, 14374, 23, 12],
            [2014, 14375, 23, 13],
            [2014, 14376, 7, 5],
            [2014, 14378, 7, 6],
            [2014, 14380, 24, 14],
            [2014, 14381, 24, 14],
            [2014, 14382, 25, 14],
            [2014, 14383, 13, 8],
            [2014, 14384, 26, 13],
            [2014, 14385, 25, 13],
            [2014, 14386, 26, 14],
            [2014, 14387, 28, 17],
            [2014, 14388, 35, 19],
            [2014, 14389, 25, 14],
            [2014, 14390, 23, 13],
            [2014, 14391, 13, 8],
            [2014, 14392, 22, 14],
            [2014, 14393, 15, 9],
            [2014, 14394, 25, 13],
            [2014, 14395, 28, 14],
            [2014, 14397, 22, 13],
            [2014, 14398, 23, 13],
            [2014, 14399, 30, 15],
            [2014, 14400, 28, 16],
            [2014, 14401, 21, 12],
            [2014, 14402, 13, 8],
            [2014, 14403, 25, 14],
            [2014, 14405, 34, 15],
            [2014, 14406, 31, 18],
            [2014, 14407, 25, 14],
            [2014, 14408, 17, 12],
            [2014, 14409, 27, 13],
            [2014, 14411, 18, 10],
            [2014, 14412, 17, 9],
            [2014, 14413, 10, 7],
            [2014, 14415, 23, 13],
            [2014, 14416, 17, 11],
            [2014, 14417, 18, 13],
            [2014, 14418, 24, 13],
            [2014, 14419, 25, 13],
            [2014, 14420, 15, 10],
            [2014, 14421, 30, 13],
            [2014, 14422, 21, 10],
            [2014, 14423, 15, 9],
            [2014, 14424, 16, 10],
            [2014, 14425, 28, 18],
            [2014, 14426, 16, 11],
            [2014, 14427, 24, 13],
            [2014, 14428, 22, 13],
            [2014, 14429, 19, 11],
            [2014, 14430, 23, 13],
            [2014, 14432, 23, 13],
            [2014, 14434, 19, 11],
            [2014, 14435, 12, 11],
            [2014, 14436, 25, 21],
            [2014, 14438, 20, 41],
            [2014, 14440, 20, 38],
            [2014, 14442, 20, 23],
            [2014, 14445, 24, 36],
            [2014, 14446, 26, 28],
            [2014, 14447, 20, 23],
            [2014, 14449, 15, 21],
            [2014, 14450, 61, 38],
            [2014, 14452, 30, 37],
            [2014, 14453, 26, 48],
            [2014, 14458, 27, 43],
            [2014, 14459, 30, 30],
            [2014, 14460, 28, 28],
            [2014, 14462, 20, 31],
            [2014, 14463, 14, 16],
            [2014, 14464, 31, 27],
            [2014, 14465, 42, 23],
            [2014, 14466, 25, 28],
            [2014, 14468, 30, 35],
            [2014, 14470, 23, 20],
            [2014, 14471, 26, 25],
            [2014, 14473, 21, 18],
            [2014, 14476, 32, 30],
            [2014, 14478, 20, 19],
            [2014, 14480, 28, 28],
            [2014, 14484, 30, 35],
            [2014, 14485, 15, 17],
            [2014, 14486, 31, 26],
            [2014, 14488, 21, 28],
            [2014, 14489, 17, 19],
            [2014, 14490, 38, 30],
            [2014, 14491, 21, 28],
            [2014, 14493, 28, 39],
            [2014, 14495, 24, 26],
            [2014, 14496, 40, 39],
            [2014, 14500, 24, 35],
            [2014, 14501, 20, 30],
            [2014, 14502, 40, 28],
            [2014, 14503, 30, 30],
            [2014, 14505, 18, 17],
            [2014, 14507, 28, 42],
            [2014, 14508, 16, 28],
            [2014, 14509, 31, 27],
            [2014, 14510, 31, 26],
            [2014, 14512, 31, 30],
            [2014, 14513, 38, 30],
            [2014, 14514, 36, 42],
            [2014, 14516, 38, 36],
            [2014, 14518, 28, 27],
            [2014, 14519, 44, 36],
            [2014, 14520, 30, 41],
            [2014, 14524, 24, 27],
            [2014, 14527, 28, 48],
            [2014, 14528, 32, 25],
            [2014, 14530, 45, 42],
            [2014, 14534, 18, 11],
            [2014, 14535, 12, 6],
            [2014, 14536, 19, 13],
            [2014, 14538, 24, 14],
            [2014, 14541, 18, 14],
            [2014, 14542, 16, 11],
            [2014, 14543, 16, 13],
            [2014, 14544, 10, 9],
            [2014, 14545, 20, 16],
            [2014, 14546, 21, 15],
            [2014, 14547, 19, 13],
            [2014, 14548, 20, 15],
            [2014, 14549, 24, 15],
            [2014, 14550, 19, 14],
            [2014, 14553, 14, 16],
            [2014, 14554, 17, 9],
            [2014, 14555, 11, 12],
            [2014, 14556, 23, 15],
            [2014, 14557, 21, 18],
            [2014, 14558, 11, 10],
            [2014, 14559, 11, 10],
            [2014, 14562, 86, 32],
            [2014, 14563, 95, 33],
            [2014, 14564, 23, 19],
            [2014, 14565, 20, 39],
            [2014, 14566, 16, 22],
            [2014, 14567, 23, 38],
            [2014, 14568, 73, 73],
            [2014, 14569, 20, 18],
            [2014, 14570, 19, 23],
            [2014, 14571, 16, 17],
            [2014, 14572, 16, 23],
            [2014, 14573, 89, 77],
            [2014, 14574, 12, 10],
            [2014, 14575, 8, 6],
            [2014, 14576, 9, 8],
            [2014, 14577, 28, 18],
            [2014, 14578, 17, 14],
            [2014, 14579, 14, 11],
            [2014, 14580, 8, 8],
            [2014, 14581, 9, 10],
            [2014, 14582, 23, 20],
            [2014, 14583, 17, 13],
            [2014, 14584, 7, 7],
            [2014, 14585, 11, 10],
            [2014, 14586, 10, 11],
            [2014, 14588, 19, 14],
            [2014, 14590, 16, 14],
            [2014, 14591, 16, 13],
            [2014, 14592, 2, 2],
            [2014, 14593, 73, 38],
            [2014, 14594, 4, 4],
            [2014, 14596, 5, 4],
            [2014, 14598, 15, 9],
            [2014, 14599, 20, 11],
            [2014, 14600, 29, 16],
            [2014, 14601, 7, 6],
            [2014, 14602, 19, 15],
            [2014, 14603, 11, 8],
            [2014, 14604, 10, 9],
            [2014, 14605, 13, 12],
            [2014, 14607, 6, 6],
            [2014, 14608, 9, 8],
            [2014, 14609, 11, 8],
            [2014, 14610, 4, 4],
            [2014, 14611, 6, 5],
            [2014, 14613, 20, 15],
            [2014, 14614, 19, 14],
            [2014, 14616, 12, 12],
            [2014, 14617, 28, 19],
            [2014, 14618, 7, 7],
            [2014, 14619, 18, 13],
            [2014, 14620, 13, 12],
            [2014, 14621, 8, 6],
            [2014, 14622, 14, 11],
            [2014, 14623, 15, 11],
            [2014, 14624, 9, 8],
            [2014, 14625, 11, 7],
            [2014, 14626, 8, 6],
            [2014, 14627, 28, 18],
            [2014, 14628, 16, 14],
            [2014, 14629, 23, 16],
            [2014, 14630, 7, 7],
            [2014, 14631, 6, 5],
            [2014, 14632, 29, 20],
            [2014, 14633, 29, 23],
            [2014, 14634, 10, 9],
            [2014, 14635, 7, 6],
            [2014, 14636, 15, 11],
            [2014, 14637, 14, 11],
            [2014, 14638, 19, 11],
            [2014, 14639, 5, 6],
            [2014, 14640, 8, 6],
            [2014, 14642, 24, 14],
            [2014, 14643, 6, 6],
            [2014, 14644, 6, 7],
            [2014, 14645, 14, 12],
            [2014, 14646, 8, 7],
            [2014, 14647, 22, 13],
            [2014, 14648, 4, 4],
            [2014, 14649, 11, 10],
            [2014, 14650, 14, 11],
            [2014, 14651, 14, 11],
            [2014, 14652, 19, 14],
            [2014, 14653, 20, 14],
            [2014, 14655, 4, 4],
            [2014, 14656, 11, 11],
            [2014, 14657, 7, 6],
            [2014, 14658, 16, 12],
            [2014, 14659, 14, 11],
            [2014, 14660, 13, 12],
            [2014, 14662, 18, 12],
            [2014, 14663, 16, 14],
            [2014, 14664, 8, 8],
            [2014, 14665, 12, 10],
            [2014, 14666, 12, 10],
            [2014, 14667, 17, 12],
            [2014, 14668, 14, 12],
            [2014, 14669, 25, 20],
            [2014, 14670, 14, 11],
            [2014, 14671, 14, 12],
            [2014, 14672, 13, 12],
            [2014, 14673, 17, 14],
            [2014, 14674, 10, 9],
            [2014, 14675, 8, 7],
            [2014, 14676, 14, 11],
            [2014, 14677, 13, 10],
            [2014, 14678, 17, 10],
            [2014, 14680, 16, 12],
            [2014, 14681, 15, 11],
            [2014, 14682, 11, 9],
            [2014, 14683, 16, 12],
            [2014, 14684, 28, 18],
            [2014, 14686, 10, 8],
            [2014, 14687, 20, 14],
            [2014, 14688, 6, 6],
            [2014, 14689, 12, 10],
            [2014, 14690, 20, 15],
            [2014, 14691, 15, 11],
            [2014, 14692, 16, 14],
            [2014, 14693, 11, 8],
            [2014, 14694, 8, 6],
            [2014, 14696, 9, 9],
            [2014, 14697, 13, 11],
            [2014, 14698, 15, 9],
            [2014, 14699, 18, 14],
            [2014, 14700, 17, 14],
            [2014, 14701, 29, 17],
            [2014, 14702, 35, 25],
            [2014, 14703, 29, 20],
            [2014, 14704, 56, 33],
            [2014, 14705, 23, 18],
            [2014, 14706, 37, 21],
            [2014, 14710, 27, 17],
            [2014, 14711, 27, 19],
            [2014, 14712, 35, 21],
            [2014, 14713, 31, 20],
            [2014, 14714, 25, 17],
            [2014, 14717, 12, 10],
            [2014, 14718, 21, 19],
            [2014, 14719, 19, 16],
            [2014, 14720, 56, 31],
            [2014, 14722, 27, 20],
            [2014, 14724, 19, 17],
            [2014, 14725, 23, 21],
            [2014, 14726, 21, 18],
            [2014, 14727, 39, 20],
            [2014, 14728, 33, 21],
            [2014, 14729, 25, 21],
            [2014, 14730, 23, 19],
            [2014, 14731, 19, 19],
            [2014, 14732, 41, 21],
            [2014, 14733, 33, 18],
            [2014, 14734, 29, 30],
            [2014, 14735, 41, 24],
            [2014, 14736, 40, 21],
            [2014, 14738, 27, 20],
            [2014, 14739, 19, 17],
            [2014, 14740, 31, 25],
            [2014, 14741, 27, 19],
            [2014, 14743, 20, 14],
            [2014, 14744, 12, 9],
            [2014, 14745, 27, 23],
            [2014, 14747, 25, 21],
            [2014, 14748, 19, 17],
            [2014, 14749, 13, 9],
            [2014, 14750, 22, 16],
            [2014, 14751, 27, 17],
            [2014, 14752, 21, 16],
            [2014, 14753, 33, 21],
            [2014, 14754, 17, 16],
            [2014, 14755, 20, 21],
            [2014, 14756, 21, 17],
            [2014, 14759, 27, 20],
            [2014, 14760, 27, 21],
            [2014, 14761, 19, 9],
            [2014, 14762, 12, 9],
            [2014, 14763, 23, 30],
            [2014, 14764, 46, 25],
            [2014, 14765, 13, 9],
            [2014, 14766, 37, 23],
            [2014, 14767, 25, 25],
            [2014, 14768, 5, 5],
            [2014, 14769, 40, 26],
            [2014, 14770, 19, 19],
            [2014, 14771, 29, 38],
            [2014, 14773, 39, 46],
            [2014, 14774, 30, 20],
            [2014, 14775, 37, 33],
            [2014, 14776, 39, 36],
            [2014, 14777, 21, 25],
            [2014, 14778, 13, 12],
            [2014, 14779, 40, 24],
            [2014, 14780, 37, 13],
            [2014, 14781, 10, 11],
            [2014, 14782, 64, 32],
            [2014, 14783, 29, 25],
            [2014, 14784, 15, 25],
            [2014, 14785, 64, 44],
            [2014, 14786, 26, 19],
            [2014, 14788, 27, 25],
            [2014, 14789, 70, 41],
            [2014, 14790, 49, 21],
            [2014, 14791, 13, 13],
            [2014, 14792, 64, 58],
            [2014, 14793, 38, 25],
            [2014, 14794, 30, 28],
            [2014, 14795, 33, 25],
            [2014, 14796, 36, 49],
            [2014, 14797, 27, 54],
            [2014, 14798, 28, 44],
            [2014, 14799, 45, 25],
            [2014, 14800, 13, 11],
            [2014, 14801, 31, 15],
            [2014, 14802, 21, 13],
            [2014, 14803, 37, 36],
            [2014, 14804, 14, 12],
            [2014, 14805, 36, 36],
            [2014, 14806, 15, 13],
            [2014, 14807, 38, 26],
            [2014, 14808, 51, 50],
            [2014, 14809, 16, 26],
            [2014, 14810, 17, 19],
            [2014, 14811, 16, 21],
            [2014, 14812, 46, 38],
            [2014, 14813, 26, 20],
            [2014, 14814, 38, 25],
            [2014, 14815, 60, 28],
            [2014, 14816, 13, 12],
            [2014, 14817, 13, 11],
            [2014, 14818, 14, 11],
            [2014, 14819, 37, 33],
            [2014, 14820, 70, 59],
            [2014, 14821, 19, 18],
            [2014, 14823, 18, 19],
            [2014, 14824, 65, 40],
            [2014, 14825, 16, 17],
            [2014, 14826, 40, 20],
            [2014, 14827, 45, 36],
            [2014, 14828, 51, 41],
            [2014, 14829, 19, 18],
            [2014, 14830, 14, 16],
            [2014, 14831, 30, 19],
            [2014, 14832, 45, 36],
            [2014, 14833, 38, 30],
            [2014, 14834, 39, 44],
            [2014, 14835, 53, 21],
            [2014, 14836, 45, 22],
            [2014, 14837, 58, 37],
            [2014, 14838, 58, 44],
            [2014, 14839, 30, 36],
            [2014, 14840, 33, 25],
            [2014, 14841, 22, 18],
            [2014, 14842, 19, 16],
            [2014, 14843, 55, 36],
            [2014, 14844, 17, 17],
            [2014, 14845, 51, 50],
            [2014, 14846, 38, 17],
            [2014, 14847, 13, 12],
            [2014, 14848, 13, 11],
            [2014, 14849, 13, 11],
            [2014, 14850, 41, 28],
            [2014, 14851, 19, 22],
            [2014, 14852, 14, 12],
            [2014, 14853, 26, 22],
            [2014, 14854, 60, 44],
            [2014, 14855, 11, 11],
            [2014, 14856, 8, 7],
            [2014, 14857, 7, 7],
            [2014, 14858, 17, 16],
            [2014, 14859, 26, 25],
            [2014, 14860, 18, 16],
            [2014, 14861, 13, 13],
            [2014, 14862, 14, 12],
            [2014, 14863, 10, 11],
            [2014, 14864, 11, 10],
            [2014, 14865, 20, 26],
            [2014, 14866, 21, 23],
            [2014, 14867, 15, 25],
            [2014, 14868, 27, 22],
            [2014, 14869, 22, 24],
            [2014, 14870, 10, 10],
            [2014, 14871, 11, 10],
            [2014, 14872, 11, 10],
            [2014, 14873, 28, 21],
            [2014, 14875, 26, 25],
            [2014, 14876, 15, 15],
            [2014, 14877, 45, 35],
            [2014, 14879, 22, 21],
            [2014, 14880, 20, 13],
            [2014, 14881, 26, 21],
            [2014, 14882, 26, 27],
            [2014, 14883, 10, 16],
            [2014, 14884, 10, 8],
            [2014, 14885, 10, 10],
            [2014, 14886, 26, 18],
            [2014, 14887, 21, 14],
            [2014, 14888, 14, 12],
            [2014, 14889, 26, 22],
            [2014, 14890, 15, 13],
            [2014, 14892, 28, 30],
            [2014, 14893, 20, 32],
            [2014, 14894, 16, 16],
            [2014, 14896, 30, 19],
            [2014, 14898, 32, 26],
            [2014, 14899, 16, 14],
            [2014, 14900, 13, 11],
            [2014, 14902, 20, 20],
            [2014, 14903, 23, 18],
            [2014, 14904, 28, 23],
            [2014, 14905, 32, 25],
            [2014, 14906, 15, 14],
            [2014, 14907, 10, 10],
            [2014, 14908, 10, 10],
            [2014, 14909, 10, 9],
            [2014, 14910, 19, 19],
            [2014, 14911, 23, 20],
            [2014, 14912, 21, 19],
            [2014, 14913, 14, 14],
            [2014, 14915, 24, 20],
            [2014, 14916, 25, 16],
            [2014, 14917, 24, 28],
            [2014, 14918, 30, 36],
            [2014, 14920, 27, 26],
            [2014, 14921, 16, 13],
            [2014, 14922, 11, 12],
            [2014, 14923, 21, 19],
            [2014, 14924, 22, 22],
            [2014, 14925, 22, 15],
            [2014, 14926, 26, 29],
            [2014, 14927, 22, 26],
            [2014, 14928, 20, 26],
            [2014, 14929, 23, 25],
            [2014, 14930, 22, 23],
            [2014, 14931, 13, 12],
            [2014, 14933, 18, 15],
            [2014, 14934, 39, 34],
            [2014, 14936, 11, 10],
            [2014, 14937, 11, 10],
            [2014, 14938, 28, 28],
            [2014, 14939, 32, 27],
            [2014, 14940, 12, 11],
            [2014, 14941, 38, 34],
            [2014, 14942, 12, 11],
            [2014, 14943, 22, 11],
            [2014, 14944, 17, 16],
            [2014, 14945, 29, 27],
            [2014, 14946, 14, 13],
            [2014, 14947, 18, 16],
            [2014, 14948, 38, 32],
            [2014, 14949, 39, 25],
            [2014, 14950, 13, 11],
            [2014, 14951, 23, 16],
            [2014, 14952, 37, 20],
            [2014, 14953, 20, 19],
            [2014, 14954, 32, 27],
            [2014, 14955, 17, 8],
            [2014, 14956, 27, 24],
            [2014, 14957, 15, 15],
            [2014, 14958, 12, 28],
            [2014, 14959, 14, 12],
            [2014, 14961, 19, 18],
            [2014, 14962, 23, 28],
            [2014, 14963, 24, 21],
            [2014, 14964, 17, 14],
            [2014, 14965, 11, 10],
            [2014, 14966, 9, 10],
            [2014, 14967, 18, 17],
            [2014, 14968, 23, 23],
            [2014, 14969, 11, 12],
            [2014, 14970, 11, 12],
            [2014, 14971, 13, 10],
            [2014, 14972, 30, 29],
            [2014, 14973, 23, 18],
            [2014, 14974, 23, 17],
            [2014, 14975, 18, 11],
            [2014, 14976, 24, 17],
            [2014, 14977, 23, 17],
            [2014, 14978, 24, 33],
            [2014, 14979, 20, 15],
            [2014, 14980, 26, 25],
            [2014, 14981, 22, 19],
            [2014, 14982, 12, 12],
            [2014, 14984, 19, 12],
            [2014, 14985, 19, 17],
            [2014, 14986, 36, 25],
            [2014, 14987, 26, 22],
            [2014, 14988, 19, 20],
            [2014, 14989, 14, 15],
            [2014, 14990, 11, 10],
            [2014, 14991, 8, 5],
            [2014, 14992, 1, 1],
            [2014, 14993, 10, 7],
            [2014, 14994, 10, 6],
            [2014, 14995, 7, 6],
            [2014, 14996, 7, 6],
            [2014, 14997, 25, 18],
            [2014, 14998, 7, 4],
            [2014, 14999, 7, 6],
            [2014, 15000, 17, 15],
            [2014, 15001, 10, 10],
            [2014, 15002, 7, 6],
            [2014, 15003, 16, 14],
            [2014, 15004, 4, 4],
            [2014, 15005, 15, 13],
            [2014, 15006, 13, 11],
            [2014, 15007, 8, 4],
            [2014, 15008, 1, 1],
            [2014, 15009, 14, 12],
            [2014, 15010, 9, 7],
            [2014, 15011, 6, 5],
            [2014, 15012, 1, 1],
            [2014, 15013, 9, 8],
            [2014, 15015, 13, 12],
            [2014, 15016, 1, 1],
            [2014, 15017, 9, 5],
            [2014, 15019, 7, 6],
            [2014, 15020, 12, 10],
            [2014, 15021, 7, 5],
            [2014, 15022, 10, 7],
            [2014, 15023, 10, 7],
            [2014, 15024, 10, 7],
            [2014, 15025, 8, 6],
            [2014, 15026, 9, 7],
            [2014, 15027, 7, 6],
            [2014, 15028, 10, 8],
            [2014, 15029, 11, 9],
            [2014, 15030, 8, 5],
            [2014, 15031, 7, 4],
            [2014, 15032, 7, 4],
            [2014, 15033, 4, 2],
            [2014, 15034, 7, 6],
            [2014, 15035, 10, 8],
            [2014, 15036, 9, 6],
            [2014, 15037, 10, 6],
            [2014, 15040, 10, 8],
            [2014, 15041, 1, 1],
            [2014, 15042, 10, 6],
            [2014, 15043, 14, 12],
            [2014, 15044, 9, 6],
            [2014, 15045, 8, 5],
            [2014, 15047, 7, 5],
            [2014, 15048, 13, 11],
            [2014, 15049, 9, 6],
            [2014, 15050, 7, 5],
            [2014, 15051, 12, 10],
            [2014, 15052, 10, 6],
            [2014, 15053, 15, 12],
            [2014, 15054, 9, 5],
            [2014, 15055, 8, 5],
            [2014, 15056, 10, 8],
            [2014, 15057, 7, 5],
            [2014, 15058, 7, 5],
            [2014, 15059, 2, 1],
            [2014, 15060, 3, 1],
            [2014, 15061, 8, 6],
            [2014, 15062, 9, 6],
            [2014, 15063, 1, 1],
            [2014, 15064, 1, 1],
            [2014, 15065, 1, 1],
            [2014, 15066, 9, 6],
            [2014, 15067, 8, 5],
            [2014, 15068, 14, 12],
            [2014, 15070, 19, 18],
            [2014, 15071, 6, 5],
            [2014, 15072, 12, 11],
            [2014, 15073, 9, 6],
            [2014, 15074, 10, 7],
            [2014, 15075, 1, 1],
            [2014, 15076, 1, 1],
            [2014, 15077, 25, 15],
            [2014, 15078, 8, 6],
            [2014, 15079, 2, 1],
            [2014, 15081, 25, 18],
            [2014, 15082, 7, 5],
            [2014, 15083, 1, 1],
            [2014, 15084, 7, 6],
            [2014, 15085, 9, 7],
            [2014, 15086, 10, 7],
            [2014, 15087, 7, 6],
            [2014, 15088, 14, 11],
            [2014, 15089, 20, 15],
            [2014, 15090, 19, 14],
            [2014, 15091, 11, 10],
            [2014, 15092, 16, 10],
            [2014, 15093, 14, 9],
            [2014, 15094, 9, 7],
            [2014, 15095, 18, 14],
            [2014, 15096, 14, 10],
            [2014, 15097, 13, 11],
            [2014, 15098, 15, 13],
            [2014, 15099, 18, 14],
            [2014, 15100, 10, 10],
            [2014, 15101, 12, 10],
            [2014, 15102, 14, 9],
            [2014, 15103, 12, 8],
            [2014, 15104, 9, 6],
            [2014, 15106, 12, 7],
            [2014, 15107, 8, 7],
            [2014, 15108, 21, 14],
            [2014, 15109, 19, 13],
            [2014, 15110, 6, 5],
            [2014, 15111, 15, 10],
            [2014, 15112, 20, 13],
            [2014, 15113, 22, 13],
            [2014, 15114, 9, 8],
            [2014, 15115, 9, 7],
            [2014, 15116, 9, 8],
            [2014, 15117, 10, 8],
            [2014, 15118, 8, 7],
            [2014, 15119, 6, 5],
            [2014, 15120, 7, 7],
            [2014, 15121, 7, 5],
            [2014, 15122, 3, 3],
            [2014, 15123, 3, 3],
            [2014, 15124, 5, 5],
            [2014, 15125, 4, 5],
            [2014, 15126, 7, 6],
            [2014, 15127, 6, 5],
            [2014, 15128, 22, 14],
            [2014, 15129, 7, 5],
            [2014, 15130, 6, 5],
            [2014, 15131, 5, 4],
            [2014, 15132, 25, 16],
            [2014, 15133, 27, 13],
            [2014, 15134, 18, 13],
            [2014, 15135, 19, 12],
            [2014, 15136, 15, 10],
            [2014, 15137, 12, 9],
            [2014, 15138, 17, 10],
            [2014, 15139, 30, 17],
            [2014, 15140, 15, 11],
            [2014, 15141, 11, 7],
            [2014, 15142, 10, 7],
            [2014, 15143, 10, 7],
            [2014, 15144, 16, 9],
            [2014, 15145, 12, 9],
            [2014, 15146, 19, 13],
            [2014, 15147, 8, 6],
            [2014, 15148, 7, 5],
            [2014, 15149, 13, 10],
            [2014, 15150, 13, 8],
            [2014, 15151, 6, 5],
            [2014, 15152, 7, 6],
            [2014, 15153, 16, 9],
            [2014, 15154, 17, 9],
            [2014, 15155, 19, 14],
            [2014, 15156, 10, 9],
            [2014, 15157, 13, 12],
            [2014, 15158, 19, 12],
            [2014, 15159, 7, 6],
            [2014, 15160, 25, 16],
            [2014, 15161, 10, 8],
            [2014, 15162, 14, 9],
            [2014, 15163, 15, 9],
            [2014, 15164, 16, 9],
            [2014, 15165, 23, 10],
            [2014, 15166, 15, 12],
            [2014, 15167, 10, 14],
            [2014, 15168, 19, 14],
            [2014, 15169, 21, 9],
            [2014, 15170, 12, 10],
            [2014, 15171, 12, 7],
            [2014, 15172, 8, 6],
            [2014, 15173, 11, 10],
            [2014, 15174, 11, 7],
            [2014, 15175, 8, 6],
            [2014, 15176, 6, 6],
            [2014, 15177, 21, 13],
            [2014, 15178, 7, 5],
            [2014, 15179, 7, 5],
            [2014, 15180, 7, 5],
            [2014, 15181, 6, 5],
            [2014, 15182, 15, 11],
            [2014, 15183, 18, 11],
            [2014, 15184, 18, 12],
            [2014, 15185, 27, 16],
            [2014, 15186, 15, 11],
            [2014, 15187, 11, 11],
            [2014, 15188, 15, 12],
            [2014, 15189, 15, 13],
            [2014, 15190, 17, 9],
            [2014, 15191, 13, 9],
            [2014, 15192, 9, 9],
            [2014, 15193, 8, 7],
            [2014, 15194, 12, 10],
            [2014, 15195, 17, 14],
            [2014, 15196, 14, 8],
            [2014, 15197, 20, 13],
            [2014, 15198, 15, 12],
            [2014, 15199, 19, 9],
            [2014, 15200, 17, 12],
            [2014, 15201, 12, 9],
            [2014, 15202, 20, 12],
            [2014, 15203, 15, 10],
            [2014, 15204, 15, 9],
            [2014, 15206, 17, 9],
            [2014, 15207, 10, 8],
            [2014, 15208, 12, 9],
            [2014, 15209, 12, 11],
            [2014, 15210, 10, 10],
            [2014, 15211, 15, 11],
            [2014, 15212, 14, 12],
            [2014, 15213, 27, 18],
            [2014, 15214, 10, 7],
            [2014, 15215, 12, 10],
            [2014, 15216, 13, 10],
            [2014, 15217, 9, 8],
            [2014, 15218, 10, 9],
            [2014, 15219, 13, 9],
            [2014, 15220, 17, 8],
            [2014, 15221, 17, 12],
            [2014, 15222, 19, 11],
            [2014, 15223, 13, 8],
            [2014, 15224, 12, 9],
            [2014, 15225, 10, 8],
            [2014, 15227, 14, 14],
            [2014, 15228, 16, 13],
            [2014, 15229, 15, 8],
            [2014, 15230, 17, 10],
            [2014, 15231, 9, 11],
            [2014, 15232, 20, 13],
            [2014, 15233, 15, 11],
            [2014, 15234, 16, 12],
            [2014, 15235, 8, 8],
            [2014, 15236, 14, 11],
            [2014, 15237, 16, 9],
            [2014, 15238, 10, 9],
            [2014, 15239, 9, 8],
            [2014, 15240, 11, 8],
            [2014, 15241, 12, 8],
            [2014, 15242, 13, 11],
            [2014, 15243, 18, 10],
            [2014, 15244, 9, 7],
            [2014, 15245, 13, 9],
            [2014, 15246, 18, 13],
            [2014, 15247, 17, 12],
            [2014, 15248, 17, 13],
            [2014, 15249, 13, 8],
            [2014, 15250, 14, 10],
            [2014, 15252, 16, 13],
            [2014, 15253, 16, 11],
            [2014, 15254, 10, 6],
            [2014, 15255, 11, 12],
            [2014, 15256, 9, 7],
            [2014, 15257, 8, 10],
            [2014, 15258, 11, 7],
            [2014, 15260, 17, 12],
            [2014, 15261, 14, 8],
            [2014, 15262, 9, 7],
            [2014, 15263, 21, 9],
            [2014, 15264, 20, 13],
            [2014, 15265, 20, 14],
            [2014, 15266, 16, 11],
            [2014, 15267, 13, 10],
            [2014, 15268, 29, 12],
            [2014, 15269, 13, 11],
            [2014, 15270, 14, 7],
            [2014, 15271, 7, 7],
            [2014, 15272, 18, 16],
            [2014, 15273, 12, 6],
            [2014, 15274, 21, 15],
            [2014, 15275, 17, 12],
            [2014, 15276, 16, 10],
            [2014, 15277, 8, 7],
            [2014, 15278, 6, 6],
            [2014, 15280, 14, 12],
            [2014, 15281, 16, 9],
            [2014, 15282, 27, 14],
            [2014, 15283, 25, 13],
            [2014, 15284, 14, 12],
            [2014, 15285, 10, 10],
            [2014, 15286, 20, 13],
            [2014, 15287, 19, 11],
            [2014, 15288, 15, 7],
            [2014, 15289, 10, 9],
            [2014, 15290, 19, 12],
            [2014, 15291, 9, 6],
            [2014, 15292, 12, 10],
            [2014, 15293, 14, 9],
            [2014, 15294, 21, 13],
            [2014, 15295, 12, 12],
            [2014, 15296, 17, 15],
            [2014, 15297, 18, 13],
            [2014, 15298, 19, 11],
            [2014, 15299, 23, 14],
            [2014, 15300, 23, 13],
            [2014, 15301, 9, 7],
            [2014, 15302, 12, 9],
            [2014, 15303, 8, 6],
            [2014, 15304, 7, 9],
            [2014, 15305, 20, 10],
            [2014, 15306, 6, 6],
            [2014, 15307, 5, 6],
            [2014, 15308, 12, 11],
            [2014, 15309, 9, 9],
            [2014, 15310, 10, 6],
            [2014, 15311, 17, 12],
            [2014, 15312, 13, 11],
            [2014, 15313, 21, 10],
            [2014, 15314, 16, 11],
            [2014, 15315, 15, 11],
            [2014, 15316, 18, 11],
            [2014, 15317, 16, 11],
            [2014, 15318, 9, 7],
            [2014, 15319, 12, 10],
            [2014, 15320, 13, 10],
            [2014, 15321, 7, 5],
            [2014, 15323, 19, 12],
            [2014, 15324, 14, 11],
            [2014, 15325, 9, 6],
            [2014, 15326, 27, 18],
            [2014, 15327, 12, 10],
            [2014, 15328, 12, 7],
            [2014, 15329, 13, 8],
            [2014, 15331, 13, 12],
            [2014, 15332, 6, 5],
            [2014, 15333, 9, 7],
            [2014, 15334, 13, 8],
            [2014, 15335, 12, 10],
            [2014, 15336, 19, 12],
            [2014, 15337, 10, 10],
            [2014, 15338, 8, 6],
            [2014, 15339, 15, 9],
            [2014, 15340, 21, 11],
            [2014, 15341, 24, 12],
            [2014, 15342, 21, 14],
            [2014, 15343, 15, 12],
            [2014, 15344, 7, 7],
            [2014, 15345, 9, 8],
            [2014, 15346, 13, 8],
            [2014, 15347, 15, 10],
            [2014, 15348, 16, 10],
            [2014, 15349, 11, 8],
            [2014, 15350, 19, 11],
            [2014, 15351, 18, 9],
            [2014, 15352, 12, 7],
            [2014, 15353, 15, 12],
            [2014, 15354, 20, 13],
            [2014, 15355, 12, 11],
            [2014, 15356, 16, 9],
            [2014, 15357, 14, 13],
            [2014, 15358, 17, 11],
            [2014, 15359, 16, 13],
            [2014, 15360, 15, 14],
            [2014, 15361, 34, 26],
            [2014, 15362, 4, 6],
            [2014, 15363, 6, 7],
            [2014, 15364, 34, 18],
            [2014, 15365, 6, 6],
            [2014, 15366, 12, 12],
            [2014, 15367, 12, 12],
            [2014, 15368, 6, 7],
            [2014, 15369, 11, 9],
            [2014, 15370, 11, 9],
            [2014, 15371, 15, 12],
            [2014, 15372, 13, 11],
            [2014, 15373, 15, 13],
            [2014, 15374, 18, 12],
            [2014, 15375, 11, 10],
            [2014, 15376, 6, 5],
            [2014, 15377, 13, 11],
            [2014, 15378, 17, 11],
            [2014, 15379, 13, 10],
            [2014, 15380, 5, 5],
            [2014, 15381, 17, 11],
            [2014, 15382, 16, 11],
            [2014, 15383, 8, 7],
            [2014, 15385, 7, 6],
            [2014, 15386, 12, 10],
            [2014, 15387, 7, 6],
            [2014, 15389, 12, 14],
            [2014, 15390, 14, 11],
            [2014, 15391, 24, 13],
            [2014, 15392, 20, 13],
            [2014, 15393, 5, 5],
            [2014, 15394, 13, 13],
            [2014, 15395, 9, 8],
            [2014, 15396, 6, 5],
            [2014, 15397, 13, 10],
            [2014, 15398, 18, 14],
            [2014, 15400, 18, 11],
            [2014, 15401, 21, 12],
            [2014, 15402, 8, 8],
            [2014, 15403, 20, 10],
            [2014, 15404, 19, 11],
            [2014, 15405, 21, 12],
            [2014, 15408, 21, 12],
            [2014, 15409, 24, 11],
            [2014, 15410, 15, 10],
            [2014, 15411, 6, 6],
            [2014, 15412, 17, 11],
            [2014, 15414, 13, 10],
            [2014, 15415, 15, 11],
            [2014, 15416, 19, 11],
            [2014, 15418, 19, 11],
            [2014, 15419, 16, 13],
            [2014, 15420, 8, 7],
            [2014, 15459, 32, 31],
            [2014, 15460, 25, 43],
            [2014, 15461, 24, 22],
            [2014, 15462, 28, 28],
            [2014, 15463, 19, 22],
            [2014, 15464, 24, 25],
            [2014, 15465, 44, 35],
            [2014, 15466, 69, 66],
            [2014, 15467, 45, 46],
            [2014, 15468, 29, 25],
            [2014, 15469, 18, 22],
            [2014, 15470, 38, 38],
            [2014, 15471, 28, 25],
            [2014, 15472, 18, 31],
            [2014, 15473, 18, 23],
            [2014, 15474, 34, 38],
            [2014, 15475, 16, 26],
            [2014, 15476, 24, 38],
            [2014, 15477, 26, 27],
            [2014, 15478, 56, 46],
            [2014, 15479, 22, 34],
            [2014, 15480, 22, 33],
            [2014, 15481, 48, 50],
            [2014, 15482, 34, 44],
            [2014, 15483, 28, 32],
            [2014, 15484, 46, 41],
            [2014, 15485, 17, 33],
            [2014, 15486, 11, 19],
            [2014, 15487, 28, 35],
            [2014, 15488, 34, 40],
            [2014, 15489, 23, 24],
            [2014, 15490, 97, 88],
            [2014, 15491, 47, 41],
            [2014, 15492, 35, 38],
            [2014, 15493, 15, 37],
            [2014, 15494, 33, 35],
            [2014, 15495, 60, 45],
            [2014, 15496, 21, 28],
            [2014, 15497, 25, 25],
            [2014, 15498, 16, 18],
            [2014, 15499, 28, 25],
            [2014, 15500, 14, 12],
            [2014, 15501, 15, 12],
            [2014, 15502, 15, 12],
            [2014, 15503, 14, 11],
            [2014, 15504, 14, 13],
            [2014, 15505, 60, 52],
            [2014, 15506, 30, 66],
            [2014, 15507, 58, 48],
            [2014, 15508, 58, 48],
            [2014, 15509, 38, 38],
            [2014, 15510, 38, 38],
            [2014, 15511, 72, 54],
            [2014, 15512, 68, 68],
            [2014, 15513, 21, 40],
            [2014, 15514, 38, 64],
            [2014, 15515, 38, 58],
            [2014, 15516, 32, 36],
            [2014, 15517, 68, 68],
            [2014, 15518, 36, 37],
            [2014, 15519, 30, 55],
            [2014, 15520, 40, 58],
            [2014, 15521, 52, 53],
            [2014, 15522, 80, 66],
            [2014, 15523, 80, 66],
            [2014, 15524, 28, 52],
            [2014, 15525, 40, 66],
            [2014, 15526, 28, 28],
            [2014, 15527, 28, 38],
            [2014, 15528, 20, 37],
            [2014, 15529, 38, 60],
            [2014, 15530, 88, 80],
            [2014, 15531, 88, 80],
            [2014, 15532, 68, 68],
            [2014, 15533, 28, 60],
            [2014, 15534, 56, 60],
            [2014, 15535, 68, 68],
            [2014, 15536, 38, 44],
            [2014, 15537, 14, 12],
            [2014, 15538, 29, 25],
            [2014, 15539, 16, 19],
            [2014, 15540, 11, 17],
            [2014, 15541, 20, 18],
            [2014, 15542, 42, 42],
            [2014, 15543, 36, 26],
            [2014, 15544, 5, 5],
            [2014, 15548, 11, 9],
            [2014, 15550, 4, 4],
            [2014, 15551, 6, 6],
            [2014, 15552, 12, 10],
            [2014, 15553, 10, 8],
            [2014, 15554, 12, 10],
            [2014, 15555, 7, 7],
            [2014, 15556, 12, 9],
            [2014, 15557, 16, 10],
            [2014, 15558, 7, 8],
            [2014, 15559, 7, 7],
            [2014, 15560, 92, 32],
            [2014, 15561, 24, 19],
            [2014, 15562, 21, 29],
            [2014, 15563, 11, 10],
            [2014, 15564, 11, 10],
            [2014, 15565, 20, 15],
            [2014, 15566, 22, 16],
            [2014, 15567, 12, 9],
            [2014, 15568, 12, 10],
            [2014, 15569, 15, 13],
            [2014, 15570, 16, 14],
            [2014, 15571, 15, 14],
            [2014, 15572, 14, 13],
            [2014, 15573, 5, 6],
            [2014, 15574, 19, 11],
            [2014, 15575, 5, 7],
            [2014, 15576, 7, 9],
            [2014, 15577, 9, 10],
            [2014, 15578, 8, 9],
            [2014, 15579, 9, 7],
            [2014, 15580, 9, 8],
            [2014, 15581, 8, 7],
            [2014, 15582, 8, 7],
            [2014, 15583, 6, 6],
            [2014, 15584, 10, 8],
            [2014, 15585, 10, 8],
            [2014, 15586, 8, 8],
            [2014, 15587, 8, 8],
            [2014, 15588, 8, 8],
            [2014, 15589, 12, 10],
            [2014, 15590, 11, 10],
            [2014, 15591, 10, 9],
            [2014, 15592, 16, 15],
            [2014, 15593, 17, 11],
            [2014, 15594, 19, 13],
            [2014, 15595, 10, 9],
            [2014, 15596, 25, 14],
            [2014, 15597, 11, 9],
            [2014, 15598, 8, 7],
            [2014, 15599, 14, 10],
            [2014, 15600, 18, 15],
            [2014, 15601, 18, 15],
            [2014, 15602, 15, 12],
            [2014, 15603, 8, 7],
            [2014, 15604, 9, 7],
            [2014, 15605, 6, 7],
            [2014, 15606, 5, 6],
            [2014, 15607, 9, 8],
            [2014, 15608, 8, 6],
            [2014, 15609, 6, 6],
            [2014, 15610, 9, 7],
            [2014, 15611, 8, 6],
            [2014, 15612, 10, 12],
            [2014, 15613, 9, 8],
            [2014, 15614, 13, 13],
            [2014, 15615, 12, 10],
            [2014, 15616, 17, 14],
            [2014, 15617, 12, 11],
            [2014, 15618, 9, 8],
            [2014, 15619, 9, 8],
            [2014, 15620, 36, 28],
            [2014, 15621, 12, 10],
            [2014, 15622, 36, 28],
            [2014, 15623, 9, 10],
            [2014, 15624, 12, 12],
            [2014, 15625, 12, 10],
            [2014, 15626, 14, 12],
            [2014, 15627, 23, 13],
            [2014, 15628, 8, 8],
            [2014, 15629, 8, 9],
            [2014, 15630, 7, 9],
            [2014, 15631, 8, 8],
            [2014, 15632, 22, 13],
            [2014, 15633, 46, 37],
            [2014, 15634, 71, 46],
            [2014, 15635, 81, 56],
            [2014, 15636, 27, 17],
            [2014, 15637, 71, 46],
            [2014, 15638, 53, 36],
            [2014, 15639, 61, 46],
            [2014, 15640, 17, 12],
            [2014, 15641, 13, 11],
            [2014, 15642, 11, 10],
            [2014, 15643, 13, 11],
            [2014, 15644, 17, 12],
            [2014, 15645, 18, 12],
            [2014, 15646, 17, 11],
            [2014, 15647, 11, 10],
            [2014, 15648, 17, 13],
            [2014, 15649, 20, 15],
            [2014, 15650, 13, 9],
            [2014, 15651, 9, 6],
            [2014, 15652, 11, 7],
            [2014, 15653, 9, 6],
            [2014, 15654, 16, 12],
            [2014, 15655, 18, 13],
            [2014, 15656, 11, 7],
            [2014, 15657, 20, 13],
            [2014, 15658, 23, 12],
            [2014, 15659, 23, 12],
            [2014, 15660, 15, 12],
            [2014, 15661, 20, 14],
            [2014, 15662, 20, 13],
            [2014, 15663, 20, 14],
            [2014, 15664, 15, 12],
            [2014, 15665, 6, 6],
            [2014, 15666, 6, 6],
            [2014, 15667, 5, 5],
            [2014, 15668, 14, 12],
            [2014, 15669, 17, 10],
            [2014, 15670, 17, 10],
            [2014, 15671, 5, 5],
            [2014, 15672, 13, 12],
            [2014, 15673, 6, 6],
            [2014, 15674, 21, 14],
            [2014, 15675, 14, 12],
            [2014, 15676, 21, 14],
            [2014, 15677, 11, 9],
            [2014, 15678, 12, 10],
            [2014, 15679, 11, 9],
            [2014, 15680, 29, 17],
            [2014, 15681, 12, 10],
            [2014, 15682, 10, 8],
            [2014, 15683, 12, 9],
            [2014, 15684, 10, 8],
            [2014, 15685, 29, 17],
            [2014, 15686, 26, 19],
            [2014, 15687, 7, 7],
            [2014, 15688, 7, 7],
            [2014, 15689, 2, 1],
            [2014, 15690, 2, 1],
            [2014, 15691, 10, 7],
            [2014, 15692, 10, 6],
            [2014, 15693, 10, 8],
            [2014, 15694, 10, 8],
            [2014, 15695, 10, 8],
            [2014, 15696, 11, 8],
            [2014, 15697, 19, 18],
            [2014, 15698, 18, 16],
            [2014, 15699, 11, 10],
            [2014, 15700, 11, 10],
            [2014, 15701, 26, 14],
            [2014, 15702, 27, 15],
            [2014, 15703, 27, 15],
            [2014, 15704, 22, 13],
            [2014, 15705, 32, 17],
            [2014, 15706, 27, 15],
            [2014, 15707, 22, 13],
            [2014, 15708, 10, 7],
            [2014, 15709, 10, 7],
            [2014, 15710, 12, 10],
            [2014, 15711, 12, 10],
            [2014, 15712, 12, 9],
            [2014, 15713, 7, 5],
            [2014, 15714, 7, 5],
            [2014, 15715, 7, 5],
            [2014, 15716, 9, 6],
            [2014, 15717, 8, 6],
            [2014, 15718, 8, 6],
            [2014, 15719, 8, 5],
            [2014, 15720, 9, 6],
            [2014, 15721, 27, 13],
            [2014, 15722, 27, 13],
            [2014, 15723, 15, 12],
            [2014, 15724, 17, 12],
            [2014, 15725, 33, 28],
            [2014, 15726, 46, 38],
            [2014, 15727, 23, 14],
            [2014, 15728, 23, 18],
            [2014, 15729, 10, 11],
            [2014, 15730, 12, 15],
            [2014, 15731, 22, 18],
            [2014, 15732, 22, 28],
            [2014, 15733, 22, 16],
            [2014, 15734, 23, 17],
            [2014, 15735, 21, 20],
            [2014, 15736, 21, 20],
            [2014, 15737, 10, 11],
            [2014, 15738, 15, 15],
            [2014, 15739, 15, 15],
            [2014, 15740, 13, 12],
            [2014, 15741, 13, 12],
            [2014, 15742, 16, 12],
            [2014, 15743, 17, 13],
            [2014, 15744, 14, 21],
            [2014, 15745, 12, 21],
            [2014, 15746, 29, 23],
            [2014, 15747, 22, 16],
            [2014, 15748, 22, 16],
            [2014, 15749, 29, 23],
            [2014, 15750, 29, 21],
            [2014, 15751, 11, 12],
            [2014, 15752, 13, 11],
            [2014, 15753, 12, 9],
            [2014, 15754, 21, 21],
            [2014, 15755, 24, 15],
            [2014, 15756, 23, 14],
            [2014, 15757, 13, 10],
            [2014, 15758, 13, 9],
            [2014, 15759, 18, 15],
            [2014, 15760, 27, 19],
            [2014, 15761, 41, 23],
            [2014, 15762, 13, 10],
            [2014, 15763, 13, 11],
            [2014, 15764, 12, 9],
            [2014, 15765, 11, 8],
            [2014, 15766, 21, 21],
            [2014, 15767, 24, 15],
            [2014, 15768, 16, 10],
            [2014, 15769, 13, 10],
            [2014, 15770, 18, 15],
            [2014, 15771, 41, 23],
            [2014, 15772, 27, 19],
            [2014, 15773, 13, 9],
            [2014, 15774, 16, 10],
            [2014, 15775, 20, 14],
            [2014, 15776, 16, 10],
            [2014, 15777, 19, 13],
            [2014, 15778, 16, 10],
            [2014, 15779, 7, 10],
            [2014, 15780, 10, 10],
            [2014, 15781, 10, 10],
            [2014, 15782, 7, 9],
            [2014, 15783, 10, 10],
            [2014, 15784, 7, 7],
            [2014, 15785, 7, 9],
            [2014, 15786, 10, 10],
            [2014, 15787, 7, 10],
            [2014, 15788, 16, 11],
            [2014, 15789, 20, 13],
            [2014, 15790, 20, 14],
            [2014, 15791, 8, 9],
            [2014, 15792, 10, 10],
            [2014, 15793, 7, 7],
            [2014, 15794, 11, 11],
            [2014, 15795, 20, 14],
            [2014, 15796, 9, 9],
            [2014, 15797, 10, 10],
            [2014, 15798, 16, 14],
            [2014, 15799, 14, 14],
            [2014, 15800, 19, 16],
            [2014, 15801, 36, 21],
            [2014, 15802, 17, 14],
            [2014, 15803, 17, 14],
            [2014, 15804, 37, 18],
            [2014, 15805, 24, 16],
            [2014, 15806, 38, 25],
            [2014, 15807, 18, 15],
            [2014, 15808, 14, 12],
            [2014, 15809, 18, 15],
            [2014, 15810, 19, 14],
            [2014, 15811, 19, 14],
            [2015, 964, 9, 8],
            [2015, 2142, 10, 9],
            [2015, 2922, 8, 8],
            [2015, 4536, 11, 10],
            [2015, 5273, 12, 10],
            [2015, 11581, 9, 9],
            [2015, 11582, 13, 11],
            [2015, 12312, 134, 84],
            [2015, 12313, 92, 72],
            [2015, 12314, 92, 72],
            [2015, 12315, 134, 84],
            [2015, 12316, 134, 84],
            [2015, 12317, 134, 84],
            [2015, 12318, 134, 84],
            [2015, 12319, 134, 84],
            [2015, 12320, 92, 72],
            [2015, 12321, 62, 66],
            [2015, 12322, 134, 84],
            [2015, 12323, 134, 84],
            [2015, 12324, 92, 72],
            [2015, 12325, 92, 72],
            [2015, 12474, 16, 15],
            [2015, 12475, 24, 15],
            [2015, 12476, 14, 12],
            [2015, 12477, 23, 16],
            [2015, 12478, 23, 18],
            [2015, 12479, 19, 19],
            [2015, 12480, 14, 12],
            [2015, 12481, 57, 34],
            [2015, 12482, 16, 13],
            [2015, 12483, 47, 39],
            [2015, 12484, 17, 13],
            [2015, 12485, 77, 37],
            [2015, 12486, 89, 35],
            [2015, 12487, 41, 24],
            [2015, 12488, 46, 32],
            [2015, 12489, 66, 19],
            [2015, 12523, 16, 10],
            [2015, 12524, 32, 20],
            [2015, 12525, 19, 15],
            [2015, 12526, 13, 11],
            [2015, 12527, 9, 9],
            [2015, 12528, 9, 9],
            [2015, 12529, 9, 10],
            [2015, 12530, 14, 9],
            [2015, 12532, 14, 10],
            [2015, 12534, 10, 10],
            [2015, 12535, 17, 12],
            [2015, 12536, 10, 9],
            [2015, 12537, 9, 9],
            [2015, 12538, 10, 11],
            [2015, 12539, 13, 9],
            [2015, 12540, 12, 11],
            [2015, 12541, 14, 11],
            [2015, 12542, 12, 12],
            [2015, 12543, 16, 14],
            [2015, 12545, 9, 9],
            [2015, 12546, 20, 18],
            [2015, 12547, 16, 14],
            [2015, 12548, 26, 18],
            [2015, 12549, 10, 9],
            [2015, 12550, 10, 9],
            [2015, 12551, 20, 14],
            [2015, 12552, 24, 15],
            [2015, 12553, 15, 11],
            [2015, 12554, 8, 9],
            [2015, 12556, 8, 8],
            [2015, 12557, 9, 11],
            [2015, 12558, 10, 12],
            [2015, 12559, 10, 9],
            [2015, 12560, 4, 5],
            [2015, 12561, 6, 7],
            [2015, 12562, 8, 9],
            [2015, 12563, 12, 9],
            [2015, 12565, 18, 12],
            [2015, 12566, 11, 9],
            [2015, 12567, 9, 9],
            [2015, 12568, 23, 21],
            [2015, 12569, 25, 22],
            [2015, 12570, 16, 15],
            [2015, 12571, 30, 16],
            [2015, 12573, 19, 16],
            [2015, 12574, 9, 9],
            [2015, 12575, 11, 9],
            [2015, 12576, 22, 15],
            [2015, 12577, 9, 9],
            [2015, 12578, 24, 20],
            [2015, 12579, 11, 14],
            [2015, 12580, 12, 12],
            [2015, 12581, 92, 90],
            [2015, 12582, 105, 121],
            [2015, 12583, 90, 93],
            [2015, 12584, 96, 75],
            [2015, 12585, 100, 92],
            [2015, 12586, 50, 18],
            [2015, 12589, 49, 39],
            [2015, 12590, 38, 27],
            [2015, 12591, 51, 44],
            [2015, 12592, 59, 45],
            [2015, 12593, 42, 28],
            [2015, 12594, 31, 25],
            [2015, 12595, 51, 54],
            [2015, 12596, 23, 21],
            [2015, 12597, 23, 19],
            [2015, 12598, 53, 44],
            [2015, 12599, 50, 44],
            [2015, 12600, 53, 42],
            [2015, 12634, 26, 20],
            [2015, 12635, 62, 47],
            [2015, 12636, 19, 19],
            [2015, 12637, 34, 16],
            [2015, 12638, 57, 21],
            [2015, 12639, 9, 8],
            [2015, 12640, 11, 9],
            [2015, 12641, 17, 17],
            [2015, 12642, 15, 15],
            [2015, 12643, 29, 23],
            [2015, 12644, 26, 18],
            [2015, 12645, 39, 37],
            [2015, 12646, 28, 26],
            [2015, 12647, 16, 21],
            [2015, 12648, 25, 20],
            [2015, 12649, 23, 19],
            [2015, 12650, 19, 18],
            [2015, 12651, 29, 22],
            [2015, 12652, 31, 24],
            [2015, 12653, 35, 30],
            [2015, 12654, 15, 15],
            [2015, 12655, 28, 23],
            [2015, 12656, 30, 21],
            [2015, 12657, 16, 15],
            [2015, 12658, 37, 28],
            [2015, 12660, 40, 30],
            [2015, 12661, 36, 30],
            [2015, 12662, 34, 27],
            [2015, 12663, 35, 25],
            [2015, 12664, 43, 33],
            [2015, 12665, 34, 29],
            [2015, 12668, 5, 4],
            [2015, 12669, 4, 4],
            [2015, 12670, 7, 7],
            [2015, 12671, 11, 10],
            [2015, 12672, 11, 11],
            [2015, 12673, 11, 11],
            [2015, 12674, 9, 8],
            [2015, 12675, 13, 12],
            [2015, 12680, 14, 11],
            [2015, 12681, 5, 4],
            [2015, 12682, 13, 10],
            [2015, 12683, 11, 9],
            [2015, 12685, 31, 21],
            [2015, 12686, 19, 15],
            [2015, 12687, 21, 17],
            [2015, 12688, 19, 16],
            [2015, 12689, 28, 18],
            [2015, 12690, 29, 18],
            [2015, 12691, 31, 19],
            [2015, 12692, 29, 20],
            [2015, 12693, 26, 17],
            [2015, 12695, 30, 18],
            [2015, 12696, 28, 16],
            [2015, 12697, 28, 19],
            [2015, 12699, 9, 7],
            [2015, 12703, 27, 26],
            [2015, 12704, 17, 11],
            [2015, 12705, 23, 13],
            [2015, 12706, 26, 20],
            [2015, 12707, 29, 21],
            [2015, 12708, 22, 16],
            [2015, 12709, 31, 21],
            [2015, 12710, 35, 22],
            [2015, 12711, 33, 23],
            [2015, 12712, 35, 28],
            [2015, 12713, 29, 25],
            [2015, 12714, 37, 24],
            [2015, 12715, 37, 26],
            [2015, 12716, 23, 18],
            [2015, 12717, 26, 21],
            [2015, 12718, 20, 14],
            [2015, 12719, 24, 17],
            [2015, 12720, 25, 17],
            [2015, 12721, 25, 15],
            [2015, 12722, 11, 10],
            [2015, 12723, 16, 14],
            [2015, 12724, 10, 9],
            [2015, 12725, 10, 11],
            [2015, 12726, 8, 8],
            [2015, 12727, 16, 22],
            [2015, 12728, 9, 9],
            [2015, 12729, 17, 25],
            [2015, 12730, 21, 11],
            [2015, 12731, 16, 23],
            [2015, 12732, 12, 12],
            [2015, 12735, 10, 10],
            [2015, 12736, 14, 13],
            [2015, 12737, 21, 12],
            [2015, 12738, 9, 9],
            [2015, 12739, 11, 12],
            [2015, 12740, 14, 15],
            [2015, 12741, 15, 14],
            [2015, 12742, 7, 7],
            [2015, 12743, 20, 12],
            [2015, 12744, 10, 10],
            [2015, 12745, 11, 12],
            [2015, 12746, 8, 9],
            [2015, 12747, 10, 11],
            [2015, 12748, 8, 10],
            [2015, 12749, 9, 11],
            [2015, 12750, 7, 7],
            [2015, 12751, 6, 7],
            [2015, 12752, 19, 13],
            [2015, 12753, 9, 10],
            [2015, 12754, 8, 8],
            [2015, 12755, 6, 6],
            [2015, 12756, 11, 9],
            [2015, 12757, 6, 7],
            [2015, 12758, 10, 10],
            [2015, 12759, 13, 12],
            [2015, 12760, 20, 14],
            [2015, 12761, 9, 10],
            [2015, 12762, 8, 8],
            [2015, 12763, 11, 13],
            [2015, 12765, 9, 8],
            [2015, 12766, 12, 13],
            [2015, 12767, 11, 14],
            [2015, 12768, 10, 10],
            [2015, 12770, 8, 10],
            [2015, 12771, 15, 13],
            [2015, 12772, 10, 10],
            [2015, 12773, 9, 9],
            [2015, 12775, 14, 15],
            [2015, 12776, 16, 15],
            [2015, 12777, 8, 7],
            [2015, 12778, 15, 16],
            [2015, 12779, 12, 12],
            [2015, 12780, 8, 8],
            [2015, 12781, 16, 16],
            [2015, 12782, 10, 11],
            [2015, 12783, 8, 7],
            [2015, 12784, 16, 16],
            [2015, 12785, 20, 13],
            [2015, 12786, 9, 9],
            [2015, 12787, 14, 15],
            [2015, 12788, 7, 8],
            [2015, 12789, 11, 13],
            [2015, 12790, 15, 12],
            [2015, 12791, 11, 8],
            [2015, 12792, 13, 12],
            [2015, 12793, 11, 10],
            [2015, 12795, 12, 10],
            [2015, 12796, 9, 9],
            [2015, 12797, 10, 8],
            [2015, 12798, 8, 11],
            [2015, 12799, 7, 8],
            [2015, 12800, 17, 10],
            [2015, 12801, 8, 6],
            [2015, 12802, 9, 8],
            [2015, 12803, 63, 39],
            [2015, 12804, 12, 11],
            [2015, 12805, 16, 10],
            [2015, 12806, 10, 10],
            [2015, 12807, 27, 14],
            [2015, 12808, 12, 12],
            [2015, 12809, 6, 9],
            [2015, 12810, 13, 14],
            [2015, 12811, 10, 11],
            [2015, 12812, 15, 12],
            [2015, 12813, 9, 9],
            [2015, 12814, 10, 11],
            [2015, 12815, 12, 10],
            [2015, 12816, 7, 8],
            [2015, 12817, 10, 9],
            [2015, 12818, 9, 9],
            [2015, 12819, 12, 15],
            [2015, 12820, 10, 9],
            [2015, 12821, 7, 4],
            [2015, 12822, 10, 10],
            [2015, 12823, 5, 4],
            [2015, 12824, 9, 11],
            [2015, 12825, 9, 8],
            [2015, 12826, 7, 6],
            [2015, 12827, 28, 15],
            [2015, 12828, 9, 7],
            [2015, 12829, 10, 10],
            [2015, 12830, 9, 5],
            [2015, 12831, 60, 41],
            [2015, 12832, 18, 16],
            [2015, 12833, 8, 5],
            [2015, 12834, 23, 13],
            [2015, 12835, 5, 4],
            [2015, 12836, 16, 9],
            [2015, 12837, 5, 4],
            [2015, 12838, 8, 5],
            [2015, 12839, 5, 4],
            [2015, 12840, 15, 8],
            [2015, 12841, 3, 2],
            [2015, 12843, 5, 5],
            [2015, 12845, 9, 6],
            [2015, 12847, 19, 12],
            [2015, 12848, 10, 8],
            [2015, 12849, 7, 8],
            [2015, 12850, 21, 10],
            [2015, 12851, 12, 8],
            [2015, 12852, 8, 8],
            [2015, 12853, 6, 4],
            [2015, 12854, 25, 16],
            [2015, 12855, 4, 3],
            [2015, 12856, 14, 8],
            [2015, 12857, 8, 6],
            [2015, 12858, 3, 2],
            [2015, 12860, 14, 10],
            [2015, 12861, 6, 4],
            [2015, 12862, 5, 5],
            [2015, 12863, 66, 29],
            [2015, 12864, 5, 4],
            [2015, 12865, 28, 12],
            [2015, 12866, 5, 4],
            [2015, 12867, 59, 23],
            [2015, 12868, 8, 5],
            [2015, 12869, 10, 9],
            [2015, 12870, 6, 5],
            [2015, 12871, 41, 16],
            [2015, 12872, 8, 6],
            [2015, 12873, 11, 9],
            [2015, 12874, 6, 5],
            [2015, 12875, 58, 33],
            [2015, 12876, 10, 7],
            [2015, 12877, 6, 5],
            [2015, 12878, 10, 8],
            [2015, 12879, 8, 8],
            [2015, 12880, 6, 5],
            [2015, 12881, 11, 8],
            [2015, 12882, 10, 8],
            [2015, 12883, 5, 4],
            [2015, 12884, 33, 20],
            [2015, 12885, 3, 2],
            [2015, 12886, 21, 15],
            [2015, 12887, 5, 4],
            [2015, 12888, 13, 10],
            [2015, 12889, 75, 35],
            [2015, 12890, 7, 4],
            [2015, 12891, 33, 18],
            [2015, 12892, 9, 7],
            [2015, 12893, 8, 5],
            [2015, 12894, 15, 11],
            [2015, 12895, 6, 5],
            [2015, 12896, 31, 16],
            [2015, 12897, 8, 6],
            [2015, 12898, 16, 10],
            [2015, 12899, 15, 11],
            [2015, 12900, 8, 6],
            [2015, 12901, 24, 13],
            [2015, 12902, 7, 5],
            [2015, 12903, 22, 23],
            [2015, 12904, 11, 8],
            [2015, 12905, 25, 16],
            [2015, 12906, 10, 7],
            [2015, 12907, 13, 11],
            [2015, 12908, 10, 8],
            [2015, 12909, 5, 4],
            [2015, 12910, 9, 6],
            [2015, 12911, 4, 4],
            [2015, 12912, 11, 8],
            [2015, 12913, 7, 6],
            [2015, 12914, 7, 5],
            [2015, 12915, 4, 3],
            [2015, 12916, 7, 5],
            [2015, 12917, 10, 8],
            [2015, 12918, 4, 3],
            [2015, 12919, 6, 4],
            [2015, 12920, 15, 12],
            [2015, 12921, 13, 10],
            [2015, 12922, 9, 7],
            [2015, 12923, 8, 6],
            [2015, 12924, 10, 8],
            [2015, 12925, 6, 5],
            [2015, 12926, 6, 5],
            [2015, 12927, 11, 9],
            [2015, 12928, 19, 12],
            [2015, 12929, 7, 5],
            [2015, 12930, 8, 6],
            [2015, 12931, 7, 5],
            [2015, 12932, 9, 6],
            [2015, 12933, 6, 4],
            [2015, 12934, 9, 6],
            [2015, 12935, 7, 6],
            [2015, 12936, 4, 3],
            [2015, 12937, 9, 6],
            [2015, 12938, 7, 5],
            [2015, 12939, 3, 2],
            [2015, 12940, 5, 4],
            [2015, 12941, 11, 8],
            [2015, 12942, 9, 7],
            [2015, 12943, 7, 6],
            [2015, 12944, 6, 5],
            [2015, 12945, 4, 3],
            [2015, 12946, 6, 4],
            [2015, 12947, 9, 6],
            [2015, 12948, 6, 5],
            [2015, 12949, 6, 5],
            [2015, 12950, 8, 6],
            [2015, 12951, 8, 6],
            [2015, 12952, 15, 12],
            [2015, 12953, 11, 10],
            [2015, 12954, 10, 7],
            [2015, 12955, 6, 5],
            [2015, 12956, 5, 4],
            [2015, 12957, 8, 6],
            [2015, 12958, 7, 6],
            [2015, 12959, 6, 4],
            [2015, 12960, 7, 5],
            [2015, 12961, 6, 4],
            [2015, 12962, 8, 5],
            [2015, 12963, 5, 4],
            [2015, 12964, 9, 6],
            [2015, 12965, 14, 11],
            [2015, 12966, 10, 7],
            [2015, 12967, 9, 7],
            [2015, 12968, 11, 9],
            [2015, 12969, 7, 5],
            [2015, 12970, 7, 5],
            [2015, 12971, 8, 6],
            [2015, 12972, 6, 5],
            [2015, 12973, 6, 4],
            [2015, 12974, 8, 5],
            [2015, 12975, 6, 5],
            [2015, 12976, 6, 5],
            [2015, 12977, 4, 3],
            [2015, 12978, 10, 7],
            [2015, 12979, 11, 8],
            [2015, 12980, 7, 5],
            [2015, 12981, 8, 5],
            [2015, 12982, 9, 8],
            [2015, 12983, 8, 5],
            [2015, 12984, 5, 4],
            [2015, 12985, 8, 6],
            [2015, 12986, 5, 4],
            [2015, 12987, 8, 6],
            [2015, 12988, 13, 11],
            [2015, 12989, 11, 8],
            [2015, 12990, 8, 5],
            [2015, 12991, 6, 5],
            [2015, 12992, 6, 5],
            [2015, 12993, 4, 3],
            [2015, 12994, 7, 5],
            [2015, 12995, 5, 4],
            [2015, 12996, 7, 5],
            [2015, 12997, 8, 5],
            [2015, 12998, 6, 5],
            [2015, 12999, 7, 5],
            [2015, 13000, 6, 5],
            [2015, 13001, 11, 11],
            [2015, 13002, 13, 12],
            [2015, 13004, 21, 15],
            [2015, 13006, 20, 16],
            [2015, 13007, 16, 15],
            [2015, 13008, 22, 16],
            [2015, 13009, 17, 15],
            [2015, 13010, 17, 15],
            [2015, 13011, 28, 17],
            [2015, 13012, 20, 17],
            [2015, 13013, 13, 12],
            [2015, 13014, 16, 16],
            [2015, 13015, 11, 14],
            [2015, 13016, 14, 12],
            [2015, 13017, 8, 4],
            [2015, 13018, 16, 16],
            [2015, 13019, 14, 7],
            [2015, 13020, 9, 13],
            [2015, 13021, 13, 16],
            [2015, 13022, 9, 4],
            [2015, 13023, 17, 12],
            [2015, 13024, 26, 19],
            [2015, 13025, 10, 15],
            [2015, 13026, 17, 11],
            [2015, 13027, 15, 10],
            [2015, 13028, 7, 4],
            [2015, 13029, 13, 13],
            [2015, 13030, 13, 13],
            [2015, 13031, 10, 10],
            [2015, 13032, 20, 16],
            [2015, 13033, 9, 7],
            [2015, 13034, 6, 4],
            [2015, 13035, 8, 4],
            [2015, 13036, 16, 7],
            [2015, 13037, 8, 5],
            [2015, 13038, 18, 12],
            [2015, 13039, 11, 10],
            [2015, 13040, 15, 13],
            [2015, 13041, 13, 11],
            [2015, 13042, 6, 8],
            [2015, 13043, 8, 5],
            [2015, 13044, 13, 16],
            [2015, 13045, 6, 8],
            [2015, 13046, 16, 13],
            [2015, 13047, 17, 16],
            [2015, 13048, 11, 9],
            [2015, 13049, 12, 10],
            [2015, 13050, 11, 10],
            [2015, 13051, 14, 14],
            [2015, 13052, 10, 11],
            [2015, 13053, 9, 7],
            [2015, 13054, 15, 16],
            [2015, 13055, 18, 12],
            [2015, 13056, 13, 13],
            [2015, 13057, 14, 12],
            [2015, 13058, 16, 15],
            [2015, 13059, 11, 7],
            [2015, 13060, 15, 11],
            [2015, 13061, 17, 14],
            [2015, 13062, 12, 9],
            [2015, 13063, 25, 5],
            [2015, 13064, 9, 11],
            [2015, 13065, 12, 12],
            [2015, 13066, 11, 9],
            [2015, 13067, 14, 12],
            [2015, 13068, 13, 15],
            [2015, 13069, 19, 14],
            [2015, 13070, 9, 4],
            [2015, 13071, 11, 6],
            [2015, 13072, 9, 11],
            [2015, 13073, 9, 9],
            [2015, 13074, 11, 11],
            [2015, 13075, 17, 16],
            [2015, 13076, 11, 7],
            [2015, 13077, 23, 16],
            [2015, 13078, 29, 23],
            [2015, 13079, 10, 12],
            [2015, 13080, 11, 7],
            [2015, 13081, 13, 12],
            [2015, 13082, 7, 7],
            [2015, 13083, 13, 8],
            [2015, 13084, 21, 14],
            [2015, 13085, 24, 15],
            [2015, 13086, 6, 5],
            [2015, 13087, 14, 10],
            [2015, 13088, 17, 11],
            [2015, 13089, 11, 10],
            [2015, 13090, 11, 11],
            [2015, 13091, 7, 4],
            [2015, 13092, 22, 16],
            [2015, 13093, 12, 7],
            [2015, 13094, 26, 14],
            [2015, 13095, 12, 12],
            [2015, 13096, 9, 11],
            [2015, 13097, 15, 10],
            [2015, 13098, 12, 11],
            [2015, 13099, 7, 10],
            [2015, 13100, 19, 17],
            [2015, 13101, 16, 14],
            [2015, 13102, 17, 13],
            [2015, 13103, 18, 14],
            [2015, 13104, 17, 22],
            [2015, 13105, 15, 12],
            [2015, 13106, 16, 12],
            [2015, 13107, 14, 10],
            [2015, 13108, 15, 12],
            [2015, 13109, 11, 10],
            [2015, 13111, 15, 12],
            [2015, 13112, 12, 10],
            [2015, 13113, 15, 10],
            [2015, 13114, 11, 11],
            [2015, 13115, 14, 10],
            [2015, 13116, 15, 15],
            [2015, 13117, 15, 13],
            [2015, 13118, 12, 9],
            [2015, 13119, 20, 15],
            [2015, 13120, 11, 7],
            [2015, 13121, 15, 16],
            [2015, 13122, 25, 13],
            [2015, 13123, 15, 12],
            [2015, 13124, 11, 11],
            [2015, 13125, 10, 8],
            [2015, 13126, 19, 14],
            [2015, 13127, 15, 12],
            [2015, 13128, 11, 11],
            [2015, 13129, 21, 16],
            [2015, 13130, 16, 12],
            [2015, 13131, 12, 10],
            [2015, 13132, 12, 10],
            [2015, 13133, 17, 12],
            [2015, 13134, 15, 11],
            [2015, 13136, 14, 16],
            [2015, 13137, 18, 16],
            [2015, 13138, 14, 10],
            [2015, 13139, 6, 5],
            [2015, 13140, 14, 9],
            [2015, 13141, 9, 7],
            [2015, 13142, 8, 7],
            [2015, 13143, 8, 6],
            [2015, 13144, 10, 9],
            [2015, 13145, 6, 6],
            [2015, 13147, 11, 8],
            [2015, 13148, 10, 9],
            [2015, 13149, 7, 6],
            [2015, 13150, 9, 8],
            [2015, 13152, 10, 8],
            [2015, 13153, 7, 6],
            [2015, 13154, 7, 7],
            [2015, 13155, 8, 7],
            [2015, 13156, 8, 7],
            [2015, 13158, 7, 6],
            [2015, 13159, 9, 7],
            [2015, 13160, 9, 7],
            [2015, 13161, 7, 7],
            [2015, 13163, 10, 7],
            [2015, 13164, 8, 7],
            [2015, 13165, 9, 7],
            [2015, 13166, 8, 7],
            [2015, 13167, 15, 9],
            [2015, 13168, 7, 6],
            [2015, 13169, 11, 8],
            [2015, 13170, 12, 9],
            [2015, 13171, 10, 8],
            [2015, 13172, 7, 6],
            [2015, 13173, 10, 8],
            [2015, 13174, 9, 7],
            [2015, 13175, 7, 6],
            [2015, 13176, 8, 7],
            [2015, 13177, 9, 8],
            [2015, 13178, 10, 8],
            [2015, 13179, 9, 7],
            [2015, 13180, 13, 9],
            [2015, 13181, 7, 7],
            [2015, 13182, 8, 7],
            [2015, 13183, 28, 19],
            [2015, 13184, 7, 6],
            [2015, 13185, 10, 10],
            [2015, 13186, 14, 13],
            [2015, 13187, 7, 10],
            [2015, 13188, 7, 9],
            [2015, 13189, 11, 9],
            [2015, 13190, 7, 9],
            [2015, 13191, 19, 13],
            [2015, 13192, 9, 10],
            [2015, 13193, 8, 10],
            [2015, 13194, 11, 9],
            [2015, 13195, 22, 14],
            [2015, 13196, 16, 10],
            [2015, 13197, 77, 28],
            [2015, 13198, 12, 9],
            [2015, 13200, 18, 12],
            [2015, 13201, 15, 11],
            [2015, 13202, 19, 12],
            [2015, 13203, 8, 8],
            [2015, 13204, 21, 12],
            [2015, 13205, 9, 10],
            [2015, 13206, 14, 11],
            [2015, 13207, 11, 10],
            [2015, 13208, 10, 10],
            [2015, 13209, 8, 7],
            [2015, 13210, 21, 15],
            [2015, 13211, 12, 10],
            [2015, 13212, 55, 30],
            [2015, 13213, 25, 15],
            [2015, 13214, 18, 14],
            [2015, 13216, 19, 14],
            [2015, 13218, 13, 11],
            [2015, 13219, 10, 10],
            [2015, 13220, 9, 10],
            [2015, 13222, 9, 10],
            [2015, 13223, 17, 13],
            [2015, 13224, 51, 21],
            [2015, 13225, 14, 10],
            [2015, 13226, 9, 10],
            [2015, 13227, 18, 13],
            [2015, 13230, 22, 14],
            [2015, 13232, 13, 11],
            [2015, 13233, 14, 11],
            [2015, 13234, 17, 11],
            [2015, 13235, 14, 10],
            [2015, 13236, 10, 8],
            [2015, 13237, 8, 6],
            [2015, 13238, 13, 11],
            [2015, 13239, 16, 10],
            [2015, 13240, 14, 11],
            [2015, 13241, 12, 10],
            [2015, 13242, 15, 11],
            [2015, 13243, 17, 11],
            [2015, 13244, 20, 13],
            [2015, 13245, 13, 11],
            [2015, 13246, 14, 10],
            [2015, 13247, 18, 12],
            [2015, 13248, 11, 9],
            [2015, 13249, 10, 7],
            [2015, 13250, 17, 12],
            [2015, 13251, 14, 11],
            [2015, 13252, 18, 12],
            [2015, 13253, 13, 11],
            [2015, 13254, 11, 9],
            [2015, 13255, 10, 8],
            [2015, 13256, 12, 10],
            [2015, 13257, 15, 10],
            [2015, 13258, 20, 13],
            [2015, 13259, 19, 11],
            [2015, 13260, 14, 10],
            [2015, 13261, 16, 11],
            [2015, 13262, 17, 12],
            [2015, 13263, 14, 11],
            [2015, 13264, 14, 11],
            [2015, 13265, 22, 15],
            [2015, 13266, 14, 9],
            [2015, 13267, 31, 24],
            [2015, 13269, 12, 10],
            [2015, 13270, 17, 11],
            [2015, 13271, 12, 10],
            [2015, 13272, 8, 7],
            [2015, 13273, 13, 10],
            [2015, 13274, 9, 8],
            [2015, 13275, 12, 10],
            [2015, 13276, 10, 8],
            [2015, 13279, 29, 15],
            [2015, 13280, 12, 9],
            [2015, 13281, 12, 11],
            [2015, 13282, 13, 10],
            [2015, 13283, 18, 15],
            [2015, 13284, 16, 14],
            [2015, 13285, 14, 10],
            [2015, 13286, 17, 12],
            [2015, 13288, 19, 12],
            [2015, 13289, 16, 13],
            [2015, 13290, 8, 8],
            [2015, 13291, 13, 11],
            [2015, 13292, 8, 7],
            [2015, 13293, 15, 14],
            [2015, 13294, 13, 10],
            [2015, 13295, 19, 13],
            [2015, 13296, 14, 13],
            [2015, 13297, 14, 9],
            [2015, 13298, 15, 13],
            [2015, 13299, 9, 10],
            [2015, 13300, 11, 12],
            [2015, 13302, 13, 11],
            [2015, 13303, 12, 12],
            [2015, 13304, 17, 12],
            [2015, 13305, 12, 10],
            [2015, 13306, 7, 7],
            [2015, 13307, 20, 19],
            [2015, 13308, 13, 11],
            [2015, 13309, 8, 8],
            [2015, 13310, 15, 10],
            [2015, 13311, 9, 8],
            [2015, 13312, 16, 11],
            [2015, 13313, 41, 22],
            [2015, 13314, 27, 17],
            [2015, 13315, 16, 11],
            [2015, 13316, 10, 8],
            [2015, 13317, 10, 7],
            [2015, 13318, 9, 8],
            [2015, 13319, 16, 11],
            [2015, 13320, 21, 14],
            [2015, 13321, 12, 12],
            [2015, 13322, 12, 10],
            [2015, 13323, 24, 14],
            [2015, 13324, 6, 6],
            [2015, 13325, 12, 13],
            [2015, 13326, 15, 10],
            [2015, 13327, 18, 11],
            [2015, 13328, 12, 10],
            [2015, 13329, 12, 11],
            [2015, 13330, 14, 10],
            [2015, 13331, 16, 12],
            [2015, 13332, 12, 10],
            [2015, 13333, 11, 12],
            [2015, 13334, 10, 9],
            [2015, 13335, 26, 20],
            [2015, 13336, 12, 10],
            [2015, 13338, 12, 10],
            [2015, 13339, 10, 8],
            [2015, 13340, 15, 11],
            [2015, 13341, 9, 8],
            [2015, 13342, 9, 8],
            [2015, 13343, 12, 9],
            [2015, 13344, 10, 9],
            [2015, 13345, 20, 14],
            [2015, 13346, 8, 6],
            [2015, 13347, 19, 19],
            [2015, 13348, 17, 11],
            [2015, 13349, 28, 18],
            [2015, 13350, 14, 11],
            [2015, 13351, 8, 7],
            [2015, 13352, 10, 9],
            [2015, 13353, 16, 10],
            [2015, 13355, 15, 9],
            [2015, 13356, 8, 6],
            [2015, 13357, 23, 16],
            [2015, 13358, 12, 11],
            [2015, 13359, 28, 18],
            [2015, 13360, 10, 7],
            [2015, 13361, 27, 18],
            [2015, 13362, 12, 11],
            [2015, 13363, 16, 12],
            [2015, 13364, 10, 10],
            [2015, 13365, 10, 6],
            [2015, 13366, 9, 9],
            [2015, 13367, 10, 6],
            [2015, 13368, 16, 16],
            [2015, 13369, 13, 10],
            [2015, 13370, 13, 10],
            [2015, 13371, 15, 12],
            [2015, 13372, 13, 10],
            [2015, 13373, 9, 8],
            [2015, 13374, 12, 10],
            [2015, 13375, 12, 10],
            [2015, 13376, 8, 9],
            [2015, 13377, 14, 11],
            [2015, 13378, 11, 9],
            [2015, 13379, 12, 9],
            [2015, 13380, 13, 11],
            [2015, 13381, 8, 7],
            [2015, 13382, 14, 10],
            [2015, 13384, 16, 14],
            [2015, 13385, 6, 6],
            [2015, 13386, 17, 12],
            [2015, 13387, 13, 11],
            [2015, 13388, 10, 10],
            [2015, 13389, 12, 10],
            [2015, 13390, 13, 10],
            [2015, 13391, 9, 9],
            [2015, 13392, 15, 10],
            [2015, 13393, 26, 23],
            [2015, 13394, 14, 10],
            [2015, 13395, 13, 9],
            [2015, 13396, 45, 22],
            [2015, 13397, 6, 6],
            [2015, 13398, 24, 16],
            [2015, 13399, 12, 10],
            [2015, 13401, 10, 9],
            [2015, 13402, 18, 11],
            [2015, 13403, 15, 13],
            [2015, 13404, 21, 15],
            [2015, 13405, 30, 16],
            [2015, 13407, 17, 16],
            [2015, 13408, 17, 13],
            [2015, 13409, 15, 13],
            [2015, 13410, 19, 13],
            [2015, 13411, 9, 9],
            [2015, 13412, 34, 19],
            [2015, 13413, 22, 16],
            [2015, 13414, 21, 14],
            [2015, 13415, 16, 13],
            [2015, 13416, 12, 10],
            [2015, 13417, 10, 9],
            [2015, 13418, 9, 7],
            [2015, 13419, 38, 19],
            [2015, 13420, 10, 9],
            [2015, 13421, 14, 10],
            [2015, 13423, 10, 10],
            [2015, 13424, 28, 14],
            [2015, 13425, 18, 14],
            [2015, 13426, 20, 14],
            [2015, 13427, 24, 19],
            [2015, 13428, 38, 16],
            [2015, 13429, 18, 16],
            [2015, 13430, 18, 16],
            [2015, 13431, 28, 19],
            [2015, 13432, 9, 9],
            [2015, 13433, 16, 12],
            [2015, 13434, 24, 16],
            [2015, 13435, 14, 12],
            [2015, 13438, 21, 16],
            [2015, 13439, 8, 8],
            [2015, 13440, 8, 8],
            [2015, 13441, 10, 11],
            [2015, 13442, 34, 18],
            [2015, 13443, 27, 21],
            [2015, 13445, 12, 9],
            [2015, 13446, 15, 13],
            [2015, 13447, 32, 20],
            [2015, 13448, 23, 21],
            [2015, 13449, 10, 8],
            [2015, 13450, 8, 8],
            [2015, 13451, 9, 7],
            [2015, 13452, 8, 7],
            [2015, 13453, 9, 8],
            [2015, 13454, 17, 11],
            [2015, 13455, 12, 10],
            [2015, 13456, 6, 6],
            [2015, 13457, 7, 6],
            [2015, 13458, 8, 8],
            [2015, 13460, 9, 7],
            [2015, 13461, 8, 6],
            [2015, 13462, 8, 7],
            [2015, 13463, 12, 9],
            [2015, 13464, 14, 8],
            [2015, 13465, 11, 9],
            [2015, 13466, 9, 8],
            [2015, 13467, 8, 7],
            [2015, 13468, 8, 7],
            [2015, 13469, 8, 7],
            [2015, 13470, 12, 9],
            [2015, 13471, 9, 8],
            [2015, 13472, 13, 8],
            [2015, 13473, 11, 8],
            [2015, 13474, 10, 8],
            [2015, 13475, 11, 8],
            [2015, 13476, 7, 7],
            [2015, 13478, 6, 7],
            [2015, 13479, 12, 9],
            [2015, 13480, 4, 4],
            [2015, 13481, 8, 7],
            [2015, 13482, 10, 9],
            [2015, 13483, 9, 9],
            [2015, 13484, 10, 8],
            [2015, 13485, 9, 8],
            [2015, 13486, 3, 4],
            [2015, 13487, 17, 10],
            [2015, 13488, 8, 6],
            [2015, 13489, 12, 9],
            [2015, 13490, 7, 7],
            [2015, 13491, 8, 8],
            [2015, 13492, 7, 7],
            [2015, 13493, 7, 6],
            [2015, 13494, 11, 8],
            [2015, 13495, 9, 8],
            [2015, 13496, 10, 9],
            [2015, 13497, 10, 8],
            [2015, 13498, 9, 7],
            [2015, 13499, 11, 8],
            [2015, 13501, 14, 9],
            [2015, 13502, 8, 6],
            [2015, 13503, 10, 8],
            [2015, 13504, 7, 6],
            [2015, 13505, 7, 6],
            [2015, 13506, 10, 7],
            [2015, 13507, 5, 5],
            [2015, 13508, 10, 8],
            [2015, 13509, 5, 6],
            [2015, 13511, 14, 10],
            [2015, 13512, 9, 7],
            [2015, 13513, 12, 8],
            [2015, 13514, 11, 9],
            [2015, 13516, 7, 6],
            [2015, 13517, 7, 7],
            [2015, 13518, 7, 7],
            [2015, 13519, 11, 8],
            [2015, 13520, 12, 9],
            [2015, 13521, 8, 7],
            [2015, 13522, 9, 8],
            [2015, 13523, 9, 8],
            [2015, 13524, 7, 7],
            [2015, 13525, 10, 9],
            [2015, 13526, 8, 7],
            [2015, 13527, 13, 10],
            [2015, 13528, 8, 7],
            [2015, 13529, 6, 6],
            [2015, 13530, 6, 5],
            [2015, 13531, 7, 6],
            [2015, 13532, 7, 6],
            [2015, 13533, 7, 6],
            [2015, 13534, 6, 6],
            [2015, 13536, 9, 8],
            [2015, 13537, 6, 6],
            [2015, 13538, 6, 5],
            [2015, 13539, 6, 6],
            [2015, 13540, 6, 6],
            [2015, 13541, 9, 8],
            [2015, 13542, 9, 8],
            [2015, 13543, 9, 7],
            [2015, 13544, 10, 9],
            [2015, 13546, 7, 6],
            [2015, 13547, 8, 7],
            [2015, 13548, 12, 9],
            [2015, 13550, 19, 10],
            [2015, 13552, 11, 9],
            [2015, 13556, 8, 7],
            [2015, 13557, 3, 3],
            [2015, 13558, 13, 9],
            [2015, 13560, 8, 7],
            [2015, 13561, 9, 7],
            [2015, 13562, 9, 8],
            [2015, 13563, 8, 6],
            [2015, 13564, 13, 9],
            [2015, 13565, 9, 7],
            [2015, 13566, 12, 10],
            [2015, 13567, 8, 8],
            [2015, 13568, 4, 5],
            [2015, 13569, 8, 7],
            [2015, 13570, 6, 7],
            [2015, 13571, 11, 8],
            [2015, 13572, 6, 5],
            [2015, 13573, 7, 7],
            [2015, 13574, 9, 8],
            [2015, 13575, 11, 8],
            [2015, 13576, 7, 6],
            [2015, 13577, 7, 6],
            [2015, 13578, 8, 8],
            [2015, 13579, 18, 10],
            [2015, 13580, 10, 7],
            [2015, 13581, 6, 6],
            [2015, 13582, 8, 7],
            [2015, 13583, 8, 7],
            [2015, 13584, 26, 13],
            [2015, 13585, 6, 7],
            [2015, 13586, 6, 6],
            [2015, 13587, 7, 6],
            [2015, 13588, 15, 10],
            [2015, 13589, 7, 7],
            [2015, 13590, 13, 10],
            [2015, 13591, 7, 6],
            [2015, 13592, 7, 7],
            [2015, 13593, 6, 7],
            [2015, 13594, 13, 10],
            [2015, 13595, 10, 7],
            [2015, 13596, 11, 9],
            [2015, 13597, 8, 6],
            [2015, 13598, 7, 6],
            [2015, 13599, 6, 7],
            [2015, 13600, 8, 7],
            [2015, 13601, 7, 6],
            [2015, 13602, 6, 6],
            [2015, 13603, 6, 6],
            [2015, 13604, 12, 9],
            [2015, 13605, 10, 8],
            [2015, 13606, 10, 9],
            [2015, 13607, 8, 6],
            [2015, 13608, 9, 8],
            [2015, 13609, 31, 31],
            [2015, 13610, 27, 26],
            [2015, 13611, 18, 16],
            [2015, 13612, 42, 20],
            [2015, 13613, 92, 32],
            [2015, 13614, 26, 26],
            [2015, 13615, 54, 31],
            [2015, 13616, 11, 10],
            [2015, 13617, 30, 32],
            [2015, 13618, 40, 37],
            [2015, 13619, 36, 52],
            [2015, 13620, 31, 30],
            [2015, 13621, 36, 32],
            [2015, 13622, 38, 27],
            [2015, 13623, 47, 31],
            [2015, 13624, 23, 15],
            [2015, 13625, 18, 15],
            [2015, 13626, 23, 18],
            [2015, 13627, 30, 37],
            [2015, 13628, 29, 31],
            [2015, 13629, 47, 37],
            [2015, 13630, 31, 31],
            [2015, 13631, 39, 42],
            [2015, 13632, 32, 15],
            [2015, 13633, 22, 14],
            [2015, 13634, 22, 19],
            [2015, 13635, 31, 32],
            [2015, 13636, 16, 13],
            [2015, 13637, 72, 53],
            [2015, 13638, 62, 40],
            [2015, 13639, 9, 9],
            [2015, 13640, 45, 50],
            [2015, 13641, 32, 16],
            [2015, 13642, 69, 32],
            [2015, 13643, 19, 22],
            [2015, 13644, 51, 30],
            [2015, 13645, 57, 38],
            [2015, 13646, 25, 37],
            [2015, 13647, 42, 21],
            [2015, 13648, 46, 32],
            [2015, 13649, 56, 32],
            [2015, 13650, 8, 8],
            [2015, 13651, 42, 32],
            [2015, 13652, 58, 46],
            [2015, 13653, 8, 7],
            [2015, 13654, 8, 8],
            [2015, 13655, 26, 26],
            [2015, 13656, 70, 44],
            [2015, 13657, 17, 14],
            [2015, 13658, 79, 43],
            [2015, 13659, 36, 24],
            [2015, 13660, 31, 29],
            [2015, 13661, 31, 24],
            [2015, 13662, 41, 26],
            [2015, 13663, 16, 14],
            [2015, 13664, 36, 35],
            [2015, 13665, 41, 31],
            [2015, 13666, 27, 26],
            [2015, 13667, 36, 24],
            [2015, 13668, 12, 10],
            [2015, 13669, 37, 22],
            [2015, 13670, 41, 26],
            [2015, 13671, 40, 21],
            [2015, 13672, 37, 30],
            [2015, 13673, 76, 32],
            [2015, 13674, 35, 26],
            [2015, 13675, 26, 20],
            [2015, 13676, 29, 21],
            [2015, 13677, 14, 15],
            [2015, 13678, 12, 14],
            [2015, 13679, 9, 13],
            [2015, 13680, 10, 12],
            [2015, 13681, 14, 12],
            [2015, 13682, 8, 8],
            [2015, 13683, 16, 13],
            [2015, 13684, 25, 15],
            [2015, 13685, 25, 14],
            [2015, 13686, 19, 13],
            [2015, 13687, 26, 17],
            [2015, 13688, 16, 12],
            [2015, 13689, 18, 11],
            [2015, 13690, 12, 10],
            [2015, 13691, 48, 15],
            [2015, 13692, 16, 15],
            [2015, 13693, 14, 11],
            [2015, 13694, 25, 18],
            [2015, 13695, 20, 15],
            [2015, 13696, 12, 11],
            [2015, 13697, 35, 15],
            [2015, 13698, 16, 12],
            [2015, 13699, 26, 14],
            [2015, 13701, 15, 14],
            [2015, 13702, 23, 12],
            [2015, 13704, 26, 14],
            [2015, 13705, 12, 11],
            [2015, 13706, 24, 14],
            [2015, 13707, 28, 16],
            [2015, 13709, 26, 16],
            [2015, 13710, 18, 13],
            [2015, 13711, 22, 14],
            [2015, 13712, 32, 17],
            [2015, 13715, 31, 16],
            [2015, 13716, 20, 12],
            [2015, 13717, 23, 20],
            [2015, 13719, 31, 15],
            [2015, 13720, 21, 14],
            [2015, 13721, 20, 9],
            [2015, 13722, 22, 18],
            [2015, 13723, 28, 21],
            [2015, 13724, 30, 15],
            [2015, 13725, 26, 12],
            [2015, 13726, 18, 9],
            [2015, 13727, 34, 19],
            [2015, 13728, 20, 14],
            [2015, 13729, 20, 11],
            [2015, 13730, 28, 21],
            [2015, 13731, 25, 14],
            [2015, 13732, 36, 18],
            [2015, 13733, 23, 14],
            [2015, 13734, 21, 11],
            [2015, 13735, 22, 10],
            [2015, 13736, 28, 15],
            [2015, 13737, 27, 14],
            [2015, 13738, 18, 15],
            [2015, 13739, 27, 18],
            [2015, 13740, 31, 10],
            [2015, 13741, 12, 10],
            [2015, 13742, 29, 15],
            [2015, 13743, 30, 18],
            [2015, 13744, 28, 13],
            [2015, 13745, 10, 8],
            [2015, 13746, 18, 15],
            [2015, 13747, 15, 13],
            [2015, 13748, 20, 15],
            [2015, 13749, 12, 10],
            [2015, 13750, 22, 16],
            [2015, 13751, 9, 9],
            [2015, 13753, 16, 13],
            [2015, 13754, 18, 13],
            [2015, 13755, 13, 12],
            [2015, 13756, 11, 9],
            [2015, 13757, 17, 14],
            [2015, 13758, 11, 9],
            [2015, 13759, 9, 7],
            [2015, 13760, 10, 9],
            [2015, 13761, 13, 9],
            [2015, 13762, 10, 10],
            [2015, 13763, 10, 8],
            [2015, 13764, 8, 7],
            [2015, 13765, 19, 10],
            [2015, 13766, 14, 11],
            [2015, 13767, 16, 12],
            [2015, 13768, 15, 10],
            [2015, 13769, 11, 10],
            [2015, 13770, 15, 12],
            [2015, 13771, 13, 11],
            [2015, 13772, 13, 10],
            [2015, 13773, 17, 13],
            [2015, 13774, 9, 8],
            [2015, 13775, 9, 11],
            [2015, 13776, 10, 10],
            [2015, 13777, 9, 9],
            [2015, 13778, 18, 14],
            [2015, 13779, 15, 11],
            [2015, 13780, 10, 12],
            [2015, 13781, 17, 12],
            [2015, 13782, 16, 30],
            [2015, 13783, 16, 37],
            [2015, 13784, 16, 36],
            [2015, 13785, 16, 29],
            [2015, 13786, 14, 30],
            [2015, 13787, 7, 5],
            [2015, 13788, 6, 6],
            [2015, 13789, 9, 7],
            [2015, 13790, 9, 8],
            [2015, 13791, 8, 7],
            [2015, 13792, 11, 11],
            [2015, 13793, 8, 8],
            [2015, 13794, 12, 11],
            [2015, 13795, 8, 7],
            [2015, 13796, 9, 10],
            [2015, 13797, 9, 9],
            [2015, 13798, 9, 7],
            [2015, 13799, 16, 12],
            [2015, 13800, 8, 7],
            [2015, 13801, 8, 6],
            [2015, 13802, 9, 8],
            [2015, 13803, 10, 8],
            [2015, 13804, 11, 11],
            [2015, 13805, 7, 6],
            [2015, 13806, 9, 8],
            [2015, 13807, 7, 7],
            [2015, 13808, 7, 5],
            [2015, 13809, 10, 8],
            [2015, 13810, 7, 6],
            [2015, 13811, 9, 9],
            [2015, 13812, 9, 8],
            [2015, 13813, 10, 9],
            [2015, 13814, 12, 11],
            [2015, 13815, 12, 10],
            [2015, 13816, 11, 9],
            [2015, 13817, 9, 9],
            [2015, 13818, 9, 8],
            [2015, 13819, 9, 8],
            [2015, 13820, 9, 7],
            [2015, 13821, 6, 6],
            [2015, 13822, 6, 6],
            [2015, 13823, 6, 6],
            [2015, 13824, 9, 8],
            [2015, 13825, 6, 5],
            [2015, 13826, 7, 6],
            [2015, 13827, 7, 6],
            [2015, 13828, 10, 9],
            [2015, 13829, 8, 8],
            [2015, 13830, 7, 7],
            [2015, 13831, 8, 8],
            [2015, 13832, 7, 8],
            [2015, 13833, 12, 11],
            [2015, 13834, 7, 7],
            [2015, 13835, 9, 9],
            [2015, 13836, 9, 8],
            [2015, 13837, 10, 9],
            [2015, 13838, 9, 8],
            [2015, 13839, 10, 11],
            [2015, 13840, 7, 6],
            [2015, 13841, 9, 8],
            [2015, 13842, 10, 9],
            [2015, 13843, 9, 8],
            [2015, 13844, 6, 6],
            [2015, 13845, 8, 7],
            [2015, 13846, 7, 7],
            [2015, 13847, 6, 6],
            [2015, 13848, 7, 7],
            [2015, 13849, 9, 8],
            [2015, 13850, 10, 8],
            [2015, 13851, 11, 11],
            [2015, 13852, 8, 8],
            [2015, 13853, 12, 10],
            [2015, 13854, 13, 12],
            [2015, 13855, 15, 14],
            [2015, 13856, 8, 8],
            [2015, 13857, 9, 7],
            [2015, 13858, 8, 7],
            [2015, 13859, 8, 7],
            [2015, 13860, 7, 6],
            [2015, 13861, 7, 6],
            [2015, 13862, 11, 9],
            [2015, 13863, 7, 6],
            [2015, 13864, 6, 5],
            [2015, 13865, 9, 7],
            [2015, 13866, 6, 6],
            [2015, 13867, 7, 6],
            [2015, 13868, 6, 6],
            [2015, 13869, 9, 7],
            [2015, 13870, 7, 6],
            [2015, 13871, 6, 5],
            [2015, 13872, 8, 6],
            [2015, 13873, 6, 5],
            [2015, 13874, 11, 9],
            [2015, 13875, 9, 7],
            [2015, 13876, 16, 10],
            [2015, 13877, 10, 9],
            [2015, 13878, 7, 6],
            [2015, 13879, 7, 6],
            [2015, 13880, 7, 6],
            [2015, 13881, 8, 6],
            [2015, 13882, 7, 6],
            [2015, 13883, 14, 9],
            [2015, 13884, 7, 8],
            [2015, 13885, 9, 6],
            [2015, 13886, 7, 6],
            [2015, 13887, 7, 6],
            [2015, 13888, 11, 9],
            [2015, 13889, 6, 5],
            [2015, 13890, 9, 8],
            [2015, 13891, 9, 7],
            [2015, 13892, 8, 8],
            [2015, 13893, 12, 12],
            [2015, 13894, 6, 7],
            [2015, 13895, 7, 7],
            [2015, 13896, 6, 6],
            [2015, 13897, 7, 7],
            [2015, 13898, 8, 7],
            [2015, 13899, 8, 7],
            [2015, 13900, 11, 8],
            [2015, 13901, 15, 10],
            [2015, 13902, 7, 7],
            [2015, 13903, 12, 9],
            [2015, 13904, 8, 6],
            [2015, 13905, 10, 9],
            [2015, 13906, 13, 9],
            [2015, 13907, 11, 9],
            [2015, 13908, 10, 9],
            [2015, 13909, 13, 10],
            [2015, 13910, 9, 7],
            [2015, 13911, 8, 7],
            [2015, 13912, 8, 8],
            [2015, 13913, 8, 8],
            [2015, 13914, 8, 8],
            [2015, 13915, 7, 7],
            [2015, 13916, 6, 7],
            [2015, 13917, 6, 6],
            [2015, 13918, 8, 8],
            [2015, 13919, 9, 8],
            [2015, 13920, 12, 9],
            [2015, 13921, 14, 9],
            [2015, 13922, 9, 8],
            [2015, 13923, 8, 7],
            [2015, 13924, 12, 9],
            [2015, 13925, 7, 7],
            [2015, 13926, 8, 8],
            [2015, 13927, 8, 8],
            [2015, 13928, 7, 6],
            [2015, 13929, 7, 7],
            [2015, 13930, 7, 6],
            [2015, 13931, 10, 9],
            [2015, 13932, 9, 7],
            [2015, 13933, 9, 8],
            [2015, 13934, 11, 10],
            [2015, 13935, 7, 6],
            [2015, 13936, 7, 7],
            [2015, 13937, 11, 10],
            [2015, 13938, 7, 7],
            [2015, 13939, 8, 7],
            [2015, 13940, 8, 7],
            [2015, 13941, 8, 8],
            [2015, 13942, 10, 8],
            [2015, 13943, 10, 8],
            [2015, 13944, 8, 8],
            [2015, 13945, 8, 7],
            [2015, 13946, 11, 9],
            [2015, 13947, 13, 10],
            [2015, 13948, 6, 6],
            [2015, 13949, 6, 6],
            [2015, 13950, 10, 9],
            [2015, 13951, 7, 7],
            [2015, 13952, 11, 10],
            [2015, 13953, 11, 9],
            [2015, 13954, 8, 8],
            [2015, 13955, 10, 9],
            [2015, 13956, 10, 9],
            [2015, 13957, 8, 7],
            [2015, 13958, 7, 7],
            [2015, 13959, 8, 8],
            [2015, 13960, 11, 9],
            [2015, 13961, 9, 8],
            [2015, 13962, 10, 9],
            [2015, 13963, 7, 7],
            [2015, 13964, 7, 7],
            [2015, 13965, 7, 7],
            [2015, 13966, 9, 7],
            [2015, 13967, 7, 6],
            [2015, 13968, 7, 7],
            [2015, 13969, 7, 6],
            [2015, 13970, 7, 7],
            [2015, 13971, 7, 7],
            [2015, 13972, 9, 8],
            [2015, 13973, 7, 6],
            [2015, 13974, 7, 6],
            [2015, 13975, 8, 7],
            [2015, 13976, 9, 8],
            [2015, 13977, 7, 8],
            [2015, 13978, 11, 10],
            [2015, 13979, 7, 6],
            [2015, 13980, 6, 6],
            [2015, 13981, 7, 7],
            [2015, 13982, 7, 7],
            [2015, 13983, 12, 9],
            [2015, 13984, 9, 8],
            [2015, 13985, 14, 9],
            [2015, 13986, 8, 8],
            [2015, 13987, 7, 7],
            [2015, 13988, 9, 8],
            [2015, 13989, 7, 6],
            [2015, 13991, 7, 7],
            [2015, 13992, 7, 6],
            [2015, 13993, 9, 8],
            [2015, 13994, 8, 8],
            [2015, 13995, 13, 11],
            [2015, 13996, 8, 8],
            [2015, 13997, 7, 6],
            [2015, 13998, 7, 7],
            [2015, 13999, 11, 10],
            [2015, 14000, 12, 10],
            [2015, 14001, 11, 9],
            [2015, 14002, 7, 7],
            [2015, 14003, 7, 7],
            [2015, 14004, 7, 7],
            [2015, 14005, 20, 16],
            [2015, 14006, 12, 8],
            [2015, 14007, 13, 11],
            [2015, 14008, 12, 9],
            [2015, 14009, 14, 8],
            [2015, 14010, 10, 8],
            [2015, 14011, 10, 10],
            [2015, 14012, 10, 10],
            [2015, 14013, 12, 10],
            [2015, 14014, 22, 14],
            [2015, 14016, 13, 11],
            [2015, 14017, 22, 13],
            [2015, 14018, 9, 9],
            [2015, 14019, 8, 7],
            [2015, 14020, 8, 7],
            [2015, 14021, 13, 9],
            [2015, 14022, 8, 8],
            [2015, 14023, 22, 14],
            [2015, 14024, 12, 12],
            [2015, 14025, 12, 11],
            [2015, 14026, 20, 14],
            [2015, 14027, 11, 11],
            [2015, 14029, 13, 11],
            [2015, 14030, 19, 12],
            [2015, 14031, 23, 16],
            [2015, 14032, 12, 10],
            [2015, 14033, 11, 11],
            [2015, 14034, 13, 11],
            [2015, 14035, 18, 12],
            [2015, 14036, 11, 10],
            [2015, 14037, 19, 12],
            [2015, 14038, 10, 10],
            [2015, 14040, 16, 12],
            [2015, 14041, 22, 17],
            [2015, 14042, 17, 13],
            [2015, 14043, 12, 10],
            [2015, 14044, 10, 10],
            [2015, 14045, 10, 8],
            [2015, 14046, 9, 12],
            [2015, 14047, 14, 12],
            [2015, 14048, 15, 12],
            [2015, 14049, 20, 12],
            [2015, 14050, 15, 12],
            [2015, 14051, 19, 14],
            [2015, 14052, 11, 10],
            [2015, 14053, 12, 10],
            [2015, 14054, 11, 11],
            [2015, 14055, 23, 13],
            [2015, 14056, 22, 12],
            [2015, 14057, 15, 12],
            [2015, 14058, 14, 11],
            [2015, 14059, 12, 11],
            [2015, 14060, 15, 11],
            [2015, 14061, 14, 12],
            [2015, 14062, 12, 14],
            [2015, 14063, 20, 10],
            [2015, 14064, 16, 11],
            [2015, 14065, 20, 11],
            [2015, 14066, 14, 9],
            [2015, 14067, 16, 14],
            [2015, 14068, 12, 8],
            [2015, 14069, 13, 12],
            [2015, 14070, 19, 16],
            [2015, 14071, 19, 15],
            [2015, 14072, 13, 9],
            [2015, 14073, 19, 16],
            [2015, 14074, 16, 16],
            [2015, 14075, 19, 12],
            [2015, 14076, 19, 12],
            [2015, 14077, 14, 10],
            [2015, 14078, 15, 10],
            [2015, 14079, 13, 10],
            [2015, 14080, 20, 12],
            [2015, 14081, 18, 12],
            [2015, 14082, 18, 13],
            [2015, 14083, 14, 8],
            [2015, 14084, 12, 9],
            [2015, 14085, 15, 10],
            [2015, 14086, 16, 12],
            [2015, 14087, 16, 12],
            [2015, 14088, 14, 10],
            [2015, 14089, 14, 10],
            [2015, 14090, 13, 11],
            [2015, 14092, 13, 8],
            [2015, 14093, 14, 8],
            [2015, 14094, 11, 8],
            [2015, 14095, 14, 12],
            [2015, 14096, 15, 12],
            [2015, 14097, 14, 10],
            [2015, 14098, 16, 10],
            [2015, 14099, 15, 10],
            [2015, 14100, 12, 8],
            [2015, 14101, 20, 12],
            [2015, 14102, 18, 10],
            [2015, 14103, 16, 13],
            [2015, 14104, 11, 10],
            [2015, 14105, 18, 12],
            [2015, 14107, 14, 10],
            [2015, 14108, 15, 11],
            [2015, 14110, 19, 10],
            [2015, 14111, 17, 12],
            [2015, 14112, 14, 10],
            [2015, 14113, 12, 11],
            [2015, 14114, 12, 11],
            [2015, 14115, 18, 13],
            [2015, 14116, 17, 14],
            [2015, 14117, 25, 11],
            [2015, 14118, 21, 14],
            [2015, 14119, 26, 18],
            [2015, 14120, 17, 11],
            [2015, 14121, 20, 11],
            [2015, 14122, 19, 12],
            [2015, 14123, 18, 13],
            [2015, 14124, 10, 9],
            [2015, 14125, 18, 14],
            [2015, 14126, 16, 11],
            [2015, 14127, 16, 11],
            [2015, 14128, 10, 8],
            [2015, 14129, 8, 8],
            [2015, 14130, 17, 13],
            [2015, 14131, 33, 15],
            [2015, 14132, 19, 11],
            [2015, 14133, 10, 8],
            [2015, 14134, 14, 11],
            [2015, 14135, 17, 12],
            [2015, 14136, 16, 11],
            [2015, 14137, 24, 12],
            [2015, 14138, 25, 12],
            [2015, 14139, 18, 12],
            [2015, 14140, 28, 14],
            [2015, 14141, 24, 14],
            [2015, 14142, 13, 11],
            [2015, 14143, 21, 13],
            [2015, 14144, 14, 9],
            [2015, 14145, 18, 11],
            [2015, 14146, 36, 13],
            [2015, 14147, 14, 12],
            [2015, 14148, 12, 8],
            [2015, 14149, 17, 12],
            [2015, 14150, 11, 9],
            [2015, 14151, 15, 11],
            [2015, 14152, 19, 12],
            [2015, 14153, 12, 11],
            [2015, 14154, 19, 11],
            [2015, 14155, 11, 8],
            [2015, 14156, 19, 13],
            [2015, 14157, 28, 15],
            [2015, 14158, 14, 11],
            [2015, 14159, 21, 12],
            [2015, 14160, 16, 12],
            [2015, 14161, 8, 8],
            [2015, 14162, 15, 12],
            [2015, 14163, 10, 9],
            [2015, 14164, 15, 13],
            [2015, 14165, 16, 11],
            [2015, 14166, 26, 12],
            [2015, 14167, 11, 8],
            [2015, 14168, 14, 11],
            [2015, 14169, 10, 7],
            [2015, 14170, 9, 8],
            [2015, 14171, 29, 13],
            [2015, 14172, 21, 15],
            [2015, 14173, 10, 12],
            [2015, 14174, 23, 15],
            [2015, 14175, 19, 30],
            [2015, 14176, 10, 10],
            [2015, 14177, 13, 11],
            [2015, 14178, 8, 8],
            [2015, 14179, 24, 16],
            [2015, 14180, 19, 12],
            [2015, 14181, 23, 13],
            [2015, 14182, 17, 12],
            [2015, 14183, 10, 8],
            [2015, 14184, 22, 9],
            [2015, 14185, 23, 11],
            [2015, 14186, 19, 11],
            [2015, 14187, 10, 11],
            [2015, 14188, 15, 12],
            [2015, 14189, 15, 11],
            [2015, 14190, 9, 8],
            [2015, 14191, 14, 15],
            [2015, 14192, 28, 16],
            [2015, 14193, 19, 16],
            [2015, 14194, 10, 9],
            [2015, 14195, 10, 8],
            [2015, 14196, 33, 17],
            [2015, 14197, 17, 12],
            [2015, 14198, 10, 10],
            [2015, 14199, 14, 13],
            [2015, 14200, 19, 11],
            [2015, 14201, 10, 10],
            [2015, 14202, 10, 10],
            [2015, 14203, 10, 8],
            [2015, 14204, 9, 8],
            [2015, 14205, 15, 11],
            [2015, 14206, 13, 11],
            [2015, 14207, 13, 10],
            [2015, 14208, 12, 9],
            [2015, 14209, 24, 13],
            [2015, 14211, 20, 13],
            [2015, 14212, 10, 9],
            [2015, 14213, 24, 15],
            [2015, 14214, 9, 8],
            [2015, 14215, 19, 12],
            [2015, 14216, 13, 11],
            [2015, 14217, 15, 12],
            [2015, 14218, 10, 8],
            [2015, 14219, 10, 8],
            [2015, 14220, 15, 12],
            [2015, 14221, 12, 10],
            [2015, 14222, 23, 13],
            [2015, 14223, 16, 12],
            [2015, 14224, 14, 12],
            [2015, 14225, 15, 12],
            [2015, 14226, 24, 11],
            [2015, 14228, 15, 14],
            [2015, 14229, 16, 12],
            [2015, 14230, 21, 11],
            [2015, 14231, 16, 10],
            [2015, 14232, 10, 8],
            [2015, 14233, 15, 12],
            [2015, 14235, 15, 11],
            [2015, 14236, 29, 18],
            [2015, 14237, 12, 9],
            [2015, 14238, 14, 12],
            [2015, 14240, 7, 5],
            [2015, 14241, 13, 8],
            [2015, 14242, 23, 13],
            [2015, 14243, 7, 5],
            [2015, 14244, 24, 13],
            [2015, 14245, 18, 13],
            [2015, 14246, 20, 14],
            [2015, 14247, 24, 14],
            [2015, 14248, 14, 10],
            [2015, 14249, 28, 16],
            [2015, 14250, 23, 13],
            [2015, 14251, 10, 7],
            [2015, 14252, 27, 15],
            [2015, 14253, 24, 13],
            [2015, 14254, 12, 9],
            [2015, 14255, 19, 11],
            [2015, 14256, 14, 9],
            [2015, 14257, 22, 12],
            [2015, 14258, 15, 9],
            [2015, 14259, 24, 13],
            [2015, 14260, 16, 10],
            [2015, 14261, 23, 12],
            [2015, 14262, 25, 14],
            [2015, 14263, 15, 10],
            [2015, 14264, 23, 12],
            [2015, 14265, 24, 14],
            [2015, 14266, 19, 13],
            [2015, 14267, 7, 6],
            [2015, 14268, 7, 6],
            [2015, 14269, 27, 15],
            [2015, 14270, 10, 8],
            [2015, 14271, 10, 8],
            [2015, 14272, 7, 6],
            [2015, 14273, 26, 14],
            [2015, 14274, 18, 12],
            [2015, 14275, 25, 13],
            [2015, 14276, 14, 11],
            [2015, 14277, 8, 6],
            [2015, 14278, 8, 7],
            [2015, 14280, 21, 12],
            [2015, 14281, 10, 7],
            [2015, 14282, 12, 9],
            [2015, 14283, 11, 7],
            [2015, 14285, 21, 12],
            [2015, 14286, 22, 13],
            [2015, 14287, 16, 11],
            [2015, 14288, 14, 10],
            [2015, 14289, 26, 13],
            [2015, 14290, 28, 16],
            [2015, 14291, 18, 12],
            [2015, 14292, 16, 11],
            [2015, 14293, 14, 9],
            [2015, 14294, 20, 12],
            [2015, 14295, 23, 12],
            [2015, 14296, 25, 13],
            [2015, 14297, 22, 13],
            [2015, 14298, 12, 8],
            [2015, 14299, 22, 13],
            [2015, 14300, 8, 6],
            [2015, 14301, 8, 7],
            [2015, 14302, 10, 8],
            [2015, 14303, 23, 13],
            [2015, 14304, 17, 11],
            [2015, 14305, 27, 15],
            [2015, 14306, 26, 15],
            [2015, 14307, 7, 6],
            [2015, 14308, 20, 12],
            [2015, 14309, 11, 9],
            [2015, 14310, 21, 13],
            [2015, 14311, 23, 14],
            [2015, 14312, 21, 14],
            [2015, 14313, 14, 9],
            [2015, 14314, 24, 13],
            [2015, 14315, 20, 12],
            [2015, 14316, 21, 13],
            [2015, 14317, 17, 12],
            [2015, 14318, 24, 15],
            [2015, 14319, 13, 10],
            [2015, 14320, 10, 8],
            [2015, 14321, 23, 14],
            [2015, 14322, 17, 12],
            [2015, 14323, 23, 13],
            [2015, 14324, 16, 11],
            [2015, 14325, 30, 13],
            [2015, 14327, 26, 13],
            [2015, 14328, 18, 11],
            [2015, 14329, 24, 13],
            [2015, 14330, 20, 12],
            [2015, 14331, 22, 14],
            [2015, 14332, 11, 8],
            [2015, 14333, 13, 9],
            [2015, 14335, 23, 14],
            [2015, 14337, 13, 10],
            [2015, 14338, 22, 13],
            [2015, 14340, 10, 7],
            [2015, 14341, 23, 13],
            [2015, 14342, 23, 14],
            [2015, 14343, 21, 12],
            [2015, 14344, 26, 13],
            [2015, 14345, 23, 13],
            [2015, 14346, 26, 13],
            [2015, 14347, 12, 9],
            [2015, 14348, 24, 13],
            [2015, 14349, 16, 10],
            [2015, 14350, 14, 9],
            [2015, 14352, 23, 12],
            [2015, 14353, 21, 12],
            [2015, 14354, 23, 14],
            [2015, 14355, 16, 12],
            [2015, 14356, 10, 7],
            [2015, 14357, 22, 12],
            [2015, 14358, 14, 10],
            [2015, 14359, 20, 12],
            [2015, 14360, 11, 8],
            [2015, 14361, 23, 13],
            [2015, 14362, 20, 12],
            [2015, 14363, 25, 14],
            [2015, 14364, 23, 12],
            [2015, 14365, 18, 12],
            [2015, 14366, 24, 13],
            [2015, 14367, 28, 14],
            [2015, 14368, 25, 14],
            [2015, 14369, 25, 13],
            [2015, 14370, 11, 8],
            [2015, 14371, 7, 5],
            [2015, 14372, 12, 8],
            [2015, 14373, 23, 13],
            [2015, 14374, 19, 11],
            [2015, 14375, 22, 12],
            [2015, 14376, 7, 5],
            [2015, 14378, 7, 6],
            [2015, 14380, 24, 13],
            [2015, 14381, 24, 13],
            [2015, 14382, 23, 13],
            [2015, 14383, 12, 8],
            [2015, 14384, 23, 12],
            [2015, 14385, 22, 12],
            [2015, 14386, 24, 13],
            [2015, 14387, 27, 16],
            [2015, 14388, 33, 17],
            [2015, 14389, 24, 13],
            [2015, 14390, 22, 12],
            [2015, 14391, 12, 8],
            [2015, 14392, 21, 13],
            [2015, 14393, 15, 9],
            [2015, 14394, 22, 12],
            [2015, 14395, 27, 13],
            [2015, 14397, 22, 11],
            [2015, 14398, 22, 12],
            [2015, 14399, 29, 14],
            [2015, 14400, 28, 15],
            [2015, 14401, 18, 11],
            [2015, 14402, 12, 8],
            [2015, 14403, 23, 13],
            [2015, 14405, 30, 14],
            [2015, 14406, 29, 15],
            [2015, 14407, 22, 13],
            [2015, 14408, 16, 11],
            [2015, 14409, 25, 12],
            [2015, 14411, 17, 10],
            [2015, 14412, 16, 9],
            [2015, 14413, 10, 7],
            [2015, 14415, 20, 12],
            [2015, 14416, 17, 11],
            [2015, 14417, 17, 12],
            [2015, 14418, 24, 12],
            [2015, 14419, 23, 12],
            [2015, 14420, 14, 9],
            [2015, 14421, 27, 12],
            [2015, 14422, 19, 9],
            [2015, 14423, 14, 9],
            [2015, 14424, 16, 10],
            [2015, 14425, 27, 16],
            [2015, 14426, 15, 10],
            [2015, 14427, 23, 12],
            [2015, 14428, 21, 12],
            [2015, 14429, 18, 10],
            [2015, 14430, 20, 12],
            [2015, 14432, 21, 12],
            [2015, 14434, 18, 10],
            [2015, 14435, 11, 10],
            [2015, 14436, 23, 18],
            [2015, 14438, 20, 41],
            [2015, 14440, 20, 38],
            [2015, 14442, 20, 23],
            [2015, 14445, 22, 34],
            [2015, 14446, 26, 26],
            [2015, 14447, 20, 23],
            [2015, 14449, 14, 17],
            [2015, 14450, 59, 36],
            [2015, 14452, 28, 35],
            [2015, 14453, 26, 48],
            [2015, 14458, 25, 41],
            [2015, 14459, 30, 30],
            [2015, 14460, 26, 26],
            [2015, 14462, 20, 28],
            [2015, 14463, 12, 13],
            [2015, 14464, 30, 25],
            [2015, 14465, 42, 23],
            [2015, 14466, 23, 26],
            [2015, 14468, 30, 35],
            [2015, 14470, 20, 17],
            [2015, 14471, 26, 23],
            [2015, 14473, 17, 14],
            [2015, 14476, 32, 30],
            [2015, 14478, 16, 16],
            [2015, 14480, 26, 26],
            [2015, 14484, 30, 35],
            [2015, 14485, 13, 15],
            [2015, 14486, 29, 24],
            [2015, 14488, 19, 26],
            [2015, 14489, 16, 16],
            [2015, 14490, 38, 30],
            [2015, 14491, 19, 26],
            [2015, 14493, 26, 37],
            [2015, 14495, 24, 24],
            [2015, 14496, 40, 39],
            [2015, 14500, 24, 35],
            [2015, 14501, 20, 30],
            [2015, 14502, 38, 26],
            [2015, 14503, 30, 30],
            [2015, 14505, 14, 13],
            [2015, 14507, 26, 40],
            [2015, 14508, 14, 26],
            [2015, 14509, 29, 25],
            [2015, 14510, 29, 24],
            [2015, 14512, 32, 30],
            [2015, 14513, 36, 28],
            [2015, 14514, 34, 40],
            [2015, 14516, 36, 34],
            [2015, 14518, 26, 25],
            [2015, 14519, 44, 36],
            [2015, 14520, 30, 41],
            [2015, 14524, 24, 27],
            [2015, 14527, 26, 46],
            [2015, 14528, 26, 20],
            [2015, 14530, 43, 40],
            [2015, 14534, 18, 11],
            [2015, 14535, 12, 6],
            [2015, 14536, 18, 12],
            [2015, 14538, 23, 13],
            [2015, 14541, 16, 12],
            [2015, 14542, 15, 10],
            [2015, 14543, 15, 12],
            [2015, 14544, 10, 8],
            [2015, 14545, 19, 14],
            [2015, 14546, 20, 13],
            [2015, 14547, 18, 12],
            [2015, 14548, 18, 13],
            [2015, 14549, 23, 14],
            [2015, 14550, 19, 13],
            [2015, 14553, 14, 15],
            [2015, 14554, 16, 9],
            [2015, 14555, 11, 11],
            [2015, 14556, 22, 14],
            [2015, 14557, 20, 16],
            [2015, 14558, 10, 9],
            [2015, 14559, 10, 9],
            [2015, 14562, 84, 31],
            [2015, 14563, 91, 32],
            [2015, 14564, 22, 18],
            [2015, 14565, 20, 37],
            [2015, 14566, 16, 22],
            [2015, 14567, 22, 37],
            [2015, 14568, 71, 71],
            [2015, 14569, 20, 18],
            [2015, 14570, 19, 22],
            [2015, 14571, 16, 17],
            [2015, 14572, 16, 23],
            [2015, 14573, 86, 75],
            [2015, 14574, 12, 10],
            [2015, 14575, 8, 6],
            [2015, 14576, 9, 8],
            [2015, 14577, 25, 15],
            [2015, 14578, 15, 12],
            [2015, 14579, 13, 10],
            [2015, 14580, 8, 7],
            [2015, 14581, 9, 9],
            [2015, 14582, 21, 17],
            [2015, 14583, 15, 12],
            [2015, 14584, 6, 6],
            [2015, 14585, 10, 9],
            [2015, 14586, 10, 10],
            [2015, 14588, 17, 12],
            [2015, 14590, 14, 12],
            [2015, 14591, 15, 12],
            [2015, 14592, 2, 2],
            [2015, 14593, 63, 36],
            [2015, 14594, 4, 4],
            [2015, 14596, 5, 4],
            [2015, 14598, 15, 9],
            [2015, 14599, 20, 10],
            [2015, 14600, 27, 15],
            [2015, 14601, 7, 6],
            [2015, 14602, 19, 14],
            [2015, 14603, 11, 8],
            [2015, 14604, 10, 8],
            [2015, 14605, 12, 11],
            [2015, 14607, 6, 6],
            [2015, 14608, 9, 8],
            [2015, 14609, 11, 8],
            [2015, 14610, 4, 4],
            [2015, 14611, 6, 5],
            [2015, 14613, 20, 14],
            [2015, 14614, 18, 12],
            [2015, 14616, 12, 11],
            [2015, 14617, 25, 16],
            [2015, 14618, 7, 7],
            [2015, 14619, 17, 12],
            [2015, 14620, 13, 11],
            [2015, 14621, 8, 6],
            [2015, 14622, 14, 10],
            [2015, 14623, 14, 10],
            [2015, 14624, 8, 8],
            [2015, 14625, 11, 7],
            [2015, 14626, 8, 6],
            [2015, 14627, 27, 18],
            [2015, 14628, 16, 13],
            [2015, 14629, 22, 15],
            [2015, 14630, 7, 7],
            [2015, 14631, 6, 5],
            [2015, 14632, 27, 18],
            [2015, 14633, 27, 21],
            [2015, 14634, 10, 9],
            [2015, 14635, 7, 6],
            [2015, 14636, 14, 10],
            [2015, 14637, 13, 10],
            [2015, 14638, 18, 11],
            [2015, 14639, 5, 6],
            [2015, 14640, 8, 6],
            [2015, 14642, 23, 13],
            [2015, 14643, 6, 6],
            [2015, 14644, 6, 7],
            [2015, 14645, 13, 11],
            [2015, 14646, 8, 7],
            [2015, 14647, 21, 13],
            [2015, 14648, 4, 4],
            [2015, 14649, 10, 9],
            [2015, 14650, 13, 10],
            [2015, 14651, 14, 10],
            [2015, 14652, 19, 13],
            [2015, 14653, 19, 13],
            [2015, 14655, 4, 4],
            [2015, 14656, 11, 10],
            [2015, 14657, 7, 6],
            [2015, 14658, 15, 11],
            [2015, 14659, 13, 10],
            [2015, 14660, 12, 11],
            [2015, 14662, 18, 11],
            [2015, 14663, 16, 13],
            [2015, 14664, 8, 8],
            [2015, 14665, 12, 9],
            [2015, 14666, 11, 9],
            [2015, 14667, 16, 11],
            [2015, 14668, 13, 11],
            [2015, 14669, 23, 17],
            [2015, 14670, 13, 10],
            [2015, 14671, 13, 11],
            [2015, 14672, 13, 11],
            [2015, 14673, 16, 12],
            [2015, 14674, 9, 8],
            [2015, 14675, 8, 7],
            [2015, 14676, 13, 10],
            [2015, 14677, 13, 10],
            [2015, 14678, 16, 10],
            [2015, 14680, 14, 11],
            [2015, 14681, 14, 10],
            [2015, 14682, 11, 8],
            [2015, 14683, 15, 11],
            [2015, 14684, 25, 16],
            [2015, 14686, 10, 8],
            [2015, 14687, 20, 14],
            [2015, 14688, 6, 6],
            [2015, 14689, 12, 9],
            [2015, 14690, 19, 14],
            [2015, 14691, 15, 10],
            [2015, 14692, 15, 13],
            [2015, 14693, 11, 8],
            [2015, 14694, 8, 6],
            [2015, 14696, 9, 8],
            [2015, 14697, 12, 10],
            [2015, 14698, 14, 9],
            [2015, 14699, 17, 13],
            [2015, 14700, 17, 13],
            [2015, 14701, 27, 16],
            [2015, 14702, 31, 21],
            [2015, 14703, 27, 18],
            [2015, 14704, 46, 27],
            [2015, 14705, 23, 16],
            [2015, 14706, 33, 19],
            [2015, 14710, 27, 16],
            [2015, 14711, 23, 16],
            [2015, 14712, 31, 19],
            [2015, 14713, 29, 18],
            [2015, 14714, 25, 15],
            [2015, 14717, 12, 10],
            [2015, 14718, 20, 17],
            [2015, 14719, 19, 15],
            [2015, 14720, 46, 25],
            [2015, 14722, 27, 18],
            [2015, 14724, 19, 16],
            [2015, 14725, 23, 18],
            [2015, 14726, 19, 16],
            [2015, 14727, 33, 18],
            [2015, 14728, 29, 19],
            [2015, 14729, 23, 18],
            [2015, 14730, 23, 17],
            [2015, 14731, 19, 17],
            [2015, 14732, 37, 18],
            [2015, 14733, 27, 16],
            [2015, 14734, 27, 25],
            [2015, 14735, 37, 21],
            [2015, 14736, 37, 18],
            [2015, 14738, 25, 18],
            [2015, 14739, 18, 15],
            [2015, 14740, 27, 21],
            [2015, 14741, 25, 18],
            [2015, 14743, 18, 13],
            [2015, 14744, 12, 8],
            [2015, 14745, 25, 20],
            [2015, 14747, 25, 19],
            [2015, 14748, 19, 16],
            [2015, 14749, 12, 9],
            [2015, 14750, 21, 15],
            [2015, 14751, 25, 15],
            [2015, 14752, 20, 15],
            [2015, 14753, 29, 19],
            [2015, 14754, 17, 15],
            [2015, 14755, 17, 18],
            [2015, 14756, 21, 16],
            [2015, 14759, 25, 17],
            [2015, 14760, 27, 19],
            [2015, 14761, 18, 9],
            [2015, 14762, 12, 9],
            [2015, 14763, 21, 25],
            [2015, 14764, 41, 23],
            [2015, 14765, 13, 9],
            [2015, 14766, 33, 19],
            [2015, 14767, 23, 21],
            [2015, 14768, 5, 5],
            [2015, 14769, 39, 25],
            [2015, 14770, 19, 19],
            [2015, 14771, 28, 37],
            [2015, 14773, 39, 45],
            [2015, 14774, 29, 19],
            [2015, 14775, 37, 33],
            [2015, 14776, 37, 35],
            [2015, 14777, 21, 24],
            [2015, 14778, 12, 11],
            [2015, 14779, 39, 23],
            [2015, 14780, 35, 13],
            [2015, 14781, 10, 11],
            [2015, 14782, 62, 31],
            [2015, 14783, 28, 24],
            [2015, 14784, 14, 24],
            [2015, 14785, 62, 42],
            [2015, 14786, 25, 19],
            [2015, 14788, 26, 24],
            [2015, 14789, 68, 41],
            [2015, 14790, 47, 20],
            [2015, 14791, 13, 13],
            [2015, 14792, 61, 55],
            [2015, 14793, 37, 24],
            [2015, 14794, 28, 27],
            [2015, 14795, 33, 24],
            [2015, 14796, 35, 47],
            [2015, 14797, 27, 51],
            [2015, 14798, 27, 42],
            [2015, 14799, 43, 24],
            [2015, 14800, 13, 11],
            [2015, 14801, 31, 15],
            [2015, 14802, 20, 13],
            [2015, 14803, 37, 35],
            [2015, 14804, 13, 11],
            [2015, 14805, 34, 35],
            [2015, 14806, 15, 13],
            [2015, 14807, 37, 25],
            [2015, 14808, 51, 49],
            [2015, 14809, 15, 25],
            [2015, 14810, 16, 19],
            [2015, 14811, 16, 20],
            [2015, 14812, 45, 37],
            [2015, 14813, 25, 19],
            [2015, 14814, 37, 24],
            [2015, 14815, 59, 27],
            [2015, 14816, 13, 11],
            [2015, 14817, 13, 11],
            [2015, 14818, 13, 11],
            [2015, 14819, 37, 33],
            [2015, 14820, 68, 57],
            [2015, 14821, 19, 17],
            [2015, 14823, 17, 18],
            [2015, 14824, 63, 39],
            [2015, 14825, 16, 17],
            [2015, 14826, 40, 20],
            [2015, 14827, 44, 35],
            [2015, 14828, 51, 41],
            [2015, 14829, 19, 17],
            [2015, 14830, 14, 16],
            [2015, 14831, 29, 19],
            [2015, 14832, 44, 35],
            [2015, 14833, 37, 29],
            [2015, 14834, 38, 42],
            [2015, 14835, 52, 20],
            [2015, 14836, 43, 21],
            [2015, 14837, 56, 37],
            [2015, 14838, 55, 42],
            [2015, 14839, 29, 35],
            [2015, 14840, 33, 24],
            [2015, 14841, 21, 17],
            [2015, 14842, 19, 16],
            [2015, 14843, 52, 35],
            [2015, 14844, 16, 17],
            [2015, 14845, 51, 50],
            [2015, 14846, 37, 17],
            [2015, 14847, 13, 11],
            [2015, 14848, 13, 11],
            [2015, 14849, 13, 11],
            [2015, 14850, 40, 27],
            [2015, 14851, 19, 21],
            [2015, 14852, 14, 11],
            [2015, 14853, 25, 21],
            [2015, 14854, 58, 42],
            [2015, 14855, 11, 10],
            [2015, 14856, 8, 7],
            [2015, 14857, 7, 7],
            [2015, 14858, 16, 14],
            [2015, 14859, 25, 22],
            [2015, 14860, 17, 15],
            [2015, 14861, 12, 11],
            [2015, 14862, 14, 11],
            [2015, 14863, 10, 10],
            [2015, 14864, 10, 10],
            [2015, 14865, 19, 24],
            [2015, 14866, 19, 20],
            [2015, 14867, 14, 23],
            [2015, 14868, 25, 19],
            [2015, 14869, 22, 24],
            [2015, 14870, 10, 10],
            [2015, 14871, 10, 10],
            [2015, 14872, 10, 9],
            [2015, 14873, 26, 18],
            [2015, 14875, 24, 22],
            [2015, 14876, 14, 13],
            [2015, 14877, 40, 31],
            [2015, 14879, 21, 19],
            [2015, 14880, 19, 12],
            [2015, 14881, 24, 19],
            [2015, 14882, 25, 25],
            [2015, 14883, 10, 14],
            [2015, 14884, 10, 8],
            [2015, 14885, 10, 10],
            [2015, 14886, 25, 16],
            [2015, 14887, 20, 13],
            [2015, 14888, 13, 11],
            [2015, 14889, 25, 20],
            [2015, 14890, 14, 12],
            [2015, 14892, 26, 26],
            [2015, 14893, 19, 28],
            [2015, 14894, 16, 15],
            [2015, 14896, 29, 18],
            [2015, 14898, 30, 24],
            [2015, 14899, 16, 13],
            [2015, 14900, 12, 10],
            [2015, 14902, 18, 18],
            [2015, 14903, 22, 17],
            [2015, 14904, 26, 20],
            [2015, 14905, 30, 24],
            [2015, 14906, 14, 12],
            [2015, 14907, 9, 10],
            [2015, 14908, 9, 10],
            [2015, 14909, 9, 9],
            [2015, 14910, 18, 18],
            [2015, 14911, 22, 17],
            [2015, 14912, 20, 17],
            [2015, 14913, 13, 12],
            [2015, 14915, 23, 19],
            [2015, 14916, 23, 15],
            [2015, 14917, 23, 25],
            [2015, 14918, 29, 33],
            [2015, 14920, 25, 22],
            [2015, 14921, 15, 12],
            [2015, 14922, 11, 11],
            [2015, 14923, 20, 18],
            [2015, 14924, 21, 19],
            [2015, 14925, 20, 14],
            [2015, 14926, 24, 24],
            [2015, 14927, 20, 22],
            [2015, 14928, 18, 24],
            [2015, 14929, 22, 23],
            [2015, 14930, 20, 22],
            [2015, 14931, 12, 11],
            [2015, 14933, 16, 13],
            [2015, 14934, 37, 33],
            [2015, 14936, 10, 10],
            [2015, 14937, 10, 10],
            [2015, 14938, 27, 25],
            [2015, 14939, 30, 24],
            [2015, 14940, 12, 10],
            [2015, 14941, 36, 31],
            [2015, 14942, 11, 10],
            [2015, 14943, 21, 11],
            [2015, 14944, 17, 15],
            [2015, 14945, 27, 26],
            [2015, 14946, 14, 12],
            [2015, 14947, 17, 14],
            [2015, 14948, 35, 28],
            [2015, 14949, 37, 23],
            [2015, 14950, 13, 10],
            [2015, 14951, 21, 14],
            [2015, 14952, 35, 19],
            [2015, 14953, 19, 17],
            [2015, 14954, 31, 26],
            [2015, 14955, 16, 7],
            [2015, 14956, 27, 22],
            [2015, 14957, 15, 14],
            [2015, 14958, 12, 26],
            [2015, 14959, 14, 11],
            [2015, 14961, 19, 16],
            [2015, 14962, 21, 25],
            [2015, 14963, 23, 20],
            [2015, 14964, 17, 13],
            [2015, 14965, 10, 10],
            [2015, 14966, 9, 9],
            [2015, 14967, 17, 16],
            [2015, 14968, 21, 20],
            [2015, 14969, 10, 11],
            [2015, 14970, 11, 11],
            [2015, 14971, 12, 10],
            [2015, 14972, 29, 25],
            [2015, 14973, 22, 17],
            [2015, 14974, 22, 15],
            [2015, 14975, 17, 10],
            [2015, 14976, 22, 16],
            [2015, 14977, 22, 16],
            [2015, 14978, 23, 31],
            [2015, 14979, 19, 14],
            [2015, 14980, 25, 23],
            [2015, 14981, 20, 17],
            [2015, 14982, 12, 11],
            [2015, 14984, 18, 11],
            [2015, 14985, 18, 15],
            [2015, 14986, 34, 25],
            [2015, 14987, 25, 20],
            [2015, 14988, 18, 17],
            [2015, 14989, 13, 13],
            [2015, 14990, 11, 9],
            [2015, 14991, 8, 5],
            [2015, 14992, 1, 1],
            [2015, 14993, 10, 7],
            [2015, 14994, 10, 6],
            [2015, 14995, 7, 6],
            [2015, 14996, 7, 6],
            [2015, 14997, 22, 15],
            [2015, 14998, 7, 4],
            [2015, 14999, 7, 6],
            [2015, 15000, 16, 13],
            [2015, 15001, 10, 10],
            [2015, 15002, 7, 6],
            [2015, 15003, 16, 13],
            [2015, 15004, 4, 4],
            [2015, 15005, 14, 11],
            [2015, 15006, 13, 11],
            [2015, 15007, 8, 4],
            [2015, 15008, 1, 1],
            [2015, 15009, 13, 11],
            [2015, 15010, 9, 7],
            [2015, 15011, 6, 5],
            [2015, 15012, 1, 1],
            [2015, 15013, 9, 8],
            [2015, 15015, 12, 11],
            [2015, 15016, 1, 1],
            [2015, 15017, 9, 5],
            [2015, 15019, 7, 6],
            [2015, 15020, 11, 9],
            [2015, 15021, 7, 5],
            [2015, 15022, 9, 7],
            [2015, 15023, 10, 7],
            [2015, 15024, 10, 7],
            [2015, 15025, 8, 6],
            [2015, 15026, 9, 7],
            [2015, 15027, 7, 6],
            [2015, 15028, 10, 8],
            [2015, 15029, 11, 8],
            [2015, 15030, 8, 5],
            [2015, 15031, 7, 4],
            [2015, 15032, 7, 4],
            [2015, 15033, 4, 2],
            [2015, 15034, 7, 6],
            [2015, 15035, 10, 7],
            [2015, 15036, 9, 6],
            [2015, 15037, 10, 6],
            [2015, 15040, 9, 7],
            [2015, 15041, 1, 1],
            [2015, 15042, 10, 6],
            [2015, 15043, 14, 11],
            [2015, 15044, 9, 6],
            [2015, 15045, 8, 5],
            [2015, 15047, 7, 5],
            [2015, 15048, 12, 10],
            [2015, 15049, 9, 6],
            [2015, 15050, 7, 5],
            [2015, 15051, 12, 10],
            [2015, 15052, 10, 6],
            [2015, 15053, 14, 11],
            [2015, 15054, 9, 5],
            [2015, 15055, 8, 5],
            [2015, 15056, 9, 7],
            [2015, 15057, 7, 5],
            [2015, 15058, 7, 5],
            [2015, 15059, 2, 1],
            [2015, 15060, 3, 1],
            [2015, 15061, 8, 6],
            [2015, 15062, 9, 6],
            [2015, 15063, 1, 1],
            [2015, 15064, 1, 1],
            [2015, 15065, 1, 1],
            [2015, 15066, 9, 6],
            [2015, 15067, 8, 5],
            [2015, 15068, 13, 10],
            [2015, 15070, 17, 15],
            [2015, 15071, 6, 5],
            [2015, 15072, 12, 10],
            [2015, 15073, 8, 6],
            [2015, 15074, 10, 7],
            [2015, 15075, 1, 1],
            [2015, 15076, 1, 1],
            [2015, 15077, 23, 13],
            [2015, 15078, 8, 6],
            [2015, 15079, 2, 1],
            [2015, 15081, 23, 16],
            [2015, 15082, 7, 5],
            [2015, 15083, 1, 1],
            [2015, 15084, 7, 6],
            [2015, 15085, 9, 7],
            [2015, 15086, 10, 7],
            [2015, 15087, 7, 6],
            [2015, 15088, 13, 10],
            [2015, 15089, 20, 14],
            [2015, 15090, 18, 13],
            [2015, 15091, 11, 10],
            [2015, 15092, 16, 9],
            [2015, 15093, 14, 9],
            [2015, 15094, 8, 7],
            [2015, 15095, 17, 13],
            [2015, 15096, 14, 9],
            [2015, 15097, 12, 10],
            [2015, 15098, 15, 12],
            [2015, 15099, 17, 13],
            [2015, 15100, 10, 10],
            [2015, 15101, 12, 10],
            [2015, 15102, 14, 9],
            [2015, 15103, 12, 8],
            [2015, 15104, 9, 6],
            [2015, 15106, 12, 7],
            [2015, 15107, 8, 7],
            [2015, 15108, 20, 13],
            [2015, 15109, 18, 12],
            [2015, 15110, 6, 5],
            [2015, 15111, 14, 9],
            [2015, 15112, 19, 12],
            [2015, 15113, 20, 12],
            [2015, 15114, 9, 8],
            [2015, 15115, 9, 7],
            [2015, 15116, 9, 8],
            [2015, 15117, 9, 8],
            [2015, 15118, 8, 7],
            [2015, 15119, 6, 5],
            [2015, 15120, 7, 7],
            [2015, 15121, 7, 5],
            [2015, 15122, 3, 3],
            [2015, 15123, 3, 3],
            [2015, 15124, 5, 5],
            [2015, 15125, 4, 5],
            [2015, 15126, 7, 6],
            [2015, 15127, 6, 5],
            [2015, 15128, 21, 13],
            [2015, 15129, 7, 5],
            [2015, 15130, 6, 5],
            [2015, 15131, 5, 4],
            [2015, 15132, 24, 15],
            [2015, 15133, 27, 12],
            [2015, 15134, 17, 12],
            [2015, 15135, 18, 11],
            [2015, 15136, 14, 10],
            [2015, 15137, 12, 9],
            [2015, 15138, 16, 10],
            [2015, 15139, 29, 16],
            [2015, 15140, 15, 10],
            [2015, 15141, 11, 7],
            [2015, 15142, 10, 7],
            [2015, 15143, 10, 7],
            [2015, 15144, 15, 9],
            [2015, 15145, 12, 9],
            [2015, 15146, 18, 12],
            [2015, 15147, 8, 6],
            [2015, 15148, 7, 5],
            [2015, 15149, 12, 9],
            [2015, 15150, 13, 8],
            [2015, 15151, 6, 5],
            [2015, 15152, 7, 6],
            [2015, 15153, 15, 9],
            [2015, 15154, 17, 9],
            [2015, 15155, 18, 13],
            [2015, 15156, 10, 9],
            [2015, 15157, 12, 11],
            [2015, 15158, 18, 11],
            [2015, 15159, 7, 6],
            [2015, 15160, 25, 15],
            [2015, 15161, 10, 8],
            [2015, 15162, 14, 9],
            [2015, 15163, 15, 9],
            [2015, 15164, 15, 9],
            [2015, 15165, 21, 10],
            [2015, 15166, 14, 11],
            [2015, 15167, 10, 12],
            [2015, 15168, 18, 13],
            [2015, 15169, 20, 9],
            [2015, 15170, 12, 10],
            [2015, 15171, 12, 7],
            [2015, 15172, 8, 6],
            [2015, 15173, 11, 10],
            [2015, 15174, 11, 7],
            [2015, 15175, 8, 6],
            [2015, 15176, 6, 6],
            [2015, 15177, 21, 12],
            [2015, 15178, 7, 5],
            [2015, 15179, 7, 5],
            [2015, 15180, 7, 5],
            [2015, 15181, 6, 5],
            [2015, 15182, 15, 10],
            [2015, 15183, 17, 10],
            [2015, 15184, 17, 11],
            [2015, 15185, 25, 14],
            [2015, 15186, 14, 10],
            [2015, 15187, 11, 10],
            [2015, 15188, 14, 11],
            [2015, 15189, 15, 12],
            [2015, 15190, 16, 9],
            [2015, 15191, 12, 9],
            [2015, 15192, 9, 8],
            [2015, 15193, 8, 7],
            [2015, 15194, 12, 10],
            [2015, 15195, 16, 13],
            [2015, 15196, 13, 8],
            [2015, 15197, 20, 12],
            [2015, 15198, 15, 11],
            [2015, 15199, 18, 9],
            [2015, 15200, 16, 11],
            [2015, 15201, 12, 9],
            [2015, 15202, 19, 11],
            [2015, 15203, 14, 9],
            [2015, 15204, 14, 8],
            [2015, 15206, 17, 9],
            [2015, 15207, 10, 8],
            [2015, 15208, 11, 8],
            [2015, 15209, 11, 10],
            [2015, 15210, 10, 9],
            [2015, 15211, 14, 10],
            [2015, 15212, 14, 11],
            [2015, 15213, 27, 16],
            [2015, 15214, 10, 7],
            [2015, 15215, 12, 10],
            [2015, 15216, 12, 9],
            [2015, 15217, 9, 8],
            [2015, 15218, 10, 9],
            [2015, 15219, 13, 9],
            [2015, 15220, 16, 8],
            [2015, 15221, 16, 11],
            [2015, 15222, 18, 10],
            [2015, 15223, 13, 8],
            [2015, 15224, 12, 9],
            [2015, 15225, 10, 8],
            [2015, 15227, 14, 13],
            [2015, 15228, 15, 12],
            [2015, 15229, 15, 8],
            [2015, 15230, 16, 10],
            [2015, 15231, 9, 10],
            [2015, 15232, 19, 12],
            [2015, 15233, 15, 10],
            [2015, 15234, 16, 11],
            [2015, 15235, 8, 8],
            [2015, 15236, 14, 10],
            [2015, 15237, 15, 9],
            [2015, 15238, 10, 9],
            [2015, 15239, 9, 8],
            [2015, 15240, 11, 8],
            [2015, 15241, 12, 8],
            [2015, 15242, 13, 10],
            [2015, 15243, 17, 10],
            [2015, 15244, 9, 7],
            [2015, 15245, 11, 8],
            [2015, 15246, 17, 12],
            [2015, 15247, 16, 11],
            [2015, 15248, 16, 12],
            [2015, 15249, 12, 8],
            [2015, 15250, 13, 9],
            [2015, 15252, 15, 12],
            [2015, 15253, 15, 10],
            [2015, 15254, 9, 6],
            [2015, 15255, 11, 11],
            [2015, 15256, 9, 7],
            [2015, 15257, 8, 9],
            [2015, 15258, 11, 7],
            [2015, 15260, 16, 11],
            [2015, 15261, 14, 8],
            [2015, 15262, 9, 7],
            [2015, 15263, 20, 9],
            [2015, 15264, 19, 12],
            [2015, 15265, 19, 13],
            [2015, 15266, 15, 10],
            [2015, 15267, 12, 9],
            [2015, 15268, 28, 11],
            [2015, 15269, 13, 10],
            [2015, 15270, 13, 7],
            [2015, 15271, 7, 7],
            [2015, 15272, 17, 14],
            [2015, 15273, 12, 6],
            [2015, 15274, 20, 14],
            [2015, 15275, 16, 11],
            [2015, 15276, 16, 10],
            [2015, 15277, 8, 7],
            [2015, 15278, 6, 6],
            [2015, 15280, 14, 11],
            [2015, 15281, 15, 9],
            [2015, 15282, 26, 13],
            [2015, 15283, 25, 12],
            [2015, 15284, 14, 11],
            [2015, 15285, 10, 9],
            [2015, 15286, 19, 12],
            [2015, 15287, 18, 10],
            [2015, 15288, 14, 7],
            [2015, 15289, 10, 9],
            [2015, 15290, 18, 11],
            [2015, 15291, 9, 6],
            [2015, 15292, 12, 9],
            [2015, 15293, 14, 9],
            [2015, 15294, 21, 12],
            [2015, 15295, 12, 11],
            [2015, 15296, 17, 14],
            [2015, 15297, 18, 12],
            [2015, 15298, 18, 10],
            [2015, 15299, 23, 13],
            [2015, 15300, 22, 12],
            [2015, 15301, 9, 7],
            [2015, 15302, 12, 9],
            [2015, 15303, 8, 6],
            [2015, 15304, 7, 9],
            [2015, 15305, 19, 10],
            [2015, 15306, 6, 6],
            [2015, 15307, 5, 6],
            [2015, 15308, 12, 10],
            [2015, 15309, 9, 9],
            [2015, 15310, 10, 6],
            [2015, 15311, 16, 11],
            [2015, 15312, 12, 10],
            [2015, 15313, 21, 10],
            [2015, 15314, 15, 10],
            [2015, 15315, 15, 10],
            [2015, 15316, 17, 10],
            [2015, 15317, 16, 10],
            [2015, 15318, 9, 7],
            [2015, 15319, 11, 10],
            [2015, 15320, 12, 9],
            [2015, 15321, 7, 5],
            [2015, 15323, 18, 11],
            [2015, 15324, 13, 10],
            [2015, 15325, 9, 6],
            [2015, 15326, 27, 16],
            [2015, 15327, 12, 10],
            [2015, 15328, 11, 7],
            [2015, 15329, 13, 8],
            [2015, 15331, 12, 11],
            [2015, 15332, 6, 5],
            [2015, 15333, 9, 7],
            [2015, 15334, 12, 8],
            [2015, 15335, 11, 10],
            [2015, 15336, 18, 11],
            [2015, 15337, 10, 10],
            [2015, 15338, 8, 6],
            [2015, 15339, 14, 9],
            [2015, 15340, 20, 10],
            [2015, 15341, 23, 11],
            [2015, 15342, 20, 13],
            [2015, 15343, 15, 11],
            [2015, 15344, 7, 7],
            [2015, 15345, 9, 8],
            [2015, 15346, 12, 8],
            [2015, 15347, 15, 10],
            [2015, 15348, 16, 10],
            [2015, 15349, 11, 8],
            [2015, 15350, 18, 10],
            [2015, 15351, 17, 9],
            [2015, 15352, 12, 7],
            [2015, 15353, 14, 11],
            [2015, 15354, 19, 12],
            [2015, 15355, 11, 10],
            [2015, 15356, 15, 9],
            [2015, 15357, 14, 12],
            [2015, 15358, 16, 10],
            [2015, 15359, 15, 12],
            [2015, 15360, 13, 13],
            [2015, 15361, 31, 22],
            [2015, 15362, 4, 5],
            [2015, 15363, 6, 7],
            [2015, 15364, 31, 16],
            [2015, 15365, 6, 6],
            [2015, 15366, 10, 10],
            [2015, 15367, 11, 10],
            [2015, 15368, 6, 6],
            [2015, 15369, 10, 8],
            [2015, 15370, 11, 9],
            [2015, 15371, 15, 12],
            [2015, 15372, 13, 11],
            [2015, 15373, 15, 12],
            [2015, 15374, 18, 11],
            [2015, 15375, 11, 10],
            [2015, 15376, 6, 5],
            [2015, 15377, 12, 10],
            [2015, 15378, 16, 10],
            [2015, 15379, 12, 10],
            [2015, 15380, 5, 5],
            [2015, 15381, 16, 10],
            [2015, 15382, 15, 10],
            [2015, 15383, 8, 7],
            [2015, 15385, 7, 6],
            [2015, 15386, 12, 10],
            [2015, 15387, 7, 6],
            [2015, 15389, 12, 13],
            [2015, 15390, 14, 10],
            [2015, 15391, 23, 13],
            [2015, 15392, 19, 12],
            [2015, 15393, 5, 5],
            [2015, 15394, 13, 12],
            [2015, 15395, 9, 8],
            [2015, 15396, 6, 5],
            [2015, 15397, 13, 10],
            [2015, 15398, 18, 13],
            [2015, 15400, 17, 10],
            [2015, 15401, 19, 11],
            [2015, 15402, 8, 8],
            [2015, 15403, 20, 10],
            [2015, 15404, 19, 11],
            [2015, 15405, 20, 11],
            [2015, 15408, 21, 12],
            [2015, 15409, 23, 11],
            [2015, 15410, 14, 9],
            [2015, 15411, 6, 6],
            [2015, 15412, 17, 11],
            [2015, 15414, 12, 9],
            [2015, 15415, 15, 10],
            [2015, 15416, 19, 11],
            [2015, 15418, 18, 11],
            [2015, 15419, 15, 12],
            [2015, 15420, 8, 7],
            [2015, 15440, 22, 22],
            [2015, 15441, 40, 34],
            [2015, 15442, 27, 18],
            [2015, 15443, 16, 13],
            [2015, 15444, 27, 23],
            [2015, 15445, 17, 14],
            [2015, 15446, 39, 35],
            [2015, 15447, 38, 26],
            [2015, 15448, 61, 33],
            [2015, 15449, 52, 37],
            [2015, 15450, 16, 16],
            [2015, 15451, 21, 21],
            [2015, 15452, 31, 29],
            [2015, 15453, 26, 25],
            [2015, 15454, 43, 20],
            [2015, 15455, 179, 32],
            [2015, 15456, 85, 35],
            [2015, 15457, 46, 26],
            [2015, 15458, 59, 36],
            [2015, 15459, 30, 29],
            [2015, 15460, 25, 43],
            [2015, 15461, 22, 20],
            [2015, 15462, 24, 23],
            [2015, 15463, 17, 20],
            [2015, 15464, 22, 23],
            [2015, 15465, 42, 33],
            [2015, 15466, 67, 64],
            [2015, 15467, 43, 44],
            [2015, 15468, 24, 20],
            [2015, 15469, 16, 20],
            [2015, 15470, 36, 36],
            [2015, 15471, 23, 20],
            [2015, 15472, 16, 29],
            [2015, 15473, 16, 21],
            [2015, 15474, 32, 36],
            [2015, 15475, 14, 24],
            [2015, 15476, 22, 36],
            [2015, 15477, 26, 27],
            [2015, 15478, 54, 44],
            [2015, 15479, 22, 34],
            [2015, 15480, 20, 31],
            [2015, 15481, 46, 48],
            [2015, 15482, 34, 44],
            [2015, 15483, 26, 30],
            [2015, 15484, 44, 39],
            [2015, 15485, 15, 31],
            [2015, 15486, 9, 17],
            [2015, 15487, 26, 33],
            [2015, 15488, 34, 40],
            [2015, 15489, 21, 22],
            [2015, 15490, 95, 86],
            [2015, 15491, 45, 39],
            [2015, 15492, 33, 36],
            [2015, 15493, 13, 35],
            [2015, 15494, 31, 33],
            [2015, 15495, 58, 43],
            [2015, 15496, 19, 26],
            [2015, 15497, 21, 20],
            [2015, 15498, 15, 16],
            [2015, 15499, 23, 20],
            [2015, 15500, 13, 11],
            [2015, 15501, 15, 11],
            [2015, 15502, 15, 11],
            [2015, 15503, 14, 11],
            [2015, 15504, 13, 11],
            [2015, 15505, 58, 50],
            [2015, 15506, 30, 66],
            [2015, 15507, 56, 46],
            [2015, 15508, 56, 46],
            [2015, 15509, 36, 36],
            [2015, 15510, 36, 36],
            [2015, 15511, 70, 52],
            [2015, 15512, 66, 66],
            [2015, 15513, 19, 38],
            [2015, 15514, 36, 62],
            [2015, 15515, 36, 56],
            [2015, 15516, 32, 36],
            [2015, 15517, 66, 66],
            [2015, 15518, 34, 32],
            [2015, 15519, 30, 55],
            [2015, 15520, 40, 58],
            [2015, 15521, 50, 51],
            [2015, 15522, 78, 64],
            [2015, 15523, 78, 64],
            [2015, 15524, 26, 50],
            [2015, 15525, 40, 66],
            [2015, 15526, 24, 23],
            [2015, 15527, 26, 36],
            [2015, 15528, 18, 35],
            [2015, 15529, 36, 58],
            [2015, 15530, 86, 78],
            [2015, 15531, 86, 78],
            [2015, 15532, 66, 66],
            [2015, 15533, 26, 58],
            [2015, 15534, 54, 58],
            [2015, 15535, 66, 66],
            [2015, 15536, 36, 42],
            [2015, 15537, 13, 11],
            [2015, 15538, 24, 21],
            [2015, 15539, 15, 16],
            [2015, 15540, 10, 14],
            [2015, 15541, 17, 14],
            [2015, 15542, 40, 40],
            [2015, 15543, 34, 24],
            [2015, 15544, 5, 5],
            [2015, 15548, 10, 9],
            [2015, 15550, 4, 4],
            [2015, 15551, 6, 6],
            [2015, 15552, 11, 9],
            [2015, 15553, 9, 8],
            [2015, 15554, 11, 9],
            [2015, 15555, 7, 7],
            [2015, 15556, 11, 9],
            [2015, 15557, 15, 9],
            [2015, 15558, 7, 7],
            [2015, 15559, 7, 7],
            [2015, 15560, 85, 30],
            [2015, 15561, 23, 18],
            [2015, 15562, 21, 27],
            [2015, 15563, 10, 9],
            [2015, 15564, 10, 8],
            [2015, 15565, 19, 14],
            [2015, 15566, 21, 14],
            [2015, 15567, 11, 8],
            [2015, 15568, 11, 9],
            [2015, 15569, 13, 11],
            [2015, 15570, 15, 13],
            [2015, 15571, 14, 12],
            [2015, 15572, 13, 11],
            [2015, 15573, 5, 5],
            [2015, 15574, 18, 10],
            [2015, 15575, 5, 7],
            [2015, 15576, 7, 8],
            [2015, 15577, 9, 9],
            [2015, 15578, 8, 8],
            [2015, 15579, 9, 7],
            [2015, 15580, 9, 8],
            [2015, 15581, 8, 7],
            [2015, 15582, 8, 7],
            [2015, 15583, 6, 6],
            [2015, 15584, 10, 8],
            [2015, 15585, 10, 8],
            [2015, 15586, 8, 8],
            [2015, 15587, 8, 7],
            [2015, 15588, 8, 7],
            [2015, 15589, 12, 9],
            [2015, 15590, 11, 9],
            [2015, 15591, 10, 9],
            [2015, 15592, 15, 13],
            [2015, 15593, 16, 10],
            [2015, 15594, 18, 12],
            [2015, 15595, 9, 8],
            [2015, 15596, 23, 13],
            [2015, 15597, 11, 8],
            [2015, 15598, 8, 7],
            [2015, 15599, 14, 9],
            [2015, 15600, 18, 13],
            [2015, 15601, 18, 13],
            [2015, 15602, 15, 11],
            [2015, 15603, 8, 7],
            [2015, 15604, 9, 7],
            [2015, 15605, 6, 6],
            [2015, 15606, 5, 6],
            [2015, 15607, 9, 7],
            [2015, 15608, 8, 6],
            [2015, 15609, 6, 6],
            [2015, 15610, 9, 7],
            [2015, 15611, 8, 6],
            [2015, 15612, 10, 11],
            [2015, 15613, 9, 8],
            [2015, 15614, 13, 13],
            [2015, 15615, 12, 10],
            [2015, 15616, 16, 13],
            [2015, 15617, 12, 10],
            [2015, 15618, 9, 8],
            [2015, 15619, 8, 8],
            [2015, 15620, 32, 25],
            [2015, 15621, 12, 10],
            [2015, 15622, 32, 25],
            [2015, 15623, 9, 9],
            [2015, 15624, 11, 11],
            [2015, 15625, 11, 9],
            [2015, 15626, 13, 11],
            [2015, 15627, 23, 13],
            [2015, 15628, 8, 8],
            [2015, 15629, 8, 9],
            [2015, 15630, 7, 8],
            [2015, 15631, 8, 8],
            [2015, 15632, 22, 12],
            [2015, 15633, 46, 36],
            [2015, 15634, 69, 45],
            [2015, 15635, 79, 54],
            [2015, 15636, 26, 17],
            [2015, 15637, 70, 45],
            [2015, 15638, 52, 35],
            [2015, 15639, 60, 45],
            [2015, 15640, 17, 11],
            [2015, 15641, 12, 10],
            [2015, 15642, 11, 10],
            [2015, 15643, 12, 11],
            [2015, 15644, 17, 11],
            [2015, 15645, 17, 11],
            [2015, 15646, 17, 10],
            [2015, 15647, 11, 10],
            [2015, 15648, 16, 12],
            [2015, 15649, 19, 14],
            [2015, 15650, 12, 8],
            [2015, 15651, 9, 6],
            [2015, 15652, 10, 7],
            [2015, 15653, 9, 6],
            [2015, 15654, 15, 11],
            [2015, 15655, 17, 13],
            [2015, 15656, 10, 7],
            [2015, 15657, 18, 12],
            [2015, 15658, 22, 11],
            [2015, 15659, 22, 11],
            [2015, 15660, 14, 11],
            [2015, 15661, 20, 13],
            [2015, 15662, 18, 12],
            [2015, 15663, 20, 13],
            [2015, 15664, 14, 11],
            [2015, 15665, 6, 6],
            [2015, 15666, 6, 6],
            [2015, 15667, 5, 5],
            [2015, 15668, 14, 12],
            [2015, 15669, 17, 10],
            [2015, 15670, 17, 10],
            [2015, 15671, 5, 5],
            [2015, 15672, 12, 11],
            [2015, 15673, 6, 6],
            [2015, 15674, 21, 14],
            [2015, 15675, 14, 11],
            [2015, 15676, 21, 13],
            [2015, 15677, 11, 9],
            [2015, 15678, 11, 9],
            [2015, 15679, 11, 8],
            [2015, 15680, 26, 15],
            [2015, 15681, 11, 9],
            [2015, 15682, 10, 8],
            [2015, 15683, 12, 9],
            [2015, 15684, 10, 8],
            [2015, 15685, 26, 15],
            [2015, 15686, 25, 17],
            [2015, 15687, 7, 7],
            [2015, 15688, 7, 7],
            [2015, 15689, 2, 1],
            [2015, 15690, 2, 1],
            [2015, 15691, 10, 7],
            [2015, 15692, 10, 6],
            [2015, 15693, 10, 8],
            [2015, 15694, 10, 8],
            [2015, 15695, 10, 8],
            [2015, 15696, 11, 8],
            [2015, 15697, 19, 18],
            [2015, 15698, 18, 15],
            [2015, 15699, 11, 10],
            [2015, 15700, 11, 9],
            [2015, 15701, 25, 13],
            [2015, 15702, 26, 14],
            [2015, 15703, 25, 14],
            [2015, 15704, 21, 12],
            [2015, 15705, 29, 15],
            [2015, 15706, 25, 14],
            [2015, 15707, 21, 12],
            [2015, 15708, 10, 7],
            [2015, 15709, 10, 7],
            [2015, 15710, 11, 9],
            [2015, 15711, 11, 9],
            [2015, 15712, 12, 9],
            [2015, 15713, 7, 5],
            [2015, 15714, 7, 5],
            [2015, 15715, 7, 5],
            [2015, 15716, 9, 6],
            [2015, 15717, 8, 6],
            [2015, 15718, 8, 6],
            [2015, 15719, 8, 5],
            [2015, 15720, 9, 6],
            [2015, 15721, 25, 12],
            [2015, 15722, 25, 12],
            [2015, 15723, 15, 11],
            [2015, 15724, 16, 11],
            [2015, 15725, 30, 24],
            [2015, 15726, 44, 34],
            [2015, 15727, 23, 13],
            [2015, 15728, 23, 17],
            [2015, 15729, 10, 11],
            [2015, 15730, 12, 15],
            [2015, 15731, 22, 17],
            [2015, 15732, 22, 27],
            [2015, 15733, 21, 14],
            [2015, 15734, 22, 16],
            [2015, 15735, 20, 18],
            [2015, 15736, 20, 18],
            [2015, 15737, 10, 10],
            [2015, 15738, 14, 14],
            [2015, 15739, 14, 14],
            [2015, 15740, 12, 11],
            [2015, 15741, 12, 11],
            [2015, 15742, 15, 11],
            [2015, 15743, 16, 12],
            [2015, 15744, 13, 19],
            [2015, 15745, 12, 20],
            [2015, 15746, 29, 23],
            [2015, 15747, 22, 15],
            [2015, 15748, 22, 15],
            [2015, 15749, 29, 23],
            [2015, 15750, 27, 19],
            [2015, 15751, 11, 12],
            [2015, 15752, 12, 10],
            [2015, 15753, 11, 8],
            [2015, 15754, 20, 18],
            [2015, 15755, 22, 14],
            [2015, 15756, 21, 13],
            [2015, 15757, 13, 9],
            [2015, 15758, 13, 9],
            [2015, 15759, 17, 14],
            [2015, 15760, 25, 17],
            [2015, 15761, 37, 20],
            [2015, 15762, 13, 9],
            [2015, 15763, 12, 10],
            [2015, 15764, 11, 8],
            [2015, 15765, 10, 8],
            [2015, 15766, 20, 18],
            [2015, 15767, 22, 14],
            [2015, 15768, 14, 10],
            [2015, 15769, 13, 9],
            [2015, 15770, 17, 14],
            [2015, 15771, 37, 20],
            [2015, 15772, 25, 17],
            [2015, 15773, 13, 9],
            [2015, 15774, 16, 10],
            [2015, 15775, 20, 13],
            [2015, 15776, 16, 10],
            [2015, 15777, 19, 12],
            [2015, 15778, 16, 10],
            [2015, 15779, 7, 9],
            [2015, 15780, 10, 9],
            [2015, 15781, 10, 9],
            [2015, 15782, 7, 8],
            [2015, 15783, 10, 9],
            [2015, 15784, 7, 7],
            [2015, 15785, 7, 8],
            [2015, 15786, 9, 10],
            [2015, 15787, 7, 9],
            [2015, 15788, 16, 11],
            [2015, 15789, 19, 12],
            [2015, 15790, 19, 13],
            [2015, 15791, 8, 8],
            [2015, 15792, 10, 10],
            [2015, 15793, 7, 7],
            [2015, 15794, 11, 10],
            [2015, 15795, 19, 13],
            [2015, 15796, 8, 8],
            [2015, 15797, 9, 9],
            [2015, 15798, 15, 14],
            [2015, 15799, 14, 13],
            [2015, 15800, 18, 15],
            [2015, 15801, 33, 19],
            [2015, 15802, 15, 13],
            [2015, 15803, 15, 12],
            [2015, 15804, 34, 16],
            [2015, 15805, 22, 15],
            [2015, 15806, 34, 22],
            [2015, 15807, 15, 14],
            [2015, 15808, 13, 11],
            [2015, 15809, 16, 13],
            [2015, 15810, 18, 13],
            [2015, 15811, 18, 13],
            [2016, 964, 8, 8],
            [2016, 2142, 10, 9],
            [2016, 2922, 8, 8],
            [2016, 4536, 10, 9],
            [2016, 5273, 11, 9],
            [2016, 11581, 9, 8],
            [2016, 11582, 12, 10],
            [2016, 12312, 127, 79],
            [2016, 12313, 85, 67],
            [2016, 12314, 85, 67],
            [2016, 12315, 127, 79],
            [2016, 12316, 127, 79],
            [2016, 12317, 127, 79],
            [2016, 12318, 127, 79],
            [2016, 12319, 127, 79],
            [2016, 12320, 85, 67],
            [2016, 12321, 55, 61],
            [2016, 12322, 127, 79],
            [2016, 12323, 127, 79],
            [2016, 12324, 85, 67],
            [2016, 12325, 85, 67],
            [2016, 12474, 16, 14],
            [2016, 12475, 22, 14],
            [2016, 12476, 13, 11],
            [2016, 12477, 22, 15],
            [2016, 12478, 21, 17],
            [2016, 12479, 17, 17],
            [2016, 12480, 13, 11],
            [2016, 12481, 53, 31],
            [2016, 12482, 16, 12],
            [2016, 12483, 43, 36],
            [2016, 12484, 17, 13],
            [2016, 12485, 71, 34],
            [2016, 12486, 83, 32],
            [2016, 12487, 38, 22],
            [2016, 12488, 42, 29],
            [2016, 12489, 61, 17],
            [2016, 12523, 15, 9],
            [2016, 12524, 28, 17],
            [2016, 12525, 18, 14],
            [2016, 12526, 12, 10],
            [2016, 12527, 8, 8],
            [2016, 12528, 9, 9],
            [2016, 12529, 9, 9],
            [2016, 12530, 14, 9],
            [2016, 12532, 12, 9],
            [2016, 12534, 10, 9],
            [2016, 12535, 16, 11],
            [2016, 12536, 9, 9],
            [2016, 12537, 8, 8],
            [2016, 12538, 10, 10],
            [2016, 12539, 12, 9],
            [2016, 12540, 11, 10],
            [2016, 12541, 14, 10],
            [2016, 12542, 11, 10],
            [2016, 12543, 14, 12],
            [2016, 12545, 9, 8],
            [2016, 12546, 18, 15],
            [2016, 12547, 14, 13],
            [2016, 12548, 25, 16],
            [2016, 12549, 9, 8],
            [2016, 12550, 9, 8],
            [2016, 12551, 18, 13],
            [2016, 12552, 22, 13],
            [2016, 12553, 14, 10],
            [2016, 12554, 7, 8],
            [2016, 12556, 7, 7],
            [2016, 12557, 9, 9],
            [2016, 12558, 10, 10],
            [2016, 12559, 10, 9],
            [2016, 12560, 4, 5],
            [2016, 12561, 6, 6],
            [2016, 12562, 7, 8],
            [2016, 12563, 11, 9],
            [2016, 12565, 16, 11],
            [2016, 12566, 11, 9],
            [2016, 12567, 9, 8],
            [2016, 12568, 20, 17],
            [2016, 12569, 22, 18],
            [2016, 12570, 15, 13],
            [2016, 12571, 26, 14],
            [2016, 12573, 19, 15],
            [2016, 12574, 9, 9],
            [2016, 12575, 11, 9],
            [2016, 12576, 20, 13],
            [2016, 12577, 8, 9],
            [2016, 12578, 20, 16],
            [2016, 12579, 10, 12],
            [2016, 12580, 11, 10],
            [2016, 12581, 87, 86],
            [2016, 12582, 105, 119],
            [2016, 12583, 86, 91],
            [2016, 12584, 93, 71],
            [2016, 12585, 95, 90],
            [2016, 12586, 46, 17],
            [2016, 12589, 43, 35],
            [2016, 12590, 34, 25],
            [2016, 12591, 46, 35],
            [2016, 12592, 53, 37],
            [2016, 12593, 37, 25],
            [2016, 12594, 27, 24],
            [2016, 12595, 43, 41],
            [2016, 12596, 22, 19],
            [2016, 12597, 20, 18],
            [2016, 12598, 49, 39],
            [2016, 12599, 44, 39],
            [2016, 12600, 48, 39],
            [2016, 12634, 24, 18],
            [2016, 12635, 57, 43],
            [2016, 12636, 17, 17],
            [2016, 12637, 31, 15],
            [2016, 12638, 53, 19],
            [2016, 12639, 9, 7],
            [2016, 12640, 10, 8],
            [2016, 12641, 16, 16],
            [2016, 12642, 13, 12],
            [2016, 12643, 27, 21],
            [2016, 12644, 23, 16],
            [2016, 12645, 34, 34],
            [2016, 12646, 25, 21],
            [2016, 12647, 14, 17],
            [2016, 12648, 23, 17],
            [2016, 12649, 21, 16],
            [2016, 12650, 18, 15],
            [2016, 12651, 27, 18],
            [2016, 12652, 28, 20],
            [2016, 12653, 31, 26],
            [2016, 12654, 14, 13],
            [2016, 12655, 25, 20],
            [2016, 12656, 28, 18],
            [2016, 12657, 14, 13],
            [2016, 12658, 35, 24],
            [2016, 12660, 38, 27],
            [2016, 12661, 35, 27],
            [2016, 12662, 32, 24],
            [2016, 12663, 33, 23],
            [2016, 12664, 40, 29],
            [2016, 12665, 31, 26],
            [2016, 12668, 5, 4],
            [2016, 12669, 4, 3],
            [2016, 12670, 7, 7],
            [2016, 12671, 11, 9],
            [2016, 12672, 11, 10],
            [2016, 12673, 10, 10],
            [2016, 12674, 9, 8],
            [2016, 12675, 12, 11],
            [2016, 12680, 13, 10],
            [2016, 12681, 5, 4],
            [2016, 12682, 12, 9],
            [2016, 12683, 10, 9],
            [2016, 12685, 29, 18],
            [2016, 12686, 18, 14],
            [2016, 12687, 21, 15],
            [2016, 12688, 18, 14],
            [2016, 12689, 26, 16],
            [2016, 12690, 27, 16],
            [2016, 12691, 28, 16],
            [2016, 12692, 27, 18],
            [2016, 12693, 24, 16],
            [2016, 12695, 28, 16],
            [2016, 12696, 26, 14],
            [2016, 12697, 24, 17],
            [2016, 12699, 8, 7],
            [2016, 12703, 25, 23],
            [2016, 12704, 16, 11],
            [2016, 12705, 23, 12],
            [2016, 12706, 25, 18],
            [2016, 12707, 27, 17],
            [2016, 12708, 20, 14],
            [2016, 12709, 27, 17],
            [2016, 12710, 32, 19],
            [2016, 12711, 29, 19],
            [2016, 12712, 33, 25],
            [2016, 12713, 26, 22],
            [2016, 12714, 34, 21],
            [2016, 12715, 34, 22],
            [2016, 12716, 21, 16],
            [2016, 12717, 24, 17],
            [2016, 12718, 19, 13],
            [2016, 12719, 22, 15],
            [2016, 12720, 23, 16],
            [2016, 12721, 23, 13],
            [2016, 12722, 10, 9],
            [2016, 12723, 14, 12],
            [2016, 12724, 9, 8],
            [2016, 12725, 9, 10],
            [2016, 12726, 7, 8],
            [2016, 12727, 15, 21],
            [2016, 12728, 8, 8],
            [2016, 12729, 15, 24],
            [2016, 12730, 21, 10],
            [2016, 12731, 15, 22],
            [2016, 12732, 11, 11],
            [2016, 12735, 9, 9],
            [2016, 12736, 13, 11],
            [2016, 12737, 20, 11],
            [2016, 12738, 8, 8],
            [2016, 12739, 10, 11],
            [2016, 12740, 13, 13],
            [2016, 12741, 14, 13],
            [2016, 12742, 7, 7],
            [2016, 12743, 20, 11],
            [2016, 12744, 10, 9],
            [2016, 12745, 10, 11],
            [2016, 12746, 8, 9],
            [2016, 12747, 10, 10],
            [2016, 12748, 7, 10],
            [2016, 12749, 8, 10],
            [2016, 12750, 7, 7],
            [2016, 12751, 6, 7],
            [2016, 12752, 17, 11],
            [2016, 12753, 8, 9],
            [2016, 12754, 8, 7],
            [2016, 12755, 6, 6],
            [2016, 12756, 10, 8],
            [2016, 12757, 6, 7],
            [2016, 12758, 9, 9],
            [2016, 12759, 11, 10],
            [2016, 12760, 19, 14],
            [2016, 12761, 9, 10],
            [2016, 12762, 8, 8],
            [2016, 12763, 10, 11],
            [2016, 12765, 8, 8],
            [2016, 12766, 11, 12],
            [2016, 12767, 11, 12],
            [2016, 12768, 10, 9],
            [2016, 12770, 8, 9],
            [2016, 12771, 14, 12],
            [2016, 12772, 9, 9],
            [2016, 12773, 8, 8],
            [2016, 12775, 13, 12],
            [2016, 12776, 15, 13],
            [2016, 12777, 8, 7],
            [2016, 12778, 14, 13],
            [2016, 12779, 11, 10],
            [2016, 12780, 8, 8],
            [2016, 12781, 15, 13],
            [2016, 12782, 9, 10],
            [2016, 12783, 8, 7],
            [2016, 12784, 15, 14],
            [2016, 12785, 19, 12],
            [2016, 12786, 9, 9],
            [2016, 12787, 13, 13],
            [2016, 12788, 7, 8],
            [2016, 12789, 10, 11],
            [2016, 12790, 15, 11],
            [2016, 12791, 11, 8],
            [2016, 12792, 13, 11],
            [2016, 12793, 11, 10],
            [2016, 12795, 12, 9],
            [2016, 12796, 9, 9],
            [2016, 12797, 10, 8],
            [2016, 12798, 8, 10],
            [2016, 12799, 6, 8],
            [2016, 12800, 16, 9],
            [2016, 12801, 8, 6],
            [2016, 12802, 8, 8],
            [2016, 12803, 63, 39],
            [2016, 12804, 11, 10],
            [2016, 12805, 15, 9],
            [2016, 12806, 10, 9],
            [2016, 12807, 25, 13],
            [2016, 12808, 11, 11],
            [2016, 12809, 6, 8],
            [2016, 12810, 12, 13],
            [2016, 12811, 10, 10],
            [2016, 12812, 14, 12],
            [2016, 12813, 9, 8],
            [2016, 12814, 10, 10],
            [2016, 12815, 11, 10],
            [2016, 12816, 7, 7],
            [2016, 12817, 9, 8],
            [2016, 12818, 9, 8],
            [2016, 12819, 12, 12],
            [2016, 12820, 9, 8],
            [2016, 12821, 7, 4],
            [2016, 12822, 10, 9],
            [2016, 12823, 5, 4],
            [2016, 12824, 9, 10],
            [2016, 12825, 9, 8],
            [2016, 12826, 7, 6],
            [2016, 12827, 25, 14],
            [2016, 12828, 9, 7],
            [2016, 12829, 10, 10],
            [2016, 12830, 9, 5],
            [2016, 12831, 49, 32],
            [2016, 12832, 18, 14],
            [2016, 12833, 8, 5],
            [2016, 12834, 22, 12],
            [2016, 12835, 5, 4],
            [2016, 12836, 15, 9],
            [2016, 12837, 5, 4],
            [2016, 12838, 8, 5],
            [2016, 12839, 5, 4],
            [2016, 12840, 14, 8],
            [2016, 12841, 3, 2],
            [2016, 12843, 5, 5],
            [2016, 12845, 9, 6],
            [2016, 12847, 19, 11],
            [2016, 12848, 10, 7],
            [2016, 12849, 7, 8],
            [2016, 12850, 21, 10],
            [2016, 12852, 8, 8],
            [2016, 12853, 6, 4],
            [2016, 12854, 25, 16],
            [2016, 12855, 4, 3],
            [2016, 12856, 14, 8],
            [2016, 12857, 8, 6],
            [2016, 12858, 3, 2],
            [2016, 12860, 14, 10],
            [2016, 12862, 5, 5],
            [2016, 12863, 66, 29],
            [2016, 12864, 5, 4],
            [2016, 12865, 25, 11],
            [2016, 12866, 5, 4],
            [2016, 12867, 59, 21],
            [2016, 12868, 8, 5],
            [2016, 12869, 10, 9],
            [2016, 12870, 6, 5],
            [2016, 12871, 41, 16],
            [2016, 12872, 8, 6],
            [2016, 12873, 10, 9],
            [2016, 12874, 6, 5],
            [2016, 12875, 58, 33],
            [2016, 12876, 10, 7],
            [2016, 12877, 6, 5],
            [2016, 12878, 10, 8],
            [2016, 12879, 8, 8],
            [2016, 12880, 6, 5],
            [2016, 12881, 11, 8],
            [2016, 12882, 10, 8],
            [2016, 12883, 5, 4],
            [2016, 12884, 28, 17],
            [2016, 12885, 3, 2],
            [2016, 12886, 18, 13],
            [2016, 12887, 5, 4],
            [2016, 12888, 12, 9],
            [2016, 12889, 75, 33],
            [2016, 12891, 33, 18],
            [2016, 12892, 9, 7],
            [2016, 12894, 14, 10],
            [2016, 12895, 6, 5],
            [2016, 12896, 29, 16],
            [2016, 12898, 15, 10],
            [2016, 12899, 14, 10],
            [2016, 12900, 8, 6],
            [2016, 12901, 22, 12],
            [2016, 12902, 7, 5],
            [2016, 12903, 18, 19],
            [2016, 12905, 24, 14],
            [2016, 12907, 13, 11],
            [2016, 12909, 5, 4],
            [2016, 12910, 9, 6],
            [2016, 12911, 4, 4],
            [2016, 12912, 10, 8],
            [2016, 12913, 7, 6],
            [2016, 12914, 7, 5],
            [2016, 12915, 4, 3],
            [2016, 12916, 7, 5],
            [2016, 12921, 12, 9],
            [2016, 12922, 9, 7],
            [2016, 12924, 10, 8],
            [2016, 12925, 6, 5],
            [2016, 12926, 6, 5],
            [2016, 12927, 11, 9],
            [2016, 12928, 19, 12],
            [2016, 12929, 7, 5],
            [2016, 12930, 8, 6],
            [2016, 12934, 9, 6],
            [2016, 12935, 7, 6],
            [2016, 12936, 4, 3],
            [2016, 12938, 7, 5],
            [2016, 12939, 3, 2],
            [2016, 12942, 9, 7],
            [2016, 12945, 4, 3],
            [2016, 12946, 6, 4],
            [2016, 12947, 9, 6],
            [2016, 12948, 6, 5],
            [2016, 12950, 8, 6],
            [2016, 12951, 8, 6],
            [2016, 12952, 15, 12],
            [2016, 12953, 11, 9],
            [2016, 12954, 10, 7],
            [2016, 12955, 6, 5],
            [2016, 12956, 5, 4],
            [2016, 12957, 8, 6],
            [2016, 12958, 7, 6],
            [2016, 12959, 6, 4],
            [2016, 12960, 7, 5],
            [2016, 12961, 6, 4],
            [2016, 12964, 9, 6],
            [2016, 12965, 13, 10],
            [2016, 12966, 10, 7],
            [2016, 12967, 9, 7],
            [2016, 12968, 11, 9],
            [2016, 12969, 7, 5],
            [2016, 12970, 7, 5],
            [2016, 12971, 8, 6],
            [2016, 12973, 6, 4],
            [2016, 12974, 8, 5],
            [2016, 12975, 6, 5],
            [2016, 12976, 6, 5],
            [2016, 12977, 4, 3],
            [2016, 12980, 7, 5],
            [2016, 12981, 8, 5],
            [2016, 12982, 9, 8],
            [2016, 12983, 8, 5],
            [2016, 12985, 8, 6],
            [2016, 12986, 5, 4],
            [2016, 12987, 8, 6],
            [2016, 12988, 13, 10],
            [2016, 12991, 6, 5],
            [2016, 12993, 4, 3],
            [2016, 12994, 7, 5],
            [2016, 12995, 5, 4],
            [2016, 12996, 7, 5],
            [2016, 12997, 8, 5],
            [2016, 12999, 7, 5],
            [2016, 13000, 6, 5],
            [2016, 13001, 10, 10],
            [2016, 13002, 12, 11],
            [2016, 13004, 20, 14],
            [2016, 13006, 18, 14],
            [2016, 13007, 15, 13],
            [2016, 13008, 21, 15],
            [2016, 13009, 16, 14],
            [2016, 13010, 16, 14],
            [2016, 13011, 25, 16],
            [2016, 13012, 19, 15],
            [2016, 13013, 12, 11],
            [2016, 13014, 16, 14],
            [2016, 13015, 11, 12],
            [2016, 13016, 13, 11],
            [2016, 13017, 8, 4],
            [2016, 13018, 15, 15],
            [2016, 13019, 13, 7],
            [2016, 13020, 9, 12],
            [2016, 13021, 13, 15],
            [2016, 13022, 9, 4],
            [2016, 13023, 16, 11],
            [2016, 13024, 25, 17],
            [2016, 13025, 10, 13],
            [2016, 13026, 16, 10],
            [2016, 13027, 14, 9],
            [2016, 13028, 7, 4],
            [2016, 13029, 12, 12],
            [2016, 13030, 13, 12],
            [2016, 13031, 10, 9],
            [2016, 13032, 19, 14],
            [2016, 13033, 9, 7],
            [2016, 13034, 6, 4],
            [2016, 13035, 8, 4],
            [2016, 13036, 15, 7],
            [2016, 13037, 8, 5],
            [2016, 13038, 16, 11],
            [2016, 13039, 10, 9],
            [2016, 13040, 15, 12],
            [2016, 13041, 12, 10],
            [2016, 13042, 6, 7],
            [2016, 13043, 8, 5],
            [2016, 13044, 12, 14],
            [2016, 13045, 6, 7],
            [2016, 13046, 15, 12],
            [2016, 13047, 15, 14],
            [2016, 13048, 11, 9],
            [2016, 13049, 11, 10],
            [2016, 13050, 11, 9],
            [2016, 13051, 13, 12],
            [2016, 13052, 10, 10],
            [2016, 13053, 9, 7],
            [2016, 13054, 14, 14],
            [2016, 13055, 17, 11],
            [2016, 13056, 12, 12],
            [2016, 13057, 13, 11],
            [2016, 13058, 15, 14],
            [2016, 13059, 11, 7],
            [2016, 13060, 15, 10],
            [2016, 13061, 16, 13],
            [2016, 13062, 12, 9],
            [2016, 13063, 23, 5],
            [2016, 13064, 9, 10],
            [2016, 13065, 11, 11],
            [2016, 13066, 10, 9],
            [2016, 13067, 14, 11],
            [2016, 13068, 12, 13],
            [2016, 13069, 18, 13],
            [2016, 13070, 9, 4],
            [2016, 13071, 11, 6],
            [2016, 13072, 9, 10],
            [2016, 13073, 9, 8],
            [2016, 13074, 11, 10],
            [2016, 13075, 15, 14],
            [2016, 13076, 11, 7],
            [2016, 13077, 20, 15],
            [2016, 13078, 27, 20],
            [2016, 13079, 10, 11],
            [2016, 13080, 11, 7],
            [2016, 13081, 12, 11],
            [2016, 13082, 7, 6],
            [2016, 13083, 12, 8],
            [2016, 13084, 20, 13],
            [2016, 13085, 22, 14],
            [2016, 13086, 6, 5],
            [2016, 13087, 13, 9],
            [2016, 13088, 16, 10],
            [2016, 13089, 10, 9],
            [2016, 13090, 11, 10],
            [2016, 13091, 7, 4],
            [2016, 13092, 20, 14],
            [2016, 13093, 12, 7],
            [2016, 13094, 24, 13],
            [2016, 13095, 12, 11],
            [2016, 13096, 9, 10],
            [2016, 13097, 15, 10],
            [2016, 13098, 12, 10],
            [2016, 13099, 7, 10],
            [2016, 13100, 18, 15],
            [2016, 13101, 16, 12],
            [2016, 13102, 15, 12],
            [2016, 13103, 17, 13],
            [2016, 13104, 16, 19],
            [2016, 13105, 15, 11],
            [2016, 13106, 14, 10],
            [2016, 13107, 14, 10],
            [2016, 13108, 15, 12],
            [2016, 13109, 11, 10],
            [2016, 13111, 15, 11],
            [2016, 13112, 12, 10],
            [2016, 13113, 14, 9],
            [2016, 13114, 10, 10],
            [2016, 13115, 14, 9],
            [2016, 13116, 14, 13],
            [2016, 13117, 15, 12],
            [2016, 13118, 12, 9],
            [2016, 13119, 19, 14],
            [2016, 13120, 10, 6],
            [2016, 13121, 15, 14],
            [2016, 13122, 24, 12],
            [2016, 13123, 15, 11],
            [2016, 13124, 11, 10],
            [2016, 13125, 9, 8],
            [2016, 13126, 17, 12],
            [2016, 13127, 15, 11],
            [2016, 13128, 10, 10],
            [2016, 13129, 20, 14],
            [2016, 13130, 16, 11],
            [2016, 13131, 12, 9],
            [2016, 13132, 12, 10],
            [2016, 13133, 17, 11],
            [2016, 13134, 14, 10],
            [2016, 13136, 14, 15],
            [2016, 13137, 18, 14],
            [2016, 13138, 14, 10],
            [2016, 13140, 14, 9],
            [2016, 13142, 8, 7],
            [2016, 13143, 7, 6],
            [2016, 13144, 10, 9],
            [2016, 13145, 6, 6],
            [2016, 13147, 10, 8],
            [2016, 13148, 10, 9],
            [2016, 13154, 7, 7],
            [2016, 13155, 8, 7],
            [2016, 13156, 8, 7],
            [2016, 13158, 7, 6],
            [2016, 13159, 9, 7],
            [2016, 13161, 7, 7],
            [2016, 13163, 10, 7],
            [2016, 13164, 8, 7],
            [2016, 13165, 9, 6],
            [2016, 13166, 8, 7],
            [2016, 13167, 15, 9],
            [2016, 13168, 7, 6],
            [2016, 13170, 11, 8],
            [2016, 13172, 7, 6],
            [2016, 13173, 10, 8],
            [2016, 13175, 7, 6],
            [2016, 13177, 9, 8],
            [2016, 13178, 10, 8],
            [2016, 13179, 9, 7],
            [2016, 13180, 13, 9],
            [2016, 13181, 7, 7],
            [2016, 13182, 8, 7],
            [2016, 13183, 26, 17],
            [2016, 13184, 7, 6],
            [2016, 13185, 10, 9],
            [2016, 13186, 13, 12],
            [2016, 13187, 7, 9],
            [2016, 13188, 7, 9],
            [2016, 13189, 10, 9],
            [2016, 13190, 7, 8],
            [2016, 13191, 17, 12],
            [2016, 13192, 8, 9],
            [2016, 13193, 8, 9],
            [2016, 13194, 11, 8],
            [2016, 13195, 20, 12],
            [2016, 13196, 15, 9],
            [2016, 13197, 66, 25],
            [2016, 13198, 11, 9],
            [2016, 13200, 16, 11],
            [2016, 13201, 14, 10],
            [2016, 13202, 17, 11],
            [2016, 13203, 8, 7],
            [2016, 13204, 19, 11],
            [2016, 13205, 8, 9],
            [2016, 13206, 13, 10],
            [2016, 13207, 10, 9],
            [2016, 13208, 9, 9],
            [2016, 13209, 7, 7],
            [2016, 13210, 20, 14],
            [2016, 13211, 11, 9],
            [2016, 13212, 50, 25],
            [2016, 13213, 23, 13],
            [2016, 13214, 17, 13],
            [2016, 13216, 18, 12],
            [2016, 13218, 12, 10],
            [2016, 13219, 9, 9],
            [2016, 13220, 9, 9],
            [2016, 13222, 9, 9],
            [2016, 13223, 15, 12],
            [2016, 13224, 47, 18],
            [2016, 13225, 14, 10],
            [2016, 13226, 9, 9],
            [2016, 13227, 18, 12],
            [2016, 13230, 21, 13],
            [2016, 13232, 12, 10],
            [2016, 13233, 13, 10],
            [2016, 13234, 17, 10],
            [2016, 13235, 13, 9],
            [2016, 13236, 10, 8],
            [2016, 13238, 12, 10],
            [2016, 13239, 15, 9],
            [2016, 13240, 13, 10],
            [2016, 13242, 14, 10],
            [2016, 13244, 19, 12],
            [2016, 13245, 13, 10],
            [2016, 13246, 14, 9],
            [2016, 13247, 18, 11],
            [2016, 13248, 11, 9],
            [2016, 13249, 10, 7],
            [2016, 13250, 16, 11],
            [2016, 13251, 13, 10],
            [2016, 13252, 17, 11],
            [2016, 13253, 12, 10],
            [2016, 13254, 11, 9],
            [2016, 13255, 10, 8],
            [2016, 13256, 12, 9],
            [2016, 13257, 14, 10],
            [2016, 13258, 19, 12],
            [2016, 13260, 13, 9],
            [2016, 13261, 15, 10],
            [2016, 13262, 16, 11],
            [2016, 13263, 13, 10],
            [2016, 13264, 14, 10],
            [2016, 13265, 20, 14],
            [2016, 13266, 13, 9],
            [2016, 13267, 30, 23],
            [2016, 13269, 11, 9],
            [2016, 13270, 16, 10],
            [2016, 13271, 10, 9],
            [2016, 13272, 8, 7],
            [2016, 13273, 12, 9],
            [2016, 13274, 8, 8],
            [2016, 13275, 12, 10],
            [2016, 13276, 10, 8],
            [2016, 13279, 27, 15],
            [2016, 13280, 12, 9],
            [2016, 13281, 11, 11],
            [2016, 13282, 13, 10],
            [2016, 13283, 17, 14],
            [2016, 13284, 15, 12],
            [2016, 13285, 13, 9],
            [2016, 13286, 16, 11],
            [2016, 13288, 18, 11],
            [2016, 13289, 15, 11],
            [2016, 13290, 7, 7],
            [2016, 13291, 13, 10],
            [2016, 13292, 7, 7],
            [2016, 13293, 15, 13],
            [2016, 13295, 18, 12],
            [2016, 13296, 14, 12],
            [2016, 13297, 13, 9],
            [2016, 13298, 15, 12],
            [2016, 13299, 8, 9],
            [2016, 13300, 10, 11],
            [2016, 13302, 12, 10],
            [2016, 13303, 12, 12],
            [2016, 13304, 16, 11],
            [2016, 13305, 12, 9],
            [2016, 13306, 7, 6],
            [2016, 13307, 17, 15],
            [2016, 13308, 12, 10],
            [2016, 13309, 8, 8],
            [2016, 13311, 8, 8],
            [2016, 13312, 16, 10],
            [2016, 13313, 37, 20],
            [2016, 13314, 24, 16],
            [2016, 13315, 15, 10],
            [2016, 13316, 10, 8],
            [2016, 13317, 10, 7],
            [2016, 13318, 8, 8],
            [2016, 13319, 16, 10],
            [2016, 13320, 18, 13],
            [2016, 13321, 11, 11],
            [2016, 13322, 12, 9],
            [2016, 13323, 19, 12],
            [2016, 13325, 11, 12],
            [2016, 13326, 14, 9],
            [2016, 13327, 17, 10],
            [2016, 13328, 12, 9],
            [2016, 13329, 11, 10],
            [2016, 13330, 13, 9],
            [2016, 13331, 14, 11],
            [2016, 13332, 12, 9],
            [2016, 13333, 11, 11],
            [2016, 13334, 10, 9],
            [2016, 13335, 23, 18],
            [2016, 13336, 12, 9],
            [2016, 13339, 10, 8],
            [2016, 13340, 14, 10],
            [2016, 13341, 9, 7],
            [2016, 13342, 8, 7],
            [2016, 13343, 12, 9],
            [2016, 13344, 9, 8],
            [2016, 13345, 18, 13],
            [2016, 13346, 8, 6],
            [2016, 13347, 18, 18],
            [2016, 13348, 16, 10],
            [2016, 13349, 26, 16],
            [2016, 13350, 13, 10],
            [2016, 13351, 7, 7],
            [2016, 13352, 9, 8],
            [2016, 13353, 16, 9],
            [2016, 13355, 14, 9],
            [2016, 13356, 8, 6],
            [2016, 13357, 22, 16],
            [2016, 13358, 12, 10],
            [2016, 13359, 25, 16],
            [2016, 13360, 10, 7],
            [2016, 13361, 25, 17],
            [2016, 13362, 12, 10],
            [2016, 13363, 15, 11],
            [2016, 13364, 9, 9],
            [2016, 13365, 10, 6],
            [2016, 13366, 8, 8],
            [2016, 13367, 10, 6],
            [2016, 13368, 14, 15],
            [2016, 13369, 13, 9],
            [2016, 13370, 13, 9],
            [2016, 13372, 12, 10],
            [2016, 13373, 8, 8],
            [2016, 13374, 12, 9],
            [2016, 13375, 12, 9],
            [2016, 13376, 7, 8],
            [2016, 13378, 10, 8],
            [2016, 13379, 11, 9],
            [2016, 13380, 11, 10],
            [2016, 13381, 7, 7],
            [2016, 13382, 14, 9],
            [2016, 13384, 15, 13],
            [2016, 13385, 6, 6],
            [2016, 13386, 14, 10],
            [2016, 13387, 12, 10],
            [2016, 13388, 9, 9],
            [2016, 13389, 11, 9],
            [2016, 13390, 12, 10],
            [2016, 13391, 8, 8],
            [2016, 13392, 14, 9],
            [2016, 13393, 25, 22],
            [2016, 13394, 13, 9],
            [2016, 13395, 12, 9],
            [2016, 13396, 42, 21],
            [2016, 13397, 6, 6],
            [2016, 13398, 21, 14],
            [2016, 13399, 12, 9],
            [2016, 13401, 9, 8],
            [2016, 13402, 16, 10],
            [2016, 13403, 14, 12],
            [2016, 13404, 20, 15],
            [2016, 13405, 27, 15],
            [2016, 13407, 16, 15],
            [2016, 13408, 14, 11],
            [2016, 13409, 13, 11],
            [2016, 13410, 17, 12],
            [2016, 13411, 9, 9],
            [2016, 13412, 31, 17],
            [2016, 13413, 21, 15],
            [2016, 13414, 20, 12],
            [2016, 13415, 16, 12],
            [2016, 13416, 10, 9],
            [2016, 13417, 10, 8],
            [2016, 13418, 8, 7],
            [2016, 13419, 35, 17],
            [2016, 13420, 9, 8],
            [2016, 13421, 12, 10],
            [2016, 13423, 9, 9],
            [2016, 13424, 26, 13],
            [2016, 13425, 18, 14],
            [2016, 13426, 19, 13],
            [2016, 13427, 23, 18],
            [2016, 13428, 34, 15],
            [2016, 13429, 17, 15],
            [2016, 13430, 17, 14],
            [2016, 13431, 25, 17],
            [2016, 13432, 8, 8],
            [2016, 13433, 14, 11],
            [2016, 13434, 22, 15],
            [2016, 13435, 13, 11],
            [2016, 13438, 19, 15],
            [2016, 13439, 8, 7],
            [2016, 13440, 8, 8],
            [2016, 13441, 10, 10],
            [2016, 13442, 30, 16],
            [2016, 13443, 25, 19],
            [2016, 13445, 11, 8],
            [2016, 13446, 15, 13],
            [2016, 13447, 28, 18],
            [2016, 13448, 21, 18],
            [2016, 13449, 10, 8],
            [2016, 13450, 8, 8],
            [2016, 13451, 9, 7],
            [2016, 13452, 8, 7],
            [2016, 13453, 9, 8],
            [2016, 13454, 17, 11],
            [2016, 13455, 12, 10],
            [2016, 13456, 6, 6],
            [2016, 13457, 7, 6],
            [2016, 13458, 8, 8],
            [2016, 13460, 9, 7],
            [2016, 13463, 12, 9],
            [2016, 13464, 14, 8],
            [2016, 13465, 11, 9],
            [2016, 13466, 9, 8],
            [2016, 13467, 8, 7],
            [2016, 13468, 8, 7],
            [2016, 13469, 8, 7],
            [2016, 13470, 12, 9],
            [2016, 13471, 9, 8],
            [2016, 13472, 13, 8],
            [2016, 13473, 11, 8],
            [2016, 13474, 10, 8],
            [2016, 13475, 11, 8],
            [2016, 13476, 7, 7],
            [2016, 13478, 6, 7],
            [2016, 13479, 12, 9],
            [2016, 13480, 4, 4],
            [2016, 13481, 8, 7],
            [2016, 13482, 9, 9],
            [2016, 13483, 9, 9],
            [2016, 13484, 10, 8],
            [2016, 13485, 9, 8],
            [2016, 13486, 3, 4],
            [2016, 13487, 17, 10],
            [2016, 13488, 8, 6],
            [2016, 13489, 12, 9],
            [2016, 13490, 7, 7],
            [2016, 13491, 8, 7],
            [2016, 13492, 7, 7],
            [2016, 13494, 11, 8],
            [2016, 13495, 9, 8],
            [2016, 13496, 10, 8],
            [2016, 13497, 9, 8],
            [2016, 13498, 9, 7],
            [2016, 13499, 11, 8],
            [2016, 13501, 14, 9],
            [2016, 13502, 8, 6],
            [2016, 13503, 9, 8],
            [2016, 13504, 7, 6],
            [2016, 13505, 7, 6],
            [2016, 13506, 10, 7],
            [2016, 13508, 10, 8],
            [2016, 13509, 6, 6],
            [2016, 13511, 14, 10],
            [2016, 13512, 9, 7],
            [2016, 13513, 11, 8],
            [2016, 13514, 11, 9],
            [2016, 13516, 7, 6],
            [2016, 13517, 7, 7],
            [2016, 13518, 7, 7],
            [2016, 13519, 11, 8],
            [2016, 13520, 12, 9],
            [2016, 13521, 8, 7],
            [2016, 13522, 9, 8],
            [2016, 13523, 9, 8],
            [2016, 13524, 7, 7],
            [2016, 13525, 10, 9],
            [2016, 13526, 8, 7],
            [2016, 13527, 13, 10],
            [2016, 13528, 8, 7],
            [2016, 13529, 6, 6],
            [2016, 13530, 6, 5],
            [2016, 13531, 7, 6],
            [2016, 13532, 7, 6],
            [2016, 13533, 7, 6],
            [2016, 13534, 6, 6],
            [2016, 13536, 9, 8],
            [2016, 13537, 6, 6],
            [2016, 13538, 6, 5],
            [2016, 13539, 6, 6],
            [2016, 13540, 6, 6],
            [2016, 13541, 9, 8],
            [2016, 13542, 9, 8],
            [2016, 13544, 10, 9],
            [2016, 13546, 7, 6],
            [2016, 13548, 12, 9],
            [2016, 13550, 18, 10],
            [2016, 13552, 11, 9],
            [2016, 13556, 8, 7],
            [2016, 13557, 3, 3],
            [2016, 13558, 13, 9],
            [2016, 13560, 8, 7],
            [2016, 13561, 8, 7],
            [2016, 13562, 9, 8],
            [2016, 13563, 8, 6],
            [2016, 13564, 13, 9],
            [2016, 13565, 9, 7],
            [2016, 13566, 12, 10],
            [2016, 13567, 8, 8],
            [2016, 13568, 4, 5],
            [2016, 13569, 8, 7],
            [2016, 13570, 6, 7],
            [2016, 13571, 11, 8],
            [2016, 13572, 6, 5],
            [2016, 13573, 7, 7],
            [2016, 13574, 9, 8],
            [2016, 13575, 11, 8],
            [2016, 13576, 7, 6],
            [2016, 13577, 7, 6],
            [2016, 13578, 8, 8],
            [2016, 13579, 17, 10],
            [2016, 13580, 10, 7],
            [2016, 13581, 6, 6],
            [2016, 13582, 8, 7],
            [2016, 13583, 8, 7],
            [2016, 13584, 25, 13],
            [2016, 13585, 6, 7],
            [2016, 13586, 6, 6],
            [2016, 13587, 7, 6],
            [2016, 13588, 15, 10],
            [2016, 13589, 7, 7],
            [2016, 13590, 13, 10],
            [2016, 13593, 6, 7],
            [2016, 13594, 13, 10],
            [2016, 13595, 10, 7],
            [2016, 13596, 11, 9],
            [2016, 13597, 8, 6],
            [2016, 13598, 7, 6],
            [2016, 13599, 6, 7],
            [2016, 13600, 8, 7],
            [2016, 13601, 7, 6],
            [2016, 13602, 6, 6],
            [2016, 13603, 6, 6],
            [2016, 13604, 12, 9],
            [2016, 13605, 10, 8],
            [2016, 13606, 10, 9],
            [2016, 13607, 8, 6],
            [2016, 13608, 9, 8],
            [2016, 13609, 28, 28],
            [2016, 13610, 24, 23],
            [2016, 13611, 18, 15],
            [2016, 13612, 39, 17],
            [2016, 13613, 89, 29],
            [2016, 13614, 23, 23],
            [2016, 13615, 52, 30],
            [2016, 13616, 11, 9],
            [2016, 13617, 27, 29],
            [2016, 13618, 37, 34],
            [2016, 13619, 33, 49],
            [2016, 13620, 28, 27],
            [2016, 13621, 33, 29],
            [2016, 13622, 35, 24],
            [2016, 13623, 44, 28],
            [2016, 13624, 20, 13],
            [2016, 13625, 15, 13],
            [2016, 13626, 21, 15],
            [2016, 13627, 27, 34],
            [2016, 13628, 26, 28],
            [2016, 13629, 46, 35],
            [2016, 13630, 28, 28],
            [2016, 13631, 36, 39],
            [2016, 13632, 29, 14],
            [2016, 13633, 19, 12],
            [2016, 13634, 20, 16],
            [2016, 13635, 28, 29],
            [2016, 13636, 15, 11],
            [2016, 13637, 69, 49],
            [2016, 13638, 60, 39],
            [2016, 13639, 9, 8],
            [2016, 13640, 42, 47],
            [2016, 13641, 29, 13],
            [2016, 13642, 66, 29],
            [2016, 13643, 17, 19],
            [2016, 13644, 48, 27],
            [2016, 13645, 54, 35],
            [2016, 13646, 23, 34],
            [2016, 13647, 39, 18],
            [2016, 13648, 43, 29],
            [2016, 13649, 53, 29],
            [2016, 13650, 7, 7],
            [2016, 13651, 39, 29],
            [2016, 13652, 55, 43],
            [2016, 13653, 7, 6],
            [2016, 13654, 8, 7],
            [2016, 13655, 23, 23],
            [2016, 13656, 67, 42],
            [2016, 13657, 15, 12],
            [2016, 13658, 76, 40],
            [2016, 13659, 33, 21],
            [2016, 13660, 28, 26],
            [2016, 13661, 28, 21],
            [2016, 13662, 38, 23],
            [2016, 13663, 14, 12],
            [2016, 13664, 33, 32],
            [2016, 13665, 38, 28],
            [2016, 13666, 25, 23],
            [2016, 13667, 33, 21],
            [2016, 13668, 11, 9],
            [2016, 13669, 34, 19],
            [2016, 13670, 38, 23],
            [2016, 13671, 37, 18],
            [2016, 13672, 34, 27],
            [2016, 13673, 73, 29],
            [2016, 13674, 32, 23],
            [2016, 13675, 23, 17],
            [2016, 13676, 26, 18],
            [2016, 13677, 13, 14],
            [2016, 13678, 11, 12],
            [2016, 13679, 9, 12],
            [2016, 13680, 9, 11],
            [2016, 13681, 13, 11],
            [2016, 13682, 8, 8],
            [2016, 13683, 16, 12],
            [2016, 13684, 23, 13],
            [2016, 13685, 23, 13],
            [2016, 13686, 19, 12],
            [2016, 13687, 24, 15],
            [2016, 13688, 15, 11],
            [2016, 13689, 16, 10],
            [2016, 13690, 11, 9],
            [2016, 13691, 40, 13],
            [2016, 13692, 15, 13],
            [2016, 13693, 13, 10],
            [2016, 13694, 23, 16],
            [2016, 13695, 18, 13],
            [2016, 13696, 11, 10],
            [2016, 13697, 31, 14],
            [2016, 13698, 15, 11],
            [2016, 13699, 22, 12],
            [2016, 13701, 14, 12],
            [2016, 13702, 22, 11],
            [2016, 13704, 22, 13],
            [2016, 13705, 10, 9],
            [2016, 13706, 23, 13],
            [2016, 13707, 24, 14],
            [2016, 13709, 22, 14],
            [2016, 13710, 17, 12],
            [2016, 13711, 21, 12],
            [2016, 13712, 30, 16],
            [2016, 13715, 28, 14],
            [2016, 13716, 20, 11],
            [2016, 13717, 21, 18],
            [2016, 13719, 28, 14],
            [2016, 13720, 19, 12],
            [2016, 13721, 19, 9],
            [2016, 13722, 21, 16],
            [2016, 13723, 26, 18],
            [2016, 13724, 28, 13],
            [2016, 13725, 22, 11],
            [2016, 13726, 16, 9],
            [2016, 13727, 31, 17],
            [2016, 13728, 19, 13],
            [2016, 13729, 20, 10],
            [2016, 13730, 24, 18],
            [2016, 13731, 20, 12],
            [2016, 13732, 30, 15],
            [2016, 13733, 21, 12],
            [2016, 13734, 20, 11],
            [2016, 13735, 19, 10],
            [2016, 13736, 25, 14],
            [2016, 13737, 23, 13],
            [2016, 13738, 16, 13],
            [2016, 13739, 23, 15],
            [2016, 13740, 28, 10],
            [2016, 13741, 10, 8],
            [2016, 13742, 27, 14],
            [2016, 13743, 29, 17],
            [2016, 13744, 25, 12],
            [2016, 13745, 9, 8],
            [2016, 13746, 16, 14],
            [2016, 13747, 15, 12],
            [2016, 13748, 19, 14],
            [2016, 13749, 12, 9],
            [2016, 13750, 21, 15],
            [2016, 13751, 9, 8],
            [2016, 13753, 15, 12],
            [2016, 13754, 18, 13],
            [2016, 13755, 13, 11],
            [2016, 13756, 11, 9],
            [2016, 13757, 16, 14],
            [2016, 13758, 11, 9],
            [2016, 13759, 9, 7],
            [2016, 13760, 10, 9],
            [2016, 13761, 13, 8],
            [2016, 13762, 10, 10],
            [2016, 13763, 10, 8],
            [2016, 13764, 8, 7],
            [2016, 13765, 19, 10],
            [2016, 13766, 13, 10],
            [2016, 13767, 15, 11],
            [2016, 13768, 15, 9],
            [2016, 13769, 11, 9],
            [2016, 13770, 15, 11],
            [2016, 13771, 12, 10],
            [2016, 13772, 13, 10],
            [2016, 13773, 17, 12],
            [2016, 13774, 9, 7],
            [2016, 13775, 9, 10],
            [2016, 13776, 9, 10],
            [2016, 13777, 9, 7],
            [2016, 13778, 18, 13],
            [2016, 13779, 15, 10],
            [2016, 13780, 10, 11],
            [2016, 13781, 16, 12],
            [2016, 13782, 15, 17],
            [2016, 13783, 14, 19],
            [2016, 13784, 15, 19],
            [2016, 13785, 16, 17],
            [2016, 13786, 13, 16],
            [2016, 13787, 7, 5],
            [2016, 13788, 6, 6],
            [2016, 13789, 9, 7],
            [2016, 13790, 8, 8],
            [2016, 13791, 8, 7],
            [2016, 13792, 11, 10],
            [2016, 13793, 8, 8],
            [2016, 13794, 11, 10],
            [2016, 13795, 8, 7],
            [2016, 13796, 8, 9],
            [2016, 13797, 9, 8],
            [2016, 13798, 8, 7],
            [2016, 13799, 15, 11],
            [2016, 13800, 8, 7],
            [2016, 13801, 8, 6],
            [2016, 13802, 9, 8],
            [2016, 13803, 9, 8],
            [2016, 13804, 10, 9],
            [2016, 13805, 7, 6],
            [2016, 13806, 9, 8],
            [2016, 13807, 7, 7],
            [2016, 13808, 7, 5],
            [2016, 13809, 9, 8],
            [2016, 13810, 7, 6],
            [2016, 13811, 9, 8],
            [2016, 13812, 8, 8],
            [2016, 13813, 10, 8],
            [2016, 13814, 11, 10],
            [2016, 13815, 11, 9],
            [2016, 13816, 11, 8],
            [2016, 13817, 8, 8],
            [2016, 13818, 9, 8],
            [2016, 13819, 9, 7],
            [2016, 13820, 9, 7],
            [2016, 13821, 6, 6],
            [2016, 13822, 6, 6],
            [2016, 13823, 6, 6],
            [2016, 13824, 9, 8],
            [2016, 13825, 6, 5],
            [2016, 13826, 7, 6],
            [2016, 13827, 7, 6],
            [2016, 13828, 9, 8],
            [2016, 13829, 8, 8],
            [2016, 13830, 7, 7],
            [2016, 13831, 8, 8],
            [2016, 13832, 7, 7],
            [2016, 13833, 11, 10],
            [2016, 13834, 7, 7],
            [2016, 13835, 9, 8],
            [2016, 13836, 9, 8],
            [2016, 13837, 10, 8],
            [2016, 13838, 9, 8],
            [2016, 13839, 10, 10],
            [2016, 13840, 7, 6],
            [2016, 13841, 8, 7],
            [2016, 13842, 9, 8],
            [2016, 13843, 9, 8],
            [2016, 13844, 6, 6],
            [2016, 13845, 7, 7],
            [2016, 13846, 7, 7],
            [2016, 13847, 6, 6],
            [2016, 13848, 7, 6],
            [2016, 13849, 9, 8],
            [2016, 13850, 9, 8],
            [2016, 13851, 10, 10],
            [2016, 13852, 8, 8],
            [2016, 13853, 12, 10],
            [2016, 13854, 12, 11],
            [2016, 13855, 13, 12],
            [2016, 13856, 8, 8],
            [2016, 13857, 9, 7],
            [2016, 13858, 8, 7],
            [2016, 13859, 8, 7],
            [2016, 13860, 7, 6],
            [2016, 13861, 7, 6],
            [2016, 13862, 11, 9],
            [2016, 13863, 7, 6],
            [2016, 13864, 6, 5],
            [2016, 13865, 9, 7],
            [2016, 13866, 6, 6],
            [2016, 13867, 7, 6],
            [2016, 13868, 6, 6],
            [2016, 13869, 9, 7],
            [2016, 13870, 7, 6],
            [2016, 13871, 6, 5],
            [2016, 13872, 8, 6],
            [2016, 13873, 6, 5],
            [2016, 13874, 11, 8],
            [2016, 13875, 9, 7],
            [2016, 13876, 15, 10],
            [2016, 13877, 9, 8],
            [2016, 13878, 7, 6],
            [2016, 13879, 7, 6],
            [2016, 13880, 7, 6],
            [2016, 13881, 8, 6],
            [2016, 13882, 7, 6],
            [2016, 13883, 13, 9],
            [2016, 13884, 7, 8],
            [2016, 13885, 9, 6],
            [2016, 13886, 7, 6],
            [2016, 13887, 7, 6],
            [2016, 13888, 10, 8],
            [2016, 13889, 6, 5],
            [2016, 13890, 9, 8],
            [2016, 13891, 9, 7],
            [2016, 13892, 8, 8],
            [2016, 13893, 11, 11],
            [2016, 13894, 6, 7],
            [2016, 13895, 7, 7],
            [2016, 13896, 6, 6],
            [2016, 13897, 7, 7],
            [2016, 13898, 8, 7],
            [2016, 13899, 8, 7],
            [2016, 13900, 10, 8],
            [2016, 13901, 14, 10],
            [2016, 13902, 7, 7],
            [2016, 13903, 11, 9],
            [2016, 13904, 8, 6],
            [2016, 13905, 9, 8],
            [2016, 13906, 13, 9],
            [2016, 13907, 10, 9],
            [2016, 13908, 10, 8],
            [2016, 13909, 12, 9],
            [2016, 13910, 8, 7],
            [2016, 13911, 8, 7],
            [2016, 13912, 8, 8],
            [2016, 13913, 8, 8],
            [2016, 13914, 8, 8],
            [2016, 13915, 7, 7],
            [2016, 13916, 6, 7],
            [2016, 13917, 6, 6],
            [2016, 13918, 8, 8],
            [2016, 13919, 9, 8],
            [2016, 13920, 11, 9],
            [2016, 13921, 13, 9],
            [2016, 13922, 8, 7],
            [2016, 13923, 8, 7],
            [2016, 13924, 11, 9],
            [2016, 13925, 7, 7],
            [2016, 13926, 8, 7],
            [2016, 13927, 8, 8],
            [2016, 13928, 7, 6],
            [2016, 13929, 7, 7],
            [2016, 13930, 7, 6],
            [2016, 13931, 10, 8],
            [2016, 13932, 9, 7],
            [2016, 13933, 8, 7],
            [2016, 13934, 11, 10],
            [2016, 13935, 7, 6],
            [2016, 13936, 7, 7],
            [2016, 13937, 11, 9],
            [2016, 13938, 7, 7],
            [2016, 13939, 8, 7],
            [2016, 13940, 8, 7],
            [2016, 13941, 8, 8],
            [2016, 13942, 9, 8],
            [2016, 13943, 10, 8],
            [2016, 13944, 8, 8],
            [2016, 13945, 8, 7],
            [2016, 13946, 11, 9],
            [2016, 13947, 12, 9],
            [2016, 13948, 6, 6],
            [2016, 13949, 6, 6],
            [2016, 13950, 9, 8],
            [2016, 13951, 7, 7],
            [2016, 13952, 11, 9],
            [2016, 13953, 10, 9],
            [2016, 13954, 8, 8],
            [2016, 13955, 10, 8],
            [2016, 13956, 10, 8],
            [2016, 13957, 8, 7],
            [2016, 13958, 7, 7],
            [2016, 13959, 7, 7],
            [2016, 13960, 11, 9],
            [2016, 13961, 8, 7],
            [2016, 13962, 9, 8],
            [2016, 13963, 7, 7],
            [2016, 13964, 7, 7],
            [2016, 13965, 7, 6],
            [2016, 13966, 9, 7],
            [2016, 13967, 7, 6],
            [2016, 13968, 7, 7],
            [2016, 13969, 7, 6],
            [2016, 13970, 7, 6],
            [2016, 13971, 7, 7],
            [2016, 13972, 8, 7],
            [2016, 13973, 7, 6],
            [2016, 13974, 7, 6],
            [2016, 13975, 7, 7],
            [2016, 13976, 8, 8],
            [2016, 13977, 7, 8],
            [2016, 13978, 10, 9],
            [2016, 13979, 7, 6],
            [2016, 13980, 6, 6],
            [2016, 13981, 7, 7],
            [2016, 13982, 7, 7],
            [2016, 13983, 12, 9],
            [2016, 13984, 9, 8],
            [2016, 13985, 13, 9],
            [2016, 13986, 8, 7],
            [2016, 13987, 7, 7],
            [2016, 13988, 9, 8],
            [2016, 13989, 7, 6],
            [2016, 13991, 7, 7],
            [2016, 13992, 7, 6],
            [2016, 13993, 9, 8],
            [2016, 13994, 8, 7],
            [2016, 13995, 13, 10],
            [2016, 13996, 7, 7],
            [2016, 13997, 7, 6],
            [2016, 13998, 7, 7],
            [2016, 13999, 11, 9],
            [2016, 14000, 11, 10],
            [2016, 14001, 11, 8],
            [2016, 14002, 7, 7],
            [2016, 14003, 7, 7],
            [2016, 14004, 7, 6],
            [2016, 14005, 18, 14],
            [2016, 14006, 11, 8],
            [2016, 14007, 12, 10],
            [2016, 14008, 12, 9],
            [2016, 14009, 13, 8],
            [2016, 14010, 10, 8],
            [2016, 14011, 9, 9],
            [2016, 14012, 10, 9],
            [2016, 14013, 11, 10],
            [2016, 14014, 20, 12],
            [2016, 14016, 12, 10],
            [2016, 14017, 21, 12],
            [2016, 14018, 9, 9],
            [2016, 14019, 7, 7],
            [2016, 14020, 7, 7],
            [2016, 14021, 12, 8],
            [2016, 14022, 8, 8],
            [2016, 14023, 20, 12],
            [2016, 14024, 11, 11],
            [2016, 14025, 11, 10],
            [2016, 14026, 19, 13],
            [2016, 14027, 11, 10],
            [2016, 14029, 13, 10],
            [2016, 14030, 18, 11],
            [2016, 14031, 21, 15],
            [2016, 14032, 11, 9],
            [2016, 14033, 11, 10],
            [2016, 14034, 12, 10],
            [2016, 14035, 16, 11],
            [2016, 14036, 10, 9],
            [2016, 14037, 18, 11],
            [2016, 14038, 9, 9],
            [2016, 14040, 15, 11],
            [2016, 14041, 22, 15],
            [2016, 14042, 15, 12],
            [2016, 14043, 11, 9],
            [2016, 14044, 10, 9],
            [2016, 14045, 9, 8],
            [2016, 14046, 9, 11],
            [2016, 14047, 13, 11],
            [2016, 14048, 14, 11],
            [2016, 14049, 18, 11],
            [2016, 14050, 14, 11],
            [2016, 14051, 18, 13],
            [2016, 14052, 11, 9],
            [2016, 14053, 11, 9],
            [2016, 14054, 10, 10],
            [2016, 14055, 21, 12],
            [2016, 14056, 21, 11],
            [2016, 14057, 15, 11],
            [2016, 14058, 14, 10],
            [2016, 14059, 12, 11],
            [2016, 14060, 14, 10],
            [2016, 14061, 14, 11],
            [2016, 14062, 12, 12],
            [2016, 14063, 19, 10],
            [2016, 14064, 16, 10],
            [2016, 14065, 19, 10],
            [2016, 14066, 14, 9],
            [2016, 14067, 16, 13],
            [2016, 14068, 10, 7],
            [2016, 14069, 13, 11],
            [2016, 14070, 19, 14],
            [2016, 14071, 18, 14],
            [2016, 14072, 12, 8],
            [2016, 14073, 18, 15],
            [2016, 14074, 15, 14],
            [2016, 14075, 18, 12],
            [2016, 14076, 18, 11],
            [2016, 14077, 13, 9],
            [2016, 14078, 14, 10],
            [2016, 14079, 13, 10],
            [2016, 14080, 20, 11],
            [2016, 14081, 16, 11],
            [2016, 14082, 16, 12],
            [2016, 14083, 12, 7],
            [2016, 14084, 11, 8],
            [2016, 14085, 14, 10],
            [2016, 14086, 15, 11],
            [2016, 14087, 15, 11],
            [2016, 14088, 14, 10],
            [2016, 14089, 13, 9],
            [2016, 14090, 12, 10],
            [2016, 14092, 12, 7],
            [2016, 14093, 12, 7],
            [2016, 14094, 11, 8],
            [2016, 14095, 12, 11],
            [2016, 14096, 14, 11],
            [2016, 14097, 12, 9],
            [2016, 14098, 14, 10],
            [2016, 14099, 14, 9],
            [2016, 14100, 11, 8],
            [2016, 14101, 19, 11],
            [2016, 14102, 18, 10],
            [2016, 14103, 16, 12],
            [2016, 14104, 11, 10],
            [2016, 14105, 16, 11],
            [2016, 14107, 14, 10],
            [2016, 14108, 15, 10],
            [2016, 14110, 18, 10],
            [2016, 14111, 15, 11],
            [2016, 14112, 13, 9],
            [2016, 14113, 11, 10],
            [2016, 14114, 11, 10],
            [2016, 14115, 18, 12],
            [2016, 14116, 17, 13],
            [2016, 14117, 22, 10],
            [2016, 14118, 21, 12],
            [2016, 14119, 23, 15],
            [2016, 14120, 17, 10],
            [2016, 14121, 18, 10],
            [2016, 14122, 19, 11],
            [2016, 14123, 18, 12],
            [2016, 14124, 10, 8],
            [2016, 14125, 16, 13],
            [2016, 14126, 16, 10],
            [2016, 14127, 16, 10],
            [2016, 14128, 9, 8],
            [2016, 14129, 8, 7],
            [2016, 14130, 17, 12],
            [2016, 14131, 28, 14],
            [2016, 14132, 18, 10],
            [2016, 14133, 10, 8],
            [2016, 14134, 14, 10],
            [2016, 14135, 15, 11],
            [2016, 14136, 16, 10],
            [2016, 14137, 22, 11],
            [2016, 14138, 22, 11],
            [2016, 14139, 16, 11],
            [2016, 14140, 25, 12],
            [2016, 14141, 21, 12],
            [2016, 14142, 12, 10],
            [2016, 14143, 21, 12],
            [2016, 14144, 13, 9],
            [2016, 14145, 18, 10],
            [2016, 14146, 32, 12],
            [2016, 14147, 13, 11],
            [2016, 14148, 11, 8],
            [2016, 14149, 17, 11],
            [2016, 14150, 10, 8],
            [2016, 14151, 15, 10],
            [2016, 14152, 17, 11],
            [2016, 14153, 12, 10],
            [2016, 14154, 18, 10],
            [2016, 14155, 10, 8],
            [2016, 14156, 18, 12],
            [2016, 14157, 26, 14],
            [2016, 14158, 13, 10],
            [2016, 14159, 19, 11],
            [2016, 14160, 15, 11],
            [2016, 14161, 8, 7],
            [2016, 14162, 15, 11],
            [2016, 14163, 9, 9],
            [2016, 14164, 15, 12],
            [2016, 14165, 16, 10],
            [2016, 14166, 24, 11],
            [2016, 14167, 11, 8],
            [2016, 14168, 12, 10],
            [2016, 14169, 9, 6],
            [2016, 14170, 8, 7],
            [2016, 14171, 26, 12],
            [2016, 14172, 19, 14],
            [2016, 14173, 10, 11],
            [2016, 14174, 21, 13],
            [2016, 14175, 17, 27],
            [2016, 14176, 10, 10],
            [2016, 14177, 12, 10],
            [2016, 14178, 8, 7],
            [2016, 14179, 23, 15],
            [2016, 14180, 18, 11],
            [2016, 14181, 22, 12],
            [2016, 14182, 17, 11],
            [2016, 14183, 10, 8],
            [2016, 14184, 20, 9],
            [2016, 14185, 20, 10],
            [2016, 14186, 17, 10],
            [2016, 14187, 10, 10],
            [2016, 14188, 14, 11],
            [2016, 14189, 15, 11],
            [2016, 14190, 9, 8],
            [2016, 14191, 14, 13],
            [2016, 14192, 26, 14],
            [2016, 14193, 19, 14],
            [2016, 14194, 10, 9],
            [2016, 14195, 9, 8],
            [2016, 14196, 28, 15],
            [2016, 14197, 17, 11],
            [2016, 14198, 10, 9],
            [2016, 14199, 14, 12],
            [2016, 14200, 19, 11],
            [2016, 14201, 9, 9],
            [2016, 14202, 10, 9],
            [2016, 14203, 9, 8],
            [2016, 14204, 8, 8],
            [2016, 14205, 13, 10],
            [2016, 14206, 12, 10],
            [2016, 14207, 12, 9],
            [2016, 14208, 11, 8],
            [2016, 14209, 23, 12],
            [2016, 14211, 20, 12],
            [2016, 14212, 9, 8],
            [2016, 14213, 22, 14],
            [2016, 14214, 8, 7],
            [2016, 14215, 18, 11],
            [2016, 14216, 12, 10],
            [2016, 14217, 15, 11],
            [2016, 14218, 9, 8],
            [2016, 14219, 10, 8],
            [2016, 14220, 15, 11],
            [2016, 14221, 11, 9],
            [2016, 14222, 20, 12],
            [2016, 14223, 16, 11],
            [2016, 14224, 13, 11],
            [2016, 14225, 14, 11],
            [2016, 14226, 21, 10],
            [2016, 14228, 15, 12],
            [2016, 14229, 16, 11],
            [2016, 14230, 21, 11],
            [2016, 14231, 15, 10],
            [2016, 14232, 10, 7],
            [2016, 14233, 15, 11],
            [2016, 14235, 14, 10],
            [2016, 14236, 26, 15],
            [2016, 14237, 11, 8],
            [2016, 14238, 14, 11],
            [2016, 14240, 7, 5],
            [2016, 14241, 12, 8],
            [2016, 14242, 21, 12],
            [2016, 14243, 7, 5],
            [2016, 14244, 23, 12],
            [2016, 14245, 18, 12],
            [2016, 14246, 20, 12],
            [2016, 14247, 22, 13],
            [2016, 14248, 13, 9],
            [2016, 14249, 27, 14],
            [2016, 14250, 20, 12],
            [2016, 14251, 10, 7],
            [2016, 14252, 27, 14],
            [2016, 14253, 23, 12],
            [2016, 14254, 11, 8],
            [2016, 14255, 18, 11],
            [2016, 14256, 13, 9],
            [2016, 14257, 21, 11],
            [2016, 14258, 14, 9],
            [2016, 14259, 23, 12],
            [2016, 14260, 15, 9],
            [2016, 14261, 22, 11],
            [2016, 14262, 23, 12],
            [2016, 14263, 14, 10],
            [2016, 14264, 20, 11],
            [2016, 14265, 23, 12],
            [2016, 14266, 18, 12],
            [2016, 14267, 7, 6],
            [2016, 14268, 7, 6],
            [2016, 14269, 25, 14],
            [2016, 14270, 10, 7],
            [2016, 14271, 9, 8],
            [2016, 14272, 7, 5],
            [2016, 14273, 25, 13],
            [2016, 14274, 17, 11],
            [2016, 14275, 24, 12],
            [2016, 14276, 13, 10],
            [2016, 14277, 7, 5],
            [2016, 14278, 7, 6],
            [2016, 14280, 20, 11],
            [2016, 14281, 10, 7],
            [2016, 14282, 11, 8],
            [2016, 14283, 11, 7],
            [2016, 14285, 20, 11],
            [2016, 14286, 21, 12],
            [2016, 14287, 15, 10],
            [2016, 14288, 12, 9],
            [2016, 14289, 25, 12],
            [2016, 14290, 26, 14],
            [2016, 14291, 17, 11],
            [2016, 14292, 14, 10],
            [2016, 14293, 13, 8],
            [2016, 14294, 18, 11],
            [2016, 14295, 22, 11],
            [2016, 14296, 23, 12],
            [2016, 14297, 21, 12],
            [2016, 14298, 11, 7],
            [2016, 14299, 21, 12],
            [2016, 14300, 8, 6],
            [2016, 14301, 8, 7],
            [2016, 14302, 10, 7],
            [2016, 14303, 22, 12],
            [2016, 14304, 16, 11],
            [2016, 14305, 25, 13],
            [2016, 14306, 25, 13],
            [2016, 14307, 7, 6],
            [2016, 14308, 19, 11],
            [2016, 14309, 10, 8],
            [2016, 14310, 20, 12],
            [2016, 14311, 22, 13],
            [2016, 14312, 19, 12],
            [2016, 14313, 13, 8],
            [2016, 14314, 23, 12],
            [2016, 14315, 19, 11],
            [2016, 14316, 20, 12],
            [2016, 14317, 17, 11],
            [2016, 14318, 22, 13],
            [2016, 14319, 13, 9],
            [2016, 14320, 9, 7],
            [2016, 14321, 22, 12],
            [2016, 14322, 17, 12],
            [2016, 14323, 22, 12],
            [2016, 14324, 14, 10],
            [2016, 14325, 27, 12],
            [2016, 14327, 24, 12],
            [2016, 14328, 17, 10],
            [2016, 14329, 23, 12],
            [2016, 14330, 19, 11],
            [2016, 14331, 22, 13],
            [2016, 14332, 11, 8],
            [2016, 14333, 13, 9],
            [2016, 14335, 22, 13],
            [2016, 14337, 13, 9],
            [2016, 14338, 21, 12],
            [2016, 14340, 10, 7],
            [2016, 14341, 22, 12],
            [2016, 14342, 20, 13],
            [2016, 14343, 19, 11],
            [2016, 14344, 25, 12],
            [2016, 14345, 22, 12],
            [2016, 14346, 24, 12],
            [2016, 14347, 11, 9],
            [2016, 14348, 22, 12],
            [2016, 14349, 14, 9],
            [2016, 14350, 14, 9],
            [2016, 14352, 22, 11],
            [2016, 14353, 21, 11],
            [2016, 14354, 21, 12],
            [2016, 14355, 14, 11],
            [2016, 14356, 9, 7],
            [2016, 14357, 21, 11],
            [2016, 14358, 14, 9],
            [2016, 14359, 16, 11],
            [2016, 14360, 11, 8],
            [2016, 14361, 22, 12],
            [2016, 14362, 20, 11],
            [2016, 14363, 23, 12],
            [2016, 14364, 22, 11],
            [2016, 14365, 18, 11],
            [2016, 14366, 23, 12],
            [2016, 14367, 26, 13],
            [2016, 14368, 24, 13],
            [2016, 14369, 24, 12],
            [2016, 14370, 11, 8],
            [2016, 14371, 7, 5],
            [2016, 14372, 11, 8],
            [2016, 14373, 23, 12],
            [2016, 14374, 16, 10],
            [2016, 14375, 21, 11],
            [2016, 14376, 7, 5],
            [2016, 14378, 7, 5],
            [2016, 14380, 23, 12],
            [2016, 14381, 23, 12],
            [2016, 14382, 22, 12],
            [2016, 14383, 11, 7],
            [2016, 14384, 21, 11],
            [2016, 14385, 20, 11],
            [2016, 14386, 23, 12],
            [2016, 14387, 27, 15],
            [2016, 14388, 31, 16],
            [2016, 14389, 23, 12],
            [2016, 14390, 21, 11],
            [2016, 14391, 12, 8],
            [2016, 14392, 21, 12],
            [2016, 14393, 15, 9],
            [2016, 14394, 20, 11],
            [2016, 14395, 25, 12],
            [2016, 14397, 21, 10],
            [2016, 14398, 21, 11],
            [2016, 14399, 27, 13],
            [2016, 14400, 27, 13],
            [2016, 14401, 16, 10],
            [2016, 14402, 11, 8],
            [2016, 14403, 22, 12],
            [2016, 14405, 27, 12],
            [2016, 14406, 27, 13],
            [2016, 14407, 19, 12],
            [2016, 14408, 15, 10],
            [2016, 14409, 24, 11],
            [2016, 14411, 16, 9],
            [2016, 14412, 15, 9],
            [2016, 14413, 10, 7],
            [2016, 14415, 18, 11],
            [2016, 14416, 16, 10],
            [2016, 14417, 16, 12],
            [2016, 14418, 23, 11],
            [2016, 14419, 22, 11],
            [2016, 14420, 13, 9],
            [2016, 14421, 25, 11],
            [2016, 14422, 18, 8],
            [2016, 14423, 13, 8],
            [2016, 14424, 16, 10],
            [2016, 14425, 26, 15],
            [2016, 14426, 13, 9],
            [2016, 14427, 22, 11],
            [2016, 14428, 20, 11],
            [2016, 14429, 18, 10],
            [2016, 14430, 18, 11],
            [2016, 14432, 20, 11],
            [2016, 14434, 17, 10],
            [2016, 14435, 10, 9],
            [2016, 14436, 21, 16],
            [2016, 14438, 20, 41],
            [2016, 14440, 20, 35],
            [2016, 14442, 20, 23],
            [2016, 14445, 22, 12],
            [2016, 14446, 26, 26],
            [2016, 14449, 14, 16],
            [2016, 14450, 55, 29],
            [2016, 14452, 33, 23],
            [2016, 14453, 26, 48],
            [2016, 14458, 25, 41],
            [2016, 14459, 30, 30],
            [2016, 14460, 25, 24],
            [2016, 14462, 20, 28],
            [2016, 14463, 10, 12],
            [2016, 14464, 30, 25],
            [2016, 14465, 29, 22],
            [2016, 14466, 22, 22],
            [2016, 14468, 30, 35],
            [2016, 14470, 17, 16],
            [2016, 14471, 26, 23],
            [2016, 14473, 10, 13],
            [2016, 14476, 32, 30],
            [2016, 14478, 11, 15],
            [2016, 14480, 26, 24],
            [2016, 14484, 19, 33],
            [2016, 14485, 13, 14],
            [2016, 14486, 47, 28],
            [2016, 14488, 19, 21],
            [2016, 14489, 14, 16],
            [2016, 14490, 58, 61],
            [2016, 14491, 19, 26],
            [2016, 14495, 24, 24],
            [2016, 14496, 64, 49],
            [2016, 14500, 24, 35],
            [2016, 14501, 20, 18],
            [2016, 14502, 68, 95],
            [2016, 14503, 30, 30],
            [2016, 14505, 13, 12],
            [2016, 14507, 25, 36],
            [2016, 14508, 14, 15],
            [2016, 14509, 29, 25],
            [2016, 14510, 34, 24],
            [2016, 14512, 32, 30],
            [2016, 14513, 36, 28],
            [2016, 14514, 33, 23],
            [2016, 14518, 26, 24],
            [2016, 14519, 90, 70],
            [2016, 14520, 52, 92],
            [2016, 14524, 24, 27],
            [2016, 14528, 16, 18],
            [2016, 14530, 33, 23],
            [2016, 14534, 18, 10],
            [2016, 14535, 12, 6],
            [2016, 14536, 18, 11],
            [2016, 14538, 22, 12],
            [2016, 14541, 14, 11],
            [2016, 14542, 14, 10],
            [2016, 14543, 15, 11],
            [2016, 14544, 9, 8],
            [2016, 14545, 18, 13],
            [2016, 14546, 20, 12],
            [2016, 14547, 17, 11],
            [2016, 14548, 16, 12],
            [2016, 14549, 22, 13],
            [2016, 14550, 18, 12],
            [2016, 14553, 14, 14],
            [2016, 14554, 16, 9],
            [2016, 14555, 11, 10],
            [2016, 14556, 21, 13],
            [2016, 14557, 20, 14],
            [2016, 14558, 9, 8],
            [2016, 14559, 10, 9],
            [2016, 14562, 82, 31],
            [2016, 14563, 88, 31],
            [2016, 14564, 22, 18],
            [2016, 14565, 20, 36],
            [2016, 14566, 16, 22],
            [2016, 14567, 21, 36],
            [2016, 14568, 70, 69],
            [2016, 14569, 19, 18],
            [2016, 14570, 19, 22],
            [2016, 14571, 16, 17],
            [2016, 14572, 16, 22],
            [2016, 14573, 84, 73],
            [2016, 14574, 11, 9],
            [2016, 14575, 7, 6],
            [2016, 14576, 9, 7],
            [2016, 14577, 22, 13],
            [2016, 14578, 13, 11],
            [2016, 14579, 11, 9],
            [2016, 14580, 8, 7],
            [2016, 14581, 8, 8],
            [2016, 14582, 20, 14],
            [2016, 14583, 14, 11],
            [2016, 14584, 6, 6],
            [2016, 14585, 10, 9],
            [2016, 14586, 9, 9],
            [2016, 14588, 15, 11],
            [2016, 14590, 12, 11],
            [2016, 14591, 13, 10],
            [2016, 14592, 2, 2],
            [2016, 14593, 53, 34],
            [2016, 14594, 4, 4],
            [2016, 14596, 5, 4],
            [2016, 14598, 14, 8],
            [2016, 14599, 17, 9],
            [2016, 14600, 25, 15],
            [2016, 14601, 6, 6],
            [2016, 14602, 18, 12],
            [2016, 14603, 10, 7],
            [2016, 14604, 10, 8],
            [2016, 14605, 10, 10],
            [2016, 14607, 6, 6],
            [2016, 14608, 8, 7],
            [2016, 14609, 10, 7],
            [2016, 14610, 4, 4],
            [2016, 14611, 6, 5],
            [2016, 14613, 19, 14],
            [2016, 14614, 17, 11],
            [2016, 14616, 11, 10],
            [2016, 14617, 22, 14],
            [2016, 14618, 6, 6],
            [2016, 14619, 17, 11],
            [2016, 14620, 13, 11],
            [2016, 14621, 7, 6],
            [2016, 14622, 14, 10],
            [2016, 14623, 14, 10],
            [2016, 14624, 8, 7],
            [2016, 14625, 11, 7],
            [2016, 14626, 8, 6],
            [2016, 14627, 25, 17],
            [2016, 14628, 15, 12],
            [2016, 14629, 21, 14],
            [2016, 14630, 7, 7],
            [2016, 14631, 6, 5],
            [2016, 14632, 25, 16],
            [2016, 14633, 25, 18],
            [2016, 14634, 10, 8],
            [2016, 14635, 7, 6],
            [2016, 14636, 13, 10],
            [2016, 14637, 12, 9],
            [2016, 14638, 18, 10],
            [2016, 14639, 5, 6],
            [2016, 14640, 7, 6],
            [2016, 14642, 22, 13],
            [2016, 14643, 6, 6],
            [2016, 14644, 6, 7],
            [2016, 14645, 13, 11],
            [2016, 14646, 8, 7],
            [2016, 14647, 20, 12],
            [2016, 14648, 4, 4],
            [2016, 14649, 9, 8],
            [2016, 14650, 12, 9],
            [2016, 14651, 13, 10],
            [2016, 14652, 18, 13],
            [2016, 14653, 18, 12],
            [2016, 14655, 4, 4],
            [2016, 14656, 11, 9],
            [2016, 14657, 7, 6],
            [2016, 14658, 15, 10],
            [2016, 14659, 12, 10],
            [2016, 14660, 12, 10],
            [2016, 14662, 17, 10],
            [2016, 14663, 15, 13],
            [2016, 14664, 8, 7],
            [2016, 14665, 11, 9],
            [2016, 14666, 11, 9],
            [2016, 14667, 16, 11],
            [2016, 14668, 13, 10],
            [2016, 14669, 21, 14],
            [2016, 14670, 12, 9],
            [2016, 14671, 11, 10],
            [2016, 14672, 12, 10],
            [2016, 14673, 14, 11],
            [2016, 14674, 9, 8],
            [2016, 14675, 8, 7],
            [2016, 14676, 13, 10],
            [2016, 14677, 12, 9],
            [2016, 14678, 16, 9],
            [2016, 14680, 13, 10],
            [2016, 14681, 14, 10],
            [2016, 14682, 11, 8],
            [2016, 14683, 15, 11],
            [2016, 14684, 22, 14],
            [2016, 14686, 9, 7],
            [2016, 14687, 19, 13],
            [2016, 14688, 6, 6],
            [2016, 14689, 11, 9],
            [2016, 14690, 19, 13],
            [2016, 14691, 14, 10],
            [2016, 14692, 14, 11],
            [2016, 14693, 10, 7],
            [2016, 14694, 7, 6],
            [2016, 14696, 9, 8],
            [2016, 14697, 12, 9],
            [2016, 14698, 14, 9],
            [2016, 14699, 16, 11],
            [2016, 14700, 16, 12],
            [2016, 14701, 27, 14],
            [2016, 14702, 29, 18],
            [2016, 14703, 25, 16],
            [2016, 14704, 37, 23],
            [2016, 14705, 21, 14],
            [2016, 14706, 29, 16],
            [2016, 14710, 25, 15],
            [2016, 14711, 21, 14],
            [2016, 14712, 27, 17],
            [2016, 14713, 25, 15],
            [2016, 14714, 23, 14],
            [2016, 14717, 12, 9],
            [2016, 14718, 19, 15],
            [2016, 14719, 19, 14],
            [2016, 14720, 39, 21],
            [2016, 14722, 25, 16],
            [2016, 14724, 19, 14],
            [2016, 14725, 21, 16],
            [2016, 14726, 17, 14],
            [2016, 14727, 29, 16],
            [2016, 14728, 27, 17],
            [2016, 14729, 21, 16],
            [2016, 14730, 23, 15],
            [2016, 14731, 19, 15],
            [2016, 14732, 33, 16],
            [2016, 14733, 25, 15],
            [2016, 14734, 25, 21],
            [2016, 14735, 33, 18],
            [2016, 14736, 33, 16],
            [2016, 14738, 23, 16],
            [2016, 14739, 18, 14],
            [2016, 14740, 25, 18],
            [2016, 14741, 25, 17],
            [2016, 14743, 17, 12],
            [2016, 14744, 10, 8],
            [2016, 14745, 23, 18],
            [2016, 14747, 23, 16],
            [2016, 14748, 19, 14],
            [2016, 14749, 11, 8],
            [2016, 14750, 20, 13],
            [2016, 14751, 23, 14],
            [2016, 14752, 20, 14],
            [2016, 14753, 27, 17],
            [2016, 14754, 16, 13],
            [2016, 14755, 16, 16],
            [2016, 14756, 20, 14],
            [2016, 14759, 23, 15],
            [2016, 14760, 25, 16],
            [2016, 14761, 18, 9],
            [2016, 14762, 12, 9],
            [2016, 14763, 21, 21],
            [2016, 14764, 36, 20],
            [2016, 14765, 12, 8],
            [2016, 14766, 27, 16],
            [2016, 14767, 23, 18],
            [2016, 14768, 5, 5],
            [2016, 14769, 38, 24],
            [2016, 14770, 18, 18],
            [2016, 14771, 26, 35],
            [2016, 14773, 39, 45],
            [2016, 14774, 28, 18],
            [2016, 14775, 37, 33],
            [2016, 14776, 35, 33],
            [2016, 14777, 20, 23],
            [2016, 14778, 12, 11],
            [2016, 14779, 38, 22],
            [2016, 14780, 33, 12],
            [2016, 14781, 10, 11],
            [2016, 14782, 60, 30],
            [2016, 14783, 28, 24],
            [2016, 14784, 13, 23],
            [2016, 14785, 59, 40],
            [2016, 14786, 24, 18],
            [2016, 14788, 26, 23],
            [2016, 14789, 65, 41],
            [2016, 14790, 45, 19],
            [2016, 14791, 12, 12],
            [2016, 14792, 57, 51],
            [2016, 14793, 34, 24],
            [2016, 14794, 28, 25],
            [2016, 14795, 33, 24],
            [2016, 14796, 33, 44],
            [2016, 14797, 26, 48],
            [2016, 14798, 26, 39],
            [2016, 14799, 41, 23],
            [2016, 14800, 13, 11],
            [2016, 14801, 30, 15],
            [2016, 14802, 19, 12],
            [2016, 14803, 37, 34],
            [2016, 14804, 13, 11],
            [2016, 14805, 32, 33],
            [2016, 14806, 15, 13],
            [2016, 14807, 36, 24],
            [2016, 14808, 51, 47],
            [2016, 14809, 15, 23],
            [2016, 14810, 16, 18],
            [2016, 14811, 15, 19],
            [2016, 14812, 44, 35],
            [2016, 14813, 23, 18],
            [2016, 14814, 36, 23],
            [2016, 14815, 58, 26],
            [2016, 14816, 13, 11],
            [2016, 14817, 13, 11],
            [2016, 14818, 13, 11],
            [2016, 14819, 37, 33],
            [2016, 14820, 66, 55],
            [2016, 14821, 19, 16],
            [2016, 14823, 17, 17],
            [2016, 14824, 61, 38],
            [2016, 14825, 16, 16],
            [2016, 14826, 40, 20],
            [2016, 14827, 43, 34],
            [2016, 14828, 51, 41],
            [2016, 14829, 18, 16],
            [2016, 14830, 13, 15],
            [2016, 14831, 28, 18],
            [2016, 14832, 43, 34],
            [2016, 14833, 35, 27],
            [2016, 14834, 36, 39],
            [2016, 14835, 50, 19],
            [2016, 14836, 40, 20],
            [2016, 14837, 55, 37],
            [2016, 14838, 52, 40],
            [2016, 14839, 28, 33],
            [2016, 14840, 32, 24],
            [2016, 14841, 20, 16],
            [2016, 14842, 18, 16],
            [2016, 14843, 49, 33],
            [2016, 14844, 16, 16],
            [2016, 14845, 51, 49],
            [2016, 14846, 35, 16],
            [2016, 14847, 13, 11],
            [2016, 14848, 12, 11],
            [2016, 14849, 13, 11],
            [2016, 14850, 39, 26],
            [2016, 14851, 18, 20],
            [2016, 14852, 14, 11],
            [2016, 14853, 24, 20],
            [2016, 14854, 56, 40],
            [2016, 14855, 10, 9],
            [2016, 14856, 8, 7],
            [2016, 14857, 7, 7],
            [2016, 14858, 15, 13],
            [2016, 14859, 22, 19],
            [2016, 14860, 16, 13],
            [2016, 14861, 12, 10],
            [2016, 14862, 14, 11],
            [2016, 14863, 10, 9],
            [2016, 14864, 9, 9],
            [2016, 14865, 18, 20],
            [2016, 14866, 18, 17],
            [2016, 14867, 13, 19],
            [2016, 14868, 24, 17],
            [2016, 14869, 21, 20],
            [2016, 14870, 9, 9],
            [2016, 14871, 9, 9],
            [2016, 14872, 9, 8],
            [2016, 14873, 24, 16],
            [2016, 14875, 23, 20],
            [2016, 14876, 14, 12],
            [2016, 14877, 39, 27],
            [2016, 14879, 20, 17],
            [2016, 14880, 18, 11],
            [2016, 14881, 22, 16],
            [2016, 14882, 23, 22],
            [2016, 14883, 10, 13],
            [2016, 14884, 9, 8],
            [2016, 14885, 9, 9],
            [2016, 14886, 22, 15],
            [2016, 14887, 19, 12],
            [2016, 14888, 12, 10],
            [2016, 14889, 24, 18],
            [2016, 14890, 13, 11],
            [2016, 14892, 23, 22],
            [2016, 14893, 17, 24],
            [2016, 14894, 16, 14],
            [2016, 14896, 28, 18],
            [2016, 14898, 29, 20],
            [2016, 14899, 16, 13],
            [2016, 14900, 11, 9],
            [2016, 14902, 17, 17],
            [2016, 14903, 21, 16],
            [2016, 14904, 25, 18],
            [2016, 14905, 27, 21],
            [2016, 14906, 13, 11],
            [2016, 14907, 8, 9],
            [2016, 14908, 8, 9],
            [2016, 14909, 9, 8],
            [2016, 14910, 16, 15],
            [2016, 14911, 21, 15],
            [2016, 14912, 20, 16],
            [2016, 14913, 12, 11],
            [2016, 14915, 22, 17],
            [2016, 14916, 22, 13],
            [2016, 14917, 21, 21],
            [2016, 14918, 28, 29],
            [2016, 14920, 23, 19],
            [2016, 14921, 14, 11],
            [2016, 14922, 11, 10],
            [2016, 14923, 20, 16],
            [2016, 14924, 20, 17],
            [2016, 14925, 18, 12],
            [2016, 14926, 21, 20],
            [2016, 14927, 18, 18],
            [2016, 14928, 17, 20],
            [2016, 14929, 21, 20],
            [2016, 14930, 19, 18],
            [2016, 14931, 11, 10],
            [2016, 14933, 15, 12],
            [2016, 14934, 34, 30],
            [2016, 14936, 10, 9],
            [2016, 14937, 9, 9],
            [2016, 14938, 25, 22],
            [2016, 14939, 28, 21],
            [2016, 14940, 11, 9],
            [2016, 14941, 33, 27],
            [2016, 14942, 11, 9],
            [2016, 14943, 20, 11],
            [2016, 14944, 17, 14],
            [2016, 14945, 26, 25],
            [2016, 14946, 14, 11],
            [2016, 14947, 16, 12],
            [2016, 14948, 31, 24],
            [2016, 14949, 33, 20],
            [2016, 14950, 13, 10],
            [2016, 14951, 20, 13],
            [2016, 14952, 33, 19],
            [2016, 14953, 18, 16],
            [2016, 14954, 28, 22],
            [2016, 14955, 15, 6],
            [2016, 14956, 25, 19],
            [2016, 14957, 15, 13],
            [2016, 14958, 11, 23],
            [2016, 14959, 13, 10],
            [2016, 14961, 18, 15],
            [2016, 14962, 20, 21],
            [2016, 14963, 22, 18],
            [2016, 14964, 16, 12],
            [2016, 14965, 10, 9],
            [2016, 14966, 9, 8],
            [2016, 14967, 16, 14],
            [2016, 14968, 19, 18],
            [2016, 14969, 10, 10],
            [2016, 14970, 11, 10],
            [2016, 14971, 12, 9],
            [2016, 14972, 26, 21],
            [2016, 14973, 21, 16],
            [2016, 14974, 21, 14],
            [2016, 14975, 15, 9],
            [2016, 14976, 21, 14],
            [2016, 14977, 21, 15],
            [2016, 14978, 22, 28],
            [2016, 14979, 19, 13],
            [2016, 14980, 23, 20],
            [2016, 14981, 18, 15],
            [2016, 14982, 11, 10],
            [2016, 14984, 16, 10],
            [2016, 14985, 17, 14],
            [2016, 14986, 30, 24],
            [2016, 14987, 24, 18],
            [2016, 14988, 16, 15],
            [2016, 14989, 12, 11],
            [2016, 14990, 11, 9],
            [2016, 14991, 8, 5],
            [2016, 14992, 1, 1],
            [2016, 14993, 10, 7],
            [2016, 14994, 10, 6],
            [2016, 14995, 7, 6],
            [2016, 14996, 7, 6],
            [2016, 14997, 18, 13],
            [2016, 14998, 7, 4],
            [2016, 14999, 7, 6],
            [2016, 15000, 15, 12],
            [2016, 15001, 10, 10],
            [2016, 15002, 7, 6],
            [2016, 15003, 16, 12],
            [2016, 15004, 4, 4],
            [2016, 15005, 12, 10],
            [2016, 15006, 13, 10],
            [2016, 15007, 8, 4],
            [2016, 15008, 1, 1],
            [2016, 15009, 12, 10],
            [2016, 15010, 9, 7],
            [2016, 15011, 6, 5],
            [2016, 15012, 1, 1],
            [2016, 15013, 8, 7],
            [2016, 15015, 11, 9],
            [2016, 15016, 1, 1],
            [2016, 15017, 9, 5],
            [2016, 15019, 7, 6],
            [2016, 15020, 10, 8],
            [2016, 15021, 7, 5],
            [2016, 15022, 9, 6],
            [2016, 15023, 10, 7],
            [2016, 15024, 9, 6],
            [2016, 15025, 8, 6],
            [2016, 15026, 8, 7],
            [2016, 15027, 7, 6],
            [2016, 15028, 10, 7],
            [2016, 15029, 10, 8],
            [2016, 15030, 8, 5],
            [2016, 15031, 7, 4],
            [2016, 15032, 7, 4],
            [2016, 15033, 4, 2],
            [2016, 15034, 7, 6],
            [2016, 15035, 9, 7],
            [2016, 15036, 9, 6],
            [2016, 15037, 9, 6],
            [2016, 15040, 9, 7],
            [2016, 15041, 1, 1],
            [2016, 15042, 10, 6],
            [2016, 15043, 14, 11],
            [2016, 15044, 9, 6],
            [2016, 15045, 8, 5],
            [2016, 15047, 7, 5],
            [2016, 15048, 11, 9],
            [2016, 15049, 9, 6],
            [2016, 15050, 7, 5],
            [2016, 15051, 12, 9],
            [2016, 15052, 10, 6],
            [2016, 15053, 13, 10],
            [2016, 15054, 9, 5],
            [2016, 15055, 8, 5],
            [2016, 15056, 9, 7],
            [2016, 15057, 7, 5],
            [2016, 15058, 7, 5],
            [2016, 15059, 2, 1],
            [2016, 15060, 3, 1],
            [2016, 15061, 8, 6],
            [2016, 15062, 9, 6],
            [2016, 15063, 1, 1],
            [2016, 15064, 1, 1],
            [2016, 15065, 1, 1],
            [2016, 15066, 9, 6],
            [2016, 15067, 8, 5],
            [2016, 15068, 12, 9],
            [2016, 15070, 15, 13],
            [2016, 15071, 6, 5],
            [2016, 15072, 12, 9],
            [2016, 15073, 8, 6],
            [2016, 15074, 10, 7],
            [2016, 15075, 1, 1],
            [2016, 15076, 1, 1],
            [2016, 15077, 21, 11],
            [2016, 15078, 8, 6],
            [2016, 15079, 2, 1],
            [2016, 15081, 20, 14],
            [2016, 15082, 7, 5],
            [2016, 15083, 1, 1],
            [2016, 15084, 7, 6],
            [2016, 15085, 9, 6],
            [2016, 15086, 10, 7],
            [2016, 15087, 7, 6],
            [2016, 15088, 13, 10],
            [2016, 15089, 20, 13],
            [2016, 15090, 18, 12],
            [2016, 15091, 11, 10],
            [2016, 15092, 15, 9],
            [2016, 15093, 14, 9],
            [2016, 15094, 8, 7],
            [2016, 15095, 16, 12],
            [2016, 15096, 13, 9],
            [2016, 15097, 12, 9],
            [2016, 15098, 15, 11],
            [2016, 15099, 16, 12],
            [2016, 15100, 10, 9],
            [2016, 15101, 11, 9],
            [2016, 15102, 14, 9],
            [2016, 15103, 12, 8],
            [2016, 15104, 9, 6],
            [2016, 15106, 12, 7],
            [2016, 15107, 8, 7],
            [2016, 15108, 19, 12],
            [2016, 15109, 18, 11],
            [2016, 15110, 6, 5],
            [2016, 15111, 13, 9],
            [2016, 15112, 18, 11],
            [2016, 15113, 19, 11],
            [2016, 15114, 9, 8],
            [2016, 15115, 8, 7],
            [2016, 15116, 9, 7],
            [2016, 15117, 9, 7],
            [2016, 15118, 8, 7],
            [2016, 15119, 6, 5],
            [2016, 15120, 7, 7],
            [2016, 15121, 7, 5],
            [2016, 15122, 3, 3],
            [2016, 15123, 3, 3],
            [2016, 15124, 5, 5],
            [2016, 15125, 4, 5],
            [2016, 15126, 7, 6],
            [2016, 15127, 6, 5],
            [2016, 15128, 20, 12],
            [2016, 15129, 7, 5],
            [2016, 15130, 6, 5],
            [2016, 15131, 5, 4],
            [2016, 15132, 23, 13],
            [2016, 15133, 25, 11],
            [2016, 15134, 17, 11],
            [2016, 15135, 17, 10],
            [2016, 15136, 14, 9],
            [2016, 15137, 12, 9],
            [2016, 15138, 15, 9],
            [2016, 15139, 28, 15],
            [2016, 15140, 15, 10],
            [2016, 15141, 10, 7],
            [2016, 15142, 10, 7],
            [2016, 15143, 10, 7],
            [2016, 15144, 15, 9],
            [2016, 15145, 12, 9],
            [2016, 15146, 18, 11],
            [2016, 15147, 8, 6],
            [2016, 15148, 7, 5],
            [2016, 15149, 11, 8],
            [2016, 15150, 13, 8],
            [2016, 15151, 6, 5],
            [2016, 15152, 7, 6],
            [2016, 15153, 13, 8],
            [2016, 15154, 16, 9],
            [2016, 15155, 18, 12],
            [2016, 15156, 10, 9],
            [2016, 15157, 12, 10],
            [2016, 15158, 18, 10],
            [2016, 15159, 7, 6],
            [2016, 15160, 24, 14],
            [2016, 15161, 10, 8],
            [2016, 15162, 13, 8],
            [2016, 15163, 15, 9],
            [2016, 15164, 14, 8],
            [2016, 15165, 20, 9],
            [2016, 15166, 13, 10],
            [2016, 15167, 10, 11],
            [2016, 15168, 17, 12],
            [2016, 15169, 19, 8],
            [2016, 15170, 12, 9],
            [2016, 15171, 11, 7],
            [2016, 15172, 8, 6],
            [2016, 15173, 11, 9],
            [2016, 15174, 10, 7],
            [2016, 15175, 8, 6],
            [2016, 15176, 6, 6],
            [2016, 15177, 20, 11],
            [2016, 15178, 7, 5],
            [2016, 15179, 7, 5],
            [2016, 15180, 7, 5],
            [2016, 15181, 6, 5],
            [2016, 15182, 15, 10],
            [2016, 15183, 17, 10],
            [2016, 15184, 16, 10],
            [2016, 15185, 23, 12],
            [2016, 15186, 13, 9],
            [2016, 15187, 11, 10],
            [2016, 15188, 14, 10],
            [2016, 15189, 15, 11],
            [2016, 15190, 15, 9],
            [2016, 15191, 11, 8],
            [2016, 15192, 8, 8],
            [2016, 15193, 8, 7],
            [2016, 15194, 12, 9],
            [2016, 15195, 16, 12],
            [2016, 15196, 13, 8],
            [2016, 15197, 19, 11],
            [2016, 15198, 15, 10],
            [2016, 15199, 16, 8],
            [2016, 15200, 14, 10],
            [2016, 15201, 12, 9],
            [2016, 15202, 18, 10],
            [2016, 15203, 14, 9],
            [2016, 15204, 12, 8],
            [2016, 15206, 16, 9],
            [2016, 15207, 10, 8],
            [2016, 15208, 10, 8],
            [2016, 15209, 11, 9],
            [2016, 15210, 10, 9],
            [2016, 15211, 14, 9],
            [2016, 15212, 13, 10],
            [2016, 15213, 26, 15],
            [2016, 15214, 10, 7],
            [2016, 15215, 12, 9],
            [2016, 15216, 12, 9],
            [2016, 15217, 9, 7],
            [2016, 15218, 10, 8],
            [2016, 15219, 13, 9],
            [2016, 15220, 15, 8],
            [2016, 15221, 15, 10],
            [2016, 15222, 16, 10],
            [2016, 15223, 13, 8],
            [2016, 15224, 12, 8],
            [2016, 15225, 10, 7],
            [2016, 15227, 14, 12],
            [2016, 15228, 14, 11],
            [2016, 15229, 15, 8],
            [2016, 15230, 14, 9],
            [2016, 15231, 9, 9],
            [2016, 15232, 18, 11],
            [2016, 15233, 14, 10],
            [2016, 15234, 16, 10],
            [2016, 15235, 8, 8],
            [2016, 15236, 13, 10],
            [2016, 15237, 13, 8],
            [2016, 15238, 10, 8],
            [2016, 15239, 9, 7],
            [2016, 15240, 10, 8],
            [2016, 15241, 12, 8],
            [2016, 15242, 12, 9],
            [2016, 15243, 16, 9],
            [2016, 15244, 9, 7],
            [2016, 15245, 10, 8],
            [2016, 15246, 16, 11],
            [2016, 15247, 15, 10],
            [2016, 15248, 15, 11],
            [2016, 15249, 12, 8],
            [2016, 15250, 13, 9],
            [2016, 15252, 14, 11],
            [2016, 15253, 14, 10],
            [2016, 15254, 9, 6],
            [2016, 15255, 11, 10],
            [2016, 15256, 9, 7],
            [2016, 15257, 8, 9],
            [2016, 15258, 11, 7],
            [2016, 15260, 15, 10],
            [2016, 15261, 14, 8],
            [2016, 15262, 9, 7],
            [2016, 15263, 20, 9],
            [2016, 15264, 18, 11],
            [2016, 15265, 18, 12],
            [2016, 15266, 14, 9],
            [2016, 15267, 11, 8],
            [2016, 15268, 27, 10],
            [2016, 15269, 12, 10],
            [2016, 15270, 12, 7],
            [2016, 15271, 7, 7],
            [2016, 15272, 17, 13],
            [2016, 15273, 12, 6],
            [2016, 15274, 19, 12],
            [2016, 15275, 15, 10],
            [2016, 15276, 15, 9],
            [2016, 15277, 8, 7],
            [2016, 15278, 6, 6],
            [2016, 15280, 13, 10],
            [2016, 15281, 13, 8],
            [2016, 15282, 25, 12],
            [2016, 15283, 25, 11],
            [2016, 15284, 13, 10],
            [2016, 15285, 10, 9],
            [2016, 15286, 18, 11],
            [2016, 15287, 17, 9],
            [2016, 15288, 13, 7],
            [2016, 15289, 10, 9],
            [2016, 15290, 18, 10],
            [2016, 15291, 9, 6],
            [2016, 15292, 12, 9],
            [2016, 15293, 14, 9],
            [2016, 15294, 20, 11],
            [2016, 15295, 11, 11],
            [2016, 15296, 17, 12],
            [2016, 15297, 17, 11],
            [2016, 15298, 17, 10],
            [2016, 15299, 22, 12],
            [2016, 15300, 21, 11],
            [2016, 15301, 8, 7],
            [2016, 15302, 12, 8],
            [2016, 15303, 8, 6],
            [2016, 15304, 7, 8],
            [2016, 15305, 19, 9],
            [2016, 15306, 6, 6],
            [2016, 15307, 5, 6],
            [2016, 15308, 12, 10],
            [2016, 15309, 9, 9],
            [2016, 15310, 10, 6],
            [2016, 15311, 14, 10],
            [2016, 15312, 11, 9],
            [2016, 15313, 20, 9],
            [2016, 15314, 14, 10],
            [2016, 15315, 15, 10],
            [2016, 15316, 16, 10],
            [2016, 15317, 15, 10],
            [2016, 15318, 9, 7],
            [2016, 15319, 11, 9],
            [2016, 15320, 11, 8],
            [2016, 15321, 7, 5],
            [2016, 15323, 17, 10],
            [2016, 15324, 12, 9],
            [2016, 15325, 9, 6],
            [2016, 15326, 25, 14],
            [2016, 15327, 12, 9],
            [2016, 15328, 11, 7],
            [2016, 15329, 13, 8],
            [2016, 15331, 12, 10],
            [2016, 15332, 6, 5],
            [2016, 15333, 9, 7],
            [2016, 15334, 12, 8],
            [2016, 15335, 10, 9],
            [2016, 15336, 17, 10],
            [2016, 15337, 10, 9],
            [2016, 15338, 8, 6],
            [2016, 15339, 14, 8],
            [2016, 15340, 19, 10],
            [2016, 15341, 22, 10],
            [2016, 15342, 19, 12],
            [2016, 15343, 15, 10],
            [2016, 15344, 7, 7],
            [2016, 15345, 8, 7],
            [2016, 15346, 11, 8],
            [2016, 15347, 15, 9],
            [2016, 15348, 16, 9],
            [2016, 15349, 11, 8],
            [2016, 15350, 18, 10],
            [2016, 15351, 17, 9],
            [2016, 15352, 12, 7],
            [2016, 15353, 14, 10],
            [2016, 15354, 18, 11],
            [2016, 15355, 10, 9],
            [2016, 15356, 14, 8],
            [2016, 15357, 13, 11],
            [2016, 15358, 15, 9],
            [2016, 15359, 14, 11],
            [2016, 15360, 12, 11],
            [2016, 15361, 28, 19],
            [2016, 15362, 4, 4],
            [2016, 15363, 6, 6],
            [2016, 15364, 28, 15],
            [2016, 15365, 5, 5],
            [2016, 15366, 9, 8],
            [2016, 15367, 10, 8],
            [2016, 15368, 6, 6],
            [2016, 15369, 10, 8],
            [2016, 15370, 10, 8],
            [2016, 15371, 15, 12],
            [2016, 15372, 13, 11],
            [2016, 15373, 15, 12],
            [2016, 15374, 18, 11],
            [2016, 15375, 11, 9],
            [2016, 15376, 6, 5],
            [2016, 15377, 11, 9],
            [2016, 15378, 15, 10],
            [2016, 15379, 11, 9],
            [2016, 15380, 5, 5],
            [2016, 15381, 15, 10],
            [2016, 15382, 14, 9],
            [2016, 15383, 8, 7],
            [2016, 15385, 7, 6],
            [2016, 15386, 12, 9],
            [2016, 15387, 7, 6],
            [2016, 15389, 11, 12],
            [2016, 15390, 14, 10],
            [2016, 15391, 22, 13],
            [2016, 15392, 18, 11],
            [2016, 15393, 5, 5],
            [2016, 15394, 13, 11],
            [2016, 15395, 9, 8],
            [2016, 15396, 6, 5],
            [2016, 15397, 13, 9],
            [2016, 15398, 18, 12],
            [2016, 15400, 16, 10],
            [2016, 15401, 17, 10],
            [2016, 15402, 7, 7],
            [2016, 15403, 20, 10],
            [2016, 15404, 19, 11],
            [2016, 15405, 19, 11],
            [2016, 15408, 20, 12],
            [2016, 15409, 22, 11],
            [2016, 15410, 13, 9],
            [2016, 15411, 6, 6],
            [2016, 15412, 17, 11],
            [2016, 15414, 11, 9],
            [2016, 15415, 15, 10],
            [2016, 15416, 19, 11],
            [2016, 15418, 18, 10],
            [2016, 15419, 14, 11],
            [2016, 15420, 8, 7],
            [2016, 15440, 22, 21],
            [2016, 15441, 38, 32],
            [2016, 15442, 26, 17],
            [2016, 15443, 15, 13],
            [2016, 15444, 26, 22],
            [2016, 15445, 16, 14],
            [2016, 15446, 37, 33],
            [2016, 15447, 36, 25],
            [2016, 15448, 58, 31],
            [2016, 15449, 49, 35],
            [2016, 15450, 15, 15],
            [2016, 15451, 20, 20],
            [2016, 15452, 29, 28],
            [2016, 15453, 25, 24],
            [2016, 15454, 41, 19],
            [2016, 15455, 167, 30],
            [2016, 15456, 80, 33],
            [2016, 15457, 44, 25],
            [2016, 15458, 56, 34],
            [2016, 15459, 30, 27],
            [2016, 15460, 47, 113],
            [2016, 15461, 26, 26],
            [2016, 15462, 24, 18],
            [2016, 15463, 17, 20],
            [2016, 15464, 44, 26],
            [2016, 15465, 40, 23],
            [2016, 15467, 21, 20],
            [2016, 15468, 18, 19],
            [2016, 15469, 16, 20],
            [2016, 15470, 36, 36],
            [2016, 15471, 13, 19],
            [2016, 15472, 19, 29],
            [2016, 15473, 16, 20],
            [2016, 15474, 32, 36],
            [2016, 15475, 14, 22],
            [2016, 15476, 22, 35],
            [2016, 15477, 36, 82],
            [2016, 15478, 29, 16],
            [2016, 15479, 65, 121],
            [2016, 15480, 37, 61],
            [2016, 15481, 63, 88],
            [2016, 15482, 65, 121],
            [2016, 15483, 26, 28],
            [2016, 15484, 23, 35],
            [2016, 15485, 16, 21],
            [2016, 15486, 10, 16],
            [2016, 15487, 29, 31],
            [2016, 15488, 34, 40],
            [2016, 15489, 45, 71],
            [2016, 15490, 47, 61],
            [2016, 15491, 35, 36],
            [2016, 15493, 13, 23],
            [2016, 15496, 18, 20],
            [2016, 15497, 11, 19],
            [2016, 15498, 15, 16],
            [2016, 15499, 19, 19],
            [2016, 15500, 12, 10],
            [2016, 15501, 15, 10],
            [2016, 15502, 15, 10],
            [2016, 15503, 13, 10],
            [2016, 15504, 13, 10],
            [2016, 15506, 30, 66],
            [2016, 15509, 36, 36],
            [2016, 15511, 65, 47],
            [2016, 15512, 102, 56],
            [2016, 15513, 19, 34],
            [2016, 15514, 35, 57],
            [2016, 15516, 114, 84],
            [2016, 15517, 82, 62],
            [2016, 15518, 89, 37],
            [2016, 15519, 121, 121],
            [2016, 15520, 121, 121],
            [2016, 15521, 49, 47],
            [2016, 15522, 72, 41],
            [2016, 15523, 75, 31],
            [2016, 15524, 41, 41],
            [2016, 15525, 40, 66],
            [2016, 15526, 26, 19],
            [2016, 15528, 17, 31],
            [2016, 15529, 36, 41],
            [2016, 15530, 86, 52],
            [2016, 15532, 82, 62],
            [2016, 15533, 26, 55],
            [2016, 15535, 64, 61],
            [2016, 15537, 12, 10],
            [2016, 15538, 18, 20],
            [2016, 15539, 15, 15],
            [2016, 15540, 10, 14],
            [2016, 15541, 10, 13],
            [2016, 15542, 25, 36],
            [2016, 15543, 42, 23],
            [2016, 15544, 5, 5],
            [2016, 15548, 10, 9],
            [2016, 15550, 4, 4],
            [2016, 15551, 6, 6],
            [2016, 15553, 9, 8],
            [2016, 15554, 10, 8],
            [2016, 15555, 7, 7],
            [2016, 15557, 15, 9],
            [2016, 15558, 7, 7],
            [2016, 15559, 7, 7],
            [2016, 15560, 79, 28],
            [2016, 15561, 21, 17],
            [2016, 15562, 21, 25],
            [2016, 15563, 9, 8],
            [2016, 15564, 9, 7],
            [2016, 15565, 17, 12],
            [2016, 15566, 20, 13],
            [2016, 15567, 10, 7],
            [2016, 15568, 10, 9],
            [2016, 15569, 12, 10],
            [2016, 15570, 14, 12],
            [2016, 15571, 14, 11],
            [2016, 15572, 12, 11],
            [2016, 15573, 5, 5],
            [2016, 15574, 18, 10],
            [2016, 15575, 5, 6],
            [2016, 15576, 6, 7],
            [2016, 15577, 8, 9],
            [2016, 15578, 8, 7],
            [2016, 15579, 9, 7],
            [2016, 15580, 8, 7],
            [2016, 15581, 8, 7],
            [2016, 15582, 7, 6],
            [2016, 15583, 6, 6],
            [2016, 15584, 9, 7],
            [2016, 15585, 9, 7],
            [2016, 15586, 8, 8],
            [2016, 15587, 7, 7],
            [2016, 15588, 7, 7],
            [2016, 15589, 11, 9],
            [2016, 15590, 10, 9],
            [2016, 15591, 9, 8],
            [2016, 15592, 13, 12],
            [2016, 15593, 15, 10],
            [2016, 15594, 17, 12],
            [2016, 15595, 8, 8],
            [2016, 15596, 20, 12],
            [2016, 15597, 11, 8],
            [2016, 15598, 8, 7],
            [2016, 15599, 14, 9],
            [2016, 15600, 17, 11],
            [2016, 15601, 18, 12],
            [2016, 15602, 14, 10],
            [2016, 15605, 6, 6],
            [2016, 15606, 5, 6],
            [2016, 15607, 9, 7],
            [2016, 15608, 8, 6],
            [2016, 15609, 6, 6],
            [2016, 15610, 9, 7],
            [2016, 15611, 8, 6],
            [2016, 15612, 10, 9],
            [2016, 15613, 9, 8],
            [2016, 15614, 12, 12],
            [2016, 15615, 11, 9],
            [2016, 15616, 16, 12],
            [2016, 15617, 12, 10],
            [2016, 15618, 9, 7],
            [2016, 15619, 8, 7],
            [2016, 15620, 29, 22],
            [2016, 15621, 11, 10],
            [2016, 15622, 29, 22],
            [2016, 15623, 8, 8],
            [2016, 15624, 11, 11],
            [2016, 15625, 10, 8],
            [2016, 15626, 13, 10],
            [2016, 15627, 23, 13],
            [2016, 15628, 8, 8],
            [2016, 15629, 8, 8],
            [2016, 15630, 7, 8],
            [2016, 15631, 8, 7],
            [2016, 15632, 21, 12],
            [2016, 15633, 46, 35],
            [2016, 15634, 67, 44],
            [2016, 15635, 77, 52],
            [2016, 15636, 25, 16],
            [2016, 15637, 69, 44],
            [2016, 15638, 49, 34],
            [2016, 15639, 58, 44],
            [2016, 15640, 17, 10],
            [2016, 15641, 11, 10],
            [2016, 15642, 11, 9],
            [2016, 15643, 11, 10],
            [2016, 15644, 16, 10],
            [2016, 15645, 17, 10],
            [2016, 15646, 17, 10],
            [2016, 15647, 11, 9],
            [2016, 15648, 16, 11],
            [2016, 15649, 19, 13],
            [2016, 15650, 11, 8],
            [2016, 15651, 9, 6],
            [2016, 15652, 10, 7],
            [2016, 15653, 9, 6],
            [2016, 15654, 15, 10],
            [2016, 15655, 17, 12],
            [2016, 15656, 10, 7],
            [2016, 15657, 17, 11],
            [2016, 15658, 21, 11],
            [2016, 15659, 21, 11],
            [2016, 15660, 13, 10],
            [2016, 15661, 19, 12],
            [2016, 15662, 17, 11],
            [2016, 15663, 19, 12],
            [2016, 15664, 13, 10],
            [2016, 15665, 6, 6],
            [2016, 15666, 6, 6],
            [2016, 15667, 5, 5],
            [2016, 15668, 14, 11],
            [2016, 15669, 17, 10],
            [2016, 15670, 17, 10],
            [2016, 15671, 5, 5],
            [2016, 15672, 11, 10],
            [2016, 15673, 6, 6],
            [2016, 15674, 20, 13],
            [2016, 15675, 14, 11],
            [2016, 15676, 20, 12],
            [2016, 15677, 10, 8],
            [2016, 15678, 11, 8],
            [2016, 15679, 10, 8],
            [2016, 15680, 23, 13],
            [2016, 15681, 11, 8],
            [2016, 15682, 9, 7],
            [2016, 15683, 11, 9],
            [2016, 15684, 9, 8],
            [2016, 15685, 23, 13],
            [2016, 15686, 23, 15],
            [2016, 15687, 7, 7],
            [2016, 15688, 7, 7],
            [2016, 15689, 2, 1],
            [2016, 15690, 2, 1],
            [2016, 15691, 9, 7],
            [2016, 15692, 10, 6],
            [2016, 15693, 10, 8],
            [2016, 15694, 10, 8],
            [2016, 15695, 10, 8],
            [2016, 15696, 11, 8],
            [2016, 15697, 19, 18],
            [2016, 15698, 17, 13],
            [2016, 15699, 11, 10],
            [2016, 15700, 11, 8],
            [2016, 15701, 23, 12],
            [2016, 15702, 25, 13],
            [2016, 15703, 24, 12],
            [2016, 15704, 21, 11],
            [2016, 15705, 27, 14],
            [2016, 15706, 24, 12],
            [2016, 15707, 21, 11],
            [2016, 15708, 9, 7],
            [2016, 15709, 9, 7],
            [2016, 15710, 11, 9],
            [2016, 15711, 11, 9],
            [2016, 15712, 11, 8],
            [2016, 15713, 7, 5],
            [2016, 15714, 7, 5],
            [2016, 15715, 7, 5],
            [2016, 15716, 9, 6],
            [2016, 15717, 8, 6],
            [2016, 15718, 8, 6],
            [2016, 15719, 8, 5],
            [2016, 15720, 9, 6],
            [2016, 15721, 23, 11],
            [2016, 15722, 23, 11],
            [2016, 15723, 14, 10],
            [2016, 15724, 15, 10],
            [2016, 15725, 28, 20],
            [2016, 15726, 42, 30],
            [2016, 15727, 23, 13],
            [2016, 15728, 23, 16],
            [2016, 15729, 10, 10],
            [2016, 15730, 12, 15],
            [2016, 15731, 22, 16],
            [2016, 15732, 22, 26],
            [2016, 15733, 20, 13],
            [2016, 15734, 21, 15],
            [2016, 15735, 20, 16],
            [2016, 15736, 20, 16],
            [2016, 15737, 9, 9],
            [2016, 15738, 13, 12],
            [2016, 15739, 13, 12],
            [2016, 15740, 12, 10],
            [2016, 15741, 12, 10],
            [2016, 15742, 13, 10],
            [2016, 15743, 15, 11],
            [2016, 15744, 12, 17],
            [2016, 15745, 11, 19],
            [2016, 15746, 29, 23],
            [2016, 15747, 22, 14],
            [2016, 15748, 22, 14],
            [2016, 15749, 29, 23],
            [2016, 15750, 25, 17],
            [2016, 15751, 11, 11],
            [2016, 15752, 11, 9],
            [2016, 15753, 10, 7],
            [2016, 15754, 19, 16],
            [2016, 15755, 19, 12],
            [2016, 15756, 18, 12],
            [2016, 15757, 12, 8],
            [2016, 15758, 12, 9],
            [2016, 15759, 16, 12],
            [2016, 15760, 23, 15],
            [2016, 15761, 33, 18],
            [2016, 15762, 12, 8],
            [2016, 15763, 11, 9],
            [2016, 15764, 10, 7],
            [2016, 15765, 9, 7],
            [2016, 15766, 19, 16],
            [2016, 15767, 19, 12],
            [2016, 15768, 13, 9],
            [2016, 15769, 12, 8],
            [2016, 15770, 16, 12],
            [2016, 15771, 33, 18],
            [2016, 15772, 23, 15],
            [2016, 15773, 12, 9],
            [2016, 15774, 16, 10],
            [2016, 15775, 19, 12],
            [2016, 15776, 16, 10],
            [2016, 15777, 18, 12],
            [2016, 15778, 16, 10],
            [2016, 15779, 7, 8],
            [2016, 15780, 10, 9],
            [2016, 15781, 10, 9],
            [2016, 15782, 7, 8],
            [2016, 15783, 10, 8],
            [2016, 15784, 7, 6],
            [2016, 15785, 7, 8],
            [2016, 15786, 9, 9],
            [2016, 15787, 7, 8],
            [2016, 15788, 15, 11],
            [2016, 15789, 18, 11],
            [2016, 15790, 18, 12],
            [2016, 15791, 8, 8],
            [2016, 15792, 10, 10],
            [2016, 15793, 7, 7],
            [2016, 15794, 11, 9],
            [2016, 15795, 18, 12],
            [2016, 15796, 8, 8],
            [2016, 15797, 9, 9],
            [2016, 15798, 15, 12],
            [2016, 15799, 14, 12],
            [2016, 15800, 17, 13],
            [2016, 15801, 30, 16],
            [2016, 15802, 13, 12],
            [2016, 15803, 13, 11],
            [2016, 15804, 31, 15],
            [2016, 15805, 19, 13],
            [2016, 15806, 31, 18],
            [2016, 15807, 13, 12],
            [2016, 15808, 12, 10],
            [2016, 15809, 14, 12],
            [2016, 15810, 17, 12],
            [2016, 15811, 17, 12],
            [2016, 15813, 6, 4],
            [2016, 15814, 8, 6],
            [2016, 15815, 10, 7],
            [2016, 15816, 12, 9],
            [2016, 15817, 7, 6],
            [2016, 15818, 6, 5],
            [2016, 15819, 8, 5],
            [2016, 15820, 11, 8],
            [2016, 15821, 11, 8],
            [2016, 15822, 10, 7],
            [2016, 15823, 6, 5],
            [2016, 15824, 6, 5],
            [2016, 15825, 6, 5],
            [2016, 15826, 7, 6],
            [2016, 15827, 11, 8],
            [2016, 15828, 5, 4],
            [2016, 15829, 9, 6],
            [2016, 15830, 6, 4],
            [2016, 15831, 9, 6],
            [2016, 15832, 7, 5],
            [2016, 15833, 8, 6],
            [2016, 15834, 14, 11],
            [2016, 15835, 6, 4],
            [2016, 15836, 10, 8],
            [2016, 15837, 10, 7],
            [2016, 15838, 8, 6],
            [2016, 15839, 8, 5],
            [2016, 15840, 7, 4],
            [2016, 15841, 6, 4],
            [2016, 15842, 12, 8],
            [2016, 15843, 16, 10],
            [2016, 15844, 16, 10],
            [2016, 15845, 8, 6],
            [2016, 15846, 6, 6],
            [2016, 15847, 7, 6],
            [2016, 15848, 13, 9],
            [2016, 15849, 13, 9],
            [2016, 15850, 13, 10],
            [2016, 15851, 13, 10],
            [2016, 15852, 12, 9],
            [2016, 15853, 11, 9],
            [2016, 15854, 14, 9],
            [2016, 15855, 18, 10],
            [2016, 15856, 14, 11],
            [2016, 15857, 17, 10],
            [2016, 15858, 11, 9],
            [2016, 15859, 10, 8],
            [2016, 15860, 10, 7],
            [2016, 15861, 9, 8],
            [2016, 15862, 9, 7],
            [2016, 15863, 7, 6],
            [2016, 15864, 10, 8],
            [2016, 15865, 10, 8],
            [2016, 15866, 9, 7],
            [2016, 15867, 7, 6],
            [2016, 15868, 9, 7],
            [2016, 15869, 8, 7],
            [2016, 15870, 9, 7],
            [2016, 15871, 9, 8],
            [2016, 15872, 9, 8],
            [2016, 15873, 10, 8],
            [2016, 15874, 7, 6],
            [2016, 15875, 6, 5],
            [2016, 15876, 7, 6],
            [2016, 15877, 9, 7],
            [2016, 15878, 7, 6],
            [2016, 15879, 9, 8],
            [2016, 15880, 11, 9],
            [2016, 15881, 9, 7],
            [2016, 15882, 8, 7],
            [2016, 15883, 6, 6],
            [2016, 15884, 8, 7],
            [2016, 15885, 5, 5],
            [2016, 15886, 57, 48],
            [2016, 15887, 36, 39],
            [2016, 15888, 77, 51],
            [2016, 15889, 60, 46],
            [2016, 15890, 59, 44],
            [2016, 15891, 77, 51],
            [2016, 15892, 36, 36],
            [2016, 15893, 46, 61],
            [2016, 15894, 46, 39],
            [2016, 15895, 46, 61],
            [2016, 15896, 54, 50],
            [2016, 15897, 59, 43],
            [2016, 15898, 64, 57],
            [2016, 15899, 60, 39],
            [2016, 15900, 29, 34],
            [2016, 15901, 83, 73],
            [2016, 15902, 35, 37],
            [2016, 15903, 57, 33],
            [2016, 15904, 35, 21],
            [2016, 15905, 35, 21],
            [2016, 15906, 54, 55],
            [2016, 15907, 48, 50],
            [2016, 15908, 57, 33],
            [2016, 15909, 36, 39],
            [2016, 15910, 121, 121],
            [2016, 15911, 8, 7],
            [2016, 15912, 7, 7],
            [2016, 15913, 8, 6],
            [2016, 15914, 7, 6],
            [2016, 15915, 7, 7],
            [2016, 15916, 8, 6],
            [2016, 15917, 35, 36],
            [2016, 15918, 108, 92],
            [2017, 12312, 120, 74],
            [2017, 12313, 78, 62],
            [2017, 12314, 78, 62],
            [2017, 12315, 120, 74],
            [2017, 12316, 120, 74],
            [2017, 12317, 120, 74],
            [2017, 12318, 120, 74],
            [2017, 12319, 120, 74],
            [2017, 12320, 78, 62],
            [2017, 12321, 48, 56],
            [2017, 12322, 120, 74],
            [2017, 12323, 120, 74],
            [2017, 12324, 78, 62],
            [2017, 12325, 78, 62],
            [2017, 12581, 83, 81],
            [2017, 12582, 103, 117],
            [2017, 12583, 82, 89],
            [2017, 12584, 90, 67],
            [2017, 12585, 90, 87],
            [2017, 12589, 39, 33],
            [2017, 12590, 30, 23],
            [2017, 12591, 42, 31],
            [2017, 12592, 48, 35],
            [2017, 12593, 31, 21],
            [2017, 12594, 24, 23],
            [2017, 12595, 41, 39],
            [2017, 12596, 20, 17],
            [2017, 12597, 18, 16],
            [2017, 12598, 44, 34],
            [2017, 12599, 39, 34],
            [2017, 12600, 44, 36],
            [2017, 12641, 15, 14],
            [2017, 12642, 11, 10],
            [2017, 12643, 24, 19],
            [2017, 12644, 20, 13],
            [2017, 12645, 29, 30],
            [2017, 12646, 23, 18],
            [2017, 12647, 13, 14],
            [2017, 12648, 21, 14],
            [2017, 12649, 20, 14],
            [2017, 12650, 17, 13],
            [2017, 12651, 25, 16],
            [2017, 12652, 25, 17],
            [2017, 12653, 26, 23],
            [2017, 12654, 12, 11],
            [2017, 12655, 23, 17],
            [2017, 12656, 25, 16],
            [2017, 12657, 13, 11],
            [2017, 12658, 33, 22],
            [2017, 12660, 35, 24],
            [2017, 12661, 33, 24],
            [2017, 12662, 30, 21],
            [2017, 12663, 31, 21],
            [2017, 12664, 36, 25],
            [2017, 12665, 28, 24],
            [2017, 12685, 26, 16],
            [2017, 12686, 18, 12],
            [2017, 12687, 20, 14],
            [2017, 12688, 18, 13],
            [2017, 12689, 24, 15],
            [2017, 12690, 24, 14],
            [2017, 12691, 26, 14],
            [2017, 12692, 26, 16],
            [2017, 12693, 23, 14],
            [2017, 12695, 25, 14],
            [2017, 12696, 23, 13],
            [2017, 12697, 22, 14],
            [2017, 12699, 8, 6],
            [2017, 12703, 23, 19],
            [2017, 12704, 15, 10],
            [2017, 12705, 23, 12],
            [2017, 12706, 25, 15],
            [2017, 12707, 24, 14],
            [2017, 12708, 17, 13],
            [2017, 12709, 22, 14],
            [2017, 12710, 30, 17],
            [2017, 12711, 26, 16],
            [2017, 12712, 30, 21],
            [2017, 12713, 24, 19],
            [2017, 12714, 31, 17],
            [2017, 12715, 31, 19],
            [2017, 12716, 20, 14],
            [2017, 12717, 22, 14],
            [2017, 12718, 17, 11],
            [2017, 12719, 22, 14],
            [2017, 12720, 22, 14],
            [2017, 12721, 22, 12],
            [2017, 12722, 9, 8],
            [2017, 12723, 13, 11],
            [2017, 12727, 14, 13],
            [2017, 12729, 14, 15],
            [2017, 12731, 13, 14],
            [2017, 12777, 8, 6],
            [2017, 12780, 8, 7],
            [2017, 12783, 8, 7],
            [2017, 12785, 19, 11],
            [2017, 12786, 9, 8],
            [2017, 12788, 7, 7],
            [2017, 12790, 14, 11],
            [2017, 12791, 11, 8],
            [2017, 12792, 12, 10],
            [2017, 12793, 11, 9],
            [2017, 12795, 12, 9],
            [2017, 12797, 9, 7],
            [2017, 12798, 8, 9],
            [2017, 12800, 15, 9],
            [2017, 12803, 63, 39],
            [2017, 12805, 14, 9],
            [2017, 12807, 23, 12],
            [2017, 12811, 9, 9],
            [2017, 12813, 9, 8],
            [2017, 12816, 7, 6],
            [2017, 12818, 9, 8],
            [2017, 12819, 12, 12],
            [2017, 12820, 9, 8],
            [2017, 12821, 7, 4],
            [2017, 12822, 10, 9],
            [2017, 12823, 5, 4],
            [2017, 12824, 8, 9],
            [2017, 12825, 9, 7],
            [2017, 12826, 7, 5],
            [2017, 12827, 23, 12],
            [2017, 12828, 8, 6],
            [2017, 12829, 10, 10],
            [2017, 12830, 9, 5],
            [2017, 12831, 47, 25],
            [2017, 12832, 17, 12],
            [2017, 12833, 7, 5],
            [2017, 12834, 22, 12],
            [2017, 12835, 5, 4],
            [2017, 12836, 14, 8],
            [2017, 12837, 5, 4],
            [2017, 12838, 8, 5],
            [2017, 12839, 5, 4],
            [2017, 12840, 14, 8],
            [2017, 12841, 3, 2],
            [2017, 12843, 5, 5],
            [2017, 12845, 8, 6],
            [2017, 12847, 18, 10],
            [2017, 12848, 9, 7],
            [2017, 12849, 7, 7],
            [2017, 12850, 21, 10],
            [2017, 12852, 8, 7],
            [2017, 12853, 6, 4],
            [2017, 12854, 23, 16],
            [2017, 12855, 4, 3],
            [2017, 12856, 14, 8],
            [2017, 12857, 8, 6],
            [2017, 12858, 3, 2],
            [2017, 12860, 14, 9],
            [2017, 12862, 5, 5],
            [2017, 12863, 61, 28],
            [2017, 12864, 5, 4],
            [2017, 12865, 23, 10],
            [2017, 12866, 5, 4],
            [2017, 12867, 55, 20],
            [2017, 12868, 8, 5],
            [2017, 12869, 9, 8],
            [2017, 12870, 6, 5],
            [2017, 12871, 40, 15],
            [2017, 12872, 7, 5],
            [2017, 12873, 10, 8],
            [2017, 12874, 6, 5],
            [2017, 12875, 58, 32],
            [2017, 12876, 9, 6],
            [2017, 12877, 6, 5],
            [2017, 12878, 10, 8],
            [2017, 12879, 8, 8],
            [2017, 12880, 6, 5],
            [2017, 12881, 10, 7],
            [2017, 12882, 9, 7],
            [2017, 12883, 5, 4],
            [2017, 12884, 24, 14],
            [2017, 12885, 3, 2],
            [2017, 12886, 16, 11],
            [2017, 12887, 5, 4],
            [2017, 12888, 10, 8],
            [2017, 12889, 73, 30],
            [2017, 12891, 33, 17],
            [2017, 12892, 9, 7],
            [2017, 12894, 14, 9],
            [2017, 12895, 6, 5],
            [2017, 12896, 28, 16],
            [2017, 12898, 15, 9],
            [2017, 12899, 13, 9],
            [2017, 12900, 8, 6],
            [2017, 12901, 22, 12],
            [2017, 12902, 7, 5],
            [2017, 12903, 16, 15],
            [2017, 12905, 24, 13],
            [2017, 12907, 13, 10],
            [2017, 12909, 5, 4],
            [2017, 12910, 9, 6],
            [2017, 12911, 4, 4],
            [2017, 12912, 10, 7],
            [2017, 12913, 7, 6],
            [2017, 12914, 7, 5],
            [2017, 12915, 4, 3],
            [2017, 12916, 7, 5],
            [2017, 12921, 12, 9],
            [2017, 12922, 8, 6],
            [2017, 12924, 9, 7],
            [2017, 12925, 6, 5],
            [2017, 12926, 6, 5],
            [2017, 12927, 10, 8],
            [2017, 12928, 19, 11],
            [2017, 12929, 7, 5],
            [2017, 12930, 7, 5],
            [2017, 12934, 8, 6],
            [2017, 12935, 7, 6],
            [2017, 12936, 4, 3],
            [2017, 12938, 7, 5],
            [2017, 12939, 3, 2],
            [2017, 12942, 9, 6],
            [2017, 12945, 4, 3],
            [2017, 12946, 6, 4],
            [2017, 12947, 9, 6],
            [2017, 12948, 6, 5],
            [2017, 12950, 8, 5],
            [2017, 12951, 7, 5],
            [2017, 12952, 15, 11],
            [2017, 12953, 10, 9],
            [2017, 12954, 9, 6],
            [2017, 12955, 6, 5],
            [2017, 12956, 5, 4],
            [2017, 12957, 8, 6],
            [2017, 12958, 7, 5],
            [2017, 12959, 6, 4],
            [2017, 12960, 7, 5],
            [2017, 12961, 6, 4],
            [2017, 12964, 8, 6],
            [2017, 12965, 13, 10],
            [2017, 12966, 10, 7],
            [2017, 12967, 9, 6],
            [2017, 12968, 11, 8],
            [2017, 12969, 7, 5],
            [2017, 12970, 7, 5],
            [2017, 12971, 8, 6],
            [2017, 12973, 6, 4],
            [2017, 12974, 8, 5],
            [2017, 12975, 6, 5],
            [2017, 12976, 6, 5],
            [2017, 12977, 4, 3],
            [2017, 12980, 7, 5],
            [2017, 12981, 8, 5],
            [2017, 12982, 8, 7],
            [2017, 12983, 8, 5],
            [2017, 12985, 8, 6],
            [2017, 12986, 5, 4],
            [2017, 12987, 8, 6],
            [2017, 12988, 12, 10],
            [2017, 12991, 6, 5],
            [2017, 12993, 4, 3],
            [2017, 12994, 7, 5],
            [2017, 12995, 5, 4],
            [2017, 12996, 7, 5],
            [2017, 12997, 8, 5],
            [2017, 12999, 7, 5],
            [2017, 13000, 6, 5],
            [2017, 13001, 9, 9],
            [2017, 13002, 10, 9],
            [2017, 13004, 18, 12],
            [2017, 13006, 16, 13],
            [2017, 13007, 14, 12],
            [2017, 13008, 19, 14],
            [2017, 13009, 15, 12],
            [2017, 13010, 15, 13],
            [2017, 13011, 22, 14],
            [2017, 13012, 17, 14],
            [2017, 13013, 11, 10],
            [2017, 13014, 15, 13],
            [2017, 13015, 10, 11],
            [2017, 13016, 12, 10],
            [2017, 13017, 8, 4],
            [2017, 13018, 14, 13],
            [2017, 13019, 12, 7],
            [2017, 13020, 9, 11],
            [2017, 13021, 12, 13],
            [2017, 13022, 9, 4],
            [2017, 13023, 14, 10],
            [2017, 13024, 24, 15],
            [2017, 13025, 9, 12],
            [2017, 13026, 15, 10],
            [2017, 13027, 12, 8],
            [2017, 13028, 7, 4],
            [2017, 13029, 11, 11],
            [2017, 13030, 13, 11],
            [2017, 13031, 10, 9],
            [2017, 13032, 17, 12],
            [2017, 13033, 9, 7],
            [2017, 13034, 6, 4],
            [2017, 13035, 8, 4],
            [2017, 13036, 14, 7],
            [2017, 13037, 8, 5],
            [2017, 13038, 15, 10],
            [2017, 13039, 9, 8],
            [2017, 13040, 15, 11],
            [2017, 13041, 11, 9],
            [2017, 13042, 6, 6],
            [2017, 13043, 8, 5],
            [2017, 13044, 11, 12],
            [2017, 13045, 6, 6],
            [2017, 13046, 13, 11],
            [2017, 13047, 14, 12],
            [2017, 13048, 11, 8],
            [2017, 13049, 10, 9],
            [2017, 13050, 11, 9],
            [2017, 13051, 12, 10],
            [2017, 13052, 10, 9],
            [2017, 13053, 9, 7],
            [2017, 13054, 13, 12],
            [2017, 13055, 16, 11],
            [2017, 13056, 12, 11],
            [2017, 13057, 12, 10],
            [2017, 13058, 14, 12],
            [2017, 13059, 11, 7],
            [2017, 13060, 15, 10],
            [2017, 13061, 16, 12],
            [2017, 13062, 11, 8],
            [2017, 13063, 20, 5],
            [2017, 13064, 8, 9],
            [2017, 13065, 11, 10],
            [2017, 13066, 10, 8],
            [2017, 13067, 14, 10],
            [2017, 13068, 11, 12],
            [2017, 13069, 18, 12],
            [2017, 13070, 9, 4],
            [2017, 13071, 11, 6],
            [2017, 13072, 9, 9],
            [2017, 13073, 9, 8],
            [2017, 13074, 10, 9],
            [2017, 13075, 14, 12],
            [2017, 13076, 11, 7],
            [2017, 13077, 18, 13],
            [2017, 13078, 25, 17],
            [2017, 13079, 10, 10],
            [2017, 13080, 11, 7],
            [2017, 13081, 12, 10],
            [2017, 13082, 7, 6],
            [2017, 13083, 11, 8],
            [2017, 13084, 20, 12],
            [2017, 13085, 21, 13],
            [2017, 13086, 6, 5],
            [2017, 13087, 13, 9],
            [2017, 13088, 15, 9],
            [2017, 13089, 10, 9],
            [2017, 13090, 10, 9],
            [2017, 13091, 7, 4],
            [2017, 13092, 19, 13],
            [2017, 13093, 12, 7],
            [2017, 13094, 22, 12],
            [2017, 13095, 12, 10],
            [2017, 13096, 9, 9],
            [2017, 13097, 15, 10],
            [2017, 13098, 12, 10],
            [2017, 13099, 7, 9],
            [2017, 13100, 17, 14],
            [2017, 13101, 15, 11],
            [2017, 13102, 13, 10],
            [2017, 13103, 16, 11],
            [2017, 13104, 16, 16],
            [2017, 13105, 14, 10],
            [2017, 13106, 13, 9],
            [2017, 13107, 14, 9],
            [2017, 13108, 15, 11],
            [2017, 13111, 15, 11],
            [2017, 13112, 12, 9],
            [2017, 13113, 13, 9],
            [2017, 13114, 9, 9],
            [2017, 13115, 14, 9],
            [2017, 13116, 14, 12],
            [2017, 13117, 15, 11],
            [2017, 13118, 12, 9],
            [2017, 13119, 19, 13],
            [2017, 13120, 9, 6],
            [2017, 13121, 15, 13],
            [2017, 13122, 23, 11],
            [2017, 13123, 14, 10],
            [2017, 13124, 10, 9],
            [2017, 13125, 8, 7],
            [2017, 13126, 15, 11],
            [2017, 13127, 15, 10],
            [2017, 13128, 10, 9],
            [2017, 13129, 20, 13],
            [2017, 13130, 15, 10],
            [2017, 13131, 12, 9],
            [2017, 13132, 12, 9],
            [2017, 13133, 16, 10],
            [2017, 13134, 12, 9],
            [2017, 13136, 14, 13],
            [2017, 13137, 17, 13],
            [2017, 13138, 14, 9],
            [2017, 13140, 14, 9],
            [2017, 13142, 8, 6],
            [2017, 13143, 7, 6],
            [2017, 13144, 10, 9],
            [2017, 13145, 6, 6],
            [2017, 13147, 10, 7],
            [2017, 13148, 10, 9],
            [2017, 13154, 7, 6],
            [2017, 13155, 8, 7],
            [2017, 13156, 8, 7],
            [2017, 13158, 7, 6],
            [2017, 13159, 9, 6],
            [2017, 13161, 7, 6],
            [2017, 13163, 10, 7],
            [2017, 13164, 8, 7],
            [2017, 13165, 8, 5],
            [2017, 13166, 8, 6],
            [2017, 13167, 14, 9],
            [2017, 13168, 7, 6],
            [2017, 13170, 11, 8],
            [2017, 13172, 7, 6],
            [2017, 13173, 9, 7],
            [2017, 13175, 7, 6],
            [2017, 13177, 8, 7],
            [2017, 13178, 9, 7],
            [2017, 13179, 9, 7],
            [2017, 13180, 13, 9],
            [2017, 13181, 7, 6],
            [2017, 13182, 8, 7],
            [2017, 13183, 24, 15],
            [2017, 13184, 7, 6],
            [2017, 13185, 9, 8],
            [2017, 13186, 13, 11],
            [2017, 13187, 7, 8],
            [2017, 13188, 7, 8],
            [2017, 13189, 10, 8],
            [2017, 13190, 7, 8],
            [2017, 13191, 15, 11],
            [2017, 13192, 8, 8],
            [2017, 13193, 7, 8],
            [2017, 13194, 10, 8],
            [2017, 13195, 19, 11],
            [2017, 13196, 15, 9],
            [2017, 13197, 57, 21],
            [2017, 13198, 11, 8],
            [2017, 13200, 15, 10],
            [2017, 13201, 13, 9],
            [2017, 13202, 15, 10],
            [2017, 13203, 7, 7],
            [2017, 13204, 18, 11],
            [2017, 13205, 8, 8],
            [2017, 13206, 11, 9],
            [2017, 13207, 9, 8],
            [2017, 13208, 9, 9],
            [2017, 13209, 7, 6],
            [2017, 13210, 19, 12],
            [2017, 13211, 10, 8],
            [2017, 13212, 45, 20],
            [2017, 13213, 21, 12],
            [2017, 13214, 17, 11],
            [2017, 13216, 16, 11],
            [2017, 13218, 11, 9],
            [2017, 13219, 8, 8],
            [2017, 13220, 8, 8],
            [2017, 13222, 9, 9],
            [2017, 13223, 14, 12],
            [2017, 13224, 43, 16],
            [2017, 13225, 13, 9],
            [2017, 13226, 9, 9],
            [2017, 13227, 17, 11],
            [2017, 13230, 20, 13],
            [2017, 13232, 12, 10],
            [2017, 13233, 13, 10],
            [2017, 13234, 16, 10],
            [2017, 13235, 13, 9],
            [2017, 13236, 10, 7],
            [2017, 13238, 12, 10],
            [2017, 13239, 14, 9],
            [2017, 13240, 12, 10],
            [2017, 13242, 14, 10],
            [2017, 13244, 17, 11],
            [2017, 13245, 12, 10],
            [2017, 13246, 13, 9],
            [2017, 13247, 16, 10],
            [2017, 13248, 11, 8],
            [2017, 13249, 9, 6],
            [2017, 13250, 15, 10],
            [2017, 13251, 13, 10],
            [2017, 13252, 16, 10],
            [2017, 13253, 12, 10],
            [2017, 13254, 11, 8],
            [2017, 13255, 10, 7],
            [2017, 13256, 11, 9],
            [2017, 13257, 13, 9],
            [2017, 13258, 17, 11],
            [2017, 13260, 12, 9],
            [2017, 13261, 14, 10],
            [2017, 13262, 15, 11],
            [2017, 13263, 13, 10],
            [2017, 13264, 14, 10],
            [2017, 13266, 12, 8],
            [2017, 13270, 15, 9],
            [2017, 13273, 12, 9],
            [2017, 13275, 11, 9],
            [2017, 13276, 9, 7],
            [2017, 13280, 12, 8],
            [2017, 13282, 13, 9],
            [2017, 13285, 13, 9],
            [2017, 13286, 15, 10],
            [2017, 13288, 17, 10],
            [2017, 13291, 13, 10],
            [2017, 13297, 12, 8],
            [2017, 13302, 12, 10],
            [2017, 13304, 15, 10],
            [2017, 13305, 11, 9],
            [2017, 13308, 12, 10],
            [2017, 13312, 15, 10],
            [2017, 13315, 14, 10],
            [2017, 13316, 10, 7],
            [2017, 13317, 9, 7],
            [2017, 13319, 15, 10],
            [2017, 13322, 11, 9],
            [2017, 13326, 13, 9],
            [2017, 13328, 11, 9],
            [2017, 13330, 12, 9],
            [2017, 13332, 11, 9],
            [2017, 13334, 9, 8],
            [2017, 13336, 12, 9],
            [2017, 13339, 9, 7],
            [2017, 13340, 13, 10],
            [2017, 13343, 11, 8],
            [2017, 13346, 8, 6],
            [2017, 13348, 15, 10],
            [2017, 13350, 13, 10],
            [2017, 13353, 15, 9],
            [2017, 13355, 13, 8],
            [2017, 13356, 8, 6],
            [2017, 13358, 11, 10],
            [2017, 13360, 9, 6],
            [2017, 13363, 14, 11],
            [2017, 13365, 9, 6],
            [2017, 13367, 9, 6],
            [2017, 13369, 12, 9],
            [2017, 13374, 11, 9],
            [2017, 13375, 11, 9],
            [2017, 13379, 11, 8],
            [2017, 13382, 13, 9],
            [2017, 13385, 6, 6],
            [2017, 13387, 12, 10],
            [2017, 13389, 11, 9],
            [2017, 13390, 12, 9],
            [2017, 13392, 13, 9],
            [2017, 13394, 12, 9],
            [2017, 13397, 6, 6],
            [2017, 13399, 11, 9],
            [2017, 13449, 9, 7],
            [2017, 13450, 8, 7],
            [2017, 13451, 9, 7],
            [2017, 13452, 8, 7],
            [2017, 13453, 9, 8],
            [2017, 13454, 17, 10],
            [2017, 13455, 12, 10],
            [2017, 13456, 6, 6],
            [2017, 13457, 7, 6],
            [2017, 13458, 7, 7],
            [2017, 13460, 8, 6],
            [2017, 13463, 11, 8],
            [2017, 13464, 14, 8],
            [2017, 13465, 11, 8],
            [2017, 13466, 9, 7],
            [2017, 13467, 8, 6],
            [2017, 13468, 8, 7],
            [2017, 13469, 8, 6],
            [2017, 13470, 12, 9],
            [2017, 13471, 9, 7],
            [2017, 13472, 12, 8],
            [2017, 13473, 11, 8],
            [2017, 13474, 9, 7],
            [2017, 13475, 11, 8],
            [2017, 13476, 7, 7],
            [2017, 13478, 6, 6],
            [2017, 13479, 12, 8],
            [2017, 13480, 4, 4],
            [2017, 13481, 8, 6],
            [2017, 13482, 9, 8],
            [2017, 13483, 9, 8],
            [2017, 13484, 10, 8],
            [2017, 13485, 8, 7],
            [2017, 13486, 3, 4],
            [2017, 13487, 17, 10],
            [2017, 13488, 8, 6],
            [2017, 13489, 11, 8],
            [2017, 13490, 7, 6],
            [2017, 13491, 7, 7],
            [2017, 13492, 7, 6],
            [2017, 13494, 11, 8],
            [2017, 13495, 8, 7],
            [2017, 13496, 9, 8],
            [2017, 13497, 9, 7],
            [2017, 13498, 8, 6],
            [2017, 13499, 10, 7],
            [2017, 13501, 14, 9],
            [2017, 13502, 8, 6],
            [2017, 13503, 9, 7],
            [2017, 13504, 7, 6],
            [2017, 13505, 7, 6],
            [2017, 13506, 9, 7],
            [2017, 13508, 10, 8],
            [2017, 13509, 6, 6],
            [2017, 13511, 13, 9],
            [2017, 13512, 9, 7],
            [2017, 13513, 11, 7],
            [2017, 13514, 11, 8],
            [2017, 13516, 7, 6],
            [2017, 13517, 7, 7],
            [2017, 13518, 7, 7],
            [2017, 13519, 11, 8],
            [2017, 13520, 11, 8],
            [2017, 13521, 8, 7],
            [2017, 13522, 9, 8],
            [2017, 13523, 9, 7],
            [2017, 13524, 7, 6],
            [2017, 13525, 10, 8],
            [2017, 13526, 8, 6],
            [2017, 13527, 13, 10],
            [2017, 13528, 8, 7],
            [2017, 13529, 6, 6],
            [2017, 13530, 6, 5],
            [2017, 13531, 7, 6],
            [2017, 13532, 7, 6],
            [2017, 13533, 7, 6],
            [2017, 13534, 6, 6],
            [2017, 13536, 9, 7],
            [2017, 13537, 6, 6],
            [2017, 13538, 6, 5],
            [2017, 13539, 6, 6],
            [2017, 13540, 6, 6],
            [2017, 13541, 9, 7],
            [2017, 13542, 9, 7],
            [2017, 13544, 10, 8],
            [2017, 13546, 7, 6],
            [2017, 13548, 11, 8],
            [2017, 13550, 18, 9],
            [2017, 13552, 11, 9],
            [2017, 13556, 8, 7],
            [2017, 13557, 3, 3],
            [2017, 13558, 13, 9],
            [2017, 13560, 8, 7],
            [2017, 13561, 8, 6],
            [2017, 13562, 9, 7],
            [2017, 13563, 8, 6],
            [2017, 13564, 13, 9],
            [2017, 13565, 8, 6],
            [2017, 13566, 12, 9],
            [2017, 13567, 8, 8],
            [2017, 13568, 4, 5],
            [2017, 13569, 8, 6],
            [2017, 13570, 6, 6],
            [2017, 13571, 10, 7],
            [2017, 13572, 6, 5],
            [2017, 13573, 7, 7],
            [2017, 13574, 9, 8],
            [2017, 13575, 11, 8],
            [2017, 13576, 7, 6],
            [2017, 13577, 7, 6],
            [2017, 13578, 8, 7],
            [2017, 13579, 16, 9],
            [2017, 13580, 10, 7],
            [2017, 13581, 6, 6],
            [2017, 13582, 8, 7],
            [2017, 13583, 8, 7],
            [2017, 13584, 24, 13],
            [2017, 13585, 6, 6],
            [2017, 13586, 6, 6],
            [2017, 13587, 7, 6],
            [2017, 13588, 15, 9],
            [2017, 13589, 7, 7],
            [2017, 13590, 12, 9],
            [2017, 13593, 6, 7],
            [2017, 13594, 12, 9],
            [2017, 13595, 9, 7],
            [2017, 13596, 10, 8],
            [2017, 13597, 8, 6],
            [2017, 13598, 7, 6],
            [2017, 13599, 6, 6],
            [2017, 13600, 8, 7],
            [2017, 13601, 7, 6],
            [2017, 13602, 6, 6],
            [2017, 13603, 6, 6],
            [2017, 13604, 11, 8],
            [2017, 13605, 10, 7],
            [2017, 13606, 10, 8],
            [2017, 13607, 8, 6],
            [2017, 13608, 8, 7],
            [2017, 13683, 15, 11],
            [2017, 13684, 22, 12],
            [2017, 13685, 22, 12],
            [2017, 13686, 19, 11],
            [2017, 13687, 21, 13],
            [2017, 13688, 15, 10],
            [2017, 13689, 15, 10],
            [2017, 13690, 9, 8],
            [2017, 13691, 34, 12],
            [2017, 13692, 15, 12],
            [2017, 13693, 11, 9],
            [2017, 13694, 22, 15],
            [2017, 13695, 16, 12],
            [2017, 13696, 10, 9],
            [2017, 13697, 27, 12],
            [2017, 13698, 14, 10],
            [2017, 13699, 20, 11],
            [2017, 13701, 12, 11],
            [2017, 13702, 21, 11],
            [2017, 13704, 20, 11],
            [2017, 13705, 9, 8],
            [2017, 13706, 21, 12],
            [2017, 13707, 21, 13],
            [2017, 13709, 20, 12],
            [2017, 13710, 16, 10],
            [2017, 13711, 20, 11],
            [2017, 13712, 28, 15],
            [2017, 13715, 26, 13],
            [2017, 13716, 19, 10],
            [2017, 13717, 20, 15],
            [2017, 13719, 26, 12],
            [2017, 13720, 17, 11],
            [2017, 13721, 19, 9],
            [2017, 13722, 20, 14],
            [2017, 13723, 24, 16],
            [2017, 13724, 26, 12],
            [2017, 13725, 20, 10],
            [2017, 13726, 15, 8],
            [2017, 13727, 28, 15],
            [2017, 13728, 18, 12],
            [2017, 13729, 19, 10],
            [2017, 13730, 21, 15],
            [2017, 13731, 17, 11],
            [2017, 13732, 25, 13],
            [2017, 13733, 18, 11],
            [2017, 13734, 19, 10],
            [2017, 13735, 17, 9],
            [2017, 13736, 23, 12],
            [2017, 13737, 20, 11],
            [2017, 13738, 15, 12],
            [2017, 13739, 20, 13],
            [2017, 13740, 25, 9],
            [2017, 13741, 9, 7],
            [2017, 13742, 25, 12],
            [2017, 13743, 29, 15],
            [2017, 13744, 22, 11],
            [2017, 13787, 7, 5],
            [2017, 13788, 6, 6],
            [2017, 13789, 8, 6],
            [2017, 13790, 8, 7],
            [2017, 13791, 7, 6],
            [2017, 13792, 10, 9],
            [2017, 13793, 7, 7],
            [2017, 13794, 10, 9],
            [2017, 13795, 7, 6],
            [2017, 13796, 8, 8],
            [2017, 13797, 8, 8],
            [2017, 13798, 8, 6],
            [2017, 13799, 14, 10],
            [2017, 13800, 7, 6],
            [2017, 13801, 8, 6],
            [2017, 13802, 8, 7],
            [2017, 13803, 8, 7],
            [2017, 13804, 10, 8],
            [2017, 13805, 7, 6],
            [2017, 13806, 8, 7],
            [2017, 13807, 7, 6],
            [2017, 13808, 6, 5],
            [2017, 13809, 8, 7],
            [2017, 13810, 7, 5],
            [2017, 13811, 8, 8],
            [2017, 13812, 8, 7],
            [2017, 13813, 9, 8],
            [2017, 13814, 11, 9],
            [2017, 13815, 11, 9],
            [2017, 13816, 10, 8],
            [2017, 13817, 8, 8],
            [2017, 13818, 8, 7],
            [2017, 13819, 8, 7],
            [2017, 13820, 8, 6],
            [2017, 13821, 6, 6],
            [2017, 13822, 5, 5],
            [2017, 13823, 6, 5],
            [2017, 13824, 8, 7],
            [2017, 13825, 6, 5],
            [2017, 13826, 7, 6],
            [2017, 13827, 6, 5],
            [2017, 13828, 9, 8],
            [2017, 13829, 7, 7],
            [2017, 13830, 7, 6],
            [2017, 13831, 7, 7],
            [2017, 13832, 7, 7],
            [2017, 13833, 10, 9],
            [2017, 13834, 7, 6],
            [2017, 13835, 8, 8],
            [2017, 13836, 8, 7],
            [2017, 13837, 9, 8],
            [2017, 13838, 8, 7],
            [2017, 13839, 9, 9],
            [2017, 13840, 6, 6],
            [2017, 13841, 8, 7],
            [2017, 13842, 9, 8],
            [2017, 13843, 8, 7],
            [2017, 13844, 6, 5],
            [2017, 13845, 7, 6],
            [2017, 13846, 7, 6],
            [2017, 13847, 6, 5],
            [2017, 13848, 6, 6],
            [2017, 13849, 8, 7],
            [2017, 13850, 9, 7],
            [2017, 13851, 9, 9],
            [2017, 13852, 7, 7],
            [2017, 13853, 12, 9],
            [2017, 13854, 11, 10],
            [2017, 13855, 12, 11],
            [2017, 13856, 8, 7],
            [2017, 13857, 8, 6],
            [2017, 13858, 8, 7],
            [2017, 13859, 8, 6],
            [2017, 13860, 6, 6],
            [2017, 13861, 7, 6],
            [2017, 13862, 10, 8],
            [2017, 13863, 7, 6],
            [2017, 13864, 6, 5],
            [2017, 13865, 8, 7],
            [2017, 13866, 6, 6],
            [2017, 13867, 6, 6],
            [2017, 13868, 6, 6],
            [2017, 13869, 8, 6],
            [2017, 13870, 7, 6],
            [2017, 13871, 6, 5],
            [2017, 13872, 7, 6],
            [2017, 13873, 6, 5],
            [2017, 13874, 11, 8],
            [2017, 13875, 8, 6],
            [2017, 13876, 14, 9],
            [2017, 13877, 9, 8],
            [2017, 13878, 7, 6],
            [2017, 13879, 7, 6],
            [2017, 13880, 7, 6],
            [2017, 13881, 8, 6],
            [2017, 13882, 7, 6],
            [2017, 13883, 13, 8],
            [2017, 13884, 7, 7],
            [2017, 13885, 9, 6],
            [2017, 13886, 7, 6],
            [2017, 13887, 7, 6],
            [2017, 13888, 10, 7],
            [2017, 13889, 6, 5],
            [2017, 13890, 9, 8],
            [2017, 13891, 9, 7],
            [2017, 13892, 8, 7],
            [2017, 13893, 11, 10],
            [2017, 13894, 6, 6],
            [2017, 13895, 7, 6],
            [2017, 13896, 6, 6],
            [2017, 13897, 6, 6],
            [2017, 13898, 7, 6],
            [2017, 13899, 8, 6],
            [2017, 13900, 10, 7],
            [2017, 13901, 12, 9],
            [2017, 13902, 7, 6],
            [2017, 13903, 11, 8],
            [2017, 13904, 8, 6],
            [2017, 13905, 9, 8],
            [2017, 13906, 12, 8],
            [2017, 13907, 10, 8],
            [2017, 13908, 9, 8],
            [2017, 13909, 11, 9],
            [2017, 13910, 8, 6],
            [2017, 13911, 7, 6],
            [2017, 13912, 8, 7],
            [2017, 13913, 7, 7],
            [2017, 13914, 7, 7],
            [2017, 13915, 6, 6],
            [2017, 13916, 6, 6],
            [2017, 13917, 6, 5],
            [2017, 13918, 8, 8],
            [2017, 13919, 9, 7],
            [2017, 13920, 11, 8],
            [2017, 13921, 12, 8],
            [2017, 13922, 8, 7],
            [2017, 13923, 7, 6],
            [2017, 13924, 11, 8],
            [2017, 13925, 7, 6],
            [2017, 13926, 8, 7],
            [2017, 13927, 8, 7],
            [2017, 13928, 7, 6],
            [2017, 13929, 7, 6],
            [2017, 13930, 7, 6],
            [2017, 13931, 9, 8],
            [2017, 13932, 8, 6],
            [2017, 13933, 8, 7],
            [2017, 13934, 11, 9],
            [2017, 13935, 6, 6],
            [2017, 13936, 7, 6],
            [2017, 13937, 10, 9],
            [2017, 13938, 7, 6],
            [2017, 13939, 8, 6],
            [2017, 13940, 8, 6],
            [2017, 13941, 8, 7],
            [2017, 13942, 9, 7],
            [2017, 13943, 9, 7],
            [2017, 13944, 8, 7],
            [2017, 13945, 7, 6],
            [2017, 13946, 10, 8],
            [2017, 13947, 12, 9],
            [2017, 13948, 6, 6],
            [2017, 13949, 6, 6],
            [2017, 13950, 9, 8],
            [2017, 13951, 7, 7],
            [2017, 13952, 10, 9],
            [2017, 13953, 10, 8],
            [2017, 13954, 8, 7],
            [2017, 13955, 10, 8],
            [2017, 13956, 10, 8],
            [2017, 13957, 7, 6],
            [2017, 13958, 7, 7],
            [2017, 13959, 7, 7],
            [2017, 13960, 10, 8],
            [2017, 13961, 8, 7],
            [2017, 13962, 9, 8],
            [2017, 13963, 7, 6],
            [2017, 13964, 7, 6],
            [2017, 13965, 6, 6],
            [2017, 13966, 8, 6],
            [2017, 13967, 6, 5],
            [2017, 13968, 6, 6],
            [2017, 13969, 7, 6],
            [2017, 13970, 6, 6],
            [2017, 13971, 7, 6],
            [2017, 13972, 8, 7],
            [2017, 13973, 6, 6],
            [2017, 13974, 6, 6],
            [2017, 13975, 7, 6],
            [2017, 13976, 8, 7],
            [2017, 13977, 7, 8],
            [2017, 13978, 10, 9],
            [2017, 13979, 7, 6],
            [2017, 13980, 6, 6],
            [2017, 13981, 6, 6],
            [2017, 13982, 7, 6],
            [2017, 13983, 11, 8],
            [2017, 13984, 9, 7],
            [2017, 13985, 12, 8],
            [2017, 13986, 7, 7],
            [2017, 13987, 7, 6],
            [2017, 13988, 9, 7],
            [2017, 13989, 7, 6],
            [2017, 13991, 7, 7],
            [2017, 13992, 7, 6],
            [2017, 13993, 8, 7],
            [2017, 13994, 7, 7],
            [2017, 13995, 12, 10],
            [2017, 13996, 7, 7],
            [2017, 13997, 7, 6],
            [2017, 13998, 7, 6],
            [2017, 13999, 10, 9],
            [2017, 14000, 11, 9],
            [2017, 14001, 10, 8],
            [2017, 14002, 7, 6],
            [2017, 14003, 7, 7],
            [2017, 14004, 6, 6],
            [2017, 14005, 16, 12],
            [2017, 14006, 11, 8],
            [2017, 14007, 11, 10],
            [2017, 14008, 11, 8],
            [2017, 14009, 13, 8],
            [2017, 14010, 10, 8],
            [2017, 14011, 9, 9],
            [2017, 14012, 10, 8],
            [2017, 14013, 11, 9],
            [2017, 14014, 18, 11],
            [2017, 14016, 12, 9],
            [2017, 14017, 19, 11],
            [2017, 14018, 9, 8],
            [2017, 14019, 7, 6],
            [2017, 14020, 7, 6],
            [2017, 14021, 10, 8],
            [2017, 14022, 7, 7],
            [2017, 14023, 18, 11],
            [2017, 14024, 10, 9],
            [2017, 14025, 10, 9],
            [2017, 14026, 18, 12],
            [2017, 14027, 11, 10],
            [2017, 14029, 13, 10],
            [2017, 14030, 16, 10],
            [2017, 14031, 20, 14],
            [2017, 14032, 10, 8],
            [2017, 14033, 10, 9],
            [2017, 14034, 12, 9],
            [2017, 14035, 14, 10],
            [2017, 14036, 9, 8],
            [2017, 14037, 17, 10],
            [2017, 14038, 8, 8],
            [2017, 14040, 14, 10],
            [2017, 14041, 20, 13],
            [2017, 14042, 14, 10],
            [2017, 14043, 10, 9],
            [2017, 14044, 10, 9],
            [2017, 14045, 9, 7],
            [2017, 14046, 9, 10],
            [2017, 14047, 11, 10],
            [2017, 14048, 13, 10],
            [2017, 14049, 17, 10],
            [2017, 14050, 13, 10],
            [2017, 14051, 16, 12],
            [2017, 14052, 10, 9],
            [2017, 14053, 11, 8],
            [2017, 14054, 9, 9],
            [2017, 14055, 20, 11],
            [2017, 14056, 19, 10],
            [2017, 14057, 15, 10],
            [2017, 14058, 13, 10],
            [2017, 14059, 12, 10],
            [2017, 14060, 14, 10],
            [2017, 14061, 13, 10],
            [2017, 14062, 11, 11],
            [2017, 14063, 19, 9],
            [2017, 14064, 16, 10],
            [2017, 14065, 19, 10],
            [2017, 14066, 13, 8],
            [2017, 14067, 16, 11],
            [2017, 14068, 9, 6],
            [2017, 14069, 13, 11],
            [2017, 14070, 18, 13],
            [2017, 14071, 17, 12],
            [2017, 14072, 12, 8],
            [2017, 14073, 17, 14],
            [2017, 14074, 14, 12],
            [2017, 14075, 17, 12],
            [2017, 14076, 17, 10],
            [2017, 14077, 12, 9],
            [2017, 14078, 13, 9],
            [2017, 14079, 13, 10],
            [2017, 14080, 19, 11],
            [2017, 14081, 15, 10],
            [2017, 14082, 15, 11],
            [2017, 14083, 11, 7],
            [2017, 14084, 9, 7],
            [2017, 14085, 13, 9],
            [2017, 14086, 13, 10],
            [2017, 14087, 14, 10],
            [2017, 14088, 14, 9],
            [2017, 14089, 13, 9],
            [2017, 14090, 11, 9],
            [2017, 14092, 10, 7],
            [2017, 14093, 11, 7],
            [2017, 14094, 11, 8],
            [2017, 14095, 11, 10],
            [2017, 14096, 14, 10],
            [2017, 14097, 11, 8],
            [2017, 14098, 13, 9],
            [2017, 14099, 13, 8],
            [2017, 14100, 9, 7],
            [2017, 14101, 18, 11],
            [2017, 14102, 18, 9],
            [2017, 14103, 16, 11],
            [2017, 14104, 11, 9],
            [2017, 14105, 15, 10],
            [2017, 14107, 14, 10],
            [2017, 14108, 15, 10],
            [2017, 14110, 18, 9],
            [2017, 14111, 14, 10],
            [2017, 14112, 12, 9],
            [2017, 14113, 10, 9],
            [2017, 14114, 10, 9],
            [2017, 14115, 18, 11],
            [2017, 14116, 17, 12],
            [2017, 14117, 19, 10],
            [2017, 14118, 20, 11],
            [2017, 14119, 20, 13],
            [2017, 14120, 16, 10],
            [2017, 14121, 17, 10],
            [2017, 14122, 18, 10],
            [2017, 14123, 18, 11],
            [2017, 14124, 9, 8],
            [2017, 14125, 15, 11],
            [2017, 14126, 15, 10],
            [2017, 14127, 16, 10],
            [2017, 14128, 9, 7],
            [2017, 14129, 7, 6],
            [2017, 14130, 17, 11],
            [2017, 14131, 24, 12],
            [2017, 14132, 18, 10],
            [2017, 14133, 9, 7],
            [2017, 14134, 13, 10],
            [2017, 14135, 14, 10],
            [2017, 14136, 16, 10],
            [2017, 14137, 20, 10],
            [2017, 14138, 19, 10],
            [2017, 14139, 16, 10],
            [2017, 14140, 25, 11],
            [2017, 14141, 18, 11],
            [2017, 14142, 11, 9],
            [2017, 14143, 20, 11],
            [2017, 14144, 12, 8],
            [2017, 14145, 17, 10],
            [2017, 14146, 29, 12],
            [2017, 14147, 13, 10],
            [2017, 14148, 11, 7],
            [2017, 14149, 17, 11],
            [2017, 14150, 10, 8],
            [2017, 14151, 15, 10],
            [2017, 14152, 16, 10],
            [2017, 14153, 11, 9],
            [2017, 14154, 17, 10],
            [2017, 14155, 10, 7],
            [2017, 14156, 18, 11],
            [2017, 14157, 24, 12],
            [2017, 14158, 13, 10],
            [2017, 14159, 17, 10],
            [2017, 14160, 15, 11],
            [2017, 14161, 7, 6],
            [2017, 14162, 15, 11],
            [2017, 14163, 9, 8],
            [2017, 14164, 14, 11],
            [2017, 14165, 16, 10],
            [2017, 14166, 22, 10],
            [2017, 14167, 10, 7],
            [2017, 14168, 12, 9],
            [2017, 14169, 8, 6],
            [2017, 14170, 8, 6],
            [2017, 14171, 23, 11],
            [2017, 14172, 17, 12],
            [2017, 14173, 10, 10],
            [2017, 14174, 20, 12],
            [2017, 14175, 15, 24],
            [2017, 14176, 10, 9],
            [2017, 14177, 12, 9],
            [2017, 14178, 7, 6],
            [2017, 14179, 22, 13],
            [2017, 14180, 17, 10],
            [2017, 14181, 21, 11],
            [2017, 14182, 16, 10],
            [2017, 14183, 9, 7],
            [2017, 14184, 17, 8],
            [2017, 14185, 18, 10],
            [2017, 14186, 16, 9],
            [2017, 14187, 10, 10],
            [2017, 14188, 14, 10],
            [2017, 14189, 15, 10],
            [2017, 14190, 8, 7],
            [2017, 14191, 14, 12],
            [2017, 14192, 23, 12],
            [2017, 14193, 18, 13],
            [2017, 14194, 9, 8],
            [2017, 14195, 9, 7],
            [2017, 14196, 24, 13],
            [2017, 14197, 17, 10],
            [2017, 14198, 10, 8],
            [2017, 14199, 14, 11],
            [2017, 14200, 19, 10],
            [2017, 14201, 8, 8],
            [2017, 14202, 10, 9],
            [2017, 14203, 9, 7],
            [2017, 14204, 8, 7],
            [2017, 14205, 13, 9],
            [2017, 14206, 11, 9],
            [2017, 14207, 10, 8],
            [2017, 14208, 10, 8],
            [2017, 14209, 22, 11],
            [2017, 14211, 19, 11],
            [2017, 14212, 9, 8],
            [2017, 14213, 19, 12],
            [2017, 14214, 8, 6],
            [2017, 14215, 17, 10],
            [2017, 14216, 11, 9],
            [2017, 14217, 15, 10],
            [2017, 14218, 8, 7],
            [2017, 14219, 9, 7],
            [2017, 14220, 15, 10],
            [2017, 14221, 10, 9],
            [2017, 14222, 18, 11],
            [2017, 14223, 16, 11],
            [2017, 14224, 12, 10],
            [2017, 14225, 13, 10],
            [2017, 14226, 19, 10],
            [2017, 14228, 14, 11],
            [2017, 14229, 16, 10],
            [2017, 14230, 20, 10],
            [2017, 14231, 15, 9],
            [2017, 14232, 9, 6],
            [2017, 14233, 14, 10],
            [2017, 14235, 12, 9],
            [2017, 14236, 23, 13],
            [2017, 14237, 10, 8],
            [2017, 14238, 14, 11],
            [2017, 14240, 7, 5],
            [2017, 14241, 12, 7],
            [2017, 14242, 20, 11],
            [2017, 14243, 7, 5],
            [2017, 14244, 22, 11],
            [2017, 14245, 17, 11],
            [2017, 14246, 19, 11],
            [2017, 14247, 20, 11],
            [2017, 14248, 12, 9],
            [2017, 14249, 25, 13],
            [2017, 14250, 18, 10],
            [2017, 14251, 10, 7],
            [2017, 14252, 26, 13],
            [2017, 14253, 21, 11],
            [2017, 14254, 10, 8],
            [2017, 14255, 17, 10],
            [2017, 14256, 12, 8],
            [2017, 14257, 20, 11],
            [2017, 14258, 14, 8],
            [2017, 14259, 22, 11],
            [2017, 14260, 15, 9],
            [2017, 14261, 21, 10],
            [2017, 14262, 22, 11],
            [2017, 14263, 14, 9],
            [2017, 14264, 18, 10],
            [2017, 14265, 21, 11],
            [2017, 14266, 17, 11],
            [2017, 14267, 7, 6],
            [2017, 14268, 7, 6],
            [2017, 14269, 23, 12],
            [2017, 14270, 9, 7],
            [2017, 14271, 9, 7],
            [2017, 14272, 6, 5],
            [2017, 14273, 24, 12],
            [2017, 14274, 16, 10],
            [2017, 14275, 23, 11],
            [2017, 14276, 12, 10],
            [2017, 14277, 6, 5],
            [2017, 14278, 6, 5],
            [2017, 14280, 20, 10],
            [2017, 14281, 9, 7],
            [2017, 14282, 10, 8],
            [2017, 14283, 10, 6],
            [2017, 14285, 19, 11],
            [2017, 14286, 19, 11],
            [2017, 14287, 15, 9],
            [2017, 14288, 11, 8],
            [2017, 14289, 24, 11],
            [2017, 14290, 24, 13],
            [2017, 14291, 17, 11],
            [2017, 14292, 13, 9],
            [2017, 14293, 12, 8],
            [2017, 14294, 16, 10],
            [2017, 14295, 21, 11],
            [2017, 14296, 22, 11],
            [2017, 14297, 21, 11],
            [2017, 14298, 10, 7],
            [2017, 14299, 21, 11],
            [2017, 14300, 8, 5],
            [2017, 14301, 7, 6],
            [2017, 14302, 9, 7],
            [2017, 14303, 21, 11],
            [2017, 14304, 16, 10],
            [2017, 14305, 24, 12],
            [2017, 14306, 23, 12],
            [2017, 14307, 7, 5],
            [2017, 14308, 17, 10],
            [2017, 14309, 10, 8],
            [2017, 14310, 19, 11],
            [2017, 14311, 21, 12],
            [2017, 14312, 17, 11],
            [2017, 14313, 12, 8],
            [2017, 14314, 22, 11],
            [2017, 14315, 18, 10],
            [2017, 14316, 19, 11],
            [2017, 14317, 17, 11],
            [2017, 14318, 21, 12],
            [2017, 14319, 12, 9],
            [2017, 14320, 9, 7],
            [2017, 14321, 20, 11],
            [2017, 14322, 17, 11],
            [2017, 14323, 21, 11],
            [2017, 14324, 12, 9],
            [2017, 14325, 24, 11],
            [2017, 14327, 23, 11],
            [2017, 14328, 16, 10],
            [2017, 14329, 22, 11],
            [2017, 14330, 17, 10],
            [2017, 14331, 21, 12],
            [2017, 14332, 10, 7],
            [2017, 14333, 13, 9],
            [2017, 14335, 21, 12],
            [2017, 14337, 13, 9],
            [2017, 14338, 21, 12],
            [2017, 14340, 9, 6],
            [2017, 14341, 20, 11],
            [2017, 14342, 18, 11],
            [2017, 14343, 17, 10],
            [2017, 14344, 24, 12],
            [2017, 14345, 20, 11],
            [2017, 14346, 23, 11],
            [2017, 14347, 11, 8],
            [2017, 14348, 20, 11],
            [2017, 14349, 13, 9],
            [2017, 14350, 13, 8],
            [2017, 14352, 20, 10],
            [2017, 14353, 20, 11],
            [2017, 14354, 19, 11],
            [2017, 14355, 13, 10],
            [2017, 14356, 8, 6],
            [2017, 14357, 20, 10],
            [2017, 14358, 13, 9],
            [2017, 14359, 13, 10],
            [2017, 14360, 11, 8],
            [2017, 14361, 22, 12],
            [2017, 14362, 19, 11],
            [2017, 14363, 22, 11],
            [2017, 14364, 21, 11],
            [2017, 14365, 17, 10],
            [2017, 14366, 22, 11],
            [2017, 14367, 25, 12],
            [2017, 14368, 23, 12],
            [2017, 14369, 22, 11],
            [2017, 14370, 11, 8],
            [2017, 14371, 7, 5],
            [2017, 14372, 11, 7],
            [2017, 14373, 22, 12],
            [2017, 14374, 14, 9],
            [2017, 14375, 20, 11],
            [2017, 14376, 7, 5],
            [2017, 14378, 6, 5],
            [2017, 14380, 22, 11],
            [2017, 14381, 22, 11],
            [2017, 14382, 20, 11],
            [2017, 14383, 10, 7],
            [2017, 14384, 18, 10],
            [2017, 14385, 17, 10],
            [2017, 14386, 21, 11],
            [2017, 14387, 26, 14],
            [2017, 14388, 30, 15],
            [2017, 14389, 22, 11],
            [2017, 14390, 20, 10],
            [2017, 14391, 11, 7],
            [2017, 14392, 20, 12],
            [2017, 14393, 15, 9],
            [2017, 14394, 18, 10],
            [2017, 14395, 24, 11],
            [2017, 14397, 21, 9],
            [2017, 14398, 20, 11],
            [2017, 14399, 25, 12],
            [2017, 14400, 27, 12],
            [2017, 14401, 13, 9],
            [2017, 14402, 11, 7],
            [2017, 14403, 20, 11],
            [2017, 14405, 24, 11],
            [2017, 14406, 25, 11],
            [2017, 14407, 16, 11],
            [2017, 14408, 15, 10],
            [2017, 14409, 22, 10],
            [2017, 14411, 16, 9],
            [2017, 14412, 14, 8],
            [2017, 14413, 9, 6],
            [2017, 14415, 16, 10],
            [2017, 14416, 16, 10],
            [2017, 14417, 15, 11],
            [2017, 14418, 22, 11],
            [2017, 14419, 20, 10],
            [2017, 14420, 12, 8],
            [2017, 14421, 23, 10],
            [2017, 14422, 16, 7],
            [2017, 14423, 12, 8],
            [2017, 14424, 15, 9],
            [2017, 14425, 25, 14],
            [2017, 14426, 12, 9],
            [2017, 14427, 21, 10],
            [2017, 14428, 18, 10],
            [2017, 14429, 17, 9],
            [2017, 14430, 16, 10],
            [2017, 14432, 19, 10],
            [2017, 14434, 16, 9],
            [2017, 14435, 10, 8],
            [2017, 14436, 20, 14],
            [2017, 14438, 20, 41],
            [2017, 14440, 20, 32],
            [2017, 14442, 20, 23],
            [2017, 14445, 12, 12],
            [2017, 14446, 26, 26],
            [2017, 14449, 14, 16],
            [2017, 14450, 51, 29],
            [2017, 14452, 33, 23],
            [2017, 14453, 21, 48],
            [2017, 14458, 25, 41],
            [2017, 14459, 30, 30],
            [2017, 14460, 24, 23],
            [2017, 14462, 20, 28],
            [2017, 14463, 10, 12],
            [2017, 14464, 30, 24],
            [2017, 14465, 28, 21],
            [2017, 14466, 21, 22],
            [2017, 14468, 21, 35],
            [2017, 14470, 17, 15],
            [2017, 14471, 18, 23],
            [2017, 14473, 10, 12],
            [2017, 14476, 32, 30],
            [2017, 14478, 11, 13],
            [2017, 14480, 26, 23],
            [2017, 14484, 19, 31],
            [2017, 14485, 13, 14],
            [2017, 14486, 47, 28],
            [2017, 14488, 19, 21],
            [2017, 14489, 14, 16],
            [2017, 14490, 58, 61],
            [2017, 14491, 19, 25],
            [2017, 14495, 24, 23],
            [2017, 14496, 64, 49],
            [2017, 14500, 24, 35],
            [2017, 14501, 20, 18],
            [2017, 14502, 50, 95],
            [2017, 14503, 23, 30],
            [2017, 14505, 12, 11],
            [2017, 14507, 24, 33],
            [2017, 14508, 14, 15],
            [2017, 14509, 29, 25],
            [2017, 14510, 34, 24],
            [2017, 14512, 27, 30],
            [2017, 14513, 36, 28],
            [2017, 14514, 32, 23],
            [2017, 14518, 26, 22],
            [2017, 14519, 87, 70],
            [2017, 14520, 40, 92],
            [2017, 14524, 23, 27],
            [2017, 14528, 16, 14],
            [2017, 14530, 33, 23],
            [2017, 14534, 18, 10],
            [2017, 14535, 12, 6],
            [2017, 14536, 17, 10],
            [2017, 14538, 21, 11],
            [2017, 14541, 13, 10],
            [2017, 14542, 14, 9],
            [2017, 14543, 14, 11],
            [2017, 14544, 9, 7],
            [2017, 14545, 17, 11],
            [2017, 14546, 19, 11],
            [2017, 14547, 16, 10],
            [2017, 14548, 15, 10],
            [2017, 14549, 21, 12],
            [2017, 14550, 18, 11],
            [2017, 14553, 14, 13],
            [2017, 14554, 15, 8],
            [2017, 14555, 10, 10],
            [2017, 14556, 20, 12],
            [2017, 14557, 19, 13],
            [2017, 14700, 16, 11],
            [2017, 14701, 25, 13],
            [2017, 14702, 25, 16],
            [2017, 14703, 23, 15],
            [2017, 14704, 31, 19],
            [2017, 14705, 21, 13],
            [2017, 14706, 25, 14],
            [2017, 14710, 25, 14],
            [2017, 14711, 19, 12],
            [2017, 14712, 23, 15],
            [2017, 14713, 23, 13],
            [2017, 14714, 21, 12],
            [2017, 14717, 12, 9],
            [2017, 14718, 18, 13],
            [2017, 14719, 19, 13],
            [2017, 14720, 34, 17],
            [2017, 14722, 23, 14],
            [2017, 14724, 19, 13],
            [2017, 14725, 21, 13],
            [2017, 14726, 16, 12],
            [2017, 14727, 29, 15],
            [2017, 14728, 25, 15],
            [2017, 14729, 20, 13],
            [2017, 14730, 21, 14],
            [2017, 14731, 18, 14],
            [2017, 14732, 27, 13],
            [2017, 14733, 25, 13],
            [2017, 14734, 23, 17],
            [2017, 14735, 27, 15],
            [2017, 14736, 27, 13],
            [2017, 14738, 23, 14],
            [2017, 14739, 17, 12],
            [2017, 14740, 23, 15],
            [2017, 14741, 25, 16],
            [2017, 14743, 16, 11],
            [2017, 14744, 9, 7],
            [2017, 14745, 21, 15],
            [2017, 14747, 21, 14],
            [2017, 14748, 19, 13],
            [2017, 14749, 11, 8],
            [2017, 14750, 19, 12],
            [2017, 14751, 23, 12],
            [2017, 14752, 20, 13],
            [2017, 14753, 25, 15],
            [2017, 14754, 16, 12],
            [2017, 14755, 16, 13],
            [2017, 14756, 20, 13],
            [2017, 14759, 21, 13],
            [2017, 14760, 23, 14],
            [2017, 14761, 17, 8],
            [2017, 14762, 12, 9],
            [2017, 14763, 19, 17],
            [2017, 14764, 31, 18],
            [2017, 14765, 12, 8],
            [2017, 14766, 23, 14],
            [2017, 14767, 21, 16],
            [2017, 14768, 5, 5],
            [2017, 14769, 37, 23],
            [2017, 14770, 18, 18],
            [2017, 14771, 24, 33],
            [2017, 14773, 39, 44],
            [2017, 14774, 27, 17],
            [2017, 14775, 37, 33],
            [2017, 14776, 33, 31],
            [2017, 14777, 19, 21],
            [2017, 14778, 11, 10],
            [2017, 14779, 37, 21],
            [2017, 14780, 31, 12],
            [2017, 14781, 10, 10],
            [2017, 14782, 57, 29],
            [2017, 14783, 27, 23],
            [2017, 14784, 12, 21],
            [2017, 14785, 56, 38],
            [2017, 14786, 23, 18],
            [2017, 14788, 25, 21],
            [2017, 14789, 64, 40],
            [2017, 14790, 42, 18],
            [2017, 14791, 12, 12],
            [2017, 14792, 53, 47],
            [2017, 14793, 33, 23],
            [2017, 14794, 27, 23],
            [2017, 14795, 32, 23],
            [2017, 14796, 31, 40],
            [2017, 14797, 26, 45],
            [2017, 14798, 25, 36],
            [2017, 14799, 39, 21],
            [2017, 14800, 13, 10],
            [2017, 14801, 30, 15],
            [2017, 14802, 18, 12],
            [2017, 14803, 36, 32],
            [2017, 14804, 13, 10],
            [2017, 14805, 30, 31],
            [2017, 14806, 14, 12],
            [2017, 14807, 34, 23],
            [2017, 14808, 51, 45],
            [2017, 14809, 15, 21],
            [2017, 14810, 15, 18],
            [2017, 14811, 14, 18],
            [2017, 14812, 43, 33],
            [2017, 14813, 21, 17],
            [2017, 14814, 35, 22],
            [2017, 14815, 55, 25],
            [2017, 14816, 13, 10],
            [2017, 14817, 13, 10],
            [2017, 14818, 13, 10],
            [2017, 14819, 36, 33],
            [2017, 14820, 63, 53],
            [2017, 14821, 18, 15],
            [2017, 14823, 15, 16],
            [2017, 14824, 59, 36],
            [2017, 14825, 14, 15],
            [2017, 14826, 39, 20],
            [2017, 14827, 42, 32],
            [2017, 14828, 51, 41],
            [2017, 14829, 18, 15],
            [2017, 14830, 13, 15],
            [2017, 14831, 27, 18],
            [2017, 14832, 41, 32],
            [2017, 14833, 34, 25],
            [2017, 14834, 33, 36],
            [2017, 14835, 48, 18],
            [2017, 14836, 37, 19],
            [2017, 14837, 53, 36],
            [2017, 14838, 49, 38],
            [2017, 14839, 25, 31],
            [2017, 14840, 32, 23],
            [2017, 14841, 19, 15],
            [2017, 14842, 18, 15],
            [2017, 14843, 46, 31],
            [2017, 14844, 15, 15],
            [2017, 14845, 51, 49],
            [2017, 14846, 33, 15],
            [2017, 14847, 12, 10],
            [2017, 14848, 12, 10],
            [2017, 14849, 12, 10],
            [2017, 14850, 38, 25],
            [2017, 14851, 18, 19],
            [2017, 14852, 13, 10],
            [2017, 14853, 23, 19],
            [2017, 14854, 52, 38],
            [2017, 14855, 9, 8],
            [2017, 14856, 8, 7],
            [2017, 14857, 7, 7],
            [2017, 14858, 14, 11],
            [2017, 14859, 19, 16],
            [2017, 14860, 15, 12],
            [2017, 14861, 11, 9],
            [2017, 14862, 13, 10],
            [2017, 14863, 10, 9],
            [2017, 14864, 9, 8],
            [2017, 14865, 16, 16],
            [2017, 14866, 17, 14],
            [2017, 14867, 12, 15],
            [2017, 14868, 22, 15],
            [2017, 14869, 18, 16],
            [2017, 14870, 8, 8],
            [2017, 14871, 9, 8],
            [2017, 14872, 9, 7],
            [2017, 14873, 22, 14],
            [2017, 14875, 21, 17],
            [2017, 14876, 13, 10],
            [2017, 14877, 38, 23],
            [2017, 14879, 19, 16],
            [2017, 14880, 17, 10],
            [2017, 14881, 21, 14],
            [2017, 14882, 22, 19],
            [2017, 14883, 10, 11],
            [2017, 14884, 8, 8],
            [2017, 14885, 8, 8],
            [2017, 14886, 19, 13],
            [2017, 14887, 18, 11],
            [2017, 14888, 11, 9],
            [2017, 14889, 23, 17],
            [2017, 14890, 12, 10],
            [2017, 14892, 20, 18],
            [2017, 14893, 15, 20],
            [2017, 14894, 16, 13],
            [2017, 14896, 27, 17],
            [2017, 14898, 27, 16],
            [2017, 14899, 16, 12],
            [2017, 14900, 10, 8],
            [2017, 14902, 16, 14],
            [2017, 14903, 20, 15],
            [2017, 14904, 23, 15],
            [2017, 14905, 25, 17],
            [2017, 14906, 13, 10],
            [2017, 14907, 8, 8],
            [2017, 14908, 8, 8],
            [2017, 14909, 8, 8],
            [2017, 14910, 14, 12],
            [2017, 14911, 19, 13],
            [2017, 14912, 19, 14],
            [2017, 14913, 11, 10],
            [2017, 14915, 22, 15],
            [2017, 14916, 20, 12],
            [2017, 14917, 18, 17],
            [2017, 14918, 26, 25],
            [2017, 14920, 21, 17],
            [2017, 14921, 13, 10],
            [2017, 14922, 11, 9],
            [2017, 14923, 19, 15],
            [2017, 14924, 19, 15],
            [2017, 14925, 16, 11],
            [2017, 14926, 20, 16],
            [2017, 14927, 17, 15],
            [2017, 14928, 16, 16],
            [2017, 14929, 19, 17],
            [2017, 14930, 18, 14],
            [2017, 14931, 10, 9],
            [2017, 14933, 14, 10],
            [2017, 14934, 31, 26],
            [2017, 14936, 9, 8],
            [2017, 14937, 9, 8],
            [2017, 14938, 24, 19],
            [2017, 14939, 26, 18],
            [2017, 14940, 11, 9],
            [2017, 14941, 30, 23],
            [2017, 14942, 10, 9],
            [2017, 14943, 19, 11],
            [2017, 14944, 17, 13],
            [2017, 14945, 25, 21],
            [2017, 14946, 13, 10],
            [2017, 14947, 14, 11],
            [2017, 14948, 27, 20],
            [2017, 14949, 31, 18],
            [2017, 14950, 12, 9],
            [2017, 14951, 19, 11],
            [2017, 14952, 31, 17],
            [2017, 14953, 18, 15],
            [2017, 14954, 25, 18],
            [2017, 14955, 14, 6],
            [2017, 14956, 22, 16],
            [2017, 14957, 15, 12],
            [2017, 14958, 11, 20],
            [2017, 14959, 13, 10],
            [2017, 14961, 18, 13],
            [2017, 14962, 19, 17],
            [2017, 14963, 22, 16],
            [2017, 14964, 16, 11],
            [2017, 14965, 9, 8],
            [2017, 14966, 8, 7],
            [2017, 14967, 15, 12],
            [2017, 14968, 17, 16],
            [2017, 14969, 9, 9],
            [2017, 14970, 10, 9],
            [2017, 14971, 11, 9],
            [2017, 14972, 23, 17],
            [2017, 14973, 20, 15],
            [2017, 14974, 19, 12],
            [2017, 14975, 13, 8],
            [2017, 14976, 19, 13],
            [2017, 14977, 21, 15],
            [2017, 14978, 21, 25],
            [2017, 14979, 18, 12],
            [2017, 14980, 21, 17],
            [2017, 14981, 16, 13],
            [2017, 14982, 11, 9],
            [2017, 14984, 14, 9],
            [2017, 14985, 16, 12],
            [2017, 14986, 26, 20],
            [2017, 14987, 23, 17],
            [2017, 14988, 15, 13],
            [2017, 14989, 11, 10],
            [2017, 14990, 11, 8],
            [2017, 14991, 8, 5],
            [2017, 14992, 1, 1],
            [2017, 14993, 9, 6],
            [2017, 14994, 9, 5],
            [2017, 14995, 7, 6],
            [2017, 14996, 7, 5],
            [2017, 14997, 16, 11],
            [2017, 14998, 7, 4],
            [2017, 14999, 7, 6],
            [2017, 15000, 15, 10],
            [2017, 15001, 10, 10],
            [2017, 15002, 7, 5],
            [2017, 15003, 16, 12],
            [2017, 15004, 4, 4],
            [2017, 15005, 11, 9],
            [2017, 15006, 13, 10],
            [2017, 15007, 8, 4],
            [2017, 15008, 1, 1],
            [2017, 15009, 12, 9],
            [2017, 15010, 9, 7],
            [2017, 15011, 6, 5],
            [2017, 15012, 1, 1],
            [2017, 15013, 8, 7],
            [2017, 15015, 10, 8],
            [2017, 15016, 1, 1],
            [2017, 15017, 8, 5],
            [2017, 15019, 7, 6],
            [2017, 15020, 9, 7],
            [2017, 15021, 7, 5],
            [2017, 15022, 8, 6],
            [2017, 15023, 9, 6],
            [2017, 15024, 9, 6],
            [2017, 15025, 7, 6],
            [2017, 15026, 8, 6],
            [2017, 15027, 7, 5],
            [2017, 15028, 9, 7],
            [2017, 15029, 10, 7],
            [2017, 15030, 8, 5],
            [2017, 15031, 7, 4],
            [2017, 15032, 7, 4],
            [2017, 15033, 4, 2],
            [2017, 15034, 7, 6],
            [2017, 15035, 9, 6],
            [2017, 15036, 9, 6],
            [2017, 15037, 9, 6],
            [2017, 15040, 8, 6],
            [2017, 15041, 1, 1],
            [2017, 15042, 10, 6],
            [2017, 15043, 14, 10],
            [2017, 15044, 8, 5],
            [2017, 15045, 8, 5],
            [2017, 15047, 7, 5],
            [2017, 15048, 11, 8],
            [2017, 15049, 9, 5],
            [2017, 15050, 7, 5],
            [2017, 15051, 12, 8],
            [2017, 15052, 10, 6],
            [2017, 15053, 12, 9],
            [2017, 15054, 9, 5],
            [2017, 15055, 8, 5],
            [2017, 15056, 8, 6],
            [2017, 15057, 7, 5],
            [2017, 15058, 7, 5],
            [2017, 15059, 2, 1],
            [2017, 15060, 3, 1],
            [2017, 15061, 7, 6],
            [2017, 15062, 9, 6],
            [2017, 15063, 1, 1],
            [2017, 15064, 1, 1],
            [2017, 15065, 1, 1],
            [2017, 15066, 8, 6],
            [2017, 15067, 7, 5],
            [2017, 15068, 11, 8],
            [2017, 15070, 14, 11],
            [2017, 15071, 6, 5],
            [2017, 15072, 11, 9],
            [2017, 15073, 7, 5],
            [2017, 15074, 10, 7],
            [2017, 15075, 1, 1],
            [2017, 15076, 1, 1],
            [2017, 15077, 19, 9],
            [2017, 15078, 8, 5],
            [2017, 15079, 2, 1],
            [2017, 15081, 18, 12],
            [2017, 15082, 7, 5],
            [2017, 15083, 1, 1],
            [2017, 15084, 7, 6],
            [2017, 15085, 8, 6],
            [2017, 15086, 10, 7],
            [2017, 15087, 7, 6],
            [2017, 15088, 12, 9],
            [2017, 15089, 19, 12],
            [2017, 15090, 17, 11],
            [2017, 15091, 11, 9],
            [2017, 15092, 15, 8],
            [2017, 15093, 14, 9],
            [2017, 15094, 7, 6],
            [2017, 15095, 15, 11],
            [2017, 15096, 13, 8],
            [2017, 15097, 11, 9],
            [2017, 15098, 15, 10],
            [2017, 15099, 15, 11],
            [2017, 15100, 10, 9],
            [2017, 15101, 11, 9],
            [2017, 15102, 14, 8],
            [2017, 15103, 11, 8],
            [2017, 15104, 9, 6],
            [2017, 15106, 12, 7],
            [2017, 15107, 8, 7],
            [2017, 15108, 18, 11],
            [2017, 15109, 17, 10],
            [2017, 15110, 6, 5],
            [2017, 15111, 12, 8],
            [2017, 15112, 18, 10],
            [2017, 15113, 18, 11],
            [2017, 15114, 9, 7],
            [2017, 15115, 8, 6],
            [2017, 15116, 8, 7],
            [2017, 15117, 8, 7],
            [2017, 15118, 8, 7],
            [2017, 15119, 6, 5],
            [2017, 15120, 7, 6],
            [2017, 15121, 7, 5],
            [2017, 15122, 3, 3],
            [2017, 15123, 3, 3],
            [2017, 15124, 5, 5],
            [2017, 15125, 4, 5],
            [2017, 15126, 7, 6],
            [2017, 15127, 6, 5],
            [2017, 15128, 18, 11],
            [2017, 15129, 6, 5],
            [2017, 15130, 6, 5],
            [2017, 15131, 5, 4],
            [2017, 15132, 22, 13],
            [2017, 15133, 25, 10],
            [2017, 15134, 16, 10],
            [2017, 15135, 16, 9],
            [2017, 15136, 13, 9],
            [2017, 15137, 12, 8],
            [2017, 15138, 14, 9],
            [2017, 15139, 27, 14],
            [2017, 15140, 15, 9],
            [2017, 15141, 10, 7],
            [2017, 15142, 10, 7],
            [2017, 15143, 10, 7],
            [2017, 15144, 14, 8],
            [2017, 15145, 12, 8],
            [2017, 15146, 17, 11],
            [2017, 15147, 8, 6],
            [2017, 15148, 7, 5],
            [2017, 15149, 10, 8],
            [2017, 15150, 12, 8],
            [2017, 15151, 6, 5],
            [2017, 15152, 7, 6],
            [2017, 15153, 12, 8],
            [2017, 15154, 16, 8],
            [2017, 15155, 17, 11],
            [2017, 15156, 10, 8],
            [2017, 15157, 11, 10],
            [2017, 15158, 17, 10],
            [2017, 15159, 7, 6],
            [2017, 15160, 23, 13],
            [2017, 15161, 10, 8],
            [2017, 15162, 13, 8],
            [2017, 15163, 14, 8],
            [2017, 15164, 13, 8],
            [2017, 15165, 19, 9],
            [2017, 15166, 13, 10],
            [2017, 15167, 9, 10],
            [2017, 15168, 16, 11],
            [2017, 15169, 18, 8],
            [2017, 15170, 12, 9],
            [2017, 15171, 11, 7],
            [2017, 15172, 8, 6],
            [2017, 15173, 11, 9],
            [2017, 15174, 10, 6],
            [2017, 15175, 7, 6],
            [2017, 15176, 5, 5],
            [2017, 15177, 20, 11],
            [2017, 15178, 7, 5],
            [2017, 15179, 7, 5],
            [2017, 15180, 7, 5],
            [2017, 15181, 6, 5],
            [2017, 15182, 15, 9],
            [2017, 15183, 16, 9],
            [2017, 15184, 15, 10],
            [2017, 15185, 21, 12],
            [2017, 15186, 12, 9],
            [2017, 15187, 11, 9],
            [2017, 15188, 13, 9],
            [2017, 15189, 14, 10],
            [2017, 15190, 15, 8],
            [2017, 15191, 11, 8],
            [2017, 15192, 8, 7],
            [2017, 15193, 8, 7],
            [2017, 15194, 12, 9],
            [2017, 15195, 15, 11],
            [2017, 15196, 12, 7],
            [2017, 15197, 19, 11],
            [2017, 15198, 15, 10],
            [2017, 15199, 15, 8],
            [2017, 15200, 13, 10],
            [2017, 15201, 12, 8],
            [2017, 15202, 17, 10],
            [2017, 15203, 13, 8],
            [2017, 15204, 11, 7],
            [2017, 15206, 16, 8],
            [2017, 15207, 9, 7],
            [2017, 15208, 10, 7],
            [2017, 15209, 10, 9],
            [2017, 15210, 10, 8],
            [2017, 15211, 13, 9],
            [2017, 15212, 13, 10],
            [2017, 15213, 25, 13],
            [2017, 15214, 10, 7],
            [2017, 15215, 12, 9],
            [2017, 15216, 11, 8],
            [2017, 15217, 9, 7],
            [2017, 15218, 10, 8],
            [2017, 15219, 13, 8],
            [2017, 15220, 14, 8],
            [2017, 15221, 14, 10],
            [2017, 15222, 15, 9],
            [2017, 15223, 13, 8],
            [2017, 15224, 12, 8],
            [2017, 15225, 9, 7],
            [2017, 15227, 14, 11],
            [2017, 15228, 14, 10],
            [2017, 15229, 14, 8],
            [2017, 15230, 13, 9],
            [2017, 15231, 9, 9],
            [2017, 15232, 17, 10],
            [2017, 15233, 14, 9],
            [2017, 15234, 15, 10],
            [2017, 15235, 8, 8],
            [2017, 15236, 13, 9],
            [2017, 15237, 12, 8],
            [2017, 15238, 10, 8],
            [2017, 15239, 8, 7],
            [2017, 15240, 10, 7],
            [2017, 15241, 12, 7],
            [2017, 15242, 12, 9],
            [2017, 15243, 15, 9],
            [2017, 15244, 9, 7],
            [2017, 15245, 9, 7],
            [2017, 15246, 16, 10],
            [2017, 15247, 14, 10],
            [2017, 15248, 15, 10],
            [2017, 15249, 11, 7],
            [2017, 15250, 12, 8],
            [2017, 15252, 14, 10],
            [2017, 15253, 13, 9],
            [2017, 15254, 8, 6],
            [2017, 15255, 11, 9],
            [2017, 15256, 9, 7],
            [2017, 15257, 8, 8],
            [2017, 15258, 11, 7],
            [2017, 15260, 14, 10],
            [2017, 15261, 13, 8],
            [2017, 15262, 9, 7],
            [2017, 15263, 19, 9],
            [2017, 15264, 17, 10],
            [2017, 15265, 17, 11],
            [2017, 15266, 13, 9],
            [2017, 15267, 10, 8],
            [2017, 15268, 26, 10],
            [2017, 15269, 12, 9],
            [2017, 15270, 12, 7],
            [2017, 15271, 7, 7],
            [2017, 15272, 16, 11],
            [2017, 15273, 11, 6],
            [2017, 15274, 18, 11],
            [2017, 15275, 15, 10],
            [2017, 15276, 15, 9],
            [2017, 15277, 8, 7],
            [2017, 15278, 6, 6],
            [2017, 15280, 13, 10],
            [2017, 15281, 12, 8],
            [2017, 15282, 24, 11],
            [2017, 15283, 23, 11],
            [2017, 15284, 13, 9],
            [2017, 15285, 9, 8],
            [2017, 15286, 16, 10],
            [2017, 15287, 16, 9],
            [2017, 15288, 13, 7],
            [2017, 15289, 10, 8],
            [2017, 15290, 17, 10],
            [2017, 15291, 9, 6],
            [2017, 15292, 12, 8],
            [2017, 15293, 14, 8],
            [2017, 15294, 19, 10],
            [2017, 15295, 11, 10],
            [2017, 15296, 16, 11],
            [2017, 15297, 17, 10],
            [2017, 15298, 16, 9],
            [2017, 15299, 21, 12],
            [2017, 15300, 20, 10],
            [2017, 15301, 8, 6],
            [2017, 15302, 11, 8],
            [2017, 15303, 8, 6],
            [2017, 15304, 7, 8],
            [2017, 15305, 18, 9],
            [2017, 15306, 6, 6],
            [2017, 15307, 5, 6],
            [2017, 15308, 12, 9],
            [2017, 15309, 9, 8],
            [2017, 15310, 10, 6],
            [2017, 15311, 13, 9],
            [2017, 15312, 10, 9],
            [2017, 15313, 19, 9],
            [2017, 15314, 14, 9],
            [2017, 15315, 15, 9],
            [2017, 15316, 16, 9],
            [2017, 15317, 15, 9],
            [2017, 15318, 8, 6],
            [2017, 15319, 10, 8],
            [2017, 15320, 10, 8],
            [2017, 15321, 7, 5],
            [2017, 15323, 16, 9],
            [2017, 15324, 11, 8],
            [2017, 15325, 9, 6],
            [2017, 15326, 23, 12],
            [2017, 15327, 12, 9],
            [2017, 15328, 10, 7],
            [2017, 15329, 12, 7],
            [2017, 15331, 11, 9],
            [2017, 15332, 6, 5],
            [2017, 15333, 9, 7],
            [2017, 15334, 11, 7],
            [2017, 15335, 10, 8],
            [2017, 15336, 17, 10],
            [2017, 15337, 10, 9],
            [2017, 15338, 8, 6],
            [2017, 15339, 13, 8],
            [2017, 15340, 18, 9],
            [2017, 15341, 21, 10],
            [2017, 15342, 18, 11],
            [2017, 15343, 15, 10],
            [2017, 15344, 7, 6],
            [2017, 15345, 8, 7],
            [2017, 15346, 11, 7],
            [2017, 15347, 14, 9],
            [2017, 15348, 16, 9],
            [2017, 15349, 11, 7],
            [2017, 15350, 17, 9],
            [2017, 15351, 16, 8],
            [2017, 15352, 12, 7],
            [2017, 15353, 13, 9],
            [2017, 15354, 17, 10],
            [2017, 15355, 9, 8],
            [2017, 15356, 14, 8],
            [2017, 15357, 13, 10],
            [2017, 15358, 14, 9],
            [2017, 15359, 14, 10],
            [2017, 15440, 22, 20],
            [2017, 15441, 36, 30],
            [2017, 15442, 24, 16],
            [2017, 15443, 14, 12],
            [2017, 15444, 24, 21],
            [2017, 15445, 15, 13],
            [2017, 15446, 35, 31],
            [2017, 15447, 34, 23],
            [2017, 15448, 54, 29],
            [2017, 15449, 46, 33],
            [2017, 15450, 14, 14],
            [2017, 15451, 19, 19],
            [2017, 15452, 27, 26],
            [2017, 15453, 24, 23],
            [2017, 15454, 38, 18],
            [2017, 15455, 155, 28],
            [2017, 15456, 74, 31],
            [2017, 15457, 41, 23],
            [2017, 15458, 52, 32],
            [2017, 15459, 30, 26],
            [2017, 15460, 47, 113],
            [2017, 15461, 26, 26],
            [2017, 15462, 24, 18],
            [2017, 15463, 17, 19],
            [2017, 15464, 44, 26],
            [2017, 15465, 38, 23],
            [2017, 15467, 21, 15],
            [2017, 15468, 18, 16],
            [2017, 15469, 16, 20],
            [2017, 15470, 36, 36],
            [2017, 15471, 13, 17],
            [2017, 15472, 19, 29],
            [2017, 15473, 16, 18],
            [2017, 15474, 32, 36],
            [2017, 15475, 14, 20],
            [2017, 15476, 22, 34],
            [2017, 15477, 34, 82],
            [2017, 15478, 29, 16],
            [2017, 15479, 65, 121],
            [2017, 15480, 37, 61],
            [2017, 15481, 63, 88],
            [2017, 15482, 65, 121],
            [2017, 15483, 26, 25],
            [2017, 15484, 22, 31],
            [2017, 15485, 16, 21],
            [2017, 15486, 10, 15],
            [2017, 15487, 29, 28],
            [2017, 15488, 34, 40],
            [2017, 15489, 45, 71],
            [2017, 15490, 46, 56],
            [2017, 15491, 34, 33],
            [2017, 15493, 12, 23],
            [2017, 15496, 17, 20],
            [2017, 15497, 10, 17],
            [2017, 15498, 15, 16],
            [2017, 15499, 19, 19],
            [2017, 15500, 12, 10],
            [2017, 15501, 15, 10],
            [2017, 15502, 14, 10],
            [2017, 15503, 13, 10],
            [2017, 15504, 12, 10],
            [2017, 15506, 30, 66],
            [2017, 15509, 36, 36],
            [2017, 15511, 59, 42],
            [2017, 15512, 102, 56],
            [2017, 15513, 18, 31],
            [2017, 15514, 33, 52],
            [2017, 15516, 114, 84],
            [2017, 15517, 82, 59],
            [2017, 15518, 89, 37],
            [2017, 15519, 121, 121],
            [2017, 15520, 121, 121],
            [2017, 15521, 47, 43],
            [2017, 15522, 66, 41],
            [2017, 15523, 72, 31],
            [2017, 15524, 41, 41],
            [2017, 15525, 40, 66],
            [2017, 15526, 26, 19],
            [2017, 15528, 16, 28],
            [2017, 15529, 36, 41],
            [2017, 15530, 86, 52],
            [2017, 15532, 82, 59],
            [2017, 15533, 26, 52],
            [2017, 15535, 63, 56],
            [2017, 15537, 12, 10],
            [2017, 15538, 18, 19],
            [2017, 15539, 15, 15],
            [2017, 15540, 10, 13],
            [2017, 15541, 9, 12],
            [2017, 15542, 25, 17],
            [2017, 15543, 42, 23],
            [2017, 15544, 5, 5],
            [2017, 15548, 9, 8],
            [2017, 15550, 4, 4],
            [2017, 15551, 6, 6],
            [2017, 15553, 8, 7],
            [2017, 15554, 10, 8],
            [2017, 15555, 7, 6],
            [2017, 15557, 14, 9],
            [2017, 15558, 7, 6],
            [2017, 15559, 7, 6],
            [2017, 15597, 10, 7],
            [2017, 15598, 7, 6],
            [2017, 15599, 13, 9],
            [2017, 15605, 6, 6],
            [2017, 15606, 5, 6],
            [2017, 15607, 8, 7],
            [2017, 15608, 7, 6],
            [2017, 15609, 6, 6],
            [2017, 15610, 8, 6],
            [2017, 15611, 7, 6],
            [2017, 15627, 23, 13],
            [2017, 15628, 8, 8],
            [2017, 15629, 8, 8],
            [2017, 15630, 7, 8],
            [2017, 15631, 7, 7],
            [2017, 15632, 20, 11],
            [2017, 15633, 46, 34],
            [2017, 15634, 65, 43],
            [2017, 15635, 74, 50],
            [2017, 15636, 24, 15],
            [2017, 15637, 67, 43],
            [2017, 15638, 47, 32],
            [2017, 15639, 56, 43],
            [2017, 15640, 16, 9],
            [2017, 15641, 11, 9],
            [2017, 15642, 10, 8],
            [2017, 15643, 11, 9],
            [2017, 15644, 15, 10],
            [2017, 15645, 17, 9],
            [2017, 15646, 16, 9],
            [2017, 15647, 11, 9],
            [2017, 15648, 15, 10],
            [2017, 15649, 18, 12],
            [2017, 15650, 10, 7],
            [2017, 15651, 8, 6],
            [2017, 15652, 9, 6],
            [2017, 15653, 9, 6],
            [2017, 15654, 14, 9],
            [2017, 15655, 16, 11],
            [2017, 15656, 9, 6],
            [2017, 15657, 16, 10],
            [2017, 15658, 19, 10],
            [2017, 15659, 19, 10],
            [2017, 15660, 12, 9],
            [2017, 15661, 19, 11],
            [2017, 15662, 16, 10],
            [2017, 15663, 19, 11],
            [2017, 15664, 12, 9],
            [2017, 15677, 10, 8],
            [2017, 15678, 10, 8],
            [2017, 15679, 10, 7],
            [2017, 15680, 19, 11],
            [2017, 15681, 10, 8],
            [2017, 15682, 9, 7],
            [2017, 15683, 11, 9],
            [2017, 15684, 9, 7],
            [2017, 15685, 19, 11],
            [2017, 15686, 22, 13],
            [2017, 15687, 7, 6],
            [2017, 15688, 7, 6],
            [2017, 15689, 2, 1],
            [2017, 15690, 2, 1],
            [2017, 15691, 9, 7],
            [2017, 15692, 10, 6],
            [2017, 15693, 10, 8],
            [2017, 15694, 9, 7],
            [2017, 15695, 10, 7],
            [2017, 15696, 11, 8],
            [2017, 15697, 19, 18],
            [2017, 15698, 16, 12],
            [2017, 15699, 11, 10],
            [2017, 15700, 11, 8],
            [2017, 15701, 22, 11],
            [2017, 15702, 24, 13],
            [2017, 15703, 22, 11],
            [2017, 15704, 20, 11],
            [2017, 15705, 24, 12],
            [2017, 15706, 22, 11],
            [2017, 15707, 20, 11],
            [2017, 15708, 9, 7],
            [2017, 15709, 9, 7],
            [2017, 15710, 10, 8],
            [2017, 15711, 10, 8],
            [2017, 15712, 11, 8],
            [2017, 15713, 7, 5],
            [2017, 15714, 7, 5],
            [2017, 15715, 7, 5],
            [2017, 15716, 8, 5],
            [2017, 15717, 8, 5],
            [2017, 15718, 8, 5],
            [2017, 15719, 8, 5],
            [2017, 15720, 8, 5],
            [2017, 15721, 21, 10],
            [2017, 15722, 21, 10],
            [2017, 15723, 12, 9],
            [2017, 15724, 14, 10],
            [2017, 15725, 25, 17],
            [2017, 15726, 40, 27],
            [2017, 15727, 23, 12],
            [2017, 15728, 23, 15],
            [2017, 15729, 10, 10],
            [2017, 15730, 12, 15],
            [2017, 15731, 22, 15],
            [2017, 15732, 22, 26],
            [2017, 15733, 18, 11],
            [2017, 15734, 20, 14],
            [2017, 15735, 19, 15],
            [2017, 15736, 19, 15],
            [2017, 15737, 8, 8],
            [2017, 15738, 12, 11],
            [2017, 15739, 12, 11],
            [2017, 15740, 11, 9],
            [2017, 15741, 11, 9],
            [2017, 15742, 12, 9],
            [2017, 15743, 14, 10],
            [2017, 15744, 11, 15],
            [2017, 15745, 11, 18],
            [2017, 15746, 29, 23],
            [2017, 15747, 21, 14],
            [2017, 15748, 21, 14],
            [2017, 15749, 29, 23],
            [2017, 15750, 23, 16],
            [2017, 15751, 11, 11],
            [2017, 15752, 11, 9],
            [2017, 15753, 9, 6],
            [2017, 15754, 18, 13],
            [2017, 15755, 17, 11],
            [2017, 15756, 16, 11],
            [2017, 15757, 12, 8],
            [2017, 15758, 12, 8],
            [2017, 15759, 15, 11],
            [2017, 15760, 23, 13],
            [2017, 15761, 29, 15],
            [2017, 15762, 11, 8],
            [2017, 15763, 11, 9],
            [2017, 15764, 9, 6],
            [2017, 15765, 8, 7],
            [2017, 15766, 18, 13],
            [2017, 15767, 17, 11],
            [2017, 15768, 11, 8],
            [2017, 15769, 12, 8],
            [2017, 15770, 15, 11],
            [2017, 15771, 29, 15],
            [2017, 15772, 23, 13],
            [2017, 15773, 12, 8],
            [2017, 15774, 16, 9],
            [2017, 15775, 19, 11],
            [2017, 15776, 16, 9],
            [2017, 15777, 18, 11],
            [2017, 15778, 16, 9],
            [2017, 15779, 6, 8],
            [2017, 15780, 9, 8],
            [2017, 15781, 9, 8],
            [2017, 15782, 6, 7],
            [2017, 15783, 9, 8],
            [2017, 15784, 6, 6],
            [2017, 15785, 7, 8],
            [2017, 15786, 8, 8],
            [2017, 15787, 7, 8],
            [2017, 15788, 14, 10],
            [2017, 15789, 16, 10],
            [2017, 15790, 17, 10],
            [2017, 15791, 7, 7],
            [2017, 15792, 9, 9],
            [2017, 15793, 6, 6],
            [2017, 15794, 10, 8],
            [2017, 15795, 17, 10],
            [2017, 15796, 8, 8],
            [2017, 15797, 9, 8],
            [2017, 15798, 14, 11],
            [2017, 15799, 14, 11],
            [2017, 15800, 16, 12],
            [2017, 15801, 27, 14],
            [2017, 15802, 11, 10],
            [2017, 15803, 12, 10],
            [2017, 15804, 28, 13],
            [2017, 15805, 17, 12],
            [2017, 15806, 28, 16],
            [2017, 15807, 11, 11],
            [2017, 15808, 11, 9],
            [2017, 15809, 13, 10],
            [2017, 15810, 16, 11],
            [2017, 15811, 16, 11],
            [2017, 15813, 6, 4],
            [2017, 15814, 8, 6],
            [2017, 15815, 9, 6],
            [2017, 15816, 12, 8],
            [2017, 15817, 7, 6],
            [2017, 15818, 6, 5],
            [2017, 15819, 7, 5],
            [2017, 15820, 10, 7],
            [2017, 15821, 10, 8],
            [2017, 15822, 9, 6],
            [2017, 15823, 6, 5],
            [2017, 15824, 6, 5],
            [2017, 15825, 6, 5],
            [2017, 15826, 7, 6],
            [2017, 15827, 10, 7],
            [2017, 15828, 5, 4],
            [2017, 15829, 8, 6],
            [2017, 15830, 6, 4],
            [2017, 15831, 9, 6],
            [2017, 15832, 7, 5],
            [2017, 15833, 8, 6],
            [2017, 15834, 14, 11],
            [2017, 15835, 6, 4],
            [2017, 15836, 9, 7],
            [2017, 15837, 10, 6],
            [2017, 15838, 8, 6],
            [2017, 15839, 8, 5],
            [2017, 15840, 7, 4],
            [2017, 15841, 6, 4],
            [2017, 15842, 11, 7],
            [2017, 15843, 15, 10],
            [2017, 15844, 15, 10],
            [2017, 15845, 8, 6],
            [2017, 15846, 6, 6],
            [2017, 15847, 7, 6],
            [2017, 15848, 13, 9],
            [2017, 15849, 13, 9],
            [2017, 15850, 12, 10],
            [2017, 15851, 12, 10],
            [2017, 15852, 11, 9],
            [2017, 15853, 11, 9],
            [2017, 15854, 13, 9],
            [2017, 15855, 16, 10],
            [2017, 15856, 13, 10],
            [2017, 15857, 15, 10],
            [2017, 15858, 11, 9],
            [2017, 15859, 10, 7],
            [2017, 15860, 9, 7],
            [2017, 15861, 8, 7],
            [2017, 15862, 9, 7],
            [2017, 15863, 7, 6],
            [2017, 15864, 10, 8],
            [2017, 15865, 10, 7],
            [2017, 15866, 8, 6],
            [2017, 15867, 7, 6],
            [2017, 15868, 9, 7],
            [2017, 15869, 8, 6],
            [2017, 15870, 8, 6],
            [2017, 15871, 9, 7],
            [2017, 15872, 8, 7],
            [2017, 15873, 9, 7],
            [2017, 15874, 7, 6],
            [2017, 15875, 6, 5],
            [2017, 15876, 7, 6],
            [2017, 15877, 8, 6],
            [2017, 15878, 7, 6],
            [2017, 15879, 9, 7],
            [2017, 15880, 10, 8],
            [2017, 15881, 8, 6],
            [2017, 15882, 8, 7],
            [2017, 15883, 6, 6],
            [2017, 15884, 8, 7],
            [2017, 15885, 5, 5],
            [2017, 15886, 56, 46],
            [2017, 15887, 36, 36],
            [2017, 15888, 77, 51],
            [2017, 15889, 59, 45],
            [2017, 15890, 59, 44],
            [2017, 15891, 77, 51],
            [2017, 15892, 36, 36],
            [2017, 15893, 46, 59],
            [2017, 15894, 43, 34],
            [2017, 15895, 46, 59],
            [2017, 15896, 54, 48],
            [2017, 15897, 59, 43],
            [2017, 15898, 62, 54],
            [2017, 15899, 53, 34],
            [2017, 15900, 29, 33],
            [2017, 15901, 79, 68],
            [2017, 15902, 33, 37],
            [2017, 15903, 56, 33],
            [2017, 15904, 35, 21],
            [2017, 15905, 35, 21],
            [2017, 15906, 54, 51],
            [2017, 15907, 48, 47],
            [2017, 15908, 56, 33],
            [2017, 15909, 36, 36],
            [2017, 15910, 121, 121],
            [2017, 15911, 8, 7],
            [2017, 15912, 7, 7],
            [2017, 15913, 8, 6],
            [2017, 15914, 7, 6],
            [2017, 15915, 7, 7],
            [2017, 15916, 8, 6],
            [2017, 15917, 33, 36],
            [2017, 15918, 108, 92],
            [2018, 12312, 113, 69],
            [2018, 12313, 71, 57],
            [2018, 12314, 71, 57],
            [2018, 12315, 113, 69],
            [2018, 12316, 113, 69],
            [2018, 12317, 113, 69],
            [2018, 12318, 113, 69],
            [2018, 12319, 113, 69],
            [2018, 12320, 71, 57],
            [2018, 12321, 41, 51],
            [2018, 12322, 113, 69],
            [2018, 12323, 113, 69],
            [2018, 12324, 71, 57],
            [2018, 12325, 71, 57],
            [2018, 12777, 7, 6],
            [2018, 12780, 7, 7],
            [2018, 12783, 7, 6],
            [2018, 12785, 18, 10],
            [2018, 12786, 9, 8],
            [2018, 12788, 7, 7],
            [2018, 12791, 11, 8],
            [2018, 12798, 8, 9],
            [2018, 12800, 13, 8],
            [2018, 12803, 63, 36],
            [2018, 12805, 12, 8],
            [2018, 12807, 21, 11],
            [2018, 12811, 9, 8],
            [2018, 12813, 9, 7],
            [2018, 12816, 6, 6],
            [2018, 12818, 9, 7],
            [2018, 12819, 12, 11],
            [2018, 12820, 9, 7],
            [2018, 12821, 7, 4],
            [2018, 12822, 10, 8],
            [2018, 12823, 5, 4],
            [2018, 12824, 8, 8],
            [2018, 12825, 9, 7],
            [2018, 12826, 6, 5],
            [2018, 12827, 21, 11],
            [2018, 12828, 8, 6],
            [2018, 12829, 10, 10],
            [2018, 12830, 8, 5],
            [2018, 12831, 46, 20],
            [2018, 12832, 17, 11],
            [2018, 12833, 7, 5],
            [2018, 12834, 22, 12],
            [2018, 12835, 5, 4],
            [2018, 12836, 12, 8],
            [2018, 12837, 5, 4],
            [2018, 12838, 7, 4],
            [2018, 12839, 5, 4],
            [2018, 12840, 13, 8],
            [2018, 12841, 3, 2],
            [2018, 12843, 5, 4],
            [2018, 12845, 8, 5],
            [2018, 12847, 17, 10],
            [2018, 12848, 9, 6],
            [2018, 12849, 7, 7],
            [2018, 12850, 21, 10],
            [2018, 12852, 8, 7],
            [2018, 12853, 6, 4],
            [2018, 12854, 23, 15],
            [2018, 12855, 4, 3],
            [2018, 12856, 14, 8],
            [2018, 12857, 8, 6],
            [2018, 12858, 3, 2],
            [2018, 12860, 14, 9],
            [2018, 12862, 5, 4],
            [2018, 12863, 61, 26],
            [2018, 12864, 5, 4],
            [2018, 12865, 20, 9],
            [2018, 12866, 5, 4],
            [2018, 12867, 52, 18],
            [2018, 12868, 7, 4],
            [2018, 12869, 9, 8],
            [2018, 12870, 6, 4],
            [2018, 12871, 39, 15],
            [2018, 12872, 7, 5],
            [2018, 12873, 10, 8],
            [2018, 12874, 6, 5],
            [2018, 12875, 58, 31],
            [2018, 12876, 9, 6],
            [2018, 12877, 6, 4],
            [2018, 12878, 10, 8],
            [2018, 12879, 8, 8],
            [2018, 12880, 6, 4],
            [2018, 12881, 10, 7],
            [2018, 12882, 9, 7],
            [2018, 12883, 5, 4],
            [2018, 12884, 20, 12],
            [2018, 12885, 3, 2],
            [2018, 12886, 14, 10],
            [2018, 12887, 5, 4],
            [2018, 12888, 9, 7],
            [2018, 12889, 71, 30],
            [2018, 12891, 33, 16],
            [2018, 12892, 9, 7],
            [2018, 12894, 13, 8],
            [2018, 12895, 6, 4],
            [2018, 12896, 27, 15],
            [2018, 12898, 14, 9],
            [2018, 12899, 12, 8],
            [2018, 12900, 8, 6],
            [2018, 12901, 21, 12],
            [2018, 12902, 7, 4],
            [2018, 12903, 13, 12],
            [2018, 12905, 23, 12],
            [2018, 12907, 13, 10],
            [2018, 12909, 5, 4],
            [2018, 12910, 9, 6],
            [2018, 12911, 4, 4],
            [2018, 12912, 9, 7],
            [2018, 12913, 7, 5],
            [2018, 12914, 6, 5],
            [2018, 12915, 4, 3],
            [2018, 12916, 7, 4],
            [2018, 12921, 11, 8],
            [2018, 12922, 8, 6],
            [2018, 12924, 9, 7],
            [2018, 12925, 6, 5],
            [2018, 12926, 6, 5],
            [2018, 12927, 10, 8],
            [2018, 12928, 19, 11],
            [2018, 12929, 6, 4],
            [2018, 12930, 7, 5],
            [2018, 12934, 8, 5],
            [2018, 12935, 7, 5],
            [2018, 12936, 4, 3],
            [2018, 12938, 7, 5],
            [2018, 12939, 3, 2],
            [2018, 12942, 9, 6],
            [2018, 12945, 4, 3],
            [2018, 12946, 6, 4],
            [2018, 12947, 8, 5],
            [2018, 12948, 6, 5],
            [2018, 12950, 7, 5],
            [2018, 12951, 7, 5],
            [2018, 12952, 14, 11],
            [2018, 12953, 10, 8],
            [2018, 12954, 9, 6],
            [2018, 12955, 6, 4],
            [2018, 12956, 5, 4],
            [2018, 12957, 8, 6],
            [2018, 12958, 6, 5],
            [2018, 12959, 6, 4],
            [2018, 12960, 7, 4],
            [2018, 12961, 6, 4],
            [2018, 12964, 8, 5],
            [2018, 12965, 12, 9],
            [2018, 12966, 10, 7],
            [2018, 12967, 8, 6],
            [2018, 12968, 11, 8],
            [2018, 12969, 7, 5],
            [2018, 12970, 6, 4],
            [2018, 12971, 7, 5],
            [2018, 12973, 6, 4],
            [2018, 12974, 7, 4],
            [2018, 12975, 6, 4],
            [2018, 12976, 6, 4],
            [2018, 12977, 4, 3],
            [2018, 12980, 6, 4],
            [2018, 12981, 7, 5],
            [2018, 12982, 8, 7],
            [2018, 12983, 8, 5],
            [2018, 12985, 8, 6],
            [2018, 12986, 5, 4],
            [2018, 12987, 7, 5],
            [2018, 12988, 12, 9],
            [2018, 12991, 6, 4],
            [2018, 12993, 4, 3],
            [2018, 12994, 7, 4],
            [2018, 12995, 5, 4],
            [2018, 12996, 7, 5],
            [2018, 12997, 7, 4],
            [2018, 12999, 7, 5],
            [2018, 13000, 6, 5],
            [2018, 13015, 10, 9],
            [2018, 13016, 11, 9],
            [2018, 13017, 8, 4],
            [2018, 13018, 14, 12],
            [2018, 13019, 12, 7],
            [2018, 13020, 9, 10],
            [2018, 13021, 12, 12],
            [2018, 13022, 9, 4],
            [2018, 13023, 13, 10],
            [2018, 13024, 23, 14],
            [2018, 13025, 9, 10],
            [2018, 13026, 15, 9],
            [2018, 13027, 11, 8],
            [2018, 13028, 7, 4],
            [2018, 13029, 11, 10],
            [2018, 13030, 13, 11],
            [2018, 13031, 10, 8],
            [2018, 13032, 15, 11],
            [2018, 13033, 9, 7],
            [2018, 13034, 6, 4],
            [2018, 13035, 8, 4],
            [2018, 13036, 13, 7],
            [2018, 13037, 7, 5],
            [2018, 13038, 14, 9],
            [2018, 13039, 9, 7],
            [2018, 13040, 14, 10],
            [2018, 13041, 11, 9],
            [2018, 13042, 6, 6],
            [2018, 13043, 8, 5],
            [2018, 13044, 11, 11],
            [2018, 13045, 6, 5],
            [2018, 13046, 12, 10],
            [2018, 13047, 12, 10],
            [2018, 13048, 10, 8],
            [2018, 13049, 10, 8],
            [2018, 13050, 10, 8],
            [2018, 13051, 11, 9],
            [2018, 13052, 10, 9],
            [2018, 13053, 9, 7],
            [2018, 13054, 12, 11],
            [2018, 13055, 16, 10],
            [2018, 13056, 11, 10],
            [2018, 13057, 12, 9],
            [2018, 13058, 14, 11],
            [2018, 13059, 11, 7],
            [2018, 13060, 15, 9],
            [2018, 13061, 15, 11],
            [2018, 13062, 11, 8],
            [2018, 13063, 18, 5],
            [2018, 13064, 8, 8],
            [2018, 13065, 10, 9],
            [2018, 13066, 9, 8],
            [2018, 13067, 13, 9],
            [2018, 13068, 11, 10],
            [2018, 13069, 17, 11],
            [2018, 13070, 9, 4],
            [2018, 13071, 11, 6],
            [2018, 13072, 9, 9],
            [2018, 13073, 9, 7],
            [2018, 13074, 10, 8],
            [2018, 13075, 12, 11],
            [2018, 13076, 10, 7],
            [2018, 13077, 15, 12],
            [2018, 13078, 23, 14],
            [2018, 13079, 9, 9],
            [2018, 13080, 11, 7],
            [2018, 13081, 11, 10],
            [2018, 13082, 7, 5],
            [2018, 13083, 11, 7],
            [2018, 13084, 19, 11],
            [2018, 13085, 19, 12],
            [2018, 13086, 6, 5],
            [2018, 13087, 12, 8],
            [2018, 13088, 14, 9],
            [2018, 13089, 9, 8],
            [2018, 13090, 10, 9],
            [2018, 13091, 7, 4],
            [2018, 13092, 18, 11],
            [2018, 13093, 12, 7],
            [2018, 13094, 21, 11],
            [2018, 13095, 12, 9],
            [2018, 13096, 9, 9],
            [2018, 13097, 15, 9],
            [2018, 13098, 12, 9],
            [2018, 13099, 7, 8],
            [2018, 13140, 13, 8],
            [2018, 13142, 7, 6],
            [2018, 13143, 6, 5],
            [2018, 13144, 10, 8],
            [2018, 13145, 6, 5],
            [2018, 13147, 9, 7],
            [2018, 13148, 10, 9],
            [2018, 13154, 7, 6],
            [2018, 13155, 8, 6],
            [2018, 13156, 8, 6],
            [2018, 13158, 7, 5],
            [2018, 13159, 8, 6],
            [2018, 13161, 6, 6],
            [2018, 13163, 10, 6],
            [2018, 13164, 7, 6],
            [2018, 13165, 7, 5],
            [2018, 13166, 8, 6],
            [2018, 13167, 13, 8],
            [2018, 13168, 7, 5],
            [2018, 13170, 10, 7],
            [2018, 13172, 7, 6],
            [2018, 13173, 9, 7],
            [2018, 13175, 7, 6],
            [2018, 13177, 8, 7],
            [2018, 13178, 9, 7],
            [2018, 13179, 8, 6],
            [2018, 13180, 11, 8],
            [2018, 13181, 7, 6],
            [2018, 13182, 8, 7],
            [2018, 13183, 23, 14],
            [2018, 13184, 7, 6],
            [2018, 13185, 9, 7],
            [2018, 13186, 13, 11],
            [2018, 13187, 7, 7],
            [2018, 13188, 7, 8],
            [2018, 13189, 9, 8],
            [2018, 13190, 7, 7],
            [2018, 13191, 14, 10],
            [2018, 13192, 7, 7],
            [2018, 13193, 7, 7],
            [2018, 13194, 10, 7],
            [2018, 13195, 17, 10],
            [2018, 13196, 14, 8],
            [2018, 13197, 48, 18],
            [2018, 13198, 10, 8],
            [2018, 13200, 13, 9],
            [2018, 13201, 12, 8],
            [2018, 13202, 14, 9],
            [2018, 13203, 7, 6],
            [2018, 13204, 16, 10],
            [2018, 13205, 7, 7],
            [2018, 13206, 10, 8],
            [2018, 13207, 8, 7],
            [2018, 13208, 9, 8],
            [2018, 13209, 6, 6],
            [2018, 13210, 18, 11],
            [2018, 13211, 9, 7],
            [2018, 13212, 41, 17],
            [2018, 13213, 19, 10],
            [2018, 13214, 16, 10],
            [2018, 13216, 15, 10],
            [2018, 13218, 11, 9],
            [2018, 13219, 7, 7],
            [2018, 13220, 8, 7],
            [2018, 13222, 9, 8],
            [2018, 13223, 12, 10],
            [2018, 13224, 40, 15],
            [2018, 13225, 13, 9],
            [2018, 13226, 9, 8],
            [2018, 13227, 16, 10],
            [2018, 13230, 19, 12],
            [2018, 13232, 11, 9],
            [2018, 13233, 12, 9],
            [2018, 13234, 14, 9],
            [2018, 13235, 12, 8],
            [2018, 13236, 10, 7],
            [2018, 13238, 11, 9],
            [2018, 13239, 13, 8],
            [2018, 13240, 11, 9],
            [2018, 13242, 13, 9],
            [2018, 13244, 16, 10],
            [2018, 13245, 12, 9],
            [2018, 13246, 11, 8],
            [2018, 13247, 15, 9],
            [2018, 13248, 11, 8],
            [2018, 13249, 9, 6],
            [2018, 13250, 13, 9],
            [2018, 13251, 12, 9],
            [2018, 13252, 15, 9],
            [2018, 13253, 11, 9],
            [2018, 13254, 11, 8],
            [2018, 13255, 10, 7],
            [2018, 13256, 11, 8],
            [2018, 13257, 12, 9],
            [2018, 13258, 16, 10],
            [2018, 13260, 11, 8],
            [2018, 13261, 13, 9],
            [2018, 13262, 14, 10],
            [2018, 13263, 12, 9],
            [2018, 13264, 13, 9],
            [2018, 13266, 11, 8],
            [2018, 13270, 14, 8],
            [2018, 13273, 11, 8],
            [2018, 13275, 11, 9],
            [2018, 13276, 9, 7],
            [2018, 13280, 11, 8],
            [2018, 13282, 11, 9],
            [2018, 13285, 12, 8],
            [2018, 13286, 14, 9],
            [2018, 13288, 15, 9],
            [2018, 13291, 12, 9],
            [2018, 13297, 11, 8],
            [2018, 13302, 11, 9],
            [2018, 13304, 14, 9],
            [2018, 13305, 11, 8],
            [2018, 13308, 11, 9],
            [2018, 13312, 14, 9],
            [2018, 13315, 13, 9],
            [2018, 13316, 9, 7],
            [2018, 13317, 9, 6],
            [2018, 13319, 14, 9],
            [2018, 13322, 11, 8],
            [2018, 13326, 12, 8],
            [2018, 13328, 11, 8],
            [2018, 13330, 11, 8],
            [2018, 13332, 11, 8],
            [2018, 13334, 9, 8],
            [2018, 13336, 11, 8],
            [2018, 13339, 9, 7],
            [2018, 13340, 12, 9],
            [2018, 13343, 11, 8],
            [2018, 13346, 8, 5],
            [2018, 13348, 14, 9],
            [2018, 13350, 12, 9],
            [2018, 13353, 14, 8],
            [2018, 13355, 12, 8],
            [2018, 13356, 8, 5],
            [2018, 13358, 11, 9],
            [2018, 13360, 9, 6],
            [2018, 13363, 13, 10],
            [2018, 13365, 9, 6],
            [2018, 13367, 9, 5],
            [2018, 13369, 12, 8],
            [2018, 13374, 11, 8],
            [2018, 13375, 11, 8],
            [2018, 13379, 10, 8],
            [2018, 13382, 12, 8],
            [2018, 13385, 6, 5],
            [2018, 13387, 11, 9],
            [2018, 13389, 10, 8],
            [2018, 13390, 11, 9],
            [2018, 13392, 12, 8],
            [2018, 13394, 11, 8],
            [2018, 13397, 6, 5],
            [2018, 13399, 11, 8],
            [2018, 13449, 9, 7],
            [2018, 13450, 7, 7],
            [2018, 13451, 9, 6],
            [2018, 13452, 8, 6],
            [2018, 13453, 9, 7],
            [2018, 13454, 17, 10],
            [2018, 13455, 12, 10],
            [2018, 13456, 6, 5],
            [2018, 13457, 7, 6],
            [2018, 13458, 7, 7],
            [2018, 13460, 8, 6],
            [2018, 13463, 11, 8],
            [2018, 13464, 14, 8],
            [2018, 13465, 10, 8],
            [2018, 13466, 8, 7],
            [2018, 13467, 7, 6],
            [2018, 13468, 8, 7],
            [2018, 13469, 7, 6],
            [2018, 13470, 12, 9],
            [2018, 13471, 8, 7],
            [2018, 13472, 12, 8],
            [2018, 13473, 11, 8],
            [2018, 13474, 9, 7],
            [2018, 13475, 11, 7],
            [2018, 13476, 7, 6],
            [2018, 13478, 6, 6],
            [2018, 13479, 11, 8],
            [2018, 13480, 4, 4],
            [2018, 13481, 7, 6],
            [2018, 13482, 8, 8],
            [2018, 13483, 8, 8],
            [2018, 13484, 10, 7],
            [2018, 13485, 8, 7],
            [2018, 13486, 3, 4],
            [2018, 13487, 17, 10],
            [2018, 13488, 7, 5],
            [2018, 13489, 11, 8],
            [2018, 13490, 7, 6],
            [2018, 13491, 7, 6],
            [2018, 13492, 7, 6],
            [2018, 13494, 10, 8],
            [2018, 13495, 8, 7],
            [2018, 13496, 9, 7],
            [2018, 13497, 8, 7],
            [2018, 13498, 8, 6],
            [2018, 13499, 10, 7],
            [2018, 13501, 14, 9],
            [2018, 13502, 8, 6],
            [2018, 13503, 8, 7],
            [2018, 13504, 7, 5],
            [2018, 13505, 7, 5],
            [2018, 13506, 9, 6],
            [2018, 13508, 10, 8],
            [2018, 13509, 6, 6],
            [2018, 13511, 13, 9],
            [2018, 13512, 9, 7],
            [2018, 13513, 10, 7],
            [2018, 13514, 10, 8],
            [2018, 13516, 7, 5],
            [2018, 13517, 7, 7],
            [2018, 13518, 7, 6],
            [2018, 13519, 10, 7],
            [2018, 13520, 11, 8],
            [2018, 13521, 8, 6],
            [2018, 13522, 9, 7],
            [2018, 13523, 8, 7],
            [2018, 13524, 7, 6],
            [2018, 13525, 10, 8],
            [2018, 13526, 7, 6],
            [2018, 13527, 13, 10],
            [2018, 13528, 8, 6],
            [2018, 13529, 6, 5],
            [2018, 13530, 6, 5],
            [2018, 13531, 7, 6],
            [2018, 13532, 7, 6],
            [2018, 13533, 6, 5],
            [2018, 13534, 6, 5],
            [2018, 13536, 8, 7],
            [2018, 13537, 6, 5],
            [2018, 13538, 6, 5],
            [2018, 13539, 6, 5],
            [2018, 13540, 6, 5],
            [2018, 13541, 9, 7],
            [2018, 13542, 8, 7],
            [2018, 13544, 10, 8],
            [2018, 13546, 7, 5],
            [2018, 13548, 11, 8],
            [2018, 13550, 17, 9],
            [2018, 13552, 11, 9],
            [2018, 13556, 8, 7],
            [2018, 13557, 3, 3],
            [2018, 13558, 13, 8],
            [2018, 13560, 8, 6],
            [2018, 13561, 7, 6],
            [2018, 13562, 9, 7],
            [2018, 13563, 7, 5],
            [2018, 13564, 13, 9],
            [2018, 13565, 8, 6],
            [2018, 13566, 12, 9],
            [2018, 13567, 8, 7],
            [2018, 13568, 4, 5],
            [2018, 13569, 7, 6],
            [2018, 13570, 6, 6],
            [2018, 13571, 10, 7],
            [2018, 13572, 6, 5],
            [2018, 13573, 7, 7],
            [2018, 13574, 9, 7],
            [2018, 13575, 11, 8],
            [2018, 13576, 7, 5],
            [2018, 13577, 6, 5],
            [2018, 13578, 7, 7],
            [2018, 13579, 15, 9],
            [2018, 13580, 9, 6],
            [2018, 13581, 6, 5],
            [2018, 13582, 8, 6],
            [2018, 13583, 8, 6],
            [2018, 13584, 23, 12],
            [2018, 13585, 6, 6],
            [2018, 13586, 6, 5],
            [2018, 13587, 7, 5],
            [2018, 13588, 14, 9],
            [2018, 13589, 7, 6],
            [2018, 13590, 12, 9],
            [2018, 13593, 6, 6],
            [2018, 13594, 12, 9],
            [2018, 13595, 9, 6],
            [2018, 13596, 10, 8],
            [2018, 13597, 8, 6],
            [2018, 13598, 7, 6],
            [2018, 13599, 6, 6],
            [2018, 13600, 8, 6],
            [2018, 13601, 6, 5],
            [2018, 13602, 6, 5],
            [2018, 13603, 6, 5],
            [2018, 13604, 11, 8],
            [2018, 13605, 9, 7],
            [2018, 13606, 9, 8],
            [2018, 13607, 8, 6],
            [2018, 13608, 8, 7],
            [2018, 13787, 7, 5],
            [2018, 13788, 6, 6],
            [2018, 13789, 8, 6],
            [2018, 13790, 7, 7],
            [2018, 13791, 7, 6],
            [2018, 13792, 10, 8],
            [2018, 13793, 7, 7],
            [2018, 13794, 10, 8],
            [2018, 13795, 7, 6],
            [2018, 13796, 7, 7],
            [2018, 13797, 8, 7],
            [2018, 13798, 7, 6],
            [2018, 13799, 13, 9],
            [2018, 13800, 7, 6],
            [2018, 13801, 8, 6],
            [2018, 13802, 8, 7],
            [2018, 13803, 7, 7],
            [2018, 13804, 9, 7],
            [2018, 13805, 7, 6],
            [2018, 13806, 8, 7],
            [2018, 13807, 7, 6],
            [2018, 13808, 6, 5],
            [2018, 13809, 7, 7],
            [2018, 13810, 7, 5],
            [2018, 13811, 8, 7],
            [2018, 13812, 7, 7],
            [2018, 13813, 9, 7],
            [2018, 13814, 11, 8],
            [2018, 13815, 11, 8],
            [2018, 13816, 10, 7],
            [2018, 13817, 7, 7],
            [2018, 13818, 8, 7],
            [2018, 13819, 8, 6],
            [2018, 13820, 8, 6],
            [2018, 13821, 6, 6],
            [2018, 13822, 5, 5],
            [2018, 13823, 6, 5],
            [2018, 13824, 8, 7],
            [2018, 13825, 6, 5],
            [2018, 13826, 7, 6],
            [2018, 13827, 6, 5],
            [2018, 13828, 8, 7],
            [2018, 13829, 7, 7],
            [2018, 13830, 7, 6],
            [2018, 13831, 7, 7],
            [2018, 13832, 7, 6],
            [2018, 13833, 9, 8],
            [2018, 13834, 7, 6],
            [2018, 13835, 8, 7],
            [2018, 13836, 8, 7],
            [2018, 13837, 9, 7],
            [2018, 13838, 8, 7],
            [2018, 13839, 9, 8],
            [2018, 13840, 6, 6],
            [2018, 13841, 7, 6],
            [2018, 13842, 9, 7],
            [2018, 13843, 8, 7],
            [2018, 13844, 6, 5],
            [2018, 13845, 6, 6],
            [2018, 13846, 7, 6],
            [2018, 13847, 6, 5],
            [2018, 13848, 6, 5],
            [2018, 13849, 8, 7],
            [2018, 13850, 9, 7],
            [2018, 13851, 9, 8],
            [2018, 13852, 7, 7],
            [2018, 13853, 11, 9],
            [2018, 13854, 11, 9],
            [2018, 13855, 10, 9],
            [2018, 13856, 8, 7],
            [2018, 13857, 8, 6],
            [2018, 13858, 8, 7],
            [2018, 13859, 8, 6],
            [2018, 13860, 6, 6],
            [2018, 13861, 7, 6],
            [2018, 13862, 10, 8],
            [2018, 13863, 7, 6],
            [2018, 13864, 6, 5],
            [2018, 13865, 8, 7],
            [2018, 13866, 6, 6],
            [2018, 13867, 6, 6],
            [2018, 13868, 6, 6],
            [2018, 13869, 8, 6],
            [2018, 13870, 7, 6],
            [2018, 13871, 6, 5],
            [2018, 13872, 7, 6],
            [2018, 13873, 6, 5],
            [2018, 13874, 11, 7],
            [2018, 13875, 8, 6],
            [2018, 13876, 13, 9],
            [2018, 13877, 8, 7],
            [2018, 13878, 7, 6],
            [2018, 13879, 7, 6],
            [2018, 13880, 7, 6],
            [2018, 13881, 8, 6],
            [2018, 13882, 7, 6],
            [2018, 13883, 13, 8],
            [2018, 13884, 7, 7],
            [2018, 13885, 9, 6],
            [2018, 13886, 7, 6],
            [2018, 13887, 7, 6],
            [2018, 13888, 10, 6],
            [2018, 13889, 6, 5],
            [2018, 13890, 9, 8],
            [2018, 13891, 9, 7],
            [2018, 13892, 8, 7],
            [2018, 13893, 11, 10],
            [2018, 13894, 6, 6],
            [2018, 13895, 7, 6],
            [2018, 13896, 6, 6],
            [2018, 13897, 6, 6],
            [2018, 13898, 7, 6],
            [2018, 13899, 8, 6],
            [2018, 13900, 10, 7],
            [2018, 13901, 11, 9],
            [2018, 13902, 7, 6],
            [2018, 13903, 10, 8],
            [2018, 13904, 8, 6],
            [2018, 13905, 9, 7],
            [2018, 13906, 12, 8],
            [2018, 13907, 10, 8],
            [2018, 13908, 9, 7],
            [2018, 13909, 10, 8],
            [2018, 13910, 7, 6],
            [2018, 13911, 7, 6],
            [2018, 13912, 8, 7],
            [2018, 13913, 7, 7],
            [2018, 13914, 7, 7],
            [2018, 13915, 6, 6],
            [2018, 13916, 6, 6],
            [2018, 13917, 6, 5],
            [2018, 13918, 8, 8],
            [2018, 13919, 9, 7],
            [2018, 13920, 10, 8],
            [2018, 13921, 11, 8],
            [2018, 13922, 7, 6],
            [2018, 13923, 7, 6],
            [2018, 13924, 11, 8],
            [2018, 13925, 7, 6],
            [2018, 13926, 8, 6],
            [2018, 13927, 8, 7],
            [2018, 13928, 7, 6],
            [2018, 13929, 7, 6],
            [2018, 13930, 7, 6],
            [2018, 13931, 9, 7],
            [2018, 13932, 8, 6],
            [2018, 13933, 7, 6],
            [2018, 13934, 11, 9],
            [2018, 13935, 6, 6],
            [2018, 13936, 7, 6],
            [2018, 13937, 10, 8],
            [2018, 13938, 7, 6],
            [2018, 13939, 8, 6],
            [2018, 13940, 8, 6],
            [2018, 13941, 8, 7],
            [2018, 13942, 9, 7],
            [2018, 13943, 9, 7],
            [2018, 13944, 8, 7],
            [2018, 13945, 7, 6],
            [2018, 13946, 10, 8],
            [2018, 13947, 11, 8],
            [2018, 13948, 6, 6],
            [2018, 13949, 6, 6],
            [2018, 13950, 9, 7],
            [2018, 13951, 7, 7],
            [2018, 13952, 10, 9],
            [2018, 13953, 9, 8],
            [2018, 13954, 8, 7],
            [2018, 13955, 10, 7],
            [2018, 13956, 10, 7],
            [2018, 13957, 7, 6],
            [2018, 13958, 7, 7],
            [2018, 13959, 6, 6],
            [2018, 13960, 10, 8],
            [2018, 13961, 7, 6],
            [2018, 13962, 8, 7],
            [2018, 13963, 7, 6],
            [2018, 13964, 7, 6],
            [2018, 13965, 6, 5],
            [2018, 13966, 8, 6],
            [2018, 13967, 6, 5],
            [2018, 13968, 6, 6],
            [2018, 13969, 7, 6],
            [2018, 13970, 6, 5],
            [2018, 13971, 7, 6],
            [2018, 13972, 7, 6],
            [2018, 13973, 6, 6],
            [2018, 13974, 6, 6],
            [2018, 13975, 6, 6],
            [2018, 13976, 7, 7],
            [2018, 13977, 7, 8],
            [2018, 13978, 10, 8],
            [2018, 13979, 7, 6],
            [2018, 13980, 6, 6],
            [2018, 13981, 6, 6],
            [2018, 13982, 7, 6],
            [2018, 13983, 11, 8],
            [2018, 13984, 9, 7],
            [2018, 13985, 11, 8],
            [2018, 13986, 7, 6],
            [2018, 13987, 7, 6],
            [2018, 13988, 9, 7],
            [2018, 13989, 7, 6],
            [2018, 13991, 7, 7],
            [2018, 13992, 7, 6],
            [2018, 13993, 8, 7],
            [2018, 13994, 7, 6],
            [2018, 13995, 12, 9],
            [2018, 13996, 6, 6],
            [2018, 13997, 7, 6],
            [2018, 13998, 7, 6],
            [2018, 13999, 10, 8],
            [2018, 14000, 11, 9],
            [2018, 14001, 10, 7],
            [2018, 14002, 7, 6],
            [2018, 14003, 7, 7],
            [2018, 14004, 6, 5],
            [2018, 14005, 15, 11],
            [2018, 14006, 11, 8],
            [2018, 14007, 11, 9],
            [2018, 14008, 11, 8],
            [2018, 14009, 12, 8],
            [2018, 14010, 10, 8],
            [2018, 14011, 9, 8],
            [2018, 14012, 10, 7],
            [2018, 14013, 10, 9],
            [2018, 14014, 17, 10],
            [2018, 14016, 11, 8],
            [2018, 14017, 17, 11],
            [2018, 14018, 9, 8],
            [2018, 14019, 7, 6],
            [2018, 14020, 6, 6],
            [2018, 14021, 10, 7],
            [2018, 14022, 7, 7],
            [2018, 14023, 16, 10],
            [2018, 14024, 10, 8],
            [2018, 14025, 9, 8],
            [2018, 14026, 18, 11],
            [2018, 14027, 11, 10],
            [2018, 14029, 13, 9],
            [2018, 14030, 15, 10],
            [2018, 14031, 19, 12],
            [2018, 14032, 9, 7],
            [2018, 14033, 10, 8],
            [2018, 14034, 11, 9],
            [2018, 14035, 12, 9],
            [2018, 14036, 8, 7],
            [2018, 14037, 17, 10],
            [2018, 14038, 7, 7],
            [2018, 14040, 13, 10],
            [2018, 14041, 19, 12],
            [2018, 14042, 13, 9],
            [2018, 14043, 9, 8],
            [2018, 14044, 10, 9],
            [2018, 14045, 9, 7],
            [2018, 14046, 9, 10],
            [2018, 14047, 10, 9],
            [2018, 14048, 12, 9],
            [2018, 14049, 15, 10],
            [2018, 14050, 12, 9],
            [2018, 14051, 15, 11],
            [2018, 14052, 10, 8],
            [2018, 14053, 10, 7],
            [2018, 14054, 8, 8],
            [2018, 14055, 18, 10],
            [2018, 14056, 17, 10],
            [2018, 14057, 15, 10],
            [2018, 14058, 13, 10],
            [2018, 14059, 12, 10],
            [2018, 14060, 13, 9],
            [2018, 14061, 13, 9],
            [2018, 14062, 11, 9],
            [2018, 14063, 19, 9],
            [2018, 14064, 16, 9],
            [2018, 14065, 19, 10],
            [2018, 14066, 13, 8],
            [2018, 14067, 16, 10],
            [2018, 14068, 8, 6],
            [2018, 14069, 13, 10],
            [2018, 14070, 18, 11],
            [2018, 14071, 17, 11],
            [2018, 14072, 12, 7],
            [2018, 14073, 16, 13],
            [2018, 14074, 13, 10],
            [2018, 14075, 16, 12],
            [2018, 14076, 17, 10],
            [2018, 14077, 11, 9],
            [2018, 14078, 12, 9],
            [2018, 14079, 13, 10],
            [2018, 14080, 19, 10],
            [2018, 14081, 14, 9],
            [2018, 14082, 13, 10],
            [2018, 14083, 10, 6],
            [2018, 14084, 8, 6],
            [2018, 14085, 12, 9],
            [2018, 14086, 12, 9],
            [2018, 14087, 13, 9],
            [2018, 14088, 14, 9],
            [2018, 14089, 12, 9],
            [2018, 14090, 10, 8],
            [2018, 14092, 9, 6],
            [2018, 14093, 10, 6],
            [2018, 14094, 11, 8],
            [2018, 14095, 10, 9],
            [2018, 14096, 13, 9],
            [2018, 14097, 10, 7],
            [2018, 14098, 12, 9],
            [2018, 14099, 12, 7],
            [2018, 14100, 8, 6],
            [2018, 14101, 17, 10],
            [2018, 14102, 18, 9],
            [2018, 14103, 16, 11],
            [2018, 14104, 11, 9],
            [2018, 14105, 14, 10],
            [2018, 14107, 14, 10],
            [2018, 14108, 15, 10],
            [2018, 14110, 18, 9],
            [2018, 14111, 13, 9],
            [2018, 14112, 12, 8],
            [2018, 14113, 9, 8],
            [2018, 14114, 9, 8],
            [2018, 14240, 7, 5],
            [2018, 14241, 11, 7],
            [2018, 14242, 18, 11],
            [2018, 14243, 7, 5],
            [2018, 14244, 21, 10],
            [2018, 14245, 17, 10],
            [2018, 14246, 19, 10],
            [2018, 14247, 19, 10],
            [2018, 14248, 12, 8],
            [2018, 14249, 24, 12],
            [2018, 14250, 17, 9],
            [2018, 14251, 10, 7],
            [2018, 14252, 25, 12],
            [2018, 14253, 19, 10],
            [2018, 14254, 9, 7],
            [2018, 14255, 17, 10],
            [2018, 14256, 11, 8],
            [2018, 14257, 20, 10],
            [2018, 14258, 14, 8],
            [2018, 14259, 20, 10],
            [2018, 14260, 14, 9],
            [2018, 14261, 20, 10],
            [2018, 14262, 21, 10],
            [2018, 14263, 13, 9],
            [2018, 14264, 17, 10],
            [2018, 14265, 19, 10],
            [2018, 14266, 17, 10],
            [2018, 14267, 7, 6],
            [2018, 14268, 7, 6],
            [2018, 14269, 22, 11],
            [2018, 14270, 9, 6],
            [2018, 14271, 9, 7],
            [2018, 14272, 6, 4],
            [2018, 14273, 22, 11],
            [2018, 14274, 15, 10],
            [2018, 14275, 21, 10],
            [2018, 14276, 12, 9],
            [2018, 14277, 6, 4],
            [2018, 14278, 6, 5],
            [2018, 14280, 19, 9],
            [2018, 14281, 9, 7],
            [2018, 14282, 10, 7],
            [2018, 14283, 10, 6],
            [2018, 14285, 19, 10],
            [2018, 14286, 18, 11],
            [2018, 14287, 14, 8],
            [2018, 14288, 10, 7],
            [2018, 14289, 23, 11],
            [2018, 14290, 23, 12],
            [2018, 14291, 16, 10],
            [2018, 14292, 11, 8],
            [2018, 14293, 11, 7],
            [2018, 14294, 15, 9],
            [2018, 14295, 20, 10],
            [2018, 14296, 21, 11],
            [2018, 14297, 20, 11],
            [2018, 14298, 10, 6],
            [2018, 14299, 21, 11],
            [2018, 14300, 8, 5],
            [2018, 14301, 6, 6],
            [2018, 14302, 9, 6],
            [2018, 14303, 20, 10],
            [2018, 14304, 15, 10],
            [2018, 14305, 22, 11],
            [2018, 14306, 22, 11],
            [2018, 14307, 7, 5],
            [2018, 14308, 16, 9],
            [2018, 14309, 10, 7],
            [2018, 14310, 18, 10],
            [2018, 14311, 21, 11],
            [2018, 14312, 16, 10],
            [2018, 14313, 11, 7],
            [2018, 14314, 21, 11],
            [2018, 14315, 18, 10],
            [2018, 14316, 19, 10],
            [2018, 14317, 17, 10],
            [2018, 14318, 19, 11],
            [2018, 14319, 12, 9],
            [2018, 14320, 9, 6],
            [2018, 14321, 19, 10],
            [2018, 14322, 17, 11],
            [2018, 14323, 21, 11],
            [2018, 14324, 11, 9],
            [2018, 14325, 22, 11],
            [2018, 14327, 21, 10],
            [2018, 14328, 15, 9],
            [2018, 14329, 21, 11],
            [2018, 14330, 16, 10],
            [2018, 14331, 21, 11],
            [2018, 14332, 10, 7],
            [2018, 14333, 13, 9],
            [2018, 14335, 20, 11],
            [2018, 14337, 13, 9],
            [2018, 14338, 20, 11],
            [2018, 14340, 9, 6],
            [2018, 14341, 19, 10],
            [2018, 14342, 15, 10],
            [2018, 14343, 15, 10],
            [2018, 14344, 22, 11],
            [2018, 14345, 19, 11],
            [2018, 14346, 22, 11],
            [2018, 14347, 11, 8],
            [2018, 14348, 19, 10],
            [2018, 14349, 12, 8],
            [2018, 14350, 13, 8],
            [2018, 14352, 19, 10],
            [2018, 14353, 20, 10],
            [2018, 14354, 17, 10],
            [2018, 14355, 11, 9],
            [2018, 14356, 7, 6],
            [2018, 14357, 20, 9],
            [2018, 14358, 13, 9],
            [2018, 14359, 11, 9],
            [2018, 14360, 11, 8],
            [2018, 14361, 21, 11],
            [2018, 14362, 19, 10],
            [2018, 14363, 20, 10],
            [2018, 14364, 20, 10],
            [2018, 14365, 17, 9],
            [2018, 14366, 21, 11],
            [2018, 14367, 23, 11],
            [2018, 14368, 22, 11],
            [2018, 14369, 21, 11],
            [2018, 14370, 11, 8],
            [2018, 14371, 7, 5],
            [2018, 14372, 11, 7],
            [2018, 14373, 22, 11],
            [2018, 14374, 12, 9],
            [2018, 14375, 19, 10],
            [2018, 14376, 7, 5],
            [2018, 14378, 6, 4],
            [2018, 14380, 21, 10],
            [2018, 14381, 21, 11],
            [2018, 14382, 19, 10],
            [2018, 14383, 9, 6],
            [2018, 14384, 16, 9],
            [2018, 14385, 15, 10],
            [2018, 14386, 20, 11],
            [2018, 14387, 25, 13],
            [2018, 14388, 28, 13],
            [2018, 14389, 20, 10],
            [2018, 14390, 19, 10],
            [2018, 14391, 11, 7],
            [2018, 14392, 20, 11],
            [2018, 14393, 15, 9],
            [2018, 14394, 16, 10],
            [2018, 14395, 23, 11],
            [2018, 14397, 20, 8],
            [2018, 14398, 20, 10],
            [2018, 14399, 24, 11],
            [2018, 14400, 26, 11],
            [2018, 14401, 12, 8],
            [2018, 14402, 10, 7],
            [2018, 14403, 18, 10],
            [2018, 14405, 22, 10],
            [2018, 14406, 23, 10],
            [2018, 14407, 14, 10],
            [2018, 14408, 14, 9],
            [2018, 14409, 21, 9],
            [2018, 14411, 15, 9],
            [2018, 14412, 13, 8],
            [2018, 14413, 9, 6],
            [2018, 14415, 15, 10],
            [2018, 14416, 16, 10],
            [2018, 14417, 14, 11],
            [2018, 14418, 21, 10],
            [2018, 14419, 18, 10],
            [2018, 14420, 11, 8],
            [2018, 14421, 21, 10],
            [2018, 14422, 15, 6],
            [2018, 14423, 11, 7],
            [2018, 14424, 15, 9],
            [2018, 14425, 23, 12],
            [2018, 14426, 11, 8],
            [2018, 14427, 20, 9],
            [2018, 14428, 17, 9],
            [2018, 14429, 16, 9],
            [2018, 14430, 15, 10],
            [2018, 14432, 18, 9],
            [2018, 14434, 15, 9],
            [2018, 14438, 19, 36],
            [2018, 14440, 20, 29],
            [2018, 14442, 20, 23],
            [2018, 14445, 12, 12],
            [2018, 14446, 26, 26],
            [2018, 14449, 14, 11],
            [2018, 14450, 47, 27],
            [2018, 14452, 33, 23],
            [2018, 14453, 21, 48],
            [2018, 14458, 25, 39],
            [2018, 14459, 30, 30],
            [2018, 14460, 23, 21],
            [2018, 14462, 20, 28],
            [2018, 14463, 10, 10],
            [2018, 14464, 29, 24],
            [2018, 14465, 27, 19],
            [2018, 14466, 20, 19],
            [2018, 14468, 21, 35],
            [2018, 14470, 17, 14],
            [2018, 14471, 18, 23],
            [2018, 14473, 10, 10],
            [2018, 14476, 32, 30],
            [2018, 14478, 10, 10],
            [2018, 14480, 26, 21],
            [2018, 14484, 19, 28],
            [2018, 14485, 13, 12],
            [2018, 14486, 47, 28],
            [2018, 14488, 19, 18],
            [2018, 14489, 14, 14],
            [2018, 14490, 58, 61],
            [2018, 14491, 19, 25],
            [2018, 14495, 24, 23],
            [2018, 14496, 56, 49],
            [2018, 14500, 24, 35],
            [2018, 14501, 20, 17],
            [2018, 14502, 50, 95],
            [2018, 14503, 23, 30],
            [2018, 14505, 11, 10],
            [2018, 14507, 23, 29],
            [2018, 14508, 14, 15],
            [2018, 14509, 29, 25],
            [2018, 14510, 34, 24],
            [2018, 14512, 27, 30],
            [2018, 14513, 36, 28],
            [2018, 14514, 31, 23],
            [2018, 14518, 26, 21],
            [2018, 14519, 86, 70],
            [2018, 14520, 40, 92],
            [2018, 14524, 21, 24],
            [2018, 14528, 15, 13],
            [2018, 14530, 33, 21],
            [2018, 14534, 18, 10],
            [2018, 14535, 12, 6],
            [2018, 14536, 16, 10],
            [2018, 14538, 21, 11],
            [2018, 14541, 12, 9],
            [2018, 14542, 13, 9],
            [2018, 14543, 14, 10],
            [2018, 14544, 9, 7],
            [2018, 14545, 17, 10],
            [2018, 14546, 19, 11],
            [2018, 14547, 15, 10],
            [2018, 14548, 13, 9],
            [2018, 14549, 20, 11],
            [2018, 14550, 18, 10],
            [2018, 14553, 14, 12],
            [2018, 14554, 15, 8],
            [2018, 14555, 10, 9],
            [2018, 14556, 20, 11],
            [2018, 14557, 18, 12],
            [2018, 14769, 35, 22],
            [2018, 14770, 18, 17],
            [2018, 14771, 22, 30],
            [2018, 14773, 39, 43],
            [2018, 14774, 26, 16],
            [2018, 14775, 37, 33],
            [2018, 14776, 30, 29],
            [2018, 14777, 19, 19],
            [2018, 14778, 11, 10],
            [2018, 14779, 36, 20],
            [2018, 14780, 29, 11],
            [2018, 14781, 10, 10],
            [2018, 14782, 54, 28],
            [2018, 14783, 26, 22],
            [2018, 14784, 12, 19],
            [2018, 14785, 52, 36],
            [2018, 14786, 22, 17],
            [2018, 14788, 24, 19],
            [2018, 14789, 62, 40],
            [2018, 14790, 39, 17],
            [2018, 14791, 11, 11],
            [2018, 14792, 49, 43],
            [2018, 14793, 31, 22],
            [2018, 14794, 26, 21],
            [2018, 14795, 32, 22],
            [2018, 14796, 29, 36],
            [2018, 14797, 25, 42],
            [2018, 14798, 24, 33],
            [2018, 14799, 37, 19],
            [2018, 14800, 12, 10],
            [2018, 14801, 29, 14],
            [2018, 14802, 17, 11],
            [2018, 14803, 36, 30],
            [2018, 14804, 13, 10],
            [2018, 14805, 28, 29],
            [2018, 14806, 14, 12],
            [2018, 14807, 32, 21],
            [2018, 14808, 51, 43],
            [2018, 14809, 15, 19],
            [2018, 14810, 15, 17],
            [2018, 14811, 14, 17],
            [2018, 14812, 42, 31],
            [2018, 14813, 19, 16],
            [2018, 14814, 33, 21],
            [2018, 14815, 54, 24],
            [2018, 14816, 12, 10],
            [2018, 14817, 12, 10],
            [2018, 14818, 13, 10],
            [2018, 14819, 36, 33],
            [2018, 14820, 61, 50],
            [2018, 14821, 17, 14],
            [2018, 14823, 15, 15],
            [2018, 14824, 57, 34],
            [2018, 14825, 14, 14],
            [2018, 14826, 39, 20],
            [2018, 14827, 41, 31],
            [2018, 14828, 51, 41],
            [2018, 14829, 17, 14],
            [2018, 14830, 12, 14],
            [2018, 14831, 26, 17],
            [2018, 14832, 41, 30],
            [2018, 14833, 32, 23],
            [2018, 14834, 30, 33],
            [2018, 14835, 44, 17],
            [2018, 14836, 34, 18],
            [2018, 14837, 51, 36],
            [2018, 14838, 46, 36],
            [2018, 14839, 25, 29],
            [2018, 14840, 31, 22],
            [2018, 14841, 18, 14],
            [2018, 14842, 18, 15],
            [2018, 14843, 42, 29],
            [2018, 14844, 14, 14],
            [2018, 14845, 51, 48],
            [2018, 14846, 31, 14],
            [2018, 14847, 11, 10],
            [2018, 14848, 11, 10],
            [2018, 14849, 12, 10],
            [2018, 14850, 37, 24],
            [2018, 14851, 18, 18],
            [2018, 14852, 13, 10],
            [2018, 14853, 22, 18],
            [2018, 14854, 50, 36],
            [2018, 14990, 11, 8],
            [2018, 14991, 8, 5],
            [2018, 14992, 1, 1],
            [2018, 14993, 9, 6],
            [2018, 14994, 9, 5],
            [2018, 14995, 7, 6],
            [2018, 14996, 7, 5],
            [2018, 14997, 13, 10],
            [2018, 14998, 7, 4],
            [2018, 14999, 7, 6],
            [2018, 15000, 14, 9],
            [2018, 15001, 10, 10],
            [2018, 15002, 7, 5],
            [2018, 15003, 16, 12],
            [2018, 15004, 4, 4],
            [2018, 15005, 10, 8],
            [2018, 15006, 13, 10],
            [2018, 15007, 8, 4],
            [2018, 15008, 1, 1],
            [2018, 15009, 11, 8],
            [2018, 15010, 9, 7],
            [2018, 15011, 6, 5],
            [2018, 15012, 1, 1],
            [2018, 15013, 7, 6],
            [2018, 15015, 10, 7],
            [2018, 15016, 1, 1],
            [2018, 15017, 8, 5],
            [2018, 15019, 7, 6],
            [2018, 15020, 9, 6],
            [2018, 15021, 7, 5],
            [2018, 15022, 8, 5],
            [2018, 15023, 9, 6],
            [2018, 15024, 9, 5],
            [2018, 15025, 7, 6],
            [2018, 15026, 7, 6],
            [2018, 15027, 7, 5],
            [2018, 15028, 9, 6],
            [2018, 15029, 10, 7],
            [2018, 15030, 8, 5],
            [2018, 15031, 7, 4],
            [2018, 15032, 7, 4],
            [2018, 15033, 4, 2],
            [2018, 15034, 7, 6],
            [2018, 15035, 9, 6],
            [2018, 15036, 9, 6],
            [2018, 15037, 9, 6],
            [2018, 15040, 8, 6],
            [2018, 15041, 1, 1],
            [2018, 15042, 10, 6],
            [2018, 15043, 14, 10],
            [2018, 15044, 8, 5],
            [2018, 15045, 8, 5],
            [2018, 15047, 7, 5],
            [2018, 15048, 11, 8],
            [2018, 15049, 9, 5],
            [2018, 15050, 7, 5],
            [2018, 15051, 12, 8],
            [2018, 15052, 10, 6],
            [2018, 15053, 11, 9],
            [2018, 15054, 9, 5],
            [2018, 15055, 8, 5],
            [2018, 15056, 8, 6],
            [2018, 15057, 7, 5],
            [2018, 15058, 7, 5],
            [2018, 15059, 2, 1],
            [2018, 15060, 3, 1],
            [2018, 15061, 7, 6],
            [2018, 15062, 9, 6],
            [2018, 15063, 1, 1],
            [2018, 15064, 1, 1],
            [2018, 15065, 1, 1],
            [2018, 15066, 8, 6],
            [2018, 15067, 7, 5],
            [2018, 15068, 11, 7],
            [2018, 15070, 13, 10],
            [2018, 15071, 6, 5],
            [2018, 15072, 11, 8],
            [2018, 15073, 7, 5],
            [2018, 15074, 10, 7],
            [2018, 15075, 1, 1],
            [2018, 15076, 1, 1],
            [2018, 15077, 17, 8],
            [2018, 15078, 8, 5],
            [2018, 15079, 2, 1],
            [2018, 15081, 17, 11],
            [2018, 15082, 7, 5],
            [2018, 15083, 1, 1],
            [2018, 15084, 7, 6],
            [2018, 15085, 8, 5],
            [2018, 15086, 10, 7],
            [2018, 15087, 7, 6],
            [2018, 15088, 12, 9],
            [2018, 15089, 19, 11],
            [2018, 15090, 17, 11],
            [2018, 15091, 11, 9],
            [2018, 15092, 14, 8],
            [2018, 15093, 14, 9],
            [2018, 15094, 7, 6],
            [2018, 15095, 14, 10],
            [2018, 15096, 13, 8],
            [2018, 15097, 11, 8],
            [2018, 15098, 15, 9],
            [2018, 15099, 14, 10],
            [2018, 15100, 10, 9],
            [2018, 15101, 11, 9],
            [2018, 15102, 14, 8],
            [2018, 15103, 11, 8],
            [2018, 15104, 9, 6],
            [2018, 15106, 12, 7],
            [2018, 15107, 8, 7],
            [2018, 15108, 18, 10],
            [2018, 15109, 16, 10],
            [2018, 15110, 6, 5],
            [2018, 15111, 11, 8],
            [2018, 15112, 17, 10],
            [2018, 15113, 17, 10],
            [2018, 15114, 9, 7],
            [2018, 15115, 7, 6],
            [2018, 15116, 8, 6],
            [2018, 15117, 8, 6],
            [2018, 15118, 8, 7],
            [2018, 15119, 6, 5],
            [2018, 15120, 7, 6],
            [2018, 15121, 7, 5],
            [2018, 15122, 3, 3],
            [2018, 15123, 3, 3],
            [2018, 15124, 5, 5],
            [2018, 15125, 4, 5],
            [2018, 15126, 7, 6],
            [2018, 15127, 6, 5],
            [2018, 15128, 17, 11],
            [2018, 15129, 6, 5],
            [2018, 15130, 6, 5],
            [2018, 15131, 5, 4],
            [2018, 15132, 21, 13],
            [2018, 15133, 24, 10],
            [2018, 15134, 16, 9],
            [2018, 15135, 15, 8],
            [2018, 15136, 13, 9],
            [2018, 15137, 12, 8],
            [2018, 15138, 13, 9],
            [2018, 15139, 26, 13],
            [2018, 15140, 15, 9],
            [2018, 15141, 10, 7],
            [2018, 15142, 10, 7],
            [2018, 15143, 10, 7],
            [2018, 15144, 14, 8],
            [2018, 15145, 12, 8],
            [2018, 15146, 16, 10],
            [2018, 15147, 8, 6],
            [2018, 15148, 7, 5],
            [2018, 15149, 9, 7],
            [2018, 15150, 12, 8],
            [2018, 15151, 6, 5],
            [2018, 15152, 7, 6],
            [2018, 15153, 11, 7],
            [2018, 15154, 16, 8],
            [2018, 15155, 16, 10],
            [2018, 15156, 10, 8],
            [2018, 15157, 11, 9],
            [2018, 15158, 16, 9],
            [2018, 15159, 7, 6],
            [2018, 15160, 22, 12],
            [2018, 15161, 10, 8],
            [2018, 15162, 13, 7],
            [2018, 15163, 14, 8],
            [2018, 15164, 12, 7],
            [2018, 15165, 18, 9],
            [2018, 15166, 12, 9],
            [2018, 15167, 9, 9],
            [2018, 15168, 15, 10],
            [2018, 15169, 17, 7],
            [2018, 15170, 12, 9],
            [2018, 15171, 11, 7],
            [2018, 15172, 8, 6],
            [2018, 15173, 11, 9],
            [2018, 15174, 10, 6],
            [2018, 15175, 7, 6],
            [2018, 15176, 5, 5],
            [2018, 15177, 19, 10],
            [2018, 15178, 7, 5],
            [2018, 15179, 7, 5],
            [2018, 15180, 7, 5],
            [2018, 15181, 6, 5],
            [2018, 15182, 15, 9],
            [2018, 15183, 16, 9],
            [2018, 15184, 14, 9],
            [2018, 15185, 19, 12],
            [2018, 15186, 12, 8],
            [2018, 15187, 11, 9],
            [2018, 15188, 13, 8],
            [2018, 15189, 14, 9],
            [2018, 15190, 14, 8],
            [2018, 15191, 10, 7],
            [2018, 15192, 7, 7],
            [2018, 15193, 8, 7],
            [2018, 15194, 12, 9],
            [2018, 15195, 15, 10],
            [2018, 15196, 12, 7],
            [2018, 15197, 18, 10],
            [2018, 15198, 15, 9],
            [2018, 15199, 14, 7],
            [2018, 15200, 12, 9],
            [2018, 15201, 12, 8],
            [2018, 15202, 17, 9],
            [2018, 15203, 13, 8],
            [2018, 15204, 10, 7],
            [2018, 15206, 16, 8],
            [2018, 15207, 9, 7],
            [2018, 15208, 9, 7],
            [2018, 15209, 10, 8],
            [2018, 15210, 10, 8],
            [2018, 15211, 13, 8],
            [2018, 15212, 13, 9],
            [2018, 15213, 23, 12],
            [2018, 15214, 10, 7],
            [2018, 15215, 12, 9],
            [2018, 15216, 11, 8],
            [2018, 15217, 9, 6],
            [2018, 15218, 10, 7],
            [2018, 15219, 13, 8],
            [2018, 15220, 13, 8],
            [2018, 15221, 13, 9],
            [2018, 15222, 14, 9],
            [2018, 15223, 13, 8],
            [2018, 15224, 12, 7],
            [2018, 15225, 9, 6],
            [2018, 15227, 14, 10],
            [2018, 15228, 13, 10],
            [2018, 15229, 14, 8],
            [2018, 15230, 12, 9],
            [2018, 15231, 9, 8],
            [2018, 15232, 17, 10],
            [2018, 15233, 14, 9],
            [2018, 15234, 15, 9],
            [2018, 15235, 8, 8],
            [2018, 15236, 13, 9],
            [2018, 15237, 11, 7],
            [2018, 15238, 10, 7],
            [2018, 15239, 8, 6],
            [2018, 15240, 10, 7],
            [2018, 15241, 12, 7],
            [2018, 15242, 12, 8],
            [2018, 15243, 14, 9],
            [2018, 15244, 9, 7],
            [2018, 15245, 8, 7],
            [2018, 15246, 15, 10],
            [2018, 15247, 13, 9],
            [2018, 15248, 14, 10],
            [2018, 15249, 11, 7],
            [2018, 15250, 12, 8],
            [2018, 15252, 13, 10],
            [2018, 15253, 12, 9],
            [2018, 15254, 8, 6],
            [2018, 15255, 11, 8],
            [2018, 15256, 9, 7],
            [2018, 15257, 8, 8],
            [2018, 15258, 11, 7],
            [2018, 15260, 13, 9],
            [2018, 15261, 13, 8],
            [2018, 15262, 9, 7],
            [2018, 15263, 18, 9],
            [2018, 15264, 17, 10],
            [2018, 15265, 17, 10],
            [2018, 15266, 12, 8],
            [2018, 15267, 9, 7],
            [2018, 15268, 24, 9],
            [2018, 15269, 11, 9],
            [2018, 15270, 11, 7],
            [2018, 15271, 7, 7],
            [2018, 15272, 16, 10],
            [2018, 15273, 11, 6],
            [2018, 15274, 18, 10],
            [2018, 15275, 14, 9],
            [2018, 15276, 15, 9],
            [2018, 15277, 8, 7],
            [2018, 15278, 6, 6],
            [2018, 15280, 13, 9],
            [2018, 15281, 11, 7],
            [2018, 15282, 22, 10],
            [2018, 15283, 22, 10],
            [2018, 15284, 13, 8],
            [2018, 15285, 9, 8],
            [2018, 15286, 15, 10],
            [2018, 15287, 15, 8],
            [2018, 15288, 12, 7],
            [2018, 15289, 10, 8],
            [2018, 15290, 16, 9],
            [2018, 15291, 9, 6],
            [2018, 15292, 12, 8],
            [2018, 15293, 14, 8],
            [2018, 15294, 18, 10],
            [2018, 15295, 11, 10],
            [2018, 15296, 16, 10],
            [2018, 15297, 17, 10],
            [2018, 15298, 15, 9],
            [2018, 15299, 20, 11],
            [2018, 15300, 19, 9],
            [2018, 15301, 7, 6],
            [2018, 15302, 11, 7],
            [2018, 15303, 8, 6],
            [2018, 15304, 7, 7],
            [2018, 15305, 17, 9],
            [2018, 15306, 6, 6],
            [2018, 15307, 5, 6],
            [2018, 15308, 12, 9],
            [2018, 15309, 9, 8],
            [2018, 15310, 10, 6],
            [2018, 15311, 12, 8],
            [2018, 15312, 10, 8],
            [2018, 15313, 19, 9],
            [2018, 15314, 13, 9],
            [2018, 15315, 15, 9],
            [2018, 15316, 15, 9],
            [2018, 15317, 15, 9],
            [2018, 15318, 8, 6],
            [2018, 15319, 10, 7],
            [2018, 15320, 9, 7],
            [2018, 15321, 7, 5],
            [2018, 15323, 15, 8],
            [2018, 15324, 10, 7],
            [2018, 15325, 9, 6],
            [2018, 15326, 21, 11],
            [2018, 15327, 12, 9],
            [2018, 15328, 10, 7],
            [2018, 15329, 12, 7],
            [2018, 15331, 11, 8],
            [2018, 15332, 6, 5],
            [2018, 15333, 9, 7],
            [2018, 15334, 11, 7],
            [2018, 15335, 9, 7],
            [2018, 15336, 16, 9],
            [2018, 15337, 10, 9],
            [2018, 15338, 8, 6],
            [2018, 15339, 13, 7],
            [2018, 15340, 18, 9],
            [2018, 15341, 20, 9],
            [2018, 15342, 17, 10],
            [2018, 15343, 15, 9],
            [2018, 15344, 7, 6],
            [2018, 15345, 7, 6],
            [2018, 15346, 10, 7],
            [2018, 15347, 14, 9],
            [2018, 15348, 16, 9],
            [2018, 15349, 11, 7],
            [2018, 15350, 16, 9],
            [2018, 15351, 16, 8],
            [2018, 15352, 12, 7],
            [2018, 15353, 13, 8],
            [2018, 15354, 16, 10],
            [2018, 15355, 9, 7],
            [2018, 15356, 13, 7],
            [2018, 15357, 13, 9],
            [2018, 15358, 13, 8],
            [2018, 15359, 13, 9],
            [2018, 15441, 33, 28],
            [2018, 15443, 13, 11],
            [2018, 15445, 14, 12],
            [2018, 15446, 32, 29],
            [2018, 15447, 31, 21],
            [2018, 15450, 13, 13],
            [2018, 15451, 17, 17],
            [2018, 15452, 25, 24],
            [2018, 15453, 22, 21],
            [2018, 15454, 35, 17],
            [2018, 15455, 144, 26],
            [2018, 15459, 30, 24],
            [2018, 15460, 47, 111],
            [2018, 15461, 25, 24],
            [2018, 15462, 24, 17],
            [2018, 15463, 17, 18],
            [2018, 15464, 44, 25],
            [2018, 15465, 36, 22],
            [2018, 15467, 21, 11],
            [2018, 15468, 17, 15],
            [2018, 15469, 16, 16],
            [2018, 15470, 36, 36],
            [2018, 15471, 12, 11],
            [2018, 15472, 18, 29],
            [2018, 15473, 16, 17],
            [2018, 15474, 32, 36],
            [2018, 15475, 14, 17],
            [2018, 15476, 22, 33],
            [2018, 15477, 32, 82],
            [2018, 15478, 28, 14],
            [2018, 15479, 65, 121],
            [2018, 15480, 37, 61],
            [2018, 15481, 63, 88],
            [2018, 15482, 63, 121],
            [2018, 15483, 26, 23],
            [2018, 15484, 20, 21],
            [2018, 15485, 16, 20],
            [2018, 15486, 10, 13],
            [2018, 15487, 29, 26],
            [2018, 15488, 34, 39],
            [2018, 15489, 45, 66],
            [2018, 15490, 46, 46],
            [2018, 15491, 33, 25],
            [2018, 15493, 12, 20],
            [2018, 15496, 16, 19],
            [2018, 15497, 10, 14],
            [2018, 15498, 15, 15],
            [2018, 15499, 19, 15],
            [2018, 15500, 11, 9],
            [2018, 15501, 14, 9],
            [2018, 15502, 13, 9],
            [2018, 15503, 12, 9],
            [2018, 15504, 12, 9],
            [2018, 15506, 30, 66],
            [2018, 15509, 36, 36],
            [2018, 15511, 54, 37],
            [2018, 15512, 102, 56],
            [2018, 15513, 18, 27],
            [2018, 15514, 32, 47],
            [2018, 15516, 114, 84],
            [2018, 15517, 82, 55],
            [2018, 15518, 89, 37],
            [2018, 15519, 121, 121],
            [2018, 15520, 121, 121],
            [2018, 15521, 46, 38],
            [2018, 15522, 59, 41],
            [2018, 15523, 69, 30],
            [2018, 15524, 41, 38],
            [2018, 15525, 40, 60],
            [2018, 15526, 26, 19],
            [2018, 15528, 15, 24],
            [2018, 15529, 36, 41],
            [2018, 15530, 86, 52],
            [2018, 15532, 82, 55],
            [2018, 15533, 26, 49],
            [2018, 15535, 61, 51],
            [2018, 15537, 11, 9],
            [2018, 15538, 17, 14],
            [2018, 15539, 15, 11],
            [2018, 15540, 10, 11],
            [2018, 15541, 9, 10],
            [2018, 15542, 25, 17],
            [2018, 15543, 42, 22],
            [2018, 15544, 5, 5],
            [2018, 15548, 9, 8],
            [2018, 15550, 4, 4],
            [2018, 15551, 6, 6],
            [2018, 15553, 8, 7],
            [2018, 15554, 9, 7],
            [2018, 15555, 7, 6],
            [2018, 15557, 13, 8],
            [2018, 15558, 7, 6],
            [2018, 15559, 7, 6],
            [2018, 15597, 10, 7],
            [2018, 15598, 7, 6],
            [2018, 15599, 13, 9],
            [2018, 15605, 6, 5],
            [2018, 15606, 5, 5],
            [2018, 15607, 8, 6],
            [2018, 15608, 7, 6],
            [2018, 15609, 6, 6],
            [2018, 15610, 8, 6],
            [2018, 15611, 7, 5],
            [2018, 15627, 21, 13],
            [2018, 15628, 8, 7],
            [2018, 15629, 8, 7],
            [2018, 15630, 7, 8],
            [2018, 15631, 7, 6],
            [2018, 15632, 19, 11],
            [2018, 15633, 46, 33],
            [2018, 15634, 63, 42],
            [2018, 15635, 71, 48],
            [2018, 15636, 22, 14],
            [2018, 15637, 65, 42],
            [2018, 15638, 44, 31],
            [2018, 15639, 54, 42],
            [2018, 15640, 15, 8],
            [2018, 15641, 11, 8],
            [2018, 15642, 9, 7],
            [2018, 15643, 11, 8],
            [2018, 15644, 14, 9],
            [2018, 15645, 16, 8],
            [2018, 15646, 16, 9],
            [2018, 15647, 11, 9],
            [2018, 15648, 15, 10],
            [2018, 15649, 18, 11],
            [2018, 15650, 10, 7],
            [2018, 15651, 8, 6],
            [2018, 15652, 9, 6],
            [2018, 15653, 9, 6],
            [2018, 15654, 14, 9],
            [2018, 15655, 16, 10],
            [2018, 15656, 9, 6],
            [2018, 15687, 7, 6],
            [2018, 15688, 7, 6],
            [2018, 15689, 2, 1],
            [2018, 15690, 2, 1],
            [2018, 15691, 9, 7],
            [2018, 15692, 10, 6],
            [2018, 15693, 10, 8],
            [2018, 15694, 9, 7],
            [2018, 15695, 10, 7],
            [2018, 15696, 11, 8],
            [2018, 15697, 19, 18],
            [2018, 15698, 15, 10],
            [2018, 15699, 11, 10],
            [2018, 15700, 11, 7],
            [2018, 15701, 21, 11],
            [2018, 15702, 24, 12],
            [2018, 15703, 21, 10],
            [2018, 15704, 20, 10],
            [2018, 15705, 22, 11],
            [2018, 15706, 21, 10],
            [2018, 15707, 20, 10],
            [2018, 15708, 9, 7],
            [2018, 15709, 9, 7],
            [2018, 15710, 10, 8],
            [2018, 15711, 10, 8],
            [2018, 15712, 11, 7],
            [2018, 15713, 7, 5],
            [2018, 15714, 7, 5],
            [2018, 15715, 7, 5],
            [2018, 15716, 8, 5],
            [2018, 15717, 8, 5],
            [2018, 15718, 8, 5],
            [2018, 15719, 8, 5],
            [2018, 15720, 8, 5],
            [2018, 15721, 20, 9],
            [2018, 15722, 20, 9],
            [2018, 15774, 16, 9],
            [2018, 15775, 19, 11],
            [2018, 15776, 16, 9],
            [2018, 15777, 18, 11],
            [2018, 15778, 16, 9],
            [2018, 15779, 6, 7],
            [2018, 15780, 9, 8],
            [2018, 15781, 9, 8],
            [2018, 15782, 6, 7],
            [2018, 15783, 9, 7],
            [2018, 15784, 6, 5],
            [2018, 15785, 7, 8],
            [2018, 15786, 8, 7],
            [2018, 15787, 7, 7],
            [2018, 15788, 13, 10],
            [2018, 15789, 15, 9],
            [2018, 15790, 16, 10],
            [2018, 15791, 7, 7],
            [2018, 15792, 9, 9],
            [2018, 15793, 6, 6],
            [2018, 15794, 10, 7],
            [2018, 15795, 16, 10],
            [2018, 15796, 7, 7],
            [2018, 15797, 8, 7],
            [2018, 15813, 6, 4],
            [2018, 15814, 7, 5],
            [2018, 15815, 9, 6],
            [2018, 15816, 12, 8],
            [2018, 15817, 7, 5],
            [2018, 15818, 6, 4],
            [2018, 15819, 7, 5],
            [2018, 15820, 10, 7],
            [2018, 15821, 10, 7],
            [2018, 15822, 9, 6],
            [2018, 15823, 6, 4],
            [2018, 15824, 6, 5],
            [2018, 15825, 6, 4],
            [2018, 15826, 7, 5],
            [2018, 15827, 10, 7],
            [2018, 15828, 5, 4],
            [2018, 15829, 8, 5],
            [2018, 15830, 6, 4],
            [2018, 15831, 8, 5],
            [2018, 15832, 7, 4],
            [2018, 15833, 8, 5],
            [2018, 15834, 13, 10],
            [2018, 15835, 5, 4],
            [2018, 15836, 9, 7],
            [2018, 15837, 10, 6],
            [2018, 15838, 7, 5],
            [2018, 15839, 8, 5],
            [2018, 15840, 6, 4],
            [2018, 15841, 6, 4],
            [2018, 15842, 11, 7],
            [2018, 15843, 13, 9],
            [2018, 15844, 13, 9],
            [2018, 15845, 8, 5],
            [2018, 15846, 6, 5],
            [2018, 15847, 7, 5],
            [2018, 15848, 12, 8],
            [2018, 15849, 12, 8],
            [2018, 15850, 11, 9],
            [2018, 15851, 11, 9],
            [2018, 15852, 11, 8],
            [2018, 15853, 10, 8],
            [2018, 15854, 12, 8],
            [2018, 15855, 15, 9],
            [2018, 15856, 12, 9],
            [2018, 15857, 14, 9],
            [2018, 15858, 10, 8],
            [2018, 15859, 9, 6],
            [2018, 15860, 9, 7],
            [2018, 15861, 8, 7],
            [2018, 15862, 8, 6],
            [2018, 15863, 6, 5],
            [2018, 15864, 9, 7],
            [2018, 15865, 9, 7],
            [2018, 15866, 8, 6],
            [2018, 15867, 7, 6],
            [2018, 15868, 8, 7],
            [2018, 15869, 7, 6],
            [2018, 15870, 8, 6],
            [2018, 15871, 8, 7],
            [2018, 15872, 8, 7],
            [2018, 15873, 9, 7],
            [2018, 15874, 6, 5],
            [2018, 15875, 6, 5],
            [2018, 15876, 6, 6],
            [2018, 15877, 8, 6],
            [2018, 15878, 6, 6],
            [2018, 15879, 8, 7],
            [2018, 15880, 10, 8],
            [2018, 15881, 8, 6],
            [2018, 15882, 7, 6],
            [2018, 15883, 6, 5],
            [2018, 15884, 7, 6],
            [2018, 15885, 5, 4],
            [2018, 15886, 54, 43],
            [2018, 15887, 36, 33],
            [2018, 15888, 77, 49],
            [2018, 15889, 56, 43],
            [2018, 15890, 58, 42],
            [2018, 15891, 77, 49],
            [2018, 15892, 36, 36],
            [2018, 15893, 46, 54],
            [2018, 15894, 43, 29],
            [2018, 15895, 46, 54],
            [2018, 15896, 54, 46],
            [2018, 15897, 59, 42],
            [2018, 15898, 61, 50],
            [2018, 15899, 46, 29],
            [2018, 15900, 29, 28],
            [2018, 15901, 76, 63],
            [2018, 15902, 31, 36],
            [2018, 15903, 55, 33],
            [2018, 15904, 34, 21],
            [2018, 15905, 34, 21],
            [2018, 15906, 54, 48],
            [2018, 15907, 48, 45],
            [2018, 15908, 55, 33],
            [2018, 15909, 36, 33],
            [2018, 15910, 121, 121],
            [2018, 15911, 8, 6],
            [2018, 15912, 7, 6],
            [2018, 15913, 8, 6],
            [2018, 15914, 7, 6],
            [2018, 15915, 7, 6],
            [2018, 15916, 8, 6],
            [2018, 15917, 30, 34],
            [2018, 15918, 108, 92],
            [2019, 12312, 106, 64],
            [2019, 12313, 64, 52],
            [2019, 12314, 64, 52],
            [2019, 12315, 106, 64],
            [2019, 12316, 106, 64],
            [2019, 12317, 106, 64],
            [2019, 12318, 106, 64],
            [2019, 12319, 106, 64],
            [2019, 12320, 64, 52],
            [2019, 12321, 34, 46],
            [2019, 12322, 106, 64],
            [2019, 12323, 106, 64],
            [2019, 12324, 64, 52],
            [2019, 12325, 64, 52],
            [2019, 12777, 7, 6],
            [2019, 12780, 7, 7],
            [2019, 12783, 7, 6],
            [2019, 12821, 6, 4],
            [2019, 12823, 5, 4],
            [2019, 12826, 6, 5],
            [2019, 12828, 8, 6],
            [2019, 12830, 8, 5],
            [2019, 12833, 7, 5],
            [2019, 12835, 5, 4],
            [2019, 12837, 5, 4],
            [2019, 12838, 7, 4],
            [2019, 12839, 5, 4],
            [2019, 12841, 3, 2],
            [2019, 12843, 5, 4],
            [2019, 12845, 8, 5],
            [2019, 12848, 8, 6],
            [2019, 12853, 6, 4],
            [2019, 12855, 4, 3],
            [2019, 12857, 8, 6],
            [2019, 12858, 3, 2],
            [2019, 12862, 5, 4],
            [2019, 12864, 5, 4],
            [2019, 12866, 5, 4],
            [2019, 12868, 7, 4],
            [2019, 12870, 6, 4],
            [2019, 12872, 7, 5],
            [2019, 12874, 6, 5],
            [2019, 12876, 9, 6],
            [2019, 12877, 6, 4],
            [2019, 12880, 6, 4],
            [2019, 12882, 8, 6],
            [2019, 12883, 5, 4],
            [2019, 12885, 3, 2],
            [2019, 12887, 5, 4],
            [2019, 12892, 9, 7],
            [2019, 12895, 6, 4],
            [2019, 12899, 11, 7],
            [2019, 12900, 8, 6],
            [2019, 12902, 7, 4],
            [2019, 12907, 13, 9],
            [2019, 12909, 5, 4],
            [2019, 12910, 9, 6],
            [2019, 12911, 4, 4],
            [2019, 12912, 9, 6],
            [2019, 12913, 7, 5],
            [2019, 12914, 6, 5],
            [2019, 12915, 4, 3],
            [2019, 12916, 6, 4],
            [2019, 12921, 11, 8],
            [2019, 12922, 8, 5],
            [2019, 12924, 8, 6],
            [2019, 12925, 6, 5],
            [2019, 12926, 6, 5],
            [2019, 12927, 9, 7],
            [2019, 12928, 19, 11],
            [2019, 12929, 6, 4],
            [2019, 12930, 7, 5],
            [2019, 12934, 8, 5],
            [2019, 12935, 7, 5],
            [2019, 12936, 4, 3],
            [2019, 12938, 7, 5],
            [2019, 12939, 3, 2],
            [2019, 12942, 8, 6],
            [2019, 12945, 4, 3],
            [2019, 12946, 6, 4],
            [2019, 12947, 8, 5],
            [2019, 12948, 6, 5],
            [2019, 12950, 7, 5],
            [2019, 12951, 7, 5],
            [2019, 12952, 14, 10],
            [2019, 12953, 10, 8],
            [2019, 12954, 8, 5],
            [2019, 12955, 6, 4],
            [2019, 12956, 5, 4],
            [2019, 12957, 8, 6],
            [2019, 12958, 6, 5],
            [2019, 12959, 6, 4],
            [2019, 12960, 7, 4],
            [2019, 12961, 6, 4],
            [2019, 12964, 8, 5],
            [2019, 12965, 11, 8],
            [2019, 12966, 10, 7],
            [2019, 12967, 8, 6],
            [2019, 12968, 11, 8],
            [2019, 12969, 7, 5],
            [2019, 12970, 6, 4],
            [2019, 12971, 7, 5],
            [2019, 12973, 6, 4],
            [2019, 12974, 7, 4],
            [2019, 12975, 6, 4],
            [2019, 12976, 6, 4],
            [2019, 12977, 4, 3],
            [2019, 12980, 6, 4],
            [2019, 12981, 7, 5],
            [2019, 12982, 8, 6],
            [2019, 12983, 8, 5],
            [2019, 12985, 8, 6],
            [2019, 12986, 5, 4],
            [2019, 12987, 7, 5],
            [2019, 12988, 11, 9],
            [2019, 12991, 6, 4],
            [2019, 12993, 4, 3],
            [2019, 12994, 7, 4],
            [2019, 12995, 5, 4],
            [2019, 12996, 7, 5],
            [2019, 12997, 7, 4],
            [2019, 12999, 7, 5],
            [2019, 13000, 6, 5],
            [2019, 13015, 10, 8],
            [2019, 13016, 11, 8],
            [2019, 13017, 8, 4],
            [2019, 13018, 13, 11],
            [2019, 13019, 11, 7],
            [2019, 13020, 9, 9],
            [2019, 13021, 12, 10],
            [2019, 13022, 9, 4],
            [2019, 13023, 12, 9],
            [2019, 13024, 22, 13],
            [2019, 13025, 9, 9],
            [2019, 13026, 14, 9],
            [2019, 13027, 9, 7],
            [2019, 13028, 7, 4],
            [2019, 13029, 10, 9],
            [2019, 13030, 13, 10],
            [2019, 13031, 10, 8],
            [2019, 13032, 14, 10],
            [2019, 13033, 9, 7],
            [2019, 13034, 6, 4],
            [2019, 13035, 8, 4],
            [2019, 13036, 12, 7],
            [2019, 13037, 7, 5],
            [2019, 13038, 12, 9],
            [2019, 13039, 8, 6],
            [2019, 13040, 14, 10],
            [2019, 13041, 10, 8],
            [2019, 13042, 6, 5],
            [2019, 13043, 8, 5],
            [2019, 13044, 10, 10],
            [2019, 13045, 6, 5],
            [2019, 13046, 11, 9],
            [2019, 13047, 11, 9],
            [2019, 13048, 10, 7],
            [2019, 13049, 9, 7],
            [2019, 13050, 10, 8],
            [2019, 13051, 10, 8],
            [2019, 13052, 10, 8],
            [2019, 13053, 9, 7],
            [2019, 13054, 11, 10],
            [2019, 13055, 15, 10],
            [2019, 13056, 11, 9],
            [2019, 13057, 11, 9],
            [2019, 13058, 13, 9],
            [2019, 13059, 11, 7],
            [2019, 13060, 15, 9],
            [2019, 13061, 15, 10],
            [2019, 13062, 11, 7],
            [2019, 13063, 16, 5],
            [2019, 13064, 7, 7],
            [2019, 13065, 10, 8],
            [2019, 13066, 9, 7],
            [2019, 13067, 12, 8],
            [2019, 13068, 10, 9],
            [2019, 13069, 17, 10],
            [2019, 13070, 9, 4],
            [2019, 13071, 11, 6],
            [2019, 13072, 9, 8],
            [2019, 13073, 9, 7],
            [2019, 13074, 10, 7],
            [2019, 13075, 11, 10],
            [2019, 13076, 10, 7],
            [2019, 13077, 14, 10],
            [2019, 13078, 21, 12],
            [2019, 13079, 9, 9],
            [2019, 13080, 11, 7],
            [2019, 13081, 11, 9],
            [2019, 13082, 6, 5],
            [2019, 13083, 10, 7],
            [2019, 13084, 19, 11],
            [2019, 13085, 18, 11],
            [2019, 13086, 6, 5],
            [2019, 13087, 12, 8],
            [2019, 13088, 13, 8],
            [2019, 13089, 9, 8],
            [2019, 13090, 10, 8],
            [2019, 13091, 7, 4],
            [2019, 13092, 17, 10],
            [2019, 13093, 11, 7],
            [2019, 13094, 19, 10],
            [2019, 13095, 12, 8],
            [2019, 13096, 9, 8],
            [2019, 13097, 15, 9],
            [2019, 13098, 12, 9],
            [2019, 13099, 7, 7],
            [2019, 13140, 13, 8],
            [2019, 13142, 7, 6],
            [2019, 13143, 6, 5],
            [2019, 13144, 10, 8],
            [2019, 13145, 6, 5],
            [2019, 13147, 8, 6],
            [2019, 13148, 10, 9],
            [2019, 13154, 7, 6],
            [2019, 13155, 8, 6],
            [2019, 13156, 8, 6],
            [2019, 13158, 7, 5],
            [2019, 13159, 8, 6],
            [2019, 13161, 6, 6],
            [2019, 13163, 10, 6],
            [2019, 13164, 7, 6],
            [2019, 13165, 7, 5],
            [2019, 13166, 8, 6],
            [2019, 13167, 12, 7],
            [2019, 13168, 7, 5],
            [2019, 13170, 9, 7],
            [2019, 13172, 7, 6],
            [2019, 13173, 8, 7],
            [2019, 13175, 7, 6],
            [2019, 13177, 8, 6],
            [2019, 13178, 8, 6],
            [2019, 13179, 8, 6],
            [2019, 13180, 11, 8],
            [2019, 13181, 7, 6],
            [2019, 13182, 8, 7],
            [2019, 13184, 7, 6],
            [2019, 13232, 11, 9],
            [2019, 13233, 11, 8],
            [2019, 13234, 12, 8],
            [2019, 13235, 11, 8],
            [2019, 13236, 8, 6],
            [2019, 13238, 11, 8],
            [2019, 13239, 12, 8],
            [2019, 13240, 11, 8],
            [2019, 13242, 12, 8],
            [2019, 13244, 15, 10],
            [2019, 13245, 11, 8],
            [2019, 13246, 11, 8],
            [2019, 13247, 13, 9],
            [2019, 13248, 10, 7],
            [2019, 13249, 8, 6],
            [2019, 13250, 12, 9],
            [2019, 13251, 11, 8],
            [2019, 13252, 14, 9],
            [2019, 13253, 10, 8],
            [2019, 13254, 9, 7],
            [2019, 13255, 8, 6],
            [2019, 13256, 11, 7],
            [2019, 13257, 12, 8],
            [2019, 13258, 15, 9],
            [2019, 13260, 11, 8],
            [2019, 13261, 12, 8],
            [2019, 13262, 13, 9],
            [2019, 13263, 11, 9],
            [2019, 13264, 12, 8],
            [2019, 13266, 11, 8],
            [2019, 13270, 13, 8],
            [2019, 13273, 11, 8],
            [2019, 13275, 11, 8],
            [2019, 13276, 8, 6],
            [2019, 13280, 9, 7],
            [2019, 13282, 11, 8],
            [2019, 13285, 11, 8],
            [2019, 13286, 13, 9],
            [2019, 13288, 14, 9],
            [2019, 13291, 10, 8],
            [2019, 13297, 11, 7],
            [2019, 13302, 10, 8],
            [2019, 13304, 13, 9],
            [2019, 13305, 10, 8],
            [2019, 13308, 11, 8],
            [2019, 13312, 12, 8],
            [2019, 13315, 13, 8],
            [2019, 13316, 9, 6],
            [2019, 13317, 9, 6],
            [2019, 13319, 12, 8],
            [2019, 13322, 11, 8],
            [2019, 13326, 11, 8],
            [2019, 13328, 11, 8],
            [2019, 13330, 11, 8],
            [2019, 13332, 11, 8],
            [2019, 13334, 8, 7],
            [2019, 13336, 11, 8],
            [2019, 13339, 9, 7],
            [2019, 13340, 11, 8],
            [2019, 13343, 10, 7],
            [2019, 13346, 7, 5],
            [2019, 13348, 13, 8],
            [2019, 13350, 11, 8],
            [2019, 13353, 12, 8],
            [2019, 13355, 12, 8],
            [2019, 13356, 7, 5],
            [2019, 13358, 11, 9],
            [2019, 13360, 8, 6],
            [2019, 13363, 13, 9],
            [2019, 13365, 8, 6],
            [2019, 13367, 8, 5],
            [2019, 13369, 11, 8],
            [2019, 13374, 10, 8],
            [2019, 13375, 10, 8],
            [2019, 13379, 10, 7],
            [2019, 13382, 11, 8],
            [2019, 13385, 6, 5],
            [2019, 13387, 10, 8],
            [2019, 13389, 10, 8],
            [2019, 13390, 11, 8],
            [2019, 13392, 11, 8],
            [2019, 13394, 11, 8],
            [2019, 13397, 6, 5],
            [2019, 13399, 10, 8],
            [2019, 13449, 8, 6],
            [2019, 13450, 7, 6],
            [2019, 13451, 9, 6],
            [2019, 13452, 8, 6],
            [2019, 13453, 9, 7],
            [2019, 13454, 17, 10],
            [2019, 13455, 12, 10],
            [2019, 13456, 6, 5],
            [2019, 13457, 7, 6],
            [2019, 13458, 7, 6],
            [2019, 13460, 8, 6],
            [2019, 13463, 11, 8],
            [2019, 13464, 14, 8],
            [2019, 13465, 10, 8],
            [2019, 13466, 8, 7],
            [2019, 13467, 7, 6],
            [2019, 13468, 8, 7],
            [2019, 13469, 7, 6],
            [2019, 13470, 12, 9],
            [2019, 13471, 8, 7],
            [2019, 13472, 12, 8],
            [2019, 13473, 11, 8],
            [2019, 13474, 9, 7],
            [2019, 13475, 11, 7],
            [2019, 13476, 7, 6],
            [2019, 13478, 6, 6],
            [2019, 13479, 11, 8],
            [2019, 13480, 4, 4],
            [2019, 13481, 7, 6],
            [2019, 13482, 8, 7],
            [2019, 13483, 8, 7],
            [2019, 13484, 10, 7],
            [2019, 13485, 8, 6],
            [2019, 13486, 3, 4],
            [2019, 13487, 17, 10],
            [2019, 13488, 7, 5],
            [2019, 13489, 10, 8],
            [2019, 13490, 7, 6],
            [2019, 13491, 7, 6],
            [2019, 13492, 7, 6],
            [2019, 13494, 9, 7],
            [2019, 13495, 7, 6],
            [2019, 13496, 8, 7],
            [2019, 13497, 8, 6],
            [2019, 13498, 8, 6],
            [2019, 13499, 9, 7],
            [2019, 13501, 14, 9],
            [2019, 13502, 8, 6],
            [2019, 13503, 8, 7],
            [2019, 13504, 7, 5],
            [2019, 13505, 7, 5],
            [2019, 13506, 8, 6],
            [2019, 13508, 10, 8],
            [2019, 13509, 6, 6],
            [2019, 13511, 12, 8],
            [2019, 13512, 9, 7],
            [2019, 13513, 10, 7],
            [2019, 13514, 10, 8],
            [2019, 13516, 7, 5],
            [2019, 13517, 7, 7],
            [2019, 13518, 7, 6],
            [2019, 13519, 10, 7],
            [2019, 13520, 11, 8],
            [2019, 13521, 8, 6],
            [2019, 13522, 9, 7],
            [2019, 13523, 8, 7],
            [2019, 13524, 7, 6],
            [2019, 13525, 10, 7],
            [2019, 13526, 7, 6],
            [2019, 13527, 13, 10],
            [2019, 13528, 8, 6],
            [2019, 13529, 6, 5],
            [2019, 13530, 6, 5],
            [2019, 13531, 7, 6],
            [2019, 13532, 7, 6],
            [2019, 13533, 6, 5],
            [2019, 13534, 6, 5],
            [2019, 13536, 8, 7],
            [2019, 13537, 6, 5],
            [2019, 13538, 6, 5],
            [2019, 13539, 6, 5],
            [2019, 13540, 6, 5],
            [2019, 13541, 9, 7],
            [2019, 13542, 8, 7],
            [2019, 13544, 10, 8],
            [2019, 13546, 7, 5],
            [2019, 13548, 10, 8],
            [2019, 13550, 17, 9],
            [2019, 13552, 11, 9],
            [2019, 13556, 8, 6],
            [2019, 13557, 3, 3],
            [2019, 13558, 13, 8],
            [2019, 13560, 8, 6],
            [2019, 13561, 7, 6],
            [2019, 13562, 9, 7],
            [2019, 13563, 7, 5],
            [2019, 13564, 13, 9],
            [2019, 13565, 7, 6],
            [2019, 13566, 12, 9],
            [2019, 13567, 8, 7],
            [2019, 13568, 4, 5],
            [2019, 13569, 7, 6],
            [2019, 13570, 6, 6],
            [2019, 13571, 10, 7],
            [2019, 13572, 6, 5],
            [2019, 13573, 7, 7],
            [2019, 13574, 9, 7],
            [2019, 13575, 11, 8],
            [2019, 13576, 7, 5],
            [2019, 13577, 6, 5],
            [2019, 13578, 7, 6],
            [2019, 13579, 14, 8],
            [2019, 13580, 9, 6],
            [2019, 13581, 6, 5],
            [2019, 13582, 8, 6],
            [2019, 13583, 8, 6],
            [2019, 13584, 22, 12],
            [2019, 13585, 6, 6],
            [2019, 13586, 6, 5],
            [2019, 13587, 7, 5],
            [2019, 13588, 14, 9],
            [2019, 13589, 7, 6],
            [2019, 13590, 11, 8],
            [2019, 13593, 6, 6],
            [2019, 13594, 11, 8],
            [2019, 13595, 9, 6],
            [2019, 13596, 9, 7],
            [2019, 13597, 8, 6],
            [2019, 13598, 7, 6],
            [2019, 13599, 6, 6],
            [2019, 13600, 8, 6],
            [2019, 13601, 6, 5],
            [2019, 13602, 6, 5],
            [2019, 13603, 6, 5],
            [2019, 13604, 11, 7],
            [2019, 13605, 9, 7],
            [2019, 13606, 9, 7],
            [2019, 13607, 8, 6],
            [2019, 13608, 8, 6],
            [2019, 14438, 19, 31],
            [2019, 14440, 20, 26],
            [2019, 14442, 20, 23],
            [2019, 14445, 12, 12],
            [2019, 14446, 26, 26],
            [2019, 14449, 14, 10],
            [2019, 14450, 43, 24],
            [2019, 14452, 33, 23],
            [2019, 14453, 21, 48],
            [2019, 14458, 25, 38],
            [2019, 14459, 30, 30],
            [2019, 14460, 22, 19],
            [2019, 14462, 20, 28],
            [2019, 14463, 10, 9],
            [2019, 14464, 29, 23],
            [2019, 14465, 26, 18],
            [2019, 14466, 20, 17],
            [2019, 14468, 21, 35],
            [2019, 14470, 17, 11],
            [2019, 14471, 18, 23],
            [2019, 14473, 10, 9],
            [2019, 14476, 32, 30],
            [2019, 14478, 10, 9],
            [2019, 14480, 26, 19],
            [2019, 14484, 19, 24],
            [2019, 14485, 13, 10],
            [2019, 14486, 47, 28],
            [2019, 14488, 19, 16],
            [2019, 14489, 14, 13],
            [2019, 14490, 58, 61],
            [2019, 14491, 19, 24],
            [2019, 14495, 24, 23],
            [2019, 14496, 56, 49],
            [2019, 14500, 24, 35],
            [2019, 14501, 20, 16],
            [2019, 14502, 50, 95],
            [2019, 14503, 23, 29],
            [2019, 14505, 11, 9],
            [2019, 14507, 23, 26],
            [2019, 14508, 14, 12],
            [2019, 14509, 29, 25],
            [2019, 14510, 34, 21],
            [2019, 14512, 27, 30],
            [2019, 14513, 36, 28],
            [2019, 14514, 30, 23],
            [2019, 14518, 26, 20],
            [2019, 14519, 85, 70],
            [2019, 14520, 40, 92],
            [2019, 14524, 20, 22],
            [2019, 14528, 15, 12],
            [2019, 14530, 33, 20],
            [2019, 15459, 30, 23],
            [2019, 15460, 46, 106],
            [2019, 15461, 23, 21],
            [2019, 15462, 24, 17],
            [2019, 15463, 17, 16],
            [2019, 15464, 44, 25],
            [2019, 15465, 34, 21],
            [2019, 15467, 21, 10],
            [2019, 15468, 17, 15],
            [2019, 15469, 16, 11],
            [2019, 15470, 36, 36],
            [2019, 15471, 12, 9],
            [2019, 15472, 18, 29],
            [2019, 15473, 16, 16],
            [2019, 15474, 32, 30],
            [2019, 15475, 14, 13],
            [2019, 15476, 22, 32],
            [2019, 15477, 30, 77],
            [2019, 15478, 27, 13],
            [2019, 15479, 65, 121],
            [2019, 15480, 37, 61],
            [2019, 15481, 59, 83],
            [2019, 15482, 59, 121],
            [2019, 15483, 26, 21],
            [2019, 15484, 19, 11],
            [2019, 15485, 16, 16],
            [2019, 15486, 10, 12],
            [2019, 15487, 29, 24],
            [2019, 15488, 34, 39],
            [2019, 15489, 45, 66],
            [2019, 15490, 46, 30],
            [2019, 15491, 32, 16],
            [2019, 15493, 11, 16],
            [2019, 15496, 15, 14],
            [2019, 15497, 10, 11],
            [2019, 15498, 15, 15],
            [2019, 15499, 19, 11],
            [2019, 15500, 11, 8],
            [2019, 15501, 12, 8],
            [2019, 15502, 11, 8],
            [2019, 15503, 11, 8],
            [2019, 15504, 11, 8],
            [2019, 15506, 30, 66],
            [2019, 15509, 36, 36],
            [2019, 15511, 48, 33],
            [2019, 15512, 102, 55],
            [2019, 15513, 17, 24],
            [2019, 15514, 31, 42],
            [2019, 15516, 114, 84],
            [2019, 15517, 82, 51],
            [2019, 15518, 89, 37],
            [2019, 15519, 121, 121],
            [2019, 15520, 121, 121],
            [2019, 15521, 44, 34],
            [2019, 15522, 53, 40],
            [2019, 15523, 66, 29],
            [2019, 15524, 41, 35],
            [2019, 15525, 40, 55],
            [2019, 15526, 26, 18],
            [2019, 15528, 14, 19],
            [2019, 15529, 36, 40],
            [2019, 15530, 86, 51],
            [2019, 15532, 82, 51],
            [2019, 15533, 26, 46],
            [2019, 15535, 60, 40],
            [2019, 15537, 10, 8],
            [2019, 15538, 17, 12],
            [2019, 15539, 15, 10],
            [2019, 15540, 10, 10],
            [2019, 15541, 9, 9],
            [2019, 15542, 25, 16],
            [2019, 15543, 42, 21],
            [2019, 15544, 5, 5],
            [2019, 15548, 8, 7],
            [2019, 15550, 4, 4],
            [2019, 15551, 6, 6],
            [2019, 15553, 8, 7],
            [2019, 15554, 9, 7],
            [2019, 15555, 7, 6],
            [2019, 15557, 12, 7],
            [2019, 15558, 7, 6],
            [2019, 15559, 7, 6],
            [2019, 15597, 9, 6],
            [2019, 15598, 7, 6],
            [2019, 15599, 12, 8],
            [2019, 15605, 6, 5],
            [2019, 15606, 5, 5],
            [2019, 15607, 7, 6],
            [2019, 15608, 7, 6],
            [2019, 15609, 6, 6],
            [2019, 15610, 7, 6],
            [2019, 15611, 7, 5],
            [2019, 15813, 6, 4],
            [2019, 15814, 7, 5],
            [2019, 15815, 8, 6],
            [2019, 15816, 11, 8],
            [2019, 15817, 7, 5],
            [2019, 15818, 6, 4],
            [2019, 15819, 7, 5],
            [2019, 15820, 10, 7],
            [2019, 15821, 10, 7],
            [2019, 15822, 8, 5],
            [2019, 15823, 6, 4],
            [2019, 15824, 6, 5],
            [2019, 15825, 6, 4],
            [2019, 15826, 7, 5],
            [2019, 15827, 10, 7],
            [2019, 15828, 5, 4],
            [2019, 15829, 8, 5],
            [2019, 15830, 6, 4],
            [2019, 15831, 8, 5],
            [2019, 15832, 7, 4],
            [2019, 15833, 8, 5],
            [2019, 15834, 12, 9],
            [2019, 15835, 5, 4],
            [2019, 15836, 9, 6],
            [2019, 15837, 9, 6],
            [2019, 15838, 7, 5],
            [2019, 15839, 7, 5],
            [2019, 15840, 6, 4],
            [2019, 15841, 6, 4],
            [2019, 15842, 10, 7],
            [2019, 15843, 12, 8],
            [2019, 15844, 12, 8],
            [2019, 15845, 7, 5],
            [2019, 15846, 6, 5],
            [2019, 15847, 6, 5],
            [2019, 15848, 11, 7],
            [2019, 15849, 11, 7],
            [2019, 15850, 11, 8],
            [2019, 15851, 11, 8],
            [2019, 15852, 11, 8],
            [2019, 15853, 10, 8],
            [2019, 15854, 12, 8],
            [2019, 15855, 13, 8],
            [2019, 15856, 12, 9],
            [2019, 15857, 13, 8],
            [2019, 15858, 10, 8],
            [2019, 15859, 8, 6],
            [2019, 15860, 9, 7],
            [2019, 15861, 8, 7],
            [2019, 15862, 8, 6],
            [2019, 15863, 6, 5],
            [2019, 15864, 8, 7],
            [2019, 15865, 8, 6],
            [2019, 15866, 7, 5],
            [2019, 15867, 7, 6],
            [2019, 15868, 8, 7],
            [2019, 15869, 7, 6],
            [2019, 15870, 8, 6],
            [2019, 15871, 8, 6],
            [2019, 15872, 7, 6],
            [2019, 15873, 8, 6],
            [2019, 15874, 6, 5],
            [2019, 15875, 6, 5],
            [2019, 15876, 6, 6],
            [2019, 15877, 7, 6],
            [2019, 15878, 6, 6],
            [2019, 15879, 8, 6],
            [2019, 15880, 10, 7],
            [2019, 15881, 7, 6],
            [2019, 15882, 7, 6],
            [2019, 15883, 6, 5],
            [2019, 15884, 7, 6],
            [2019, 15885, 5, 4],
            [2019, 15886, 53, 41],
            [2019, 15887, 36, 31],
            [2019, 15888, 77, 47],
            [2019, 15889, 55, 40],
            [2019, 15890, 57, 40],
            [2019, 15891, 77, 47],
            [2019, 15892, 36, 36],
            [2019, 15893, 46, 49],
            [2019, 15894, 39, 28],
            [2019, 15895, 46, 49],
            [2019, 15896, 54, 42],
            [2019, 15897, 59, 40],
            [2019, 15898, 59, 47],
            [2019, 15899, 39, 28],
            [2019, 15900, 29, 23],
            [2019, 15901, 73, 54],
            [2019, 15902, 29, 31],
            [2019, 15903, 54, 33],
            [2019, 15904, 30, 21],
            [2019, 15905, 30, 21],
            [2019, 15906, 54, 45],
            [2019, 15907, 48, 41],
            [2019, 15908, 54, 33],
            [2019, 15909, 36, 31],
            [2019, 15910, 121, 121],
            [2019, 15911, 8, 6],
            [2019, 15912, 7, 6],
            [2019, 15913, 8, 6],
            [2019, 15914, 7, 6],
            [2019, 15915, 7, 6],
            [2019, 15916, 8, 6],
            [2019, 15917, 28, 29],
            [2019, 15918, 108, 92]
        ]
        for years_code_conjunts_table in limits_table_dech_fec:
            if years_code_conjunts_table[0] == year and years_code_conjunts_table[1] == code_conjunt:
                dec_fec_limits = years_code_conjunts_table[2:]
        return dec_fec_limits

    def __set_dec_fec_limits(self):
        temp = CompensationContinuityConsumer.get_dec_fec_limits(self.__code_conjunt, self.__year)
        self.__limit_dec_yearly_h = temp[0]
        self.__limit_fec_yearly = temp[1]

    @classmethod
    def get_table(cls, type_tension, type_area, type_system):
        table = 0
        if type_tension == "AT":
            table = 1
        elif type_tension == "MT" and type_area == "URB" and type_system == "INT":
            table = 2
        elif (type_tension == "MT" and type_area == "NRB") or type_system == "ISO":
            table = 3
        elif type_tension == "BT" and type_area == "URB" and type_system == "INT":
            table = 4
        elif type_tension == "BT" and type_area == "NRB" and type_system == "INT":
            table = 5
        return table

    @classmethod
    def get_index_table(cls, limit, type_tension, type_area, type_system):
        index = 0
        lanes = [
            [0, 1, 0],
            [1, 2, 1],
            [2, 3, 2],
            [3, 4, 3],
            [4, 5, 4],
            [5, 6, 5],
            [6, 7, 6],
            [7, 8, 7],
            [8, 9, 8],
            [9, 10, 9],
            [10, 11, 10],
            [11, 12, 11],
            [12, 13, 12],
            [13, 14, 13],
            [14, 15, 14],
            [15, 16, 15],
            [16, 17, 16],
            [17, 18, 17],
            [18, 19, 18],
            [19, 20, 19],
            [20, 22, 20],
            [22, 24, 21],
            [24, 26, 22],
            [26, 28, 23],
            [28, 30, 24],
            [30, 32, 25],
            [32, 34, 26],
            [34, 36, 27],
            [36, 38, 28],
            [38, 40, 29],
            [40, 45, 30],
            [45, 50, 31],
            [50, 55, 32],
            [55, 60, 33],
            [60, 65, 34],
            [65, 70, 35],
            [70, 80, 36],
            [80, 90, 37],
            [90, 100, 38],
            [100, 110, 39],
            [110, 120, 40],
            [120, 9999, 41],
        ]
        table = cls.get_table(type_tension, type_area, type_system)
        if table == 1:
            if type_system == "INT":
                index = 0
            else:
                index = 1
        else:
            for lane in lanes:
                if limit > lane[0] and limit <= lane[1]:
                    index = lane[2]
                    break
        return index

    @classmethod
    def get_dic_fic_dmic_limits(cls, code_conjunt, year, type_tension, type_area, type_system):
        dic_fic_dmic_limits = [0.0] * 7
        # Each register must follow the pattern
        # [table, index, yearlyDich, quartlyDich, monthlyDich, yearlyFic, quartlyFic, monthlyFic, monthlyDmich]
        limits_table_dich_fic_dmich = [
            [1, 0, 5.00, 3.00, 2.00, 5.00, 3.00, 2.00, 1.50],
            [1, 1, 6.00, 4.00, 3.00, 6.00, 4.00, 3.00, 2.50],
            [2, 0, 11.25, 5.62, 2.81, 6.48, 3.24, 1.62, 2.36],
            [2, 1, 11.68, 5.84, 2.92, 6.93, 3.46, 1.73, 2.39],
            [2, 2, 12.12, 6.06, 3.03, 7.37, 3.68, 1.84, 2.41],
            [2, 3, 12.55, 6.27, 3.13, 7.82, 3.91, 1.95, 2.44],
            [2, 4, 12.99, 6.49, 3.24, 8.27, 4.13, 2.06, 2.46],
            [2, 5, 13.43, 6.71, 3.35, 8.71, 4.35, 2.17, 2.49],
            [2, 6, 13.86, 6.93, 3.46, 9.16, 4.58, 2.29, 2.52],
            [2, 7, 14.3, 7.15, 3.57, 9.61, 4.8, 2.4, 2.54],
            [2, 8, 14.73, 7.36, 3.68, 10.05, 5.02, 2.51, 2.57],
            [2, 9, 15.17, 7.58, 3.79, 10.5, 5.25, 2.62, 2.6],
            [2, 10, 15.61, 7.8, 3.9, 10.95, 5.47, 2.73, 2.62],
            [2, 11, 16.04, 8.02, 4.01, 11.4, 5.7, 2.85, 2.65],
            [2, 12, 16.48, 8.24, 4.12, 11.84, 5.92, 2.96, 2.68],
            [2, 13, 16.91, 8.45, 4.22, 12.29, 6.14, 3.07, 2.71],
            [2, 14, 17.35, 8.67, 4.33, 12.74, 6.37, 3.18, 2.74],
            [2, 15, 17.79, 8.89, 4.44, 13.18, 6.59, 3.29, 2.76],
            [2, 16, 18.22, 9.11, 4.55, 13.63, 6.81, 3.4, 2.79],
            [2, 17, 18.66, 9.33, 4.66, 14.08, 7.04, 3.52, 2.82],
            [2, 18, 19.09, 9.54, 4.77, 14.52, 7.26, 3.63, 2.85],
            [2, 19, 19.53, 9.76, 4.88, 14.97, 7.48, 3.74, 2.88],
            [2, 20, 19.97, 9.98, 4.99, 15.42, 7.71, 3.85, 2.91],
            [2, 21, 20.84, 10.42, 5.21, 16.31, 8.15, 4.07, 2.98],
            [2, 22, 21.71, 10.85, 5.42, 17.2, 8.6, 4.3, 3.04],
            [2, 23, 22.58, 11.29, 5.64, 18.1, 9.05, 4.52, 3.1],
            [2, 24, 23.45, 11.72, 5.86, 18.99, 9.49, 4.74, 3.17],
            [2, 25, 24.33, 12.16, 6.08, 19.88, 9.94, 4.97, 3.24],
            [2, 26, 25.2, 12.6, 6.3, 20.78, 10.39, 5.19, 3.31],
            [2, 27, 26.07, 13.03, 6.51, 21.67, 10.83, 5.41, 3.38],
            [2, 28, 26.94, 13.47, 6.73, 22.57, 11.28, 5.64, 3.45],
            [2, 29, 27.81, 13.9, 6.95, 23.46, 11.73, 5.86, 3.52],
            [2, 30, 29.34, 14.67, 7.33, 25.02, 12.51, 6.25, 3.55],
            [2, 31, 31.52, 15.76, 7.88, 27.26, 13.63, 6.81, 3.8],
            [2, 32, 33.7, 16.85, 8.42, 29.49, 14.74, 7.37, 4.06],
            [2, 33, 35.88, 17.94, 8.97, 31.72, 15.86, 7.93, 4.34],
            [2, 34, 38.06, 19.03, 9.51, 33.96, 16.98, 8.49, 4.64],
            [2, 35, 40.24, 20.12, 10.06, 36.19, 18.09, 9.04, 4.96],
            [2, 36, 43.51, 21.75, 10.87, 39.54, 19.77, 9.88, 5.47],
            [2, 37, 47.87, 23.93, 11.96, 44.01, 22, 11, 6.23],
            [2, 38, 52.23, 26.11, 13.05, 48.48, 24.24, 12.12, 7.1],
            [2, 39, 56.59, 28.29, 14.14, 52.95, 26.47, 13.23, 8.07],
            [2, 40, 60.95, 30.47, 15.23, 57.42, 28.71, 14.35, 9.17],
            [2, 41, 63.13, 31.56, 15.78, 59.65, 29.82, 14.91, 9.77],
            [3, 0, 31.98, 15.99, 7.99, 15.49, 7.74, 3.87, 4.32],
            [3, 1, 32.62, 16.31, 8.15, 15.96, 7.98, 3.99, 4.39],
            [3, 2, 33.26, 16.63, 8.31, 16.43, 8.21, 4.1, 4.46],
            [3, 3, 33.9, 16.95, 8.47, 16.9, 8.45, 4.22, 4.53],
            [3, 4, 34.54, 17.27, 8.63, 17.37, 8.68, 4.34, 4.6],
            [3, 5, 35.18, 17.59, 8.79, 17.84, 8.92, 4.46, 4.67],
            [3, 6, 35.82, 17.91, 8.95, 18.31, 9.15, 4.57, 4.74],
            [3, 7, 36.46, 18.23, 9.11, 18.78, 9.39, 4.69, 4.81],
            [3, 8, 37.1, 18.55, 9.27, 19.25, 9.62, 4.81, 4.88],
            [3, 9, 37.74, 18.87, 9.43, 19.72, 9.86, 4.93, 4.95],
            [3, 10, 38.38, 19.19, 9.59, 20.19, 10.09, 5.04, 5.02],
            [3, 11, 39.02, 19.51, 9.75, 20.66, 10.33, 5.16, 5.09],
            [3, 12, 39.66, 19.83, 9.91, 21.13, 10.56, 5.28, 5.16],
            [3, 13, 40.3, 20.15, 10.07, 21.6, 10.8, 5.4, 5.24],
            [3, 14, 40.94, 20.47, 10.23, 22.07, 11.03, 5.51, 5.31],
            [3, 15, 41.58, 20.79, 10.39, 22.54, 11.27, 5.63, 5.38],
            [3, 16, 42.22, 21.11, 10.55, 23.01, 11.5, 5.75, 5.45],
            [3, 17, 42.86, 21.43, 10.71, 23.48, 11.74, 5.87, 5.52],
            [3, 18, 43.5, 21.75, 10.87, 23.95, 11.97, 5.98, 5.59],
            [3, 19, 44.14, 22.07, 11.03, 24.42, 12.21, 6.1, 5.66],
            [3, 20, 44.78, 22.39, 11.19, 24.9, 12.45, 6.22, 5.73],
            [3, 21, 46.06, 23.03, 11.51, 25.84, 12.92, 6.46, 5.87],
            [3, 22, 47.34, 23.67, 11.83, 26.78, 13.39, 6.69, 6.01],
            [3, 23, 48.61, 24.3, 12.15, 27.72, 13.86, 6.93, 6.15],
            [3, 24, 49.89, 24.94, 12.47, 28.66, 14.33, 7.16, 6.29],
            [3, 25, 51.17, 25.58, 12.79, 29.6, 14.8, 7.4, 6.43],
            [3, 26, 52.45, 26.22, 13.11, 30.54, 15.27, 7.63, 6.57],
            [3, 27, 53.73, 26.86, 13.43, 31.48, 15.74, 7.87, 6.72],
            [3, 28, 55.01, 27.5, 13.75, 32.42, 16.21, 8.1, 6.86],
            [3, 29, 56.29, 28.14, 14.07, 33.36, 16.68, 8.34, 7],
            [3, 30, 58.53, 29.26, 14.63, 35.01, 17.5, 8.75, 7.24],
            [3, 31, 61.73, 30.86, 15.43, 37.36, 18.68, 9.34, 7.6],
            [3, 32, 64.92, 32.46, 16.23, 39.71, 19.85, 9.92, 7.95],
            [3, 33, 68.12, 34.06, 17.03, 42.06, 21.03, 10.51, 8.3],
            [3, 34, 71.32, 35.66, 17.83, 44.42, 22.21, 11.1, 8.65],
            [3, 35, 74.52, 37.26, 18.63, 46.77, 23.38, 11.69, 9.01],
            [3, 36, 79.32, 39.66, 19.83, 50.3, 25.15, 12.57, 9.54],
            [3, 37, 85.71, 42.85, 21.42, 55, 27.5, 13.75, 10.24],
            [3, 38, 92.11, 46.05, 23.02, 59.7, 29.85, 14.92, 10.95],
            [3, 39, 98.5, 49.25, 24.62, 64.41, 32.2, 16.1, 11.65],
            [3, 40, 104.9, 52.45, 26.22, 69.11, 34.55, 17.27, 12.36],
            [3, 41, 108.1, 54.05, 27.02, 71.46, 35.73, 17.86, 12.71],
            [4, 0, 16, 8, 4, 11.2, 5.6, 2.8, 2.09],
            [4, 1, 16.47, 8.23, 4.11, 11.45, 5.72, 2.86, 2.18],
            [4, 2, 16.95, 8.47, 4.23, 11.7, 5.85, 2.92, 2.26],
            [4, 3, 17.43, 8.71, 4.35, 11.95, 5.97, 2.98, 2.35],
            [4, 4, 17.91, 8.95, 4.47, 12.2, 6.1, 3.05, 2.43],
            [4, 5, 18.38, 9.19, 4.59, 12.45, 6.22, 3.11, 2.52],
            [4, 6, 18.86, 9.43, 4.71, 12.7, 6.35, 3.17, 2.6],
            [4, 7, 19.34, 9.67, 4.83, 12.95, 6.47, 3.23, 2.69],
            [4, 8, 19.82, 9.91, 4.95, 13.2, 6.6, 3.3, 2.77],
            [4, 9, 20.3, 10.15, 5.07, 13.45, 6.72, 3.36, 2.86],
            [4, 10, 20.77, 10.38, 5.19, 13.7, 6.85, 3.42, 2.94],
            [4, 11, 21.25, 10.62, 5.31, 13.95, 6.97, 3.48, 3.03],
            [4, 12, 21.73, 10.86, 5.43, 14.2, 7.1, 3.55, 3.11],
            [4, 13, 22.21, 11.1, 5.55, 14.45, 7.22, 3.61, 3.2],
            [4, 14, 22.69, 11.34, 5.67, 14.7, 7.35, 3.67, 3.29],
            [4, 15, 23.16, 11.58, 5.79, 14.95, 7.47, 3.73, 3.37],
            [4, 16, 23.64, 11.82, 5.91, 15.2, 7.6, 3.8, 3.46],
            [4, 17, 24.12, 12.06, 6.03, 15.45, 7.72, 3.86, 3.54],
            [4, 18, 24.6, 12.3, 6.15, 15.7, 7.85, 3.92, 3.63],
            [4, 19, 25.08, 12.54, 6.27, 15.96, 7.98, 3.99, 3.71],
            [4, 20, 25.89, 12.94, 6.47, 16.47, 8.23, 4.11, 3.8],
            [4, 21, 27.48, 13.74, 6.87, 17.42, 8.71, 4.35, 3.97],
            [4, 22, 29.06, 14.53, 7.26, 18.37, 9.18, 4.59, 4.14],
            [4, 23, 30.65, 15.32, 7.66, 19.32, 9.66, 4.83, 4.31],
            [4, 24, 32.23, 16.11, 8.05, 20.28, 10.14, 5.07, 4.48],
            [4, 25, 33.82, 16.91, 8.45, 21.23, 10.61, 5.3, 4.65],
            [4, 26, 35.4, 17.7, 8.85, 22.18, 11.09, 5.54, 4.82],
            [4, 27, 36.99, 18.49, 9.24, 23.13, 11.56, 5.78, 4.99],
            [4, 28, 38.57, 19.28, 9.64, 24.08, 12.04, 6.02, 5.16],
            [4, 29, 40.16, 20.08, 10.04, 25.04, 12.52, 6.26, 5.33],
            [4, 30, 42.93, 21.46, 10.73, 26.7, 13.35, 6.67, 5.63],
            [4, 31, 46.89, 23.44, 11.72, 29.08, 14.54, 7.27, 6.05],
            [4, 32, 50.86, 25.43, 12.71, 31.46, 15.73, 7.86, 6.48],
            [4, 33, 54.82, 27.41, 13.7, 33.84, 16.92, 8.46, 6.9],
            [4, 34, 58.78, 29.39, 14.69, 36.22, 18.11, 9.05, 7.33],
            [4, 35, 62.74, 31.37, 15.68, 38.6, 19.3, 9.65, 7.75],
            [4, 36, 68.68, 34.34, 17.17, 42.17, 21.08, 10.54, 8.39],
            [4, 37, 76.61, 38.3, 19.15, 46.93, 23.46, 11.73, 9.24],
            [4, 38, 84.53, 42.26, 21.13, 51.69, 25.84, 12.92, 10.09],
            [4, 39, 92.46, 46.23, 23.11, 56.45, 28.22, 14.11, 10.94],
            [4, 40, 100.38, 50.19, 25.09, 61.21, 30.6, 15.3, 11.8],
            [4, 41, 104.34, 52.17, 26.08, 63.59, 31.79, 15.89, 12.22],
            [5, 0, 36, 18, 9, 28, 14, 7, 4.57],
            [5, 1, 36.57, 18.28, 9.14, 28.29, 14.14, 7.07, 4.67],
            [5, 2, 37.15, 18.57, 9.28, 28.59, 14.29, 7.14, 4.77],
            [5, 3, 37.73, 18.86, 9.43, 28.89, 14.44, 7.22, 4.87],
            [5, 4, 38.3, 19.15, 9.57, 29.19, 14.59, 7.29, 4.97],
            [5, 5, 38.88, 19.44, 9.72, 29.49, 14.74, 7.37, 5.07],
            [5, 6, 39.46, 19.73, 9.86, 29.79, 14.89, 7.44, 5.17],
            [5, 7, 40.03, 20.01, 10, 30.09, 15.04, 7.52, 5.28],
            [5, 8, 40.61, 20.3, 10.15, 30.39, 15.19, 7.59, 5.38],
            [5, 9, 41.19, 20.59, 10.29, 30.69, 15.34, 7.67, 5.48],
            [5, 10, 41.76, 20.88, 10.44, 30.98, 15.49, 7.74, 5.58],
            [5, 11, 42.34, 21.17, 10.58, 31.28, 15.64, 7.82, 5.68],
            [5, 12, 42.92, 21.46, 10.73, 31.58, 15.79, 7.89, 5.78],
            [5, 13, 43.49, 21.74, 10.87, 31.88, 15.94, 7.97, 5.88],
            [5, 14, 44.07, 22.03, 11.01, 32.18, 16.09, 8.04, 5.98],
            [5, 15, 44.65, 22.32, 11.16, 32.48, 16.24, 8.12, 6.08],
            [5, 16, 45.22, 22.61, 11.3, 32.78, 16.39, 8.19, 6.19],
            [5, 17, 45.8, 22.9, 11.45, 33.08, 16.54, 8.27, 6.29],
            [5, 18, 46.38, 23.19, 11.59, 33.38, 16.69, 8.34, 6.39],
            [5, 19, 46.96, 23.48, 11.74, 33.68, 16.84, 8.42, 6.49],
            [5, 20, 47.79, 23.89, 11.94, 34.16, 17.08, 8.54, 6.59],
            [5, 21, 49.42, 24.71, 12.35, 35.1, 17.55, 8.77, 6.79],
            [5, 22, 51.05, 25.52, 12.76, 36.04, 18.02, 9.01, 6.99],
            [5, 23, 52.68, 26.34, 13.17, 36.98, 18.49, 9.24, 7.2],
            [5, 24, 54.31, 27.15, 13.57, 37.92, 18.96, 9.48, 7.4],
            [5, 25, 55.94, 27.97, 13.98, 38.86, 19.43, 9.71, 7.6],
            [5, 26, 57.57, 28.78, 14.39, 39.8, 19.9, 9.95, 7.8],
            [5, 27, 59.2, 29.6, 14.8, 40.74, 20.37, 10.18, 8.01],
            [5, 28, 60.83, 30.41, 15.2, 41.69, 20.84, 10.42, 8.21],
            [5, 29, 62.45, 31.22, 15.61, 42.63, 21.31, 10.65, 8.41],
            [5, 30, 65.3, 32.65, 16.32, 44.27, 22.13, 11.06, 8.76],
            [5, 31, 69.38, 34.69, 17.34, 46.62, 23.31, 11.65, 9.27],
            [5, 32, 73.45, 36.72, 18.36, 48.98, 24.49, 12.24, 9.77],
            [5, 33, 77.52, 38.76, 19.38, 51.33, 25.66, 12.83, 10.28],
            [5, 34, 81.59, 40.79, 20.39, 53.68, 26.84, 13.42, 10.79],
            [5, 35, 85.66, 42.83, 21.41, 56.03, 28.01, 14, 11.29],
            [5, 36, 91.77, 45.88, 22.94, 59.56, 29.78, 14.89, 12.05],
            [5, 37, 99.92, 49.96, 24.98, 64.26, 32.13, 16.06, 13.06],
            [5, 38, 108.06, 54.03, 27.01, 68.97, 34.48, 17.24, 14.07],
            [5, 39, 116.2, 58.1, 29.05, 73.67, 36.83, 18.41, 15.08],
            [5, 40, 124.35, 62.17, 31.08, 78.38, 39.19, 19.59, 16.09],
            [5, 41, 128.42, 64.21, 32.1, 80.73, 40.36, 20.18, 16.6],
        ]
        table = cls.get_table(type_tension, type_area, type_system)
        dec_fec_limits = cls.get_dec_fec_limits(code_conjunt, year)
        index_dec = cls.get_index_table(dec_fec_limits[0], type_tension, type_area, type_system)
        index_fec = cls.get_index_table(dec_fec_limits[1], type_tension, type_area, type_system)
        for register in limits_table_dich_fic_dmich:
            if register[0] == table and register[1] == index_dec:
                dic_fic_dmic_limits[0] = register[2]
                dic_fic_dmic_limits[1] = register[3]
                dic_fic_dmic_limits[2] = register[4]
                dic_fic_dmic_limits[6] = register[8]
            if register[0] == table and register[1] == index_fec:
                dic_fic_dmic_limits[3] = register[5]
                dic_fic_dmic_limits[4] = register[6]
                dic_fic_dmic_limits[5] = register[7]
        return dic_fic_dmic_limits

    def __set_dic_fic_dmic_limits(self):
        temp = CompensationContinuityConsumer.get_dic_fic_dmic_limits(self.__code_conjunt, self.__year,
                                                                      self.__type_tension,
                                                                      self.__type_area, self.__type_system)
        self.__limit_dic_yearly_h = temp[0]
        self.__limit_dic_quartely_h = temp[1]
        self.__limit_dic_monthly_h = temp[2]
        self.__limit_fic_yearly = temp[3]
        self.__limit_fic_quartely = temp[4]
        self.__limit_fic_monthly = temp[5]
        self.__limit_dmic_monthly_h = temp[6]

    def __set_time_variables(self):
        self.__dic_quartely_h = [0.0] * 4
        self.__fic_quartely = [0.0] * 4
        self.__eusd_quartely_rs = [0.0] * 4
        self.__proportion_dic_quartely = [0.0] * 4
        self.__proportion_fic_quartely = [0.0] * 4
        self.__dic_yearly_h = [0.0] * 1
        self.__fic_yearly = [0.0] * 1
        self.__eusd_yearly_rs = [0.0] * 1
        self.__proportion_dic_yearly = [0.0] * 1
        self.__proportion_fic_yearly = [0.0] * 1
        for i, value in enumerate(self.__dic_monthly_h):
            self.__dic_quartely_h[i // 3] += self.__dic_monthly_h[i]
            self.__fic_quartely[i // 3] += self.__fic_monthly[i]
            self.__eusd_quartely_rs[i // 3] += self.__eusd_monthly_rs[i] / 3
            self.__dic_yearly_h[i // 12] += self.__dic_monthly_h[i]
            self.__fic_yearly[i // 12] += self.__fic_monthly[i]
            self.__eusd_yearly_rs[i // 12] += self.__eusd_monthly_rs[i] / 12
        for i, value in enumerate(self.__dic_monthly_h):
            if self.__dic_monthly_h[i] <= self.__limit_dic_monthly_h:
                self.__proportion_dic_quartely[i // 3] += self.__dic_monthly_h[i] / self.__dic_quartely_h[i // 3]
                self.__proportion_dic_yearly[i // 12] += self.__dic_monthly_h[i] / self.__dic_yearly_h[i // 12]
            if self.__fic_monthly[i] <= self.__limit_fic_monthly:
                self.__proportion_fic_quartely[i // 3] += self.__fic_monthly[i] / self.__fic_quartely[i // 3]
                self.__proportion_fic_yearly[i // 12] += self.__fic_monthly[i] / self.__fic_yearly[i // 12]

    def __calculate_compensation_monthly(self):
        self.__monthly_value_compensation = [0.0] * 12
        self.__monthly_indicator_compensation = ["NA"] * 12
        gross_compensation_dic_rs = [0] * 12
        gross_compensation_fic_rs = [0] * 12
        gross_compensation_dmic_rs = [0] * 12
        for i, value in enumerate(self.__dic_monthly_h):
            if self.__dic_monthly_h[i] > self.__limit_dic_monthly_h:
                gross_compensation_dic_rs[i] = (self.__dic_monthly_h[
                                                    i] / self.__limit_dic_monthly_h - 1) * self.__limit_dic_monthly_h * \
                                               self.__eusd_monthly_rs[i] * self.__kei / 730
            if self.__dmic_monthly_h[i] > self.__limit_dmic_monthly_h:
                gross_compensation_dmic_rs[i] = (self.__dmic_monthly_h[
                                                     i] / self.__limit_dmic_monthly_h - 1) * self.__limit_dmic_monthly_h * \
                                                self.__eusd_monthly_rs[i] * self.__kei / 730
            if self.__fic_monthly[i] > self.__limit_fic_monthly:
                gross_compensation_fic_rs[i] = (self.__fic_monthly[
                                                    i] / self.__limit_fic_monthly - 1) * self.__limit_dic_monthly_h * \
                                               self.__eusd_monthly_rs[i] * self.__kei / 730
            if gross_compensation_dic_rs[i] > 0 and gross_compensation_dic_rs[i] >= gross_compensation_fic_rs[i] and \
                            gross_compensation_dic_rs[i] >= gross_compensation_dmic_rs[i]:
                self.__monthly_value_compensation[i] = gross_compensation_dic_rs[i]
                self.__monthly_indicator_compensation[i] = "DIC"
            elif gross_compensation_fic_rs[i] > 0 and gross_compensation_fic_rs[i] > gross_compensation_dic_rs[i] and \
                            gross_compensation_fic_rs[i] > gross_compensation_dmic_rs[i]:
                self.__monthly_value_compensation[i] = gross_compensation_fic_rs[i]
                self.__monthly_indicator_compensation[i] = "FIC"
            elif gross_compensation_dmic_rs[i] > 0 and gross_compensation_dmic_rs[i] > gross_compensation_dic_rs[i] and \
                            gross_compensation_dmic_rs[i] > gross_compensation_fic_rs[i]:
                self.__monthly_value_compensation[i] = gross_compensation_dmic_rs[i]
                self.__monthly_indicator_compensation[i] = "DMIC"
            else:
                self.__monthly_value_compensation[i] = 0
                self.__monthly_indicator_compensation[i] = "NA"

    def __calculate_paid_compensation_monthly(self):
        self.__paid_monthly_dic_quartely_rs = [0.0] * 4
        self.__paid_monthly_dic_yearly_rs = [0.0] * 1
        self.__paid_monthly_fic_quartely_rs = [0.0] * 4
        self.__paid_monthly_fic_yearly_rs = [0.0] * 1
        for i, value in enumerate(self.__monthly_value_compensation):
            if self.__monthly_indicator_compensation[i] == "DIC":
                self.__paid_monthly_dic_quartely_rs[i // 3] += self.__monthly_value_compensation[i]
                self.__paid_monthly_dic_yearly_rs[i // 12] += self.__monthly_value_compensation[i]
            if self.__monthly_indicator_compensation[i] == "FIC":
                self.__paid_monthly_fic_quartely_rs[i // 3] += self.__monthly_value_compensation[i]
                self.__paid_monthly_fic_yearly_rs[i // 12] += self.__monthly_value_compensation[i]

    def __calculate_compensation_quartely(self):
        self.__quartely_value_compensation = [0.0] * 4
        self.__quartely_indicator_compensation = ["NA"] * 4
        gross_compensation_dic_rs = [0] * 4
        gross_compensation_fic_rs = [0] * 4
        for i, value in enumerate(self.__dic_quartely_h):
            if self.__dic_quartely_h[i] > self.__limit_dic_quartely_h:
                gross_compensation_dic_rs[i] = (
                                                   self.__dic_quartely_h[
                                                       i] / self.__limit_dic_quartely_h - 1) * self.__limit_dic_quartely_h * \
                                               self.__eusd_quartely_rs[i] * self.__kei / 730
            if self.__fic_quartely[i] > self.__limit_fic_quartely:
                gross_compensation_fic_rs[i] = (self.__fic_quartely[
                                                    i] / self.__limit_fic_quartely - 1) * self.__limit_dic_quartely_h * \
                                               self.__eusd_quartely_rs[i] * self.__kei / 730
            if self.__proportion_dic_quartely[i] != 0:
                gross_compensation_dic_rs[i] *= self.__proportion_dic_quartely[i]
            else:
                gross_compensation_dic_rs[i] -= self.__paid_monthly_dic_quartely_rs[i]
            if self.__proportion_fic_quartely[i] != 0:
                gross_compensation_fic_rs[i] *= self.__proportion_fic_quartely[i]
            else:
                gross_compensation_fic_rs[i] -= self.__paid_monthly_fic_quartely_rs[i]
            if gross_compensation_dic_rs[i] > 0 and gross_compensation_dic_rs[i] >= gross_compensation_fic_rs[i]:
                self.__quartely_value_compensation[i] = gross_compensation_dic_rs[i]
                self.__quartely_indicator_compensation[i] = "DIC"
            elif gross_compensation_fic_rs[i] > 0 and gross_compensation_fic_rs[i] > gross_compensation_dic_rs[i]:
                self.__quartely_value_compensation[i] = gross_compensation_fic_rs[i]
                self.__quartely_indicator_compensation[i] = "FIC"
            else:
                self.__quartely_value_compensation[i] = 0
                self.__quartely_indicator_compensation[i] = "NA"

    def __calculate_compensation_yearly(self):
        self.__yearly_value_compensation = [0.0] * 1
        self.__yearly_indicator_compensation = ["NA"] * 1
        gross_compensation_dic_rs = [0] * 1
        gross_compensation_fic_rs = [0] * 1
        for i, value in enumerate(self.__dic_yearly_h):
            if self.__dic_yearly_h[i] > self.__limit_dic_yearly_h:
                gross_compensation_dic_rs[i] = (
                                                   self.__dic_yearly_h[
                                                       i] / self.__limit_dic_yearly_h - 1) * self.__limit_dic_yearly_h * \
                                               self.__eusd_yearly_rs[i] * self.__kei / 730
            if self.__fic_yearly[i] > self.__limit_fic_yearly:
                gross_compensation_fic_rs[i] = (self.__fic_yearly[
                                                    i] / self.__limit_fic_yearly - 1) * self.__limit_dic_yearly_h * \
                                               self.__eusd_yearly_rs[i] * self.__kei / 730
            if self.__proportion_dic_yearly[i] != 0:
                gross_compensation_dic_rs[i] *= self.__proportion_dic_yearly[i]
            else:
                gross_compensation_dic_rs[i] -= self.__paid_monthly_dic_yearly_rs[i]
            if self.__proportion_fic_yearly[i] != 0:
                gross_compensation_fic_rs[i] *= self.__proportion_fic_yearly[i]
            else:
                gross_compensation_fic_rs[i] -= self.__paid_monthly_fic_yearly_rs[i]
            if gross_compensation_dic_rs[i] > 0 and gross_compensation_dic_rs[i] >= gross_compensation_fic_rs[i]:
                self.__yearly_value_compensation[i] = gross_compensation_dic_rs[i]
                self.__yearly_indicator_compensation[i] = "DIC"
            elif gross_compensation_fic_rs[i] > 0 and gross_compensation_fic_rs[i] > gross_compensation_dic_rs[i]:
                self.__yearly_value_compensation[i] = gross_compensation_fic_rs[i]
                self.__yearly_indicator_compensation[i] = "FIC"
            else:
                self.__yearly_value_compensation[i] = 0
                self.__yearly_indicator_compensation[i] = "NA"

    def calculate_compensation(self):
        self.__set_kei()
        self.__set_dec_fec_limits()
        self.__set_dic_fic_dmic_limits()
        self.__set_time_variables()
        self.__calculate_compensation_monthly()
        self.__calculate_paid_compensation_monthly()
        self.__calculate_compensation_quartely()
        self.__calculate_compensation_yearly()

    def to_JSON(self):
        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=True, indent=4)

    def __repr__(self):
        return json.dumps(self.__dict__, sort_keys=True, indent=2)


"""
Criação de módulo que calcula as compensações de continuidade à consumidores informado em um padrão de CSV estabelecido.
"""


class CalculateCompensationCSV:
    __csv_path_file = ""
    __content_file = []
    __data_base = []
    __calculator = CompensationContinuityConsumer()

    def set_csv_path_file(self, csv_path_file):
        self.__csv_path_file = csv_path_file
        with open(self.__csv_path_file, "rt") as temp:
            self.__content_file = list(csv.reader(temp, delimiter=";", quotechar="\""))
        self.__ajust_data()
        self.__execute_calculations()

    def __ajust_data(self):
        for i, value in enumerate(self.__content_file):
            if i > 0:
                temp = [value[0], int(value[1]), value[2], value[3], value[4], int(value[5]),
                        [float(j) for j in value[6:18]], [float(j) for j in value[18:30]],
                        [float(j) for j in value[30:42]], [float(j) for j in value[42:54]]]
                self.__data_base.append(temp)

    def __execute_calculations(self):
        for i, value in enumerate(self.__data_base):
            self.__calculator.set_features(value[0], value[1], value[2], value[3], value[4], value[5], value[6],
                                           value[7], value[8], value[9])

    def write_result(self):
        temp01 = self.__csv_path_file
        temp02 = datetime.datetime.now().__str__().replace(" ", "-").replace(":", "-").replace(".", "-")
        with open(temp01.replace(".csv", "{}.csv".format(temp02)), "wt") as csv_file:
            temp03 = csv.writer(csv_file, delimiter=";", quoting=csv.QUOTE_NONNUMERIC)
            for linha in self.__data_base:
                temp03.writerow(linha[:6] + linha[6][:] + linha[7][:] + linha[8][:] + linha[9][:])

    def print_data(self):
        for linha in self.__data_base:
            # for linha in self.__data_base:
            print(linha)
            # for coluna in linha:
            # print("{}".format(coluna))


if __name__ == "__main__":
    print(datetime.datetime.now().__str__().replace(" ", "-").replace(":", "-").replace(".", "-"))
    my_consumer = CompensationContinuityConsumer()
    my_consumer.set_features("abc", 2005, "BT", "URB", "INT", 327, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
                             [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12], [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
                             [40, 42, 43, 44, 45, 56, 47, 38, 49, 40, 51, 62])
    print(my_consumer)
    print(CompensationContinuityConsumer.get_dec_fec_limits(1111, 2016))
    print(CompensationContinuityConsumer.get_kei("BT"))
    print(CompensationContinuityConsumer.get_table("BT", "URB", "INT"))
    print(CompensationContinuityConsumer.get_dic_fic_dmic_limits(1111, 2016, "BT", "URB", "INT"))
    my_file = CalculateCompensationCSV()
    my_file.set_csv_path_file("dados.csv")
    my_file.write_result()
    my_file.print_data()
    print(datetime.datetime.now().__str__().replace(" ", "-").replace(":", "-").replace(".", "-"))
